@@ -123,6 +123,8 @@ public class GifEncoder extends ImageEncoder {
   private int bitsPerPixel = 1;
 
   private int byteCount;
+  private int loopCount; // indefinite loop
+  private boolean isDelay;
 
   /**
    * we allow for animated GIF by being able to re-enter the code with different
@@ -174,11 +176,13 @@ public class GifEncoder extends ImageEncoder {
         int fps = Math.abs(((Integer) params.get("captureFps")).intValue());
         delayTime100ths = (fps == 0 ? 0 : 100 / fps);
       } else {
+        isDelay = true;
         // one-time frame delay
         delayTime100ths = msDelay.intValue() / 10;
         params.remove("captureDelayMS");
       }
       looping = (Boolean.FALSE != params.get("captureLooping"));
+      loopCount = (looping ? 0 : 1);
       break;
     case 2: // end
       addHeader = false;
@@ -200,7 +204,7 @@ public class GifEncoder extends ImageEncoder {
     if (addImage) {
       createPalette();
       writeGraphicControlExtension();
-      if (delayTime100ths >= 0 && looping)
+      if (delayTime100ths >= 0 && (looping || isDelay))
         writeNetscapeLoopExtension();
       writeImage();
     }
@@ -802,7 +806,7 @@ public class GifEncoder extends ImageEncoder {
     putString("NETSCAPE2.0");
     putByte(3);
     putByte(1);
-    putWord(0); // loop indefinitely
+    putWord(loopCount);
     putByte(0); // end-of-block
 
   }
