@@ -203,9 +203,9 @@ public class MessagePackReader {
         case STR8:
           return doc.readString(doc.readUInt8());
         case STR16:
-          return doc.readString(doc.readShort());
+          return doc.readString(doc.readUnsignedShort());
         case STR32:
-          return doc.readString(doc.readInt());
+          return doc.readString(doc.readInt()); // technically should be unisigned int
         }
       } else {
         switch (b) {
@@ -243,10 +243,10 @@ public class MessagePackReader {
           ((String[]) array)[pt] = doc.readString(doc.readUInt8());
           break;
         case STR16:
-          ((String[]) array)[pt] = doc.readString(doc.readShort());
+          ((String[]) array)[pt] = doc.readString(doc.readUnsignedShort());
           break;
         case STR32:
-          ((String[]) array)[pt] = doc.readString(doc.readInt());
+          ((String[]) array)[pt] = doc.readString(doc.readInt()); // technically shoild be unsigned int
           break;
         }
       }
