@@ -146,7 +146,7 @@ public class JSVApplet implements JSVAppletInterface,
   @Override
 	public String getParameter(String paramName) {
     Object o = htParams.get(paramName.toLowerCase());
-    return (o == null ? null : new String(o.toString()));
+    return (o == null ? null : o.toString());
   }
 
   private boolean getBooleanValue(String propertyName, boolean defaultValue) {
@@ -656,4 +656,9 @@ public class JSVApplet implements JSVAppletInterface,
 		return s;
 	}
 
+  @Override
+  public void processKeyEvent(Object event) {
+    //TODO
+  }
+
 }
