@@ -88,14 +88,11 @@ import jspecview.app.JSVAppPro;
 import jspecview.common.JSVFileManager;
 import jspecview.common.JSViewer;
 import jspecview.common.PanelNode;
-import jspecview.common.Parameters;
 import jspecview.common.PeakPickEvent;
 import jspecview.common.ScriptToken;
 import jspecview.common.SubSpecChangeEvent;
 import jspecview.common.ZoomEvent;
 import jspecview.export.Exporter;
-import jspecview.java.AwtFileHelper;
-import jspecview.java.AwtMainPanel;
 import jspecview.source.JDXSource;
 
 // BH 1/14/17 moves command checking to JSViewer
@@ -806,6 +803,8 @@ public class MainFrame extends JFrame implements JmolSyncInterface,
       case GRIDON:
         toolBar.gridToggleButton.setSelected(tf);
         break;
+      default:
+        break;
       }
   }
 
