@@ -100,7 +100,7 @@ public class JSVFileManager {
   }
 
 	public static BufferedReader getBufferedReaderFromName(String name,
-			String startCode) throws JSVException {
+			String startCode) throws Exception {
 		if (name == null)
 			throw new JSVException("Cannot find " + name);
 		Logger.info("JSVFileManager getBufferedReaderFromName " + name);
@@ -172,7 +172,7 @@ public class JSVFileManager {
 	}
 
 	private static BufferedReader getUnzippedBufferedReaderFromName(String name,
-			String startCode) throws JSVException {
+			String startCode) throws Exception {
 		String[] subFileList = null;
 		if (name.indexOf("|") >= 0) {
 			subFileList = PT.split(name, "|");
@@ -199,7 +199,7 @@ public class JSVFileManager {
 						.getInterface("jspecview.common.JSVZipUtil")).newGZIPInputStream(in);
 			return new BufferedReader(new InputStreamReader(in, "UTF-8"));
 		} catch (Exception e) {
-			throw new JSVException("Cannot read file " + name + " " + e);
+      throw e;
 		}
 	}
 
