@@ -1509,14 +1509,14 @@ public class JSViewer implements PlatformViewer, BytePoster {
     JSVTreeNode rootNode = spectraTree.getRootNode();
     String fileName = (source == null ? null : source.getFilePath());
     Lst<JSVTreeNode> toDelete = new Lst<JSVTreeNode>();
-    Enumeration<?> enume = rootNode.children();
+    Enumeration<JSVTreeNode> enume = rootNode.children();
     while (enume.hasMoreElements()) {
-      JSVTreeNode node = (JSVTreeNode) enume.nextElement();
+      JSVTreeNode node = enume.nextElement();
       if (fileName == null
           || node.getPanelNode().source.matchesFilePath(fileName)) {
         Logger.info("Closing " + node.getPanelNode().source.getFilePath());
-        for (Enumeration<?> e = node.children(); e.hasMoreElements();) {
-          JSVTreeNode childNode = (JSVTreeNode) e.nextElement();
+        for (Enumeration<JSVTreeNode> e = node.children(); e.hasMoreElements();) {
+          JSVTreeNode childNode = e.nextElement();
           toDelete.addLast(childNode);
           panelNodes.removeObj(childNode.getPanelNode());
         }
