@@ -134,8 +134,8 @@ public class AwtPlatform implements GenericPlatform {
   }
 
   @Override
-	public int[] grabPixels(Object imageobj, int width, int height, int[] pixels, int startRow, int nRows) {
-    return Image.grabPixels(imageobj, width, height, pixels, startRow, nRows); 
+	public int[] grabPixels(Object imageobj, int width, int height, int[] pixels) {
+    return Image.grabPixels(imageobj, width, height, pixels); 
   }
 
   @Override
