@@ -3,8 +3,6 @@ package jspecview.tree;
 import java.util.Enumeration;
 
 import javajs.util.Lst;
-
-
 import jspecview.api.JSVTreeNode;
 import jspecview.common.PanelNode;
 
@@ -40,7 +38,8 @@ public class SimpleTreeNode implements JSVTreeNode {
 			this.index = index;
 		}
 
-		public Enumeration children() {
+		@Override
+    public Enumeration<JSVTreeNode> children() {
 			return new SimpleTreeEnumeration(this);
 		}
 
