@@ -147,10 +147,12 @@ public class CifReader extends AtomSetCollectionReader {
   private boolean addAtomLabelNumbers;
   private boolean ignoreGeomBonds;
   private boolean allowWyckoff = true;
+  private boolean stopOn_SHELX_HKL;
 
   @Override
   public void initializeReader() throws Exception {
     initSubclass();
+    stopOn_SHELX_HKL = checkFilterKey("STOPONSHELXHKL");    
     allowPDBFilter = true;
     appendedData = (String) htParams.get("appendedData");
     String conf = getFilter("CONF ");
@@ -213,7 +215,10 @@ public class CifReader extends AtomSetCollectionReader {
   }
 
   private boolean continueWith(String key) {
-    boolean ret = (key != null && (ac == 0 || !key.equals("_shelx_hkl_file")));
+    boolean isHKL = false;
+    boolean ret = key != null && (!stopOn_SHELX_HKL || (ac == 0 || !key.equals("_shelx_hkl_file")));
+    if (ret && isHKL)
+      System.err.println("CIFReader reading _shelx_hkl_file; use FILTER 'StopOnShelxHKL' to stop when this is found");
     return ret;
   }
 
@@ -225,7 +230,6 @@ public class CifReader extends AtomSetCollectionReader {
   }
 
   private boolean readEntryOrLoopData() throws Exception {
-    //System.out.println("key is " + key);
     if (key.startsWith("data_")) {
       isLigand = false;
       if (asc.atomSetCount == 0)  
@@ -511,6 +515,8 @@ public class CifReader extends AtomSetCollectionReader {
   protected void finalizeSubclassReader() throws Exception {
     if (htOxStates != null)
       setOxidationStates();
+    if (htJmolNames != null)
+      setJmolNames();
     // added check for final data_global
     if (asc.iSet > 0 && asc.getAtomSetAtomCount(asc.iSet) == 0)
       asc.atomSetCount--;
@@ -525,6 +531,9 @@ public class CifReader extends AtomSetCollectionReader {
     addHeader();
     if (haveAromatic)
       addJmolScript("calculate aromatic");
+    if (!isMMCIF && asc.xtalSymmetry != null) {
+      asc.xtalSymmetry.setPartProperty();
+    }
   }
 
   private void setOxidationStates() {
@@ -940,6 +949,10 @@ public class CifReader extends AtomSetCollectionReader {
         processGeomBondLoopBlock();
       return;
     }
+    if (key.startsWith("_jmol")) {
+      processJmolBlock();
+      return;
+    }
     if (processSubclassLoopBlock())
       return;
     if (key.equals("_propagation_vector_seq_id")) {// Bilbao mCIF
@@ -1047,6 +1060,49 @@ public class CifReader extends AtomSetCollectionReader {
     return true;
   }
 
+  //final private static byte JMOL_ATOM_INDEX = 0;
+  final private static byte JMOL_ATOM_NAME = 1;
+  final private static byte JMOL_ATOM_SITE_LABEL = 2;
+
+  final private static String[] jmolAtomFields = { 
+      "_jmol_atom_index",
+      "_jmol_atom_name", 
+      "_jmol_atom_site_label" 
+      };
+
+//  loop_
+//  _jmol_atom_index
+//  _jmol_atom_name
+//  _jmol_atom_site_label
+//    0 FE1    Fe1
+//    1 CL1    Cl1
+//    2 P1     P1
+//    3 N1     N1
+//  143 Q11   Xx11
+
+  private Map<String, String> htJmolNames;
+  
+  private void processJmolBlock() throws Exception {
+    htJmolNames = new Hashtable<>();
+    parseLoopParameters(jmolAtomFields);
+    while (cifParser.getData()) {
+      String jmolName = getFieldString(JMOL_ATOM_NAME);
+      String cifName = getFieldString(JMOL_ATOM_SITE_LABEL);
+      if (jmolName == null || cifName == null)
+        continue;
+      htJmolNames.put(cifName,  jmolName);
+    }
+  }
+
+  private void setJmolNames() {
+    for (int i = 0, n = asc.ac; i < n; i++) {
+      Atom a = asc.atoms[i];
+      String name = htJmolNames.get(a.atomName);
+      if (name != null)
+        a.atomName = name;
+    }
+  }
+
   ////////////////////////////////////////////////////////////////
   // atom site data
   ////////////////////////////////////////////////////////////////
@@ -1149,7 +1205,7 @@ public class CifReader extends AtomSetCollectionReader {
       "*_label_alt_id", // 
       "*_group_pdb", //
       "*_pdbx_pdb_model_num", // 
-      "*_calc_flag", // 
+      "*_calc_flag", //  18
       "*_disorder_group", //
       "*_aniso_label", // 
       "*_anisotrop_id", // 
@@ -1314,7 +1370,7 @@ public class CifReader extends AtomSetCollectionReader {
         if ((f0 = f = fieldProperty(key2col[LABEL])) != NONE
             || (f = fieldProperty(key2col[CC_ATOM_ID])) != NONE
             || (f = fieldProperty(key2col[LABEL_ATOM_ID])) != NONE
-            || (f = fieldProperty(key2col[ANISO_LABEL])) != NONE
+            || (f0 = f = fieldProperty(key2col[ANISO_LABEL])) != NONE
             || (f = fieldProperty(key2col[ANISO_MMCIF_ID])) != NONE
             || (f = fieldProperty(key2col[MOMENT_LABEL])) != NONE) {
           if (f0 != NONE && atomLabels != null) {
@@ -1486,7 +1542,11 @@ public class CifReader extends AtomSetCollectionReader {
           disorderAssembly = field;
           break;
         case DISORDER_GROUP:
-          if (firstChar == '-' && field.length() > 1) {
+          if (!isMMCIF) {
+            atom.part = PT.parseInt(field);
+          }
+          atom.altLoc = (atom.part < 0 ? field.charAt(1) : firstChar);
+
             // disorder group -1
 
             // email exchange with Brian McMahon 22.10.11
@@ -1510,17 +1570,11 @@ public class CifReader extends AtomSetCollectionReader {
             //            PDB format. However, this notation is difficult to use when there
             //            is a disorder within a disorder."
 
-            // atom.basLoc provides the base altloc "n" of "-n"
-            // as symmetry is applied, if basLoc is found, then 
+            // atom.part < 0 indicates the negative case; atom.altloc is the "n" of "-n"
+            // as symmetry is applied, if atom.isNegDisorder is true, then 
             // the cloned atom is given an incremented altloc
             // this only works with C2 and m; with higher-order symmetry, this
             // will dump all the symmetry-related groups into the same configuration=2
-
-            atom.altLoc = field.charAt(1);
-            atom.isNegDisorder = true;
-          } else {
-            atom.altLoc = firstChar;
-          }
           break;
         case GROUP_PDB:
           if ("HETATM".equals(field))
@@ -1789,7 +1843,8 @@ public class CifReader extends AtomSetCollectionReader {
       "*_magn_ssg_operation_timereversal", // another iteration
       "*_operation_timereversal", // preliminary only
 
-      "*_magn_centering_xyz", "*_magn_ssg_centering_algebraic",
+      "*_magn_centering_xyz", 
+      "*_magn_ssg_centering_algebraic",
       "*_magn_ssg_centering_xyz" // preliminary
   };
 
@@ -2169,7 +2224,11 @@ public class CifReader extends AtomSetCollectionReader {
       Atom a1 = getAtomFromNameCheckCase((String) o[0]);
       Atom a2 = getAtomFromNameCheckCase((String) o[1]);
       if (a1 == null || a2 == null) {
-        a2 = getAtomFromNameCheckCase((String) o[1]);
+        System.err.println("CifReader checking GEOM_BOND " + o[0] + "-" + o[1] + " found " + a1 + " " + a2);
+        continue;
+      }
+      if (Float.isNaN(a1.x) || Float.isNaN(a2.x)) {
+        System.err.println("CifReader checking GEOM_BOND " + o[0] + "-" + o[1] + " found x coord NaN");
         continue;
       }
       int iatom1 = a1.index;
@@ -2191,11 +2250,13 @@ public class CifReader extends AtomSetCollectionReader {
       for (int j = bs1.nextSetBit(0); j >= 0; j = bs1.nextSetBit(j + 1)) {
         for (int k = bs2.nextSetBit(0); k >= 0; k = bs2.nextSetBit(k + 1)) {
           if ((!isMolecular || !bsConnected[j + firstAtom].get(k))
-              && checkBondDistance(atoms[j + firstAtom], atoms[k + firstAtom], distance, dx))
+              && checkBondDistance(atoms[j + firstAtom], atoms[k + firstAtom],
+                  distance, dx)) {
             addNewBond(j + firstAtom, k + firstAtom, order);
         }
       }
     }
+    }
 
     if (!iHaveFractionalCoordinates)
       return false;
