@@ -233,7 +233,7 @@ public class MSCifParser extends MSRdr {
     CifReader cr = (CifReader) this.cr;
     if (cr.key.equals("_cell_commen_t_section_1")) {
       isCommensurate = true;
-      commensurateSection1 = cr.parseIntStr(cr.data);
+      commensurateSection1 = cr.parseIntField();
     }
     if (cr.key.startsWith("_cell_commen_supercell_matrix")) {
       isCommensurate = true;
@@ -243,7 +243,7 @@ public class MSCifParser extends MSRdr {
       int r = cr.parseIntStr(tokens[tokens.length - 2]);
       int c = cr.parseIntStr(tokens[tokens.length - 1]);
       if (r > 0 && c > 0)
-        comSSMat.setElement(r - 1, c - 1, cr.parseFloatStr(cr.data)); 
+        comSSMat.setElement(r - 1, c - 1, cr.parseFloatField()); 
     }
   }
 
@@ -275,7 +275,7 @@ public class MSCifParser extends MSRdr {
     }
     if (cr.asc.iSet < 0)
       cr.asc.newAtomSet();
-    cr.parseLoopParametersFor(CifReader.FAMILY_ATOM, modulationFields);
+    cr.parseLoopParametersFor(CifReader.CAT_ATOM_SITE, modulationFields);
     int tok;
 //    if (cr.key2col[JANA_FWV_Q1_COEF] != NONE) {
 //      // disable x y z for atom_site_fourier if we have coefficients
@@ -305,8 +305,9 @@ public class MSCifParser extends MSRdr {
           break;
         case WV_ID:
           cr.haveCellWaveVector = true;
+          type_id = "W_" + field;
           sep = "";
-          //$FALL-THROUGH$
+          break;
         case FD_ID:
         case FO_ID:
         case FU_ID:
@@ -321,28 +322,25 @@ public class MSCifParser extends MSRdr {
         case FOPARAM_ID:
         case FUPARAM_ID:
           switch (tok) {
-          case WV_ID:
-            type_id = "W_";
-            sep = "";
-            break;
           case FD_ID:
           case FO_ID:
           case FU_ID:
-            fid = "?" + field;
+            fid = "?id" + field;
             pt[2] = 1;
+            sep = "_";
             continue;
           case FDPARAM_ID:
           case FOPARAM_ID:
           case FUPARAM_ID:
             atomLabel = axis = "*";
-            //$FALL-THROUGH$
+            sep = "_id";
+            type_id = modulationFields[tok].substring(11, 12).toUpperCase();
+          break;
           case FWV_DISP_SEQ_ID:
           case FWV_OCC_SEQ_ID:
           case FWV_SPIN_SEQ_ID:
           case FWV_U_SEQ_ID:
             type_id = modulationFields[tok].substring(11, 12).toUpperCase();
-//            type_id = Character.toUpperCase(modulationFields[tok].charAt(11))
-//                + "_";
             break;
           }
           type_id += sep + field;
@@ -554,7 +552,7 @@ public class MSCifParser extends MSRdr {
     return 1;
   }
   
-  private void addMod(String key, String id, String fid, double[] params) {
+  private void addMod(@SuppressWarnings("unused") String key, String id, String fid, double[] params) {
     String k = (fid == null ? id : id + fid);
 //    System.out.println("!mscifp addMod id=" + id + " fid=" + fid + " key = " + k + " " + Arrays.toString(params) + " for " + key);
     addModulation(null, k, params, -1);
@@ -638,13 +636,12 @@ public class MSCifParser extends MSRdr {
 //    for (int i = pt.length; --i >= 0;)
 //      pt[i] = fixDouble(pt[i]);
 //  }
-//
+
   private double fixDouble(double d) {
     // was fixFloat(float[] pt  -- removed in Jmol 15.32.53
     // this is fine -- we are just removing the lower-order bits; 
     // none of these numbers will have much precision
-    return d;
-//    return Math.round(d * 10000000000.) / 10000000000.;
+    return d;//Math.round(d * 10000000000.) / 10000000000.;
   }
 
   private int fieldProperty(CifReader cr, int i) {
