@@ -2,7 +2,7 @@ package org.jmol.adapter.readers.cif;
 
 import java.util.Map.Entry;
 
-import org.jmol.api.SymmetryInterface;
+import org.jmol.adapter.smarter.XtalSymmetry.FileSymmetry;
 import org.jmol.util.Logger;
 import org.jmol.util.SimpleUnitCell;
 
@@ -20,7 +20,7 @@ class Subsystem {
   private int d;
   private Matrix w;
 
-  private SymmetryInterface symmetry;
+  private FileSymmetry symmetry;
   private Matrix[] modMatrices;
   private boolean isFinalized;
 
@@ -31,7 +31,7 @@ class Subsystem {
     d = w.getArray().length - 3;
   }
 
-  public SymmetryInterface getSymmetry() {
+  public FileSymmetry getSymmetry() {
     if (!isFinalized)
       setSymmetry(true);
     return symmetry;
@@ -72,7 +72,7 @@ class Subsystem {
     
     // Part 2: Get the new unit cell and symmetry operators
 
-    SymmetryInterface s0 = msRdr.cr.asc.getSymmetry();
+    FileSymmetry s0 = msRdr.cr.asc.getSymmetry();
     T3[] vu43 = s0.getUnitCellVectors();
     T3[] vr43 = SimpleUnitCell.getReciprocal(vu43, null, 1);
 
@@ -102,7 +102,7 @@ class Subsystem {
     for (int i = 0; i < 3; i++)
       uc_nu[i + 1] = V3.new3((float) a[i][0], (float) a[i][1], (float) a[i][2]);    
     uc_nu = SimpleUnitCell.getReciprocal(uc_nu, null, 1);
-    symmetry = ((SymmetryInterface) msRdr.cr.getInterface("org.jmol.symmetry.Symmetry")).getUnitCell(uc_nu, false, null);
+    (symmetry = msRdr.cr.asc.newFileSymmetry()).getUnitCell(uc_nu, false, null);
     modMatrices = new Matrix[] { sigma_nu, tFactor };
     if (!setOperators)
       return;
