@@ -1,6 +1,6 @@
 package org.jmol.adapter.readers.more;
 
-import org.jmol.adapter.readers.xml.XmlChemDrawReader;
+import org.jmol.adapter.readers.xml.XmlCdxReader;
 import org.jmol.adapter.readers.xml.XmlReader;
 import org.jmol.adapter.writers.CDXMLWriter;
 
@@ -25,7 +25,7 @@ import javajs.util.Rdr;
  * @version 1.0
  */
 
-public class CDXReader extends XmlChemDrawReader {
+public class CDXReader extends XmlCdxReader {
 
   @Override
   protected void processXml2(XmlReader parent, Object saxReader) throws Exception {
@@ -35,6 +35,7 @@ public class CDXReader extends XmlChemDrawReader {
     reader = Rdr.getBR(xml);
     super.processXml2(this, saxReader);
     binaryDoc = null;
+    isCDX = true;
   }
   
   
