@@ -106,8 +106,10 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
 
   private BS bsStructureDefined = new BS();
   private BS bsBytesExcluded;
+  private BS bsValence = new BS();
 
   private int[] atomMap;
+  private int[] jmolToUniqueID;
   private Map<String, BS> ssMapSeq;
 
   private PyMOLScene pymolScene;
@@ -146,6 +148,15 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
 
   private boolean haveBinaryArrays = true;
 
+  private byte[] aTemp = new byte[16];
+  private final P3 ptTemp = new P3();
+
+
+  /**
+   * set TRUE using FILTER "SHOWVALENCE" to force multiple bonding
+   */
+  private boolean forceValence;
+
   @Override
   protected void setup(String fullPath, Map<String, Object> htParams, Object reader) {
     isBinary = mustFinalizeModelSet = true;
@@ -156,13 +167,13 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
   protected void initializeReader() throws Exception {
     baseAtomIndex = ((Integer) htParams.get("baseAtomIndex")).intValue();
     baseModelIndex = ((Integer) htParams.get("baseModelIndex")).intValue();
+    forceValence = checkFilterKey("SHOWVALENCE");
     asc.setInfo("noAutoBond",
         Boolean.TRUE);
     asc.setCurrentModelInfo("pdbNoHydrogens", Boolean.TRUE);
     asc.setInfo("isPyMOL", Boolean.TRUE);
     if (isTrajectory)
       trajectorySteps = new Lst<P3[]>();
-
     isStateScript = htParams.containsKey("isStateScript");
     sourcePNGJ = htParams.containsKey("sourcePNGJ");
     doResize = checkFilterKey("DORESIZE");
@@ -213,7 +224,9 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
 
   @Override
   protected void finalizeSubclassReader() throws Exception {
-    finalizeReaderPDB();
+    if (asc.atomSetCount == 1 && pymolScene.modelName != null && pymolScene.modelName.length() == 4)
+      pdbID = pymolScene.modelName;
+    super.finalizeSubclassReader();
     asc.setTensors();
   }
   /**
@@ -399,6 +412,12 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     }
     int n = names.size();
     
+    int nAtomsJmol = 0;
+    for (int j = 0; j < stateCount; j++) {
+      for (int i = 1; i < n; i++)
+        nAtomsJmol += processObject(listAt(names, i), true, j, true);
+    }
+    jmolToUniqueID = new int[nAtomsJmol];
     for (int j = 0; j < stateCount; j++) {
       if (!doGetModel(++nModels, null))
         continue;
@@ -410,10 +429,10 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
         trajectoryPtr = 0;
       }
       for (int i = 1; i < n; i++)
-        processObject(listAt(names, i), true, j);
+        processObject(listAt(names, i), true, j, false);
     }
     for (int i = 1; i < n; i++)
-      processObject(listAt(names, i), false, 0);
+      processObject(listAt(names, i), false, 0, false);
     pymolScene.setReaderObjectInfo(null, 0, null, false, null, null, null);
 
     // meshes are special objects that depend upon grid map data
@@ -453,16 +472,16 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     int n = settings.size();
     for (int i = 0; i < n; i++) {
       @SuppressWarnings("unchecked")
-      int i2 = intAt((Lst<Object>) settings.get(i), 0);
+      Lst<Object> setting = (Lst<Object>) settings.get(i);
+      int i2 = intAt(setting, 0);
       if (i2 == -1) {
-        Logger.info("PyMOL reader adding null setting #" + i);
         settings.set(i, new Lst<Object>()); // PyMOL 1.7 needs this
       } else {
         while (i < i2) {
-          Logger.info("PyMOL reader adding null setting #" + i);
           settings.add(i++, new Lst<Object>());
           n++;
         }
+        System.out.println("PyMOL global setting " + setting);
       }
     }
     return settings;
@@ -498,6 +517,7 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
   private int setUniqueSettings(Lst<Object> list) {
     uniqueSettings = new Hashtable<Integer, Lst<Object>>();
     int max = 0;
+    int n = 0;
     if (list != null && list.size() != 0) {
       for (int i = list.size(); --i >= 0;) {
         Lst<Object> atomSettings = (Lst<Object>) list.get(i);
@@ -507,17 +527,21 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
         Lst<Object> mySettings = (Lst<Object>) atomSettings.get(1);
         for (int j = mySettings.size(); --j >= 0;) {
           Lst<Object> setting = (Lst<Object>) mySettings.get(j);
-          int uid = (id << 10) + intAt(setting, 0);
+          int type = intAt(setting, 0);
+          int uid = (id << 10) + type;
           uniqueSettings.put(Integer.valueOf(uid), setting);
-          //System.out.println("PyMOL unique setting " + id + " " + setting);
+          n++;
+          if (type != 64)
+            System.out.println("UniqueSetting " + id + " " + setting);
+          if (Logger.debugging)
+            Logger.info("PyMOL unique setting " + id + " " + setting);
         }
       }
     }
+    Logger.info("PyMOL uniqueSettings: " + n);
     return max;
   }
 
-  private final P3 ptTemp = new P3();
-
   /**
    * Add new colors from the main "colors" map object.
    * Not 100% clear how color clamping works.
@@ -676,17 +700,18 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
    * @param execObject
    * @param moleculeOnly
    * @param iState
+   * @param justCountJmolAtoms
    */
   @SuppressWarnings("unchecked")
-  private void processObject(Lst<Object> execObject, boolean moleculeOnly,
-                             int iState) {
+  private int processObject(Lst<Object> execObject, boolean moleculeOnly,
+                            int iState, boolean justCountJmolAtoms) {
     if (execObject == null)
-      return;
+      return 0;
     int type = intAt(execObject, 4);
-    Lst<Object> startLen = (Lst<Object>) execObject
-        .get(execObject.size() - 1);
-    if ((type == PyMOL.OBJECT_MOLECULE) != moleculeOnly || !checkObject(execObject))
-      return;
+    Lst<Object> startLen = (Lst<Object>) execObject.get(execObject.size() - 1);
+    if ((type == PyMOL.OBJECT_MOLECULE) != moleculeOnly
+        || !checkObject(execObject))
+      return 0;
     Lst<Object> pymolObject = listAt(execObject, 5);
     Lst<Object> stateSettings = null;
     if (type == PyMOL.OBJECT_MOLECULE) {
@@ -694,10 +719,13 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
       Lst<Object> state = listAt(states, iState);
       Lst<Object> idxToAtm = listAt(state, 3);
       if (iState > 0 && (idxToAtm == null || idxToAtm.size() == 0))
-        return;
+        return 0;
       stateSettings = listAt(state, 7);
+      if (justCountJmolAtoms) {
+        return intAt(pymolObject, 3);
+      }
     } else   if (iState > 0) {
-        return;
+      return 0;
     }
     
     Logger.info("PyMOL model " + (nModels) + " Object " + objectName
@@ -778,6 +806,7 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     }
     if (msg != null)
       Logger.error("Unprocessed object type " + msg + " " + objectName);
+    return 0;
   }
 
   /**
@@ -853,7 +882,7 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     if (nCoord == 0)
       return;
     Lst<Object> setting = listAt(pymolObject, 0);
-    BS bsReps = getBsReps(listAt(setting, 3));
+    BS bsReps = getBsReps(setting, 3);
     Lst<Object> list = listAt(measure, pt);
     Lst<Object> offsets = listAt(measure, 8);
     boolean haveLabels = (measure.size() > 8);
@@ -875,6 +904,7 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     Lst<Object> idxToAtm;
     Lst<Object> coords;
     Lst<Object> labelPositions;
+    Lst<Object> uniqueIds = listAt(state, 11);
     int[] idxArray = null;
     float[] coordsArray = null;
     float[] labelArray = null;
@@ -896,8 +926,7 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     } else {
       coords = listAt(state, 2);
       idxToAtm = listAt(state, 3);
-      // atomToIdx = listAt(state, 4);
-      
+      // atomToIdx = listAt(state, 4);      
       labelPositions = listAt(state, 8);
       if (idxToAtm != null)
         n = idxToAtm.size();
@@ -911,7 +940,6 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     ssMapSeq = new Hashtable<String, BS>();
     if (iState == 0)
       processMolCryst(listAt(pymolObject, 10));
-    Lst<Bond> bonds = getBondList(listAt(pymolObject, 6));
     Lst<Object> pymolAtoms = listAt(pymolObject, 7);
     atomMap = new int[nAtoms];
     BS bsAtoms = pymolScene.setAtomMap(atomMap, ac0);
@@ -920,6 +948,7 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
 
     // TODO: Implement trajectory business here.
 
+    pymolScene.htSpacefill.clear();
     if (iState == 0 || !isTrajectory) {
       pymolScene.ensureCapacity(n);
       String[] lexStr = null;
@@ -933,19 +962,22 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
         vArray = (haveBinaryArrays ? PyMOL.getVArray(ver) : null);
       }
       for (int idx = 0; idx < n; idx++) {
-        P3 a = addAtom(pymolAtoms, (idxToAtm != null ? intAt(idxToAtm, idx)
-            : idxArray != null ? idxArray[idx] : idx),
+        int index = (idxToAtm != null ? intAt(idxToAtm, idx)
+            : idxArray != null ? idxArray[idx] : idx);
+        P3 a = addAtom(pymolAtoms, index,
             atomArray, vArray, lexStr, idx, coords,
-            coordsArray, labelPositions, labelArray, bsAtoms, iState);
+            coordsArray, labelPositions, uniqueIds, labelArray, bsAtoms, iState);
         if (a != null)
           trajectoryStep[trajectoryPtr++] = a;
       }
     }
-    addBonds(bonds);
+    addBonds(getBondList(listAt(pymolObject, 6)));
     addMolStructures();
     atoms = asc.atoms;
-    if (!isStateScript)
+    if (!isStateScript) {
+      asc.setCurrentModelInfo("name", pymolScene.modelName);
       createShapeObjects();
+    }
     ssMapSeq = null;
 
     Logger.info("reading " + (ac - ac0) + " atoms and " + nBonds + " bonds");
@@ -990,9 +1022,6 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     }
   }
 
-  byte[] aTemp = new byte[16];
-
-
   /**
    * Pick up the crystal data.
    * 
@@ -1047,8 +1076,11 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
       }
       if (order < 1 || order > 3)
         order = 1;
-      order |= (asSingle || order == 1 ? JmolAdapter.ORDER_PYMOL_SINGLE
+      boolean isSpecial = (order > 1 && bsValence.get(ia) && bsValence.get(ib));
+      order |= (order == 1 || asSingle && !isSpecial ? JmolAdapter.ORDER_PYMOL_SINGLE
           : JmolAdapter.ORDER_PYMOL_MULT);
+      // initially this is an apt
+      
       Bond bond = new Bond(ia, ib, order);
       bond.uniqueID = uid;
       bondList.addLast(bond);
@@ -1128,12 +1160,13 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
    * @param atomArray 
    * @param vArray 
    * @param lexStr 
-   * @param icoord
+   * @param idx
    *        array pointer into coords (/3)
    * @param coords
    *        coordinates array
    * @param coordArray 
    * @param labelPositions
+   * @param uniqueIds 
    * @param labelArray 
    * @param bsState
    *        this state -- Jmol atomIndex
@@ -1143,13 +1176,14 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
    */
   private P3 addAtom(Lst<Object> pymolAtoms, int apt, 
                      byte[] atomArray, int[] vArray, String[] lexStr,
-                     int icoord,
+                     int idx,
                      Lst<Object> coords, float[] coordArray, 
-                     Lst<Object> labelPositions, float[] labelArray,
+                     Lst<Object> labelPositions, Lst<Object> uniqueIds, float[] labelArray,
                      BS bsState, int iState) {
     atomMap[apt] = -1;
     String chainID, altLoc, group3, name, sym, label, ssType, resi, insCode = null;
-    float bfactor, occupancy, radius, partialCharge;
+    float bfactor, occupancy;
+    float radius, partialCharge;
     int seqNo, intReps, formalCharge, atomColor, serNo, cartoonType, flags, uniqueID = -1;
     boolean isHetero, bonded;
     float[] anisou = null;
@@ -1188,8 +1222,6 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
       cartoonType = atomInt(atomArray, pt, vArray[PyMOL.CARTOON]);
       flags = atomInt(atomArray, pt, vArray[PyMOL.FLAGS]);
       uniqueID = atomInt(atomArray, pt, vArray[PyMOL.UNIQUEID]);
-      if (uniqueID == 0)
-        uniqueID = -1;
       anisou = new float[8];
       if ((vpt = vArray[PyMOL.ANISOU]) > 0)
         for (int i = 0; i < 6; i++)
@@ -1218,17 +1250,29 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
       partialCharge = floatAt(a, 17);
       formalCharge = intAt(a, 18);
       isHetero = (intAt(a, 19) != 0);
-      bsReps = getBsReps(listAt(a, 20));
+      bsReps = getBsReps(a, 20);
       intReps = (bsReps == null ? intAt(a, 20) : 0); // Pymol 1.8      
       atomColor = intAt(a, 21);
       serNo = intAt(a, 22);
       cartoonType = intAt(a, 23);
       flags = intAt(a, 24);
       bonded = (intAt(a, 25) != 0);
-      uniqueID = (a.size() > 40 && intAt(a, 40) == 1 ? intAt(a, 32) : -1);
+      uniqueID = (a.size() > 40 && intAt(a, 40) == 1 ? intAt(a, 32) : 0);
       if (a.size() > 46)
         anisou = floatsAt(a, 41, new float[8], 6);
     }
+    if (uniqueID == 0) {
+      uniqueID = -1;
+      if (uniqueIds != null) {
+        Integer id = (Integer) uniqueIds.get(idx);
+        if (id != null) {
+          uniqueID = id.intValue();
+        }
+      }
+    }
+    if (forceValence  || pymolScene.getUniqueFloatDef(uniqueID, PyMOL.valence, pymolScene.valence) == 1) {
+      bsValence.set(apt);
+    }
     if (insCode == null) {
       int len = resi.length();
       char ch = (len > 0 ? resi.charAt(len - 1) : ' ');
@@ -1242,12 +1286,13 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     if (sym.equals("A"))
       sym = "C";
     int ichain = vwr.getChainID(chainID, true);
-    Atom atom = processAtom(new Atom(), name, (altLoc.length() == 0 ? ' ' : altLoc.charAt(0)), group3, 
-        ichain, seqNo, insCode.charAt(0), isHetero, sym);
+    Atom atom = processAtom(new Atom(), name,
+        (altLoc.length() == 0 ? ' ' : altLoc.charAt(0)), group3, ichain, seqNo,
+        insCode.charAt(0), isHetero, sym);
     if (!filterPDBAtom(atom, fileAtomIndex++))
       return null;
     float x, y, z;
-    icoord *= 3;
+    int icoord = idx * 3;
     if (haveBinaryArrays) {
       x = coordArray[icoord];
       y = coordArray[++icoord];
@@ -1287,13 +1332,20 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     if (anisou != null && anisou[0] != 0)
       asc.setAnisoBorU(atom, anisou, 12);
     pymolScene.setAtomColor(atomColor);
+    if (pymolScene.getUniqueFloatDef(uniqueID, PyMOL.valence, pymolScene.valence) == 1) {
+      bsValence.set(apt);
+    }
+
     processAtom2(atom, serNo, x, y, z, formalCharge);
 
     // set pymolScene bit sets and create labels
 
-    if (!bonded)
+    if (!bonded) {
+      // setting 420 apparently this is not necessary
+      //if (pymolScene.getUniqueFloatDef(uniqueID, PyMOL.auto_show_spheres, 0) == 0)
       pymolScene.bsNonbonded.set(ac);
-    if (!label.equals(" ")) {
+    }
+    if (label.trim().length() > 0) {
       pymolScene.bsLabeled.set(ac);
       float[] labelPos = new float[7];
       if (labelArray != null) {
@@ -1303,9 +1355,10 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
         Lst<Object> labelOffset = listAt(labelPositions, apt);
         if (labelOffset != null) {
           for (int i = 0; i < 7; i++)
-          labelPos[i] = floatAt(labelOffset, i);
+            labelPos[i] = floatAt(labelOffset, i);
         }
       }
+      labelPos = PyMOL.fixAllZeroLabelPosition(labelPos);
       pymolScene.addLabel(ac, uniqueID, atomColor, labelPos, label);
     }
     if (isHidden)
@@ -1319,6 +1372,7 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
       pymolScene.bsHydrogen.set(ac);
     if ((flags & PyMOL.FLAG_NOSURFACE) != 0)
       pymolScene.bsNoSurface.set(ac);
+    jmolToUniqueID[ac] = uniqueID;
     atomMap[apt] = ac++;
     return null;
   }
@@ -1350,15 +1404,31 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     int n = bonds.size();
     for (int i = 0; i < n; i++) {
       Bond bond = bonds.get(i);
-      bond.atomIndex1 = atomMap[bond.atomIndex1];
-      bond.atomIndex2 = atomMap[bond.atomIndex2];
-      if (bond.atomIndex1 < 0 || bond.atomIndex2 < 0)
+      int a1 = atomMap[bond.atomIndex1];
+      int a2 = atomMap[bond.atomIndex2];
+      if (a1 < 0 || a2 < 0)
         continue;
+      bond.atomIndex1 = a1;
+      bond.atomIndex2 = a2;
+      checkStickBall(a1);
+      checkStickBall(a2);
       pymolScene.setUniqueBond(bondCount++, bond.uniqueID);
       asc.addBond(bond);
     }
   }
 
+  private void checkStickBall(int iatom) {
+    int id = jmolToUniqueID[iatom];
+    float radius = (pymolScene.getUniqueFloatDef(id, PyMOL.stick_ball, pymolScene.stickBalls));
+    if (radius == 1) {
+      radius = pymolScene.getUniqueFloatDef(id,  PyMOL.stick_radius, pymolScene.stickRadius) 
+          * pymolScene.getUniqueFloatDef(id, PyMOL.stick_ball_ratio, pymolScene.stickBallRatio);
+    } else {
+      radius = 0;
+    }
+    pymolScene.addSpacefill(iatom, radius, false);
+  }
+
   private void addMolStructures() {
     addMolSS("H", STR.HELIX);
     addMolSS("S", STR.SHEET);
@@ -1643,14 +1713,27 @@ public class PyMOLReader extends PdbReader implements PymolAtomReader {
     return (Lst<Object>) map.get(key);
   }
 
-  private static BS getBsReps(Lst<Object> list) {
-    if (list == null)
+  private static BS getBsReps(Lst<Object> setting, int pt) {
+    if (setting.size() <= pt)
       return null;
     BS bsReps = new BS();
-    int n = Math.min(list.size(), PyMOL.REP_MAX);
-    for (int i = 0; i < n; i++) {
-      if (intAt(list, i) == 1)
-        bsReps.set(i);
+    Object o = setting.get(pt);
+    if (o instanceof Integer) {
+      int bits = ((Integer) o).intValue();
+      for (int i = 0, b = 1; i < 32; i++) {
+        if ((bits & b) != 0) {
+          bsReps.set(i);
+        }
+        b <<= 1;
+      }
+    } else {
+      @SuppressWarnings("unchecked")
+      Lst<Object> list = (Lst<Object>) o;
+      int n = Math.min(list.size(), PyMOL.REP_MAX);
+      for (int i = 0; i < n; i++) {
+        if (intAt(list, i) == 1)
+          bsReps.set(i);
+      }
     }
     return bsReps;
   }
