@@ -72,6 +72,14 @@ class PyMOLScene implements JmolSceneGenerator {
 //  ring_radius
 //  ring_width
 
+  private final static int[] MEAS_DIGITS = { 
+      PyMOL.label_distance_digits,
+      PyMOL.label_angle_digits, 
+      PyMOL.label_dihedral_digits 
+  };
+
+  private static final double PYMOL_FONT_SIZE_FACTOR = 1.25d;
+
   private Viewer vwr;
   private int pymolVersion;
 
@@ -85,7 +93,8 @@ class PyMOLScene implements JmolSceneGenerator {
 
   // private -- only needed for file reading
 
-  private Map<Float, BS> htSpacefill = new Hashtable<Float, BS>();
+  Map<Float, BS> htSpacefill = new Hashtable<Float, BS>();
+  BS bsSpacefillSphere = new BS();
   private Map<String, BS> ssMapAtom = new Hashtable<String, BS>();
   private Lst<Integer> atomColorList = new Lst<Integer>();
   private Map<String, Boolean> occludedObjects = new Hashtable<String, Boolean>();
@@ -123,6 +132,8 @@ class PyMOLScene implements JmolSceneGenerator {
 
   // private -- needed for processing Scenes
 
+  private final P3 ptTemp = new P3();
+
   private BS bsCartoon = new BS();
   private Map<String, BS> htCarveSets = new Hashtable<String, BS>();
   private Map<String, BS> htDefinedAtoms = new Hashtable<String, BS>();
@@ -141,16 +152,7 @@ class PyMOLScene implements JmolSceneGenerator {
   private Map<Integer, Lst<Object>> uniqueSettings;
   private Map<Integer, Integer> uniqueList;
   private BS bsUniqueBonds;
-  void setUniqueBond(int index, int uniqueID) {
-    if (uniqueID < 0)
-      return;
-    if (uniqueList == null) {
-      uniqueList = new Hashtable<Integer, Integer>();
-      bsUniqueBonds = new BS();
-    }
-    uniqueList.put(Integer.valueOf(index), Integer.valueOf(uniqueID));
-    bsUniqueBonds.set(index);
-  }
+  
   private int bgRgb;
   private int dotColor;
   private int surfaceMode;
@@ -170,6 +172,11 @@ class PyMOLScene implements JmolSceneGenerator {
   private float sphereTranslucency;
   private float stickTranslucency;
   private float transparency;
+  float stickBallRatio;
+  float stickBalls;
+  float stickRadius;
+  float valence;
+
   private boolean cartoonLadderMode;
   private boolean cartoonRockets;
   private boolean haveNucleicLadder;
@@ -208,10 +215,7 @@ class PyMOLScene implements JmolSceneGenerator {
   private int thisState;
   int currentAtomSetIndex;
   String surfaceInfoName;
-
-  void setStateCount(int stateCount) {
-    this.stateCount = stateCount;
-  }
+  String modelName;
 
   PyMOLScene(PymolAtomReader reader, Viewer vwr, Lst<Object> settings,
       Map<Integer, Lst<Object>> uniqueSettings, int pymolVersion,
@@ -229,10 +233,31 @@ class PyMOLScene implements JmolSceneGenerator {
     this.surfaceInfoName = filePath + "##JmolSurfaceInfo##";
     setVersionSettings();
     settings.trimToSize();
-    bgRgb = colorSetting(PyMOL.bg_rgb);
+    bgRgb = PyMOL.getRGB(colorSetting(PyMOL.bg_rgb));
     labelPosition0 = pointSetting(PyMOL.label_position);
   }
 
+  void setUniqueBond(int index, int uniqueID) {
+    if (uniqueID < 0)
+      return;
+    if (uniqueList == null) {
+      uniqueList = new Hashtable<Integer, Integer>();
+      bsUniqueBonds = new BS();
+    }
+    uniqueList.put(Integer.valueOf(index), Integer.valueOf(uniqueID));
+    bsUniqueBonds.set(index);
+  }
+
+  void setStateCount(int stateCount) {
+    this.stateCount = stateCount;
+  }
+
+  /**
+   * Find the color setting and return an int AARRGGBB for it;
+   * Accept either an integer value or an (r,g,b) triplet
+   * @param i 
+   * @return AARRGGBB
+   */
   @SuppressWarnings("unchecked")
   private int colorSetting(int i) {
     Lst<Object> pos = PyMOLReader.listAt(settings, i);
@@ -297,6 +322,10 @@ class PyMOLScene implements JmolSceneGenerator {
   }
 
   private void getObjectSettings() {
+    stickBallRatio = floatSetting(PyMOL.stick_ball_ratio);
+    stickBalls = floatSetting(PyMOL.stick_ball);
+    stickRadius = floatSetting(PyMOL.stick_radius);
+    valence = floatSetting(PyMOL.valence);
     transparency = floatSetting(PyMOL.transparency);
     dotColor = (int) floatSetting(PyMOL.dot_color);
     nonbondedSize = floatSetting(PyMOL.nonbonded_size);
@@ -633,7 +662,8 @@ class PyMOLScene implements JmolSceneGenerator {
     // through all molecules...
     //    for (int m = moleculeNames.size(); --m >= 0;) {
     for (int m = 0; m < moleculeNames.size(); m++) {
-      setSceneObject(moleculeNames.get(m), thisState);
+      String name = moleculeNames.get(m);
+      setSceneObject(name, thisState);
       if (objectHidden)
         continue;
       BS[] molReps = new BS[PyMOL.REP_JMOL_MAX];
@@ -662,8 +692,6 @@ class PyMOLScene implements JmolSceneGenerator {
       bs.set(atomMap[PyMOLReader.intAt(list, i)]);
   }
 
-  private final P3 ptTemp = new P3();
-
   void setReaderObjects() {
     clearReaderData();
     finalizeObjects();
@@ -916,15 +944,50 @@ class PyMOLScene implements JmolSceneGenerator {
       icolor = atomColor;
     }
     if (labelPos == null) {
-      P3 offset = getUniquePoint(uniqueID, PyMOL.label_position, null);
-      if (offset == null)
-        offset = labelPosition;
-      else
-        offset.add(labelPosition);
-      setLabelPosition(offset, labelPos);
+      labelPos = setLabelPosition(
+          getUniquePoint(uniqueID, PyMOL.label_position, labelPosition),
+          labelPos, false);
+
+      // from pymol/data/setting_help.csv
+      //
+      //      "label_position","controls the position and alignment of labels in camera X, Y, and Z.  
+      //      Values between -1.0 and 1.0 affect alignment only, with the label attached to the atom position.  
+      //      Values beyond that range represent coordinate displacements.  
+      //      For the z dimension, values from -1 to 1 do not mean anything.  Values above 1 and below -1 are offsets 
+      //      (minus 1 of the absolute value) in world coordinates.  For example, the default 1.75 is .75 angstroms closer 
+      //      to the viewer.","vector","[0.0, 0.0, 1.75]","4"
+      //
+      //      "label_placement_offset","controls the position of labels in camera X, Y, and Z.  
+      //      This value is changed at the atom-state level when the labels are dragged with the mouse.  
+      //      This setting behaves similar to the label_position 
+      //      setting without the alignment functionality.","vector","[0.0, 0.0, 0.0]","4"
+      //
+      // THIS IS NOT HELPFUL!!!
+      // It is actually not this at all. 
+      // These are two completely different (and additive) parameters.
+      //
+      // label_placement sets the base location of the center of the label. 
+      // It is not in camera coordinates; it is in CARTESIAN space, a relative 
+      // offset from the atom coordinate.
+      // It is static, unless the atom is moved.
+      //
+      // label_position is completely different. "-1 to 1" relates to an alignment relative to centered:
+      //   -- horizontally, -1 is right-justified; +1 is left-justified
+      //      anything beyond 1 or -1 is ADDED to this justification in Angstroms
+      //   -- vertically -1 is top-aligned; +1 is bottom aligned, then similarly, 
+      //      any additional value is added in Angstroms (converted to screen coordinates).
+      //   -- forward/back is just the same, but there is no alignment, and the 
+      //      shift is Math.max(0, abs(value) - 1)*sign(value)
+      // This value is adjusted at rendering time, keeping the offset the same no matter how the
+      // molecule is rotated.
+
     }
-    labels.put(Integer.valueOf(atomIndex), newTextLabel(label, labelPos,
-        icolor, labelFontId, labelSize));
+    P3 offset = getUniquePoint(uniqueID, PyMOL.label_placement_offset, null);
+    if (offset != null) {
+      labelPos = setLabelPosition(offset, labelPos, true);
+    }
+    labels.put(Integer.valueOf(atomIndex),
+        newTextLabel(label, labelPos, icolor, labelFontId, labelSize));
   }
 
   float getUniqueFloatDef(int id, int key, float defaultValue) {
@@ -985,11 +1048,19 @@ class PyMOLScene implements JmolSceneGenerator {
     return setting;
   }
 
-  float[] setLabelPosition(P3 offset, float[] labelPos) {
-    labelPos[0] = 1;
-    labelPos[1] = offset.x;
-    labelPos[2] = offset.y;
-    labelPos[3] = offset.z;
+  float[] setLabelPosition(P3 offset, float[] labelPos, boolean isPlacement) {
+    if (labelPos == null)
+      labelPos = new float[7];
+    labelPos[0] = Text.PYMOL_LABEL_OFFSET_REL_ANG;
+    if (isPlacement) {
+      labelPos[4] = offset.x;
+      labelPos[5] = offset.y;
+      labelPos[6] = offset.z;
+    } else {
+      labelPos[1] = offset.x;
+      labelPos[2] = offset.y;
+      labelPos[3] = offset.z;
+    }
     return labelPos;
   }
 
@@ -1008,9 +1079,10 @@ class PyMOLScene implements JmolSceneGenerator {
     int n = (isNew ? list.size() / 3 / nCoord : mdList.length);
     if (n == 0)
       return false;
-    boolean drawLabel = haveLabels && bsReps.get(PyMOL.REP_LABELS);
-    boolean drawDashes = bsReps.get(PyMOL.REP_DASHES);
-    float rad = floatSetting(PyMOL.dash_width) / 20;
+    boolean drawLabel = haveLabels && (bsReps == null || bsReps.get(PyMOL.REP_LABELS));
+    boolean drawDashes = (bsReps == null || bsReps.get(PyMOL.REP_DASHES));
+   float rad = floatSetting(PyMOL.dash_width);
+   rad /= 400; // I don't know what these units are!
     if (rad == 0)
       rad = 0.05f;
     if (!drawDashes)
@@ -1031,10 +1103,10 @@ class PyMOLScene implements JmolSceneGenerator {
       if (isNew) {
         Lst<Object> points = new Lst<Object>();
         for (int i = 0; i < nCoord; i++, p += 3)
-          points.addLast(PyMOLReader.pointAt(list, p, new Point3fi()));
-        offset = PyMOLReader.floatsAt(PyMOLReader.listAt(offsets, index), 0, new float[7], 7);
+          points.addLast(newP3i(PyMOLReader.pointAt(list, p, new P3())));
+        offset = (PyMOLReader.floatsAt(PyMOLReader.listAt(offsets, index), 0, new float[7], 7));
         if (offset == null)
-          offset = setLabelPosition(labelPosition, new float[7]);
+          offset = setLabelPosition(labelPosition, new float[7], false);
         md = mdList[index] = vwr.newMeasurementData(objectNameID + "_"
             + (index + 1), points);
         md.note = objectName;
@@ -1042,20 +1114,29 @@ class PyMOLScene implements JmolSceneGenerator {
         md = mdList[index];
         offset = md.text.pymolOffset;
       }
+      offset = PyMOL.fixAllZeroLabelPosition(offset);
+      if (offset == null)
+        offset = new float[] {Text.PYMOL_LABEL_OFFSET_REL_ANG, 0, 0, 0, 0, 0, 0};
       int nDigits = (int) floatSetting(MEAS_DIGITS[nCoord - 2]);
       String strFormat = nCoord + ": "
           + (drawLabel ? "%0." + (nDigits < 0 ? 1 : nDigits) + "VALUE" : "");
       //strFormat += " -- " + objectNameID + " " + floatSetting(PyMOL.surface_color) + " " + Integer.toHexString(c);
+      float fontSize = floatSetting(PyMOL.label_size);
       Text text = newTextLabel(strFormat, offset, clabel,
-          (int) floatSetting(PyMOL.label_font_id),
-          floatSetting(PyMOL.label_size));
+          (int) floatSetting(PyMOL.label_font_id), fontSize);
       md.set(T.define, null, null, null, strFormat, "angstroms", null, false, false, null,
-          false, (int) (rad * 2000), colix, text, Float.NaN, null);
+          false,(int) (rad * 2000), colix, text, Float.NaN, null);
       addJmolObject(JC.SHAPE_MEASURES, bs, md);
     }
     return true;
   }
 
+  private static Point3fi newP3i(P3 p) {
+    Point3fi pi = new Point3fi();
+    pi.set(p.x, p.y, p.z);
+    return pi;
+  }
+
   SB getViewScript(Lst<Object> view) {
     SB sb = new SB();
     float[] pymolView = getPymolView(view, true);
@@ -1125,17 +1206,15 @@ class PyMOLScene implements JmolSceneGenerator {
     BS bsAtoms = htDefinedAtoms.get(objectJmolName);
     if (bsAtoms == null) {
       bsAtoms = BS.newN(ac0 + atomMap.length);
-      Logger.info("PyMOL molecule " + objectName);
+      Logger.info("PyMOL molecule " + objectName + " " + objectHidden);
       htDefinedAtoms.put(objectJmolName, bsAtoms);
       htObjectAtoms.put(objectName, bsAtoms);
       moleculeNames.addLast(objectName);
+      modelName = objectName;
     }
     return bsAtoms;
   }
-
-  private final static int[] MEAS_DIGITS = { PyMOL.label_distance_digits,
-      PyMOL.label_angle_digits, PyMOL.label_dihedral_digits };
-
+  
   private Text newTextLabel(String label, float[] labelOffset, int colorIndex,
                             int fontID, float fontSize) {
     // 0 GLUT 8x13 
@@ -1159,7 +1238,6 @@ class PyMOLScene implements JmolSceneGenerator {
     // 18 DejaVuSerif_BoldOblique
 
     String face;
-    float factor = 1f;
     switch (fontID) {
     default:
     case 11:
@@ -1204,8 +1282,17 @@ class PyMOLScene implements JmolSceneGenerator {
       style = "BoldItalic";
       break;
     }
-    Font font = vwr.getFont3D(face, style, fontSize == 0 ? 12 : fontSize
-        * factor);
+  
+// pymol/data/setting_help.csv   
+//    label_size  controls the approximate size of label text.  Negative values specify label size in world coordinates (e.g., -1. will show a label 1 angstrom in height)
+
+    if (fontSize > 0)
+      fontSize *= PYMOL_FONT_SIZE_FACTOR;
+    // PyMOL is using the front of the viewing box; Jmol uses the center, 
+    // so we boost this a bit to approximately match.
+    // note that this font could have negative size. 
+    // this means use angstroms
+    Font font = vwr.getFont3D(face, style, fontSize == 0 ? 12 : fontSize);
     Text t = Text.newLabel(vwr, font, label, getColix(
         colorIndex, 0), (short) 0, 0, 0);
     if (t != null)
@@ -1250,7 +1337,6 @@ class PyMOLScene implements JmolSceneGenerator {
   }
 
   private void fixReps(BS[] reps) {
-    htSpacefill.clear();
     bsCartoon.clearAll();
     for (int iAtom = bsAtoms.nextSetBit(0); iAtom >= 0; iAtom = bsAtoms
         .nextSetBit(iAtom + 1)) {
@@ -1265,11 +1351,7 @@ class PyMOLScene implements JmolSceneGenerator {
         rad = nonbondedSize;
       }
       if (rad != 0) {
-        Float r = Float.valueOf(rad);
-        BS bsr = htSpacefill.get(r);
-        if (bsr == null)
-          htSpacefill.put(r, bsr = new BS());
-        bsr.set(iAtom);
+        addSpacefill(iAtom, rad, true);
       }
       int cartoonType = (reader == null ? cartoonTypes[iAtom] : reader
           .getCartoonType(iAtom));
@@ -1317,6 +1399,17 @@ class PyMOLScene implements JmolSceneGenerator {
     bsCartoon.and(reps[PyMOL.REP_CARTOON]);
   }
 
+  void addSpacefill(int iAtom, float rad, boolean doCheck) {
+    if (doCheck && bsSpacefillSphere.get(iAtom))
+      return;
+    bsSpacefillSphere.set(iAtom);
+    Float r = Float.valueOf(rad);
+    BS bsr = htSpacefill.get(r);
+    if (bsr == null)
+      htSpacefill.put(r, bsr = new BS());
+    bsr.set(iAtom);
+  }
+
   /**
    * PyMOL does not display cartoons or traces for single-residue runs. This
    * two-pass routine first sets bits in a residue bitset, then it clears out
@@ -1468,7 +1561,9 @@ class PyMOLScene implements JmolSceneGenerator {
     float[] sizes = new float[n];
     for (int pt = 0, i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1), pt++) {
       int id = (reader == null ? uniqueIDs[i] : reader.getUniqueID(i));
-      if (colixes != null) {
+      if (setColor == 0) {
+        
+      } else {
         int c = (int) getUniqueFloatDef(id, setColor, color);
         if (c > 0)
           colixes[pt] = getColix(c, 0);
