@@ -38,7 +38,6 @@ import javajs.util.SB;
 import org.jmol.adapter.smarter.Atom;
 import org.jmol.quantum.QS;
 import org.jmol.util.Logger;
-import org.jmol.viewer.FileManager;
 import org.jmol.viewer.JC;
 import org.jmol.viewer.Viewer;
 
@@ -781,7 +780,7 @@ public class GenNBOReader extends MOReader {
    * @return true if sucessful or false if required file is missing
    */
   @SuppressWarnings("unchecked")
-  public static boolean readNBOCoefficients(Map<String, Object> moData, String nboType,
+  public boolean readNBOCoefficients(Map<String, Object> moData, String nboType,
                                    Viewer vwr) {
     int ext = JC.getNBOTypeFromName(nboType);
     boolean isAO = nboType.equals("AO");
@@ -937,8 +936,9 @@ public class GenNBOReader extends MOReader {
     if (nOrbitals == 0)
       return;
     line = null;
-    int pt = 0;
-    for (int i = nOrbitals0, n = nOrbitals0 + nOrbitals; i < n; i++, pt++) {
+    int pt = 0; 
+    // BH 2024.03.15 changed limit to + nNOs here. 
+    for (int i = nOrbitals0, n = nOrbitals0 + nNOs; i < n; i++, pt++) {
       if (pt == nNOs) {
         if (isNBO) {
           readNBO37Occupancies(pt);
