@@ -277,6 +277,11 @@ public class MoldenReader extends MopacSlaterReader {
         slater[1] = type;
         slater[2] = gaussianPtr + 1;
         slater[3] = nPrimitives;
+        int n = getDfCoefMaps()[type].length;
+        if (!haveCoefs) {
+          System.out.println(this.nCoef + " adding " + n + " coefficients type " + BasisFunctionReader.getQuantumShellTag(type) + " for atom " + atomIndex);
+          nCoef += n;
+        }
         for (int ip = nPrimitives; --ip >= 0;) {
           // Read ip primitives, each containing an exponent and one (s,p,d,f)
           // or two (sp) contraction coefficient(s)
