@@ -840,6 +840,9 @@ public class XmlCmlReader extends XmlReader {
       return;
     parent.setSpaceGroupName(localSpaceGroupName);
     parent.iHaveSymmetryOperators = iHaveSymmetryOperators;
+    if (parent == this)
+      super.applySymmetryAndSetTrajectory();
+    else
     parent.applySymmetryAndSetTrajectory();
   }
 
