@@ -44,14 +44,18 @@ package org.jmol.adapter.readers.xtal;
 
 import javajs.util.DF;
 import javajs.util.Lst;
+import javajs.util.M3;
 import javajs.util.M4;
 import javajs.util.PT;
 
 
 import org.jmol.adapter.smarter.AtomSetCollectionReader;
+import org.jmol.api.SymmetryInterface;
+import org.jmol.symmetry.SymmetryOperation;
 import org.jmol.adapter.smarter.Atom;
-import org.jmol.util.Escape;
 import org.jmol.util.Logger;
+import org.jmol.util.SimpleUnitCell;
+
 import javajs.util.P3;
 import org.jmol.util.Tensor;
 import javajs.util.V3;
@@ -116,9 +120,12 @@ public class CastepReader extends AtomSetCollectionReader {
 
   private String tsType;
 
+  private boolean allowSymmetryGeneration = true;
+
   @Override
   public void initializeReader() throws Exception {
     if (filter != null) {
+      allowSymmetryGeneration = !checkFilterKey("NOSYM");
       chargeType = getFilter("CHARGE=");
       if (chargeType != null && chargeType.length() > 4)
         chargeType = chargeType.substring(0, 4);
@@ -129,6 +136,7 @@ public class CastepReader extends AtomSetCollectionReader {
       if (!isAllQ && filter.indexOf("{") >= 0)
         setDesiredQpt(filter.substring(filter.indexOf("{")));
       filter = PT.rep(filter, "-PT", "");
+      
     }
     continuing = readFileData();
   }
@@ -189,7 +197,7 @@ public class CastepReader extends AtomSetCollectionReader {
   }
 
   private boolean readFileData() throws Exception {
-    while (tokenizeCastepCell() > 0)
+    while (tokenizeCastepCell() > 0) {
       if (tokens.length >= 2 && tokens[0].equalsIgnoreCase("%BLOCK")) {
         Logger.info(line);
         /*
@@ -238,7 +246,14 @@ public class CastepReader extends AtomSetCollectionReader {
           readPositionsAbs();
           continue;
         }
+        if (tokens[1].equalsIgnoreCase("SYMMETRY_OPS")) {
+          readSymmetryOps();
+          continue;
+        }
+      } else if (allowSymmetryGeneration && tokens[0].equalsIgnoreCase("SYMMETRY_GENERATE")) {
+        addJmolScript("print 'CastepReader SYMMETRY_GENERATE';modelkit spacegroup");
       }
+    }
     if (isPhonon || isOutput || isTS) {
       if (isPhonon) {
         isTrajectory = (desiredVibrationNumber <= 0);
@@ -249,6 +264,76 @@ public class CastepReader extends AtomSetCollectionReader {
     return false;
   }
 
+  /**
+   * Add the operators. The list is 3x3 rotation operator op3, followed by a
+   * translation t
+   * 
+   * For each op3 and t, given transpose(latt) and inv(transpose(latt)), we calculate:
+   * 
+   *  M4(lattTrInv * transpose(op3) * lattTr, t)
+   * 
+   * 
+   * @throws Exception
+   */
+  private void readSymmetryOps() throws Exception {
+//    %BLOCK symmetry_ops
+//    # Symm. op. 1       E
+//              1.000000000000000      -0.000000000000000       0.000000000000000
+//              0.000000000000000       1.000000000000000       0.000000000000000
+//              0.000000000000000       0.000000000000000       1.000000000000000
+//              0.000000000000000       0.000000000000000       0.000000000000000
+//    # Symm. op. 2     6_3
+//              0.500000000000000       0.866025403784439       0.000000000000000
+//             -0.866025403784438       0.500000000000000       0.000000000000000
+//              0.000000000000000       0.000000000000000       1.000000000000000
+//              0.000000000000000       0.000000000000000       0.500000000000000
+    // generate the transpose of the lattice and its inverse
+    if (lattTr == null) {
+      setLatticeVectors();
+      SymmetryInterface uc = getSymmetry().setUnitCellFromParams(unitCellParams, false, 0.0001f);
+      P3[] vecs = uc.getUnitCellVectors();
+      lattTr = new M3();
+      lattTr.setColumnV(0, vecs[1]);
+      lattTr.setColumnV(1, vecs[2]);
+      lattTr.setColumnV(2, vecs[3]);
+    }
+    M3 lattTrInv = M3.newM3(lattTr);
+    lattTrInv.invert();
+    M4 op = new M4();
+    int nop = 0;
+    tokenizeCastepCell();
+    while (tokens.length > 0
+        && !tokens[0].equalsIgnoreCase("%ENDBLOCK")) {
+      M3 op3 = new M3();
+      P3 t = new P3();
+      for (int i = 0; i < 4; i++) {
+        if (tokens.length >= 3) {
+          float x = parseCalcStr(tokens[0]);
+          float y = parseCalcStr(tokens[1]);
+          float z = parseCalcStr(tokens[2]);
+          if (i < 3) {
+            op3.setColumn3(i, x, y, z);
+          } else {
+            t.set(x, y, z);
+          }
+        } else {
+          Logger.warn("cannot read line with CASTEP symmetr_ops: " + line);
+        }
+        tokenizeCastepCell();
+      }
+      //System.out.println(op3);
+      op3.mul2(op3, lattTr);
+      op3.mul2(lattTrInv, op3);
+      op.setMV(op3, t);
+      //System.out.println(op);
+      String xyz = SymmetryOperation.getXYZFromMatrix(op, false, true, false);
+      nop++;
+      Logger.info("CASTEP reader op[" + nop+ "] = " + xyz);
+      setSymmetryOperator(xyz);
+    }
+  }
+  
+
   @Override
   protected boolean checkLine() throws Exception {
     // only for .phonon, castep output, or other BEGIN HEADER type files
@@ -426,9 +511,9 @@ public class CastepReader extends AtomSetCollectionReader {
       return;
     float factor = readLengthUnit(tokens[0]);
     if (tokens.length >= 3) {
-      a = parseFloatStr(tokens[0]) * factor;
-      b = parseFloatStr(tokens[1]) * factor;
-      c = parseFloatStr(tokens[2]) * factor;
+      a = parseCalcStr(tokens[0]) * factor;
+      b = parseCalcStr(tokens[1]) * factor;
+      c = parseCalcStr(tokens[2]) * factor;
     } else {
       Logger
           .warn("error reading a,b,c in %BLOCK LATTICE_ABC in CASTEP .cell file");
@@ -438,26 +523,30 @@ public class CastepReader extends AtomSetCollectionReader {
     if (tokenizeCastepCell() == 0)
       return;
     if (tokens.length >= 3) {
-      alpha = parseFloatStr(tokens[0]);
-      beta = parseFloatStr(tokens[1]);
-      gamma = parseFloatStr(tokens[2]);
+      alpha = parseCalcStr(tokens[0]);
+      beta = parseCalcStr(tokens[1]);
+      gamma = parseCalcStr(tokens[2]);
     } else {
       Logger
           .warn("error reading alpha,beta,gamma in %BLOCK LATTICE_ABC in CASTEP .cell file");
     }
   }
 
+  private M3 lattTr;
+  
   private void readLatticeCart() throws Exception {
     if (tokenizeCastepCell() == 0)
       return;
     float factor = readLengthUnit(tokens[0]);
     float x, y, z;
+    lattTr = new M3();
     for (int i = 0; i < 3; i++) {
       if (tokens.length >= 3) {
-        x = parseFloatStr(tokens[0]) * factor;
-        y = parseFloatStr(tokens[1]) * factor;
-        z = parseFloatStr(tokens[2]) * factor;
+        x = parseCalcStr(tokens[0]) * factor;
+        y = parseCalcStr(tokens[1]) * factor;
+        z = parseCalcStr(tokens[2]) * factor;
         abc[i] = V3.new3(x, y, z);
+        lattTr.setColumnV(i, abc[i]);
       } else {
         Logger.warn("error reading coordinates of lattice vector "
             + Integer.toString(i + 1)
@@ -475,6 +564,16 @@ public class CastepReader extends AtomSetCollectionReader {
     gamma = (float) (abc[0].angle(abc[1]) * RAD_TO_DEG);
   }
 
+  private static String[] functions = { "sqrt","sin","cos","tan", "+", "-", "*", "/"}; 
+
+  private float parseCalcStr(String s) {
+    float f = SimpleUnitCell.parseCalc(vwr, functions, s);
+    if (Float.isNaN(f)) {
+      Logger.error("CASTEP math error in " + s);
+    }
+    return f;
+  }
+
   private void readPositionsFrac() throws Exception {
     if (tokenizeCastepCell() == 0)
       return;
@@ -520,8 +619,8 @@ public class CastepReader extends AtomSetCollectionReader {
           atom.elementSymbol = tokens[0];
         }
         
-        atom.set(parseFloatStr(tokens[1]), parseFloatStr(tokens[2]),
-            parseFloatStr(tokens[3]));
+        atom.set(parseCalcStr(tokens[1]), parseCalcStr(tokens[2]),
+            parseCalcStr(tokens[3]));
         atom.scale(factor);
       } else {
         Logger.warn("cannot read line with CASTEP atom data: " + line);
@@ -584,14 +683,9 @@ public class CastepReader extends AtomSetCollectionReader {
   }
 
   private void getTensor(Atom atom, String line0) throws Exception {
-    float[] data = new float[9];
-    double[][] a = new double[3][3];
-    fillFloatArray(line0, 0, data);
-    Logger.info("tensor " +  atom.atomName 
-        + "\t" +Escape.eAF(data)); 
-    for (int p = 0, i = 0; i < 3; i++)
-      for (int j = 0; j < 3; j++)
-        a[i][j] = data[p++];
+    line0 += rd() + rd();
+    Logger.info("tensor " +  atom.atomName + " " + line0); 
+    double[][] a = fill3x3(PT.getTokens(line0), 0);
     atom.addTensor((new Tensor()).setFromAsymmetricTensor(a, "charge", atom.atomName + " " + line0), null, false);
     if (!haveCharges)
       appendLoadNote("Ellipsoids set \"charge\": Born Effective Charges");
