@@ -6,7 +6,7 @@ import java.util.Map;
 
 import org.jmol.adapter.smarter.AtomSetCollectionReader;
 import org.jmol.adapter.smarter.Atom;
-import org.jmol.api.SymmetryInterface;
+import org.jmol.adapter.smarter.XtalSymmetry.FileSymmetry;
 
 import javajs.util.PT;
 import javajs.util.V3;
@@ -305,7 +305,7 @@ public class GulpReader extends AtomSetCollectionReader {
   public void applySymmetryAndSetTrajectory() throws Exception {
     if (coordinatesArePrimitive && iHaveUnitCell && doCheckUnitCell && primitiveData != null && !isPrimitive) {
       setModelParameters(false);
-      SymmetryInterface symFull = symmetry;
+      FileSymmetry symFull = symmetry;
       setModelParameters(true);
       // Full cell -- must convert primitive to conventional
       
@@ -316,8 +316,7 @@ public class GulpReader extends AtomSetCollectionReader {
         Atom atom = atoms[i];
         symmetry.toCartesian(atom, true);
         symFull.toFractional(atom, true);
-        if (fixJavaFloat)
-          PT.fixPtFloats(atom, PT.FRACTIONAL_PRECISION);
+        fixFloatPt(atom, PT.FRACTIONAL_PRECISION);
       }
       setModelParameters(false);
     }
