@@ -31,7 +31,7 @@ import org.jmol.adapter.smarter.Atom;
 import org.jmol.adapter.smarter.AtomSetCollectionReader;
 import org.jmol.adapter.smarter.MSInterface;
 import org.jmol.api.Interface;
-import org.jmol.api.SymmetryInterface;
+import org.jmol.adapter.smarter.XtalSymmetry.FileSymmetry;
 import javajs.util.BS;
 
 import javajs.util.A4;
@@ -937,7 +937,7 @@ public class JanaReader extends AtomSetCollectionReader {
   private void adjustM40Occupancies() {
     Map<String, Integer> htSiteMult = new Hashtable<String, Integer>();    
     Atom[] atoms = asc.atoms;
-    SymmetryInterface symmetry = asc.getSymmetry();
+    FileSymmetry symmetry = asc.getSymmetry();
     for (int i = asc.ac; --i >= 0;) {
       Atom a = atoms[i];
       Integer ii = htSiteMult.get(a.atomName);
