@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2024-03-15 17:42:21 -0500 (Fri, 15 Mar 2024) $
- * $Revision: 22610 $
+ * $Date: 2024-09-06 21:43:08 -0500 (Fri, 06 Sep 2024) $
+ * $Revision: 22632 $
  *
  * Copyright (C) 2003-2005  Miguel, Jmol Development, www.jmol.org
  *
@@ -830,9 +830,9 @@ public class AtomSetCollection {
         atoms[i].setT(trajectory[ii]);
       ii++;
     }
-    setInfo("trajectorySteps", trajectorySteps);
+    setInfo(JC.INFO_TRAJECTORY_STEPS, trajectorySteps);
     if (vibrationSteps != null)
-      setInfo("vibrationSteps", vibrationSteps);
+      setInfo(JC.INFO_VIBRATION_STEPS, vibrationSteps);
     if (ac == 0)
       ac = trajectory.length;
   }
@@ -1135,7 +1135,7 @@ public class AtomSetCollection {
       return;
     for (int i = 0; i < a.trajectoryStepCount; i++)
       trajectorySteps.add(trajectoryStepCount++, a.trajectorySteps.get(i));
-    setInfo("trajectorySteps", trajectorySteps);
+    setInfo(JC.INFO_TRAJECTORY_STEPS, trajectorySteps);
     setInfo("ignoreUnitCell", a.atomSetInfo.get("ignoreUnitCell"));
   }
 
@@ -1261,10 +1261,6 @@ public class AtomSetCollection {
         bsAtoms.clear(b.atomIndex1);
       }
     }
-
-    // TODO
-    
   }
 
-
 }
