@@ -423,13 +423,15 @@ public abstract class AtomSetCollectionReader implements GenericLineReader {
   protected void initializeTrajectoryFile() {
     // add a dummy atom, just so not "no atoms found"
     asc.addAtom(new Atom());
-    trajectorySteps = (Lst<P3[]>) htParams.get("trajectorySteps");
+    trajectorySteps = (Lst<P3[]>) htParams.get(JC.INFO_TRAJECTORY_STEPS);
     if (trajectorySteps == null)
-      htParams.put("trajectorySteps", trajectorySteps = new Lst<P3[]>());
+      htParams.put(JC.INFO_TRAJECTORY_STEPS, trajectorySteps = new Lst<P3[]>());
   }
 
-  /**
-   * optional reader-specific method run first.
+  /*
+   * Optional reader-specific method run first. May or may not call
+   * finalizeReaderASCR(), when symmetry for the last model is finalized if
+   * necessary.
    * 
    * @throws Exception
    */
@@ -750,19 +752,32 @@ public abstract class AtomSetCollectionReader implements GenericLineReader {
   /**
    * Track the precision (count of y digits in "xx.yyyy") for setting cellSlop.
    * 
-   * We assume that with the numbers 0.25 0.33333 that the precision is really 5, not 2.
+   * We assume that with the numbers 0.25 0.33333 that the precision is really
+   * 5, not 2.
+   * 
+   * Note that in the end, the precision will never be set lower than 4. 
    * 
    * @param s
    * @return parsed number
    */
   protected float parsePrecision(String s) {
-    // will be double in JavaScript
-    // Max of xx.yyyyy  number of y digits.
+    // xx.yyyyy  max of current precision and number of y digits (5 here).
+    // xx.yyyyy(zz) min of current precision and number of y digits - 1 (4 here)
+    // I considered subtracting the number of z digits, 
+    // but I think that is probably too extreme. 
+    // this fixes the Wyckoff calculation for CSD XAZTAW and BROFRM05
+    
     if (!filteredPrecision) {
       int pt = s.indexOf('.') + 1;
       if (pt >= 0) {
         int n = s.indexOf('(');
-        precision = Math.max(precision, (n < 0 ? s.length() : n) - pt);
+        if (n < 0) {
+          precision = Math.max(precision, s.length() - pt);          
+        } else {
+          if (precision == 0)
+            precision = n;
+          precision = Math.min(precision, n - 1 - pt);
+        } 
       }
     }
     return parseFloatStr(s);
@@ -789,6 +804,7 @@ public abstract class AtomSetCollectionReader implements GenericLineReader {
       precision = 4; // legacy
     } else {
       if (precision > 1000) {
+        // from filter "PRECISION=n"
         precision -= 1000;
       } else {
         // packingRange must be null
@@ -941,7 +957,7 @@ public abstract class AtomSetCollectionReader implements GenericLineReader {
       return -1;
     int isym = asc.getXSymmetry().addSpaceGroupOperation(xyz, true);
     if (isym < 0)
-      Logger.warn("Skippings symmetry operation " + xyz);
+      Logger.warn("Skipping symmetry operation " + xyz);
     iHaveSymmetryOperators = true;
     return isym;
   }
