@@ -2,7 +2,7 @@ package org.jmol.adapter.smarter;
 
 import java.util.Map;
 
-import org.jmol.api.SymmetryInterface;
+import org.jmol.adapter.smarter.XtalSymmetry.FileSymmetry;
 
 import javajs.util.Lst;
 import javajs.util.Matrix;
@@ -15,7 +15,7 @@ import javajs.util.P3;
  */
 public interface MSInterface {
 
-  // methods called from org.jmol.adapters.readers.xtal.JanaReader
+  // methods called from org.jmol.adapter.readers.xtal.JanaReader
   
   void addModulation(Map<String, double[]> map, String id, double[] pt, int iModel);
 
@@ -27,13 +27,13 @@ public interface MSInterface {
 
   int initialize(AtomSetCollectionReader r, int modDim) throws Exception;
 
-  void setModulation(boolean isPost, SymmetryInterface symmetry) throws Exception;
+  void setModulation(boolean isPost, FileSymmetry symmetry) throws Exception;
 
-  SymmetryInterface getAtomSymmetry(Atom a, SymmetryInterface symmetry);
+  FileSymmetry getAtomSymmetry(Atom a, FileSymmetry symmetry);
 
   void setMinMax0(P3 minXYZ0, P3 maxXYZ0);
 
-  SymmetryInterface getSymmetryFromCode(String spaceGroupOperationCode);
+  FileSymmetry getSymmetryFromCode(String spaceGroupOperationCode);
 
   boolean addLatticeVector(Lst<float[]> lattvecs, String substring) throws Exception;
 
