@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2024-04-16 21:43:34 -0500 (Tue, 16 Apr 2024) $
- * $Revision: 22613 $
+ * $Date: 2024-08-15 08:50:13 -0500 (Thu, 15 Aug 2024) $
+ * $Revision: 22630 $
  *
  * Copyright (C) 2003-2005  Miguel, Jmol Development, www.jmol.org
  *
@@ -339,24 +339,63 @@ public class Resolver {
   // Test 2. check to see if first few bytes (trimmed) start with any of these strings
   ////////////////////////////////////////////////////////////////
 
-  private static byte[] cdxMagic = new byte[] { 'V', 'j', 'C', 'D' };
+  private static byte[] cdxMagic = new byte[] { 0+'V', 0+'j', 0+'C', 0+'D' };
   
-  private static byte[] cmdfMagic = new byte[] { 'C', 'M', 'D', 'F' };
+  private static byte[] cmdfMagic = new byte[] { 0+'C', 0+'M', 0+'D', 0+'F' };
+
+  private static byte[] mmtfMagic = new byte[] { 0+'m', 0+'m', 0+'t', 0+'f' };
+
+  // various flavors of BCIF file format
+
+  private static byte[] bcifMolstarMagic = new byte[] { 0+'m', 0+'o', 0+'l', 0+'*' };
+
+  private static byte[] bcifDensityMagic = new byte[] { 0+'D', 0+'e', 0+'n', 0+'s' };
+
+  private static byte[] bcifVolumeMagic = new byte[] { 0+'V', 0+'o', 0+'l', 0+'u' };
+
+  private static byte[] bcifModelMagic = new byte[] { 0+'M', 0+'o', 0+'d', 0+'e' };
+
+  private static byte[] bcifCoordMagic = new byte[] { 0+'C', 0+'o', 0+'o', 0+'r', 0+'d'};
+
+  private static byte[] bcifServerMagic = new byte[] { 0+'S', 0+'E', 0+'R', 0+'V', 0+'E', 0+'R'};
 
   public static String getBinaryType(InputStream inputStream) {
-    byte[] magic4 = null;
-    return (Rdr.isPickleS(inputStream) ? "PyMOL" 
-        : (Rdr.getMagic(inputStream, 1)[0] & 0xFF) == 0xDE ? "MMTF" 
-        : (Rdr.getMagic(inputStream, 10)[9] & 0xFF) == 0xB6 ? "BCIF" 
-        : bytesMatch((magic4 = Rdr.getMagic(inputStream, 4)), cdxMagic) ? "CDX" 
-        : bytesMatch(magic4, cmdfMagic) ? "Cmdf" : null);
+    byte[] magic = Rdr.getMagic(inputStream, 100);
+    int m0 = magic[0] & 0xff;
+    return (Rdr.isPickleB(magic) ? "PyMOL" 
+        : m0 == 0xDE ? (bytesMatch(magic, 4, mmtfMagic) ? "MMTF" : null)
+        : m0 == 0x83 ? (checkBCIF(magic, true) ? "BCIF" : null) 
+        : bytesMatch(magic, 0, cdxMagic) ? "CDX" 
+        : bytesMatch(magic, 0, cmdfMagic) ? "Cmdf" 
+        : null);
   }
 
-  private static boolean bytesMatch(byte[] a, byte[] b) {
-    if (b.length > a.length)
+  public static boolean checkBCIF(byte[] magic, boolean forCoord) {
+    if (bytesMatch(magic, 10, bcifMolstarMagic) || bytesMatch(magic, 10, bcifModelMagic)
+        || bytesMatch(magic, 10, bcifModelMagic)
+        || bytesMatch(magic, 10, bcifCoordMagic))
+      return forCoord;
+    if (bytesMatch(magic, 10, bcifDensityMagic) || bytesMatch(magic, 10, bcifVolumeMagic))
+      return !forCoord;
+    return ((findBytes(magic, bcifServerMagic) < 0) == forCoord);
+  }
+
+  private static int findBytes(byte[] bytes, byte[] find) {
+    out: for (int j = bytes.length - find.length; --j >= 0;) {
+      for (int i = find.length; --i >= 0;) {
+        if (bytes[j + i] != find[i])
+          continue out;
+      }
+      return j;
+    }
+    return -1;
+  }
+
+  private static boolean bytesMatch(byte[] a, int pt, byte[] b) {
+    if (b.length > a.length - pt)
       return false;
     for (int i = b.length; --i >= 0;) {
-      if (a[i] != b[i])
+      if (a[pt + i] != b[i])
         return false;
     }
     return true;
