@@ -1,9 +1,12 @@
 package org.jmol.adapter.writers;
 
+import org.jmol.api.JmolDataManager;
 import org.jmol.api.JmolWriter;
 import org.jmol.api.SymmetryInterface;
 import org.jmol.modelset.Atom;
+import org.jmol.util.BSUtil;
 import org.jmol.util.SimpleUnitCell;
+import org.jmol.viewer.JC;
 import org.jmol.viewer.Viewer;
 
 import javajs.util.BS;
@@ -42,29 +45,37 @@ public class CIFWriter extends XtlWriter implements JmolWriter {
   public String write(BS bs) {
     if (bs == null)
       bs = vwr.bsA();
+    else
+      bs = BSUtil.copy(bs);      
     try {
-      short mi = vwr.ms.at[bs.nextSetBit(0)].mi;
-
-      SymmetryInterface uc = vwr.getCurrentUnitCell();
+      // note that this is confined to the FIRST model in the set. 
+      // TODO allow multiple unit cells? 
+      int mi = vwr.ms.at[bs.nextSetBit(0)].mi;
+      int n0 = bs.cardinality();
+      bs.and(vwr.getModelUndeletedAtomsBitSet(mi));
+      if (n0 < bs.cardinality()) {
+        System.err.println("CIFWriter Warning: Atoms not in model " + (mi + 1) + " ignored");
+      }
+      SymmetryInterface uc = vwr.ms.getUnitCell(mi);
       haveUnitCell = (uc != null);
       if (!haveUnitCell)
         uc = vwr.getSymTemp().setUnitCellFromParams(null, false, 0.00001f);
       slop = uc.getPrecision();
-      isHighPrecision = (slop == SimpleUnitCell.SLOPDP);
       precision = (int) -Math.log10(slop);
-      P3 offset = uc.getFractionalOffset();
-      boolean fractionalOffset = offset != null && (offset.x != (int) offset.x
-          || offset.y != (int) offset.y || offset.z != (int) offset.z);
+      isHighPrecision = (slop == SimpleUnitCell.SLOPDP); // not used in legacy Jmol
+      boolean fractionalOffset = (uc.getFractionalOffset(true) != null);
       T3 fset;
       boolean haveCustom = (fractionalOffset
           || (fset = uc.getUnitCellMultiplier()) != null
               && (fset.z == 1 ? !fset.equals(fset0) : fset.z != 0));
       SymmetryInterface ucm = uc.getUnitCellMultiplied();
-      isP1 = (isP1 || ucm != uc || fractionalOffset || uc.getSpaceGroupOperationCount() < 2);
+      isP1 = (isP1 || ucm != uc || fractionalOffset 
+    		  || uc.getSpaceGroupOperationCount() < 2);
       uc = ucm;
-
       // only write the asymmetric unit set
-      BS modelAU = (!haveUnitCell ? bs : isP1 ? uc.removeDuplicates(vwr.ms, bs, false) : vwr.ms.am[mi].bsAsymmetricUnit);
+      BS modelAU = (!haveUnitCell ? bs 
+    		  : isP1 ? uc.removeDuplicates(vwr.ms, bs, false) // in SwingJS this is isHighPrecision
+    				  : vwr.ms.am[mi].bsAsymmetricUnit);
       BS bsOut;
       if (modelAU == null) {
         bsOut = bs;
@@ -105,9 +116,9 @@ public class CIFWriter extends XtlWriter implements JmolWriter {
         n = 0;
       } else {
         uc.getSpaceGroupInfo(vwr.ms, null, mi, true, null);
-        ita = uc.getSpaceGroupNameType("ITA");
-        hallName = uc.getSpaceGroupNameType("Hall");
-        hmName = uc.getSpaceGroupNameType("HM");
+        ita = uc.geCIFWriterValue(JC.INFO_ITA);
+        hallName = uc.geCIFWriterValue(JC.INFO_HALL);
+        hmName = uc.geCIFWriterValue(JC.INFO_HM);
         n = uc.getSpaceGroupOperationCount();
       }
       appendKey(sb, "_space_group_IT_number")
@@ -144,27 +155,39 @@ public class CIFWriter extends XtlWriter implements JmolWriter {
           }
         }
       }
+      boolean haveAltLoc = false;
+      for (int i = bsOut.nextSetBit(0); i >= 0; i = bsOut.nextSetBit(i + 1)) {
+        if (atoms[i].altloc != '\0') {
+          haveAltLoc = true;
+          break;
+        }
+      }
+      float[] parts = (haveAltLoc ? (float[]) vwr.getDataObj("property_part", bsOut, JmolDataManager.DATA_TYPE_AF) : null);
+      
       int sbLength = sb.length();
       
       sb.append("\n" + "\nloop_" + "\n_atom_site_label"
           + "\n_atom_site_type_symbol" + "\n_atom_site_fract_x"
           + "\n_atom_site_fract_y" + "\n_atom_site_fract_z");
+      if (haveAltLoc) {
+        sb.append("\n_atom_site_disorder_group");
+      }
       if (haveOccupancy) {
         sb.append("\n_atom_site_occupancy");
-      } else if (!haveUnitCell)
+      } else if (!haveUnitCell) {
         sb.append("\n_atom_site_Cartn_x" + "\n_atom_site_Cartn_y"
             + "\n_atom_site_Cartn_z");
+      }
       sb.append("\n");
 
       SB jmol_atom = new SB();
-      jmol_atom.append("\n" + "\nloop_" + "\n_jmol_atom_index" + "\n_jmol_atom_name"
-          + "\n_jmol_atom_site_label\n");
+      jmol_atom.append("\n" + "\nloop_" + "\n_jmol_atom_index"
+          + "\n_jmol_atom_name" + "\n_jmol_atom_site_label\n");
 
       int nAtoms = 0;
       P3 p = new P3();
       int[] elemNums = new int[130];
-      for (int i = bsOut.nextSetBit(0); i >= 0; i = bsOut
-          .nextSetBit(i + 1)) {
+      for (int pi = 0, i = bsOut.nextSetBit(0); i >= 0; i = bsOut.nextSetBit(i + 1)) {
         Atom a = atoms[i];
         p.setT(a);
         if (haveUnitCell) {
@@ -183,10 +206,19 @@ public class CIFWriter extends XtlWriter implements JmolWriter {
         String label = sym + ++elemNums[elemno];
         
         sb.append(PT.formatS(label, 5, 0, true, false)).append(" ")
-        .append(PT.formatS(sym, 3, 0, true, false))
-        .append(clean(p.x))
-        .append(clean(p.y))
-        .append(clean(p.z));
+            .append(PT.formatS(sym, 3, 0, true, false)).append(clean(p.x))
+            .append(clean(p.y)).append(clean(p.z));
+        if (haveAltLoc) {
+          sb.append(" ");
+          String sdis;
+          if (parts != null) {
+            int part = (int) parts[pi++];
+            sdis = (part == 0 ? "." : "" + part);
+          } else {
+            sdis = "" + (a.altloc == '\0' ? '.' : a.altloc);
+          }
+          sb.append(sdis);
+          }
         if (haveOccupancy) 
           sb.append(" ").append(clean(occ[i]/100));
         else if (!haveUnitCell)
