@@ -8,9 +8,9 @@ import org.jmol.api.JmolWriter;
 import org.jmol.api.SymmetryInterface;
 import org.jmol.modelset.Atom;
 import org.jmol.util.Logger;
+import org.jmol.util.SimpleUnitCell;
 import org.jmol.viewer.Viewer;
 
-import javajs.util.AU;
 import javajs.util.BS;
 import javajs.util.Lst;
 import javajs.util.OC;
@@ -40,7 +40,7 @@ public class PWMATWriter extends XtlWriter implements JmolWriter {
 
   
   public PWMATWriter() {
-    // for JavaScript dynamic loading
+    isHighPrecision = true;
   }
 
   @Override
@@ -82,7 +82,7 @@ public class PWMATWriter extends XtlWriter implements JmolWriter {
       uc = vwr.getSymTemp();
       V3 bb = vwr.getBoundBoxCornerVector();
       float len = Math.round(bb.length() * 2);
-      uc.setUnitCell(new float[] { len, len, len, 90, 90, 90 }, false);
+      uc.setUnitCellFromParams(new float[] { len, len, len, 90, 90, 90 }, false, SimpleUnitCell.SLOPDP);
     }
     P3[] abc = uc.getUnitCellVectors();
     String f = "%18.10p%18.10p%18.10p\n";
