@@ -92,12 +92,10 @@ public interface GenericPlatform extends FontManager {
    * @param width
    * @param height
    * @param pixels 
-   * @param startRow 
-   * @param nRows 
    * @return         pixels
    */
   int[] grabPixels(Object image, int width, int height, 
-                   int[] pixels, int startRow, int nRows);
+                   int[] pixels);
 
   /**
    * can be ignored (return false) if platform cannot save images
