@@ -7,7 +7,7 @@ import javajs.util.V3;
 
 public interface JmolModulationSet {
 
-  Object getModulation(char type, T3 t456);
+  Object getModulation(char type, T3 t456, boolean occ100);
 
   String getState();
 
