@@ -37,11 +37,11 @@ public interface SymmetryInterface {
 
   void getEquivPointList(Lst<P3> pts, int nIgnore, String flags, M4[] opsCtr);
 
-  P3 getFractionalOffset();
+  P3 getFractionalOffset(boolean onlyIfFractional);
 
   String getIntTableNumber();
 
-  String getIntTableNumberFull();
+  String getSpaceGroupJmolId();
 
   int getLatticeOp();
 
@@ -66,12 +66,7 @@ public interface SymmetryInterface {
 
   String getSpaceGroupName();
 
-  /**
-   * 
-   * @param type "Hall" or "HM" or "ITA"
-   * @return type or null
-   */
-  String getSpaceGroupNameType(String type);
+  String geCIFWriterValue(String type);
 
   M4 getSpaceGroupOperation(int i);
   
@@ -207,6 +202,8 @@ public interface SymmetryInterface {
 
   P3[] getCanonicalCopy(float scale, boolean withOffset);
 
+  P3[] getCanonicalCopyTrimmed(P3 frac, float scale);
+
   Lst<P3> getLatticeCentering();
 
   Object getLatticeDesignation();
@@ -244,7 +241,7 @@ public interface SymmetryInterface {
   
   Object getWyckoffPosition(Viewer vwr, P3 pt, String letter);
 
-  Object getSpaceGroupJSON(Viewer vwr, String name, Object data, int index);
+  Object getSpaceGroupJSON(Viewer vwr, String name, String data, int index);
 
   float getCellWeight(P3 pt);
 
@@ -272,9 +269,29 @@ public interface SymmetryInterface {
   
   String staticToRationalXYZ(P3 fPt, String sep);
 
-  String getClegId();
+  String getSpaceGroupClegId();
 
   int getFinalOperationCount();
   
   Object convertTransform(String transform, M4 trm);
+
+  String[] getSymopList(boolean normalize);
+
+  /**
+   * for Viewer.getSymStatic only
+   * @param vwr
+   * @return this
+   */
+  SymmetryInterface setViewer(Viewer vwr);
+
+  M4 staticGetMatrixTransform(String cleg);
+
+  String staticTransformSpaceGroup(BS bs, String cleg, Object paramsOrUC, SB sb);
+  
+  int getPeriodicity();
+
+  int getDimensionality();
+
+  P3 getUnitCellCenter();
+
 }
