@@ -39,8 +39,6 @@ import java.beans.PropertyChangeSupport;
 import java.io.File;
 import java.util.List;
 
-import javax.swing.text.JTextComponent;
-
 import org.jmol.api.JmolDropEditor;
 import org.jmol.api.JmolScriptManager;
 import org.jmol.api.JmolStatusListener;
@@ -81,7 +79,7 @@ public class FileDropper implements DropTargetListener {
         doDrop(evt);
       }
     }));
-    Component display = (Component) vwr.display;
+    Component display = (vwr == null ? (Component) dropListener : (Component) vwr.display);
     display.setDropTarget(new DropTarget(display, this));
     display.setEnabled(true);
     //System.out.println("File dropper enabled for " + display);
