@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-02-20 18:01:18 -0600 (Sun, 20 Feb 2022) $
- * $Revision: 22345 $
+ * $Date: 2024-04-14 22:04:09 -0500 (Sun, 14 Apr 2024) $
+ * $Revision: 22612 $
  *
  * Copyright (C) 2004-2005  The Jmol Development Team
  *
@@ -232,7 +232,7 @@ public class AppletConsole extends JmolConsole {
   @Override
   public void setVisible(boolean visible) {
     super.setVisible(visible);
-    ((JTextArea) input).requestFocus();
+    regainFocus();
   }
 
   @Override
@@ -244,7 +244,7 @@ public class AppletConsole extends JmolConsole {
   protected void execute(String strCommand) {
     super.execute(strCommand);
     if (strCommand == null)
-      ((JTextArea) input).requestFocus();
+      regainFocus();
   }
 
   class ControlEnterTextArea extends JTextArea implements GenericConsoleTextArea {
@@ -265,4 +265,11 @@ public class AppletConsole extends JmolConsole {
     }
   }
   
+  @Override
+  public void regainFocus() {
+    ((JTextArea) input).requestFocus();
+  }
+  
+
+  
 }
