@@ -229,7 +229,7 @@ public abstract class GenericConsole implements JmolAppConsoleInterface, JmolCal
     String cmd = (strCommand == null ? input.getText() : strCommand);
     if (strCommand == null)
       input.setText(null);
-    String strErrorMessage = vwr.script(cmd + JC.SCRIPT_GUI + JC.SCRIPT_EDITOR_IGNORE);
+    String strErrorMessage = vwr.script(cmd + JC.SCRIPT_CONSOLE);
     if (strErrorMessage != null && !strErrorMessage.equals("pending"))
       outputMsg(strErrorMessage);
   }
@@ -342,8 +342,9 @@ public abstract class GenericConsole implements JmolAppConsoleInterface, JmolCal
       if (mystatus.indexOf("Picked") >= 0 || mystatus.indexOf("Sequence") >= 0) // picking mode
         sendConsoleMessage(strInfo);
       else if (mystatus.indexOf("Completed") >= 0)
-        sendConsoleEcho(strInfo.substring(strInfo.lastIndexOf(",") + 2,
-            strInfo.length() - 1));
+        sendConsoleEcho(strInfo);
+//        sendConsoleEcho(strInfo.substring(strInfo.lastIndexOf(",") + 2,
+//            strInfo.length() - 1));
       break;
     case MESSAGE:
       sendConsoleMessage(data == null ? null : strInfo);
@@ -430,7 +431,10 @@ public abstract class GenericConsole implements JmolAppConsoleInterface, JmolCal
   }
   
   protected String trimGUI(String cmd) {
-    int pt = cmd.indexOf(JC.SCRIPT_GUI);
+    int pt = cmd.indexOf(JC.SCRIPT_EXT);
+    if (pt >= 0)
+      cmd = cmd.substring(0, pt);
+    pt = cmd.indexOf(JC.SCRIPT_GUI);
     if (pt >= 0)
       cmd = cmd.substring(0, pt);
    return PT.trim(cmd, "; ");
