@@ -313,8 +313,8 @@ abstract public class __CartesianExporter extends ___Exporter {
     }    
     // vectors, polyhedra
     // was (int) in older version
-    int mad = Math.round(vwr.tm.unscaleToScreen((screenA.z + screenB.z) / 2,
-        screenDiameter) * 1000);
+    int mad = (screenDiameter < 0 ? -screenDiameter * 10 : Math.round(vwr.tm.unscaleToScreen((screenA.z + screenB.z) / 2,
+        screenDiameter)) * 1000);
     fillCylinderScreenMad(colix, endcaps, mad, screenA, screenB);
   }
 
@@ -363,6 +363,7 @@ abstract public class __CartesianExporter extends ___Exporter {
    * @param tempP1  
    * @param tempP2  
    * @param tempP3  
+   * @param colix 
    */
   protected void outputSolidPlate(P3 tempP1, P3 tempP2, P3 tempP3, @SuppressWarnings("unused") short colix) {
     // VRML/STL only
