@@ -178,7 +178,7 @@ public abstract class ___Exporter {
   
   int exportType;
   
-  final protected static float degreesPerRadian = (float) (180 / Math.PI);
+  final protected static double degreesPerRadian = 180 / Math.PI;
 
   final protected P3 tempP1 = new P3();
   final protected P3 tempP2 = new P3();
@@ -292,7 +292,7 @@ public abstract class ___Exporter {
     sb.append("\n").append(commentChar).append("boundboxCenter: " + vwr.getBoundBoxCenter());
     sb.append("\n").append(commentChar).append("translationOffset: " + tm.getTranslationScript());
     sb.append("\n").append(commentChar).append("zoom: " + vwr.tm.zmPct);
-    sb.append("\n").append(commentChar).append("moveto command: " + vwr.getOrientation(T.moveto, null, null));
+    sb.append("\n").append(commentChar).append("moveto command: " + vwr.getOrientation(T.moveto, null, null, null));
     sb.append("\n");
     return sb.toString();
   }
