@@ -31,6 +31,6 @@ class TextString extends P3i implements Comparator<TextString> {
 
   @Override
   public String toString() {
-    return super.toString() + " " + text;
+    return asString() + " " + text;
   }
 }
