@@ -296,7 +296,7 @@ public class SurfaceGenerator {
     }
 
     if ("propertyDistanceMax" == propertyName) {
-      params.propertyDistanceMax = ((Float) value).floatValue();
+      params.propertyDistanceMax = ((Number) value).floatValue();
       return true;
     }
 
@@ -322,7 +322,7 @@ public class SurfaceGenerator {
     if ("sigma" == propertyName) {
       // not all readers will take this, so we assign
       // cutoff to the value as well.
-      params.cutoff = params.sigma = ((Float) value).floatValue();
+      params.cutoff = params.sigma = ((Number) value).floatValue();
       params.cutoffRange = null;
       //params.isPositiveOnly = false;
       params.cutoffAutomatic = false;
@@ -330,7 +330,7 @@ public class SurfaceGenerator {
     }
 
     if ("cutoff" == propertyName) {
-      params.cutoff = ((Float) value).floatValue();
+      params.cutoff = ((Number) value).floatValue();
       params.cutoffRange = null;
       params.isPositiveOnly = false;
       params.cutoffAutomatic = false;
@@ -338,7 +338,7 @@ public class SurfaceGenerator {
     }
     
     if ("cutoffPositive" == propertyName) {
-      params.cutoff = ((Float) value).floatValue();
+      params.cutoff = ((Number) value).floatValue();
       params.cutoffRange = null;
       params.isPositiveOnly = true;
       params.isCutoffAbsolute = false;
@@ -368,12 +368,12 @@ public class SurfaceGenerator {
     }
 
     if ("scale" == propertyName) {
-      params.scale = ((Float) value).floatValue();
+      params.scale = ((Number) value).floatValue();
       return true;
     }
 
     if ("scale3d" == propertyName) {
-      params.scale3d = ((Float) value).floatValue();
+      params.scale3d = ((Number) value).floatValue();
       return true;
     }
 
@@ -383,7 +383,7 @@ public class SurfaceGenerator {
     }
 
     if ("resolution" == propertyName) {
-      float resolution = ((Float) value).floatValue();
+      float resolution = ((Number) value).floatValue();
       params.resolution = (resolution > 0 ? resolution : Float.MAX_VALUE);
       return true;
     }
@@ -472,12 +472,12 @@ public class SurfaceGenerator {
     }
 
     if ("red" == propertyName) {
-      params.valueMappedToRed = ((Float) value).floatValue();
+      params.valueMappedToRed = ((Number) value).floatValue();
       return true;
     }
 
     if ("blue" == propertyName) {
-      params.valueMappedToBlue = ((Float) value).floatValue();
+      params.valueMappedToBlue = ((Number) value).floatValue();
       if (params.valueMappedToRed > params.valueMappedToBlue) {
         float f = params.valueMappedToRed;
         params.valueMappedToRed = params.valueMappedToBlue;
@@ -532,7 +532,7 @@ public class SurfaceGenerator {
     }
 
     if ("withinDistance" == propertyName) {
-      params.distance = ((Float) value).floatValue();
+      params.distance = ((Number) value).floatValue();
       return true;
     }
 
@@ -586,12 +586,12 @@ public class SurfaceGenerator {
     }
 
     if ("envelopeRadius" == propertyName) {
-      params.envelopeRadius = ((Float) value).floatValue();
+      params.envelopeRadius = ((Number) value).floatValue();
       return true;
     }
 
     if ("cavityRadius" == propertyName) {
-      params.cavityRadius = ((Float) value).floatValue();
+      params.cavityRadius = ((Number) value).floatValue();
       return true;
     }
 
@@ -670,7 +670,7 @@ public class SurfaceGenerator {
     if ("colorDensity" == propertyName) {
       params.colorDensity = true;
       if (value != null)
-        params.pointSize = ((Float) value).floatValue();
+        params.pointSize = ((Number) value).floatValue();
       return false;
     }
     if ("fullPlane" == propertyName) {
@@ -693,7 +693,7 @@ public class SurfaceGenerator {
     }
 
     if ("extendGrid" == propertyName) {
-      params.extendGrid = ((Float) value).floatValue();
+      params.extendGrid = ((Number) value).floatValue();
       return true;
     }
 
@@ -708,7 +708,7 @@ public class SurfaceGenerator {
 
     // these next four set the reader themselves.
     if ("sphere" == propertyName) {
-      params.setSphere(((Float) value).floatValue(), false);
+      params.setSphere(((Number) value).floatValue(), false);
       readerData = Float.valueOf(params.distance);
       surfaceReader = newReader("IsoShapeReader");
       generateSurface();
@@ -717,7 +717,7 @@ public class SurfaceGenerator {
 
     // these next four set the reader themselves.
     if ("geodesic" == propertyName) {
-      params.setSphere(((Float) value).floatValue(), true);
+      params.setSphere(((Number) value).floatValue(), true);
       readerData = Float.valueOf(params.distance);
       surfaceReader = newReader("IsoShapeReader");
       generateSurface();
@@ -814,7 +814,7 @@ public class SurfaceGenerator {
 
     if ("molecular" == propertyName || "solvent" == propertyName
         || "sasurface" == propertyName || "nomap" == propertyName) {
-      params.setSolvent(propertyName, ((Float) value).floatValue());
+      params.setSolvent(propertyName, ((Number) value).floatValue());
       if (!params.isSilent)
         Logger.info(params.calculationType);
       processState();
