@@ -325,6 +325,7 @@ public abstract class SurfaceReader implements VertexDataServer {
   protected boolean jvxlDataIs2dContour;
   protected boolean jvxlDataIsColorDensity;
   protected float jvxlCutoff;
+  protected float[] jvxlCutoffRange;
   protected int jvxlNSurfaceInts;
   protected char cJvxlEdgeNaN = '\0';
 
@@ -354,6 +355,7 @@ public abstract class SurfaceReader implements VertexDataServer {
     if (params.showTiming)
       Logger.startTimer("isosurface creation");
     jvxlData.cutoff = Float.NaN;
+    jvxlData.cutoffRange = null;
     if (!readAndSetVolumeParameters(justForPlane))
       return false;
     if (!justForPlane && !Float.isNaN(params.sigma) && !allowSigma) {
@@ -418,7 +420,8 @@ public abstract class SurfaceReader implements VertexDataServer {
     jvxlData.boundingBox = new P3[] { xyzMin, xyzMax };
     jvxlData.dataMin = dataMin;
     jvxlData.dataMax = dataMax;
-    jvxlData.cutoff = (isJvxl ? jvxlCutoff : params.cutoff);
+    jvxlData.cutoffRange = (isJvxl ? jvxlCutoffRange : params.cutoffRange);
+    jvxlData.cutoff = (jvxlCutoffRange != null ? jvxlData.cutoffRange[0] : isJvxl ? jvxlCutoff : params.cutoff);
     jvxlData.isCutoffAbsolute = params.isCutoffAbsolute;
     jvxlData.isModelConnected = params.isModelConnected;
     jvxlData.pointsPerAngstrom = 1f / volumeData.volumetricVectorLengths[0];
