@@ -33,7 +33,6 @@ import org.jmol.minimize.MinAngle;
 import org.jmol.minimize.MinAtom;
 import org.jmol.minimize.MinBond;
 import org.jmol.minimize.MinObject;
-import org.jmol.minimize.MinPosition;
 import org.jmol.minimize.MinTorsion;
 import org.jmol.minimize.Util;
 
@@ -82,7 +81,6 @@ abstract class Calculations {
   MinBond[] minBonds;
   MinAngle[] minAngles;
   MinTorsion[] minTorsions;
-  private MinPosition[] minPositions;
 //  private Lst<MMConstraint> constraints;
   private MMConstraint[][] constraintsByType;
   private boolean haveConstraints;
@@ -91,14 +89,13 @@ abstract class Calculations {
 
   Calculations(ForceField ff, 
       MinAtom[] minAtoms, MinBond[] minBonds,
-      MinAngle[] minAngles, MinTorsion[] minTorsions, MinPosition[] minPositions,
+      MinAngle[] minAngles, MinTorsion[] minTorsions,
       Lst<MMConstraint> constraints) {
     this.ff = ff;
     this.minAtoms = minAtoms;
     this.minBonds = minBonds;
     this.minAngles = minAngles;
     this.minTorsions = minTorsions;
-    this.minPositions = minPositions;
     ac = minAtoms.length;
     bondCount = minBonds.length;
     angleCount = minAngles.length;
@@ -409,6 +406,8 @@ abstract class Calculations {
         + "---------BONDED ATOMS--------\n"
         + trailer);
     for (int i = 0; i < ac; i++) {
+      if (ff.minimizer.isLoggable(null, i) == Boolean.FALSE)
+        continue;
       MinAtom atom = minAtoms[i];
       int[] others = atom.getBondedAtomIndexes();
       int[] iVal = new int[others.length + 2];
