@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2024-04-14 22:04:09 -0500 (Sun, 14 Apr 2024) $
- * $Revision: 22612 $
+ * $Date: 2024-10-08 18:58:53 -0500 (Tue, 08 Oct 2024) $
+ * $Revision: 22635 $
 
  *
  * Copyright (C) 2003-2005  The Jmol Development Team
@@ -25,14 +25,6 @@
 
 package org.jmol.modelset;
 
-import javajs.util.CU;
-import javajs.util.Lst;
-import javajs.util.P3;
-import javajs.util.PT;
-import javajs.util.SB;
-import javajs.util.T3;
-import javajs.util.V3;
-
 import org.jmol.api.JmolDataManager;
 import org.jmol.api.JmolModulationSet;
 import org.jmol.api.SymmetryInterface;
@@ -40,7 +32,6 @@ import org.jmol.atomdata.RadiusData;
 import org.jmol.atomdata.RadiusData.EnumType;
 import org.jmol.c.PAL;
 import org.jmol.c.VDW;
-import javajs.util.BS;
 import org.jmol.modelsetbio.BioModel;
 import org.jmol.script.T;
 import org.jmol.util.C;
@@ -53,6 +44,15 @@ import org.jmol.util.Vibration;
 import org.jmol.viewer.JC;
 import org.jmol.viewer.Viewer;
 
+import javajs.util.BS;
+import javajs.util.CU;
+import javajs.util.Lst;
+import javajs.util.P3;
+import javajs.util.PT;
+import javajs.util.SB;
+import javajs.util.T3;
+import javajs.util.V3;
+
 
 
 
@@ -90,13 +90,14 @@ public class Atom extends Point3fi implements Node {
   short atomNumberFlags;
   public BS atomSymmetry;
 
-  private int formalChargeAndFlags; //  cccc CIP_ _CIP --hv
+  private int formalChargeAndFlags; //  cccc CIP_ _CIP -nhv
   
   private final static int CHARGE_OFFSET = 24;
 
   private final static int FLAG_MASK = 0xF;
   private final static int VIBRATION_VECTOR_FLAG = 1;
   private final static int IS_HETERO_FLAG = 2;
+  private final static int NEG_DISORDER_FLAG = 4;
   
   private final static int CIP_CHIRALITY_OFFSET = 4;
   private final static int CIP_CHIRALITY_MASK = 0x1F0;
@@ -135,6 +136,7 @@ public class Atom extends Point3fi implements Node {
    * @param atomicAndIsotopeNumber
    * @param formalCharge
    * @param isHetero
+   * @param isNegDisorder TODO
    * @return this
    */
   
@@ -142,7 +144,7 @@ public class Atom extends Point3fi implements Node {
         P3 xyz, float radius,
         BS atomSymmetry, int atomSite,
         short atomicAndIsotopeNumber, int formalCharge, 
-        boolean isHetero) {
+        boolean isHetero, boolean isNegDisorder) {
     this.mi = (short)modelIndex;
     this.atomSymmetry = atomSymmetry;
     this.atomSite = atomSite;
@@ -380,6 +382,14 @@ public class Atom extends Point3fi implements Node {
     formalChargeAndFlags |= VIBRATION_VECTOR_FLAG;
   }
   
+ void setNegativeDisorder() {
+    formalChargeAndFlags |= NEG_DISORDER_FLAG;
+  }
+  
+  boolean isNegativeDisorder() {
+    return ((formalChargeAndFlags & NEG_DISORDER_FLAG) != 0);
+  }
+  
   @Override
   public int getFormalCharge() {
     return formalChargeAndFlags >> CHARGE_OFFSET;
@@ -764,7 +774,7 @@ public class Atom extends Point3fi implements Node {
       for (int j = 0; j < nOps; j++)
         if (atomSymmetry.get(pt++))
           if (isAll) {
-            str += "," + (j + 1) + cellRange[i];
+            str += "," + (j + 1) + (cellRange == null ? 555 : cellRange[i]);
           } else {
             bs.set(j + 1);
           }
@@ -774,9 +784,6 @@ public class Atom extends Point3fi implements Node {
     return (str.length() == 0 ? "" : str.substring(1));
   }
    
-  /**
-   * SMILES only
-   */
   @Override
   public int getModelIndex() {
     return mi;
@@ -1342,6 +1349,10 @@ public class Atom extends Point3fi implements Node {
       return getSurfaceDistance100() / 100f;
     case T.temperature: // 0 - 9999
       return getBfactor100() / 100f;
+    case T.translucent:
+      return C.getColixTranslucencyFractional(colixAtom);
+    case T.volume:
+      return getVolume(vwr, VDW.AUTO);
     case T.unitx:
       return getFractionalUnitCoord(!vwr.g.legacyJavaFloat, 'X', ptTemp);
     case T.unity:
@@ -1373,8 +1384,6 @@ public class Atom extends Point3fi implements Node {
       return getVib('2');
     case T.modt3:
       return getVib('3');
-    case T.volume:
-      return getVolume(vwr, VDW.AUTO);
     case T.fracxyz:
     case T.fuxyz:
     case T.unitxyz:
@@ -1475,7 +1484,7 @@ public class Atom extends Point3fi implements Node {
     if (id != 0) {
       int m = id >> 16;
       char c = (char) (id & 0xFF);
-      return (withMultiplicity ? "" + (id >> 16) : "") + (char) (id & 0xFF);
+      return (withMultiplicity ? "" + m : "") + c;
     }
     SymmetryInterface sym = getUnitCell();
     String s;
