@@ -52,6 +52,7 @@ import org.jmol.util.Parser;
 import org.jmol.util.Tensor;
 import org.jmol.util.Vibration;
 import org.jmol.viewer.JC;
+import org.jmol.viewer.StateManager;
 import org.jmol.viewer.Viewer;
 
 import javajs.util.A4;
@@ -69,8 +70,8 @@ import javajs.util.V3;
 
 abstract public class AtomCollection {
   
-  private final static float almost180 = (float) Math.PI * 0.95f;
-  private final static float sqrt3_2 = (float) (Math.sqrt(3) / 2);
+  private final static double almost180 = Math.PI * 0.95;
+  private final static double sqrt3_2 = Math.sqrt(3) / 2;
   private final static V3 vRef = V3.new3(3.14159f, 2.71828f, 1.41421f);
 
   public Viewer vwr;
@@ -100,8 +101,8 @@ abstract public class AtomCollection {
   
   // the maximum BondingRadius seen in this set of atoms
   // used in autobonding
-  protected float maxBondingRadius = PT.FLOAT_MIN_SAFE;
-  private float maxVanderwaalsRadius = PT.FLOAT_MIN_SAFE;
+  protected float maxBondingRadius = JC.FLOAT_MIN_SAFE;
+  private float maxVanderwaalsRadius = JC.FLOAT_MIN_SAFE;
 
   private boolean hasBfactorRange;
   private int bfactor100Lo;
@@ -350,7 +351,7 @@ abstract public class AtomCollection {
   
   public float getMaxVanderwaalsRadius() {
     //Dots
-    if (maxVanderwaalsRadius == PT.FLOAT_MIN_SAFE)
+    if (maxVanderwaalsRadius == JC.FLOAT_MIN_SAFE)
       findMaxRadii();
     return maxVanderwaalsRadius;
   }
@@ -771,10 +772,15 @@ abstract public class AtomCollection {
     return (JmolModulationSet) (v != null && v.modDim > 0 ? v : null);
   }
 
-  protected void setVibrationVector(int atomIndex, T3 vib) {
-    if (Float.isNaN(vib.x) || Float.isNaN(vib.y) || Float.isNaN(vib.z))
+  public void setVibrationVector(int atomIndex, T3 vib) {
+    if (vib == null) {
+      if (vibrations != null && vibrations.length > atomIndex)
+        vibrations[atomIndex] = null;
       return;
-    if (vibrations == null || vibrations.length < atomIndex)
+    }
+    if (Double.isNaN(vib.x) || Double.isNaN(vib.y) || Double.isNaN(vib.z))
+      return;
+    if (vibrations == null || vibrations.length <= atomIndex)
       vibrations = new Vibration[at.length];
     if (vib instanceof Vibration) {
       vibrations[atomIndex] = (Vibration) vib;
@@ -886,7 +892,7 @@ abstract public class AtomCollection {
     taintAtom(atomIndex, TAINT_RESNO);
   }
   
-  private void setAtomSeqID(int atomIndex, int seqID) {
+  void setAtomSeqID(int atomIndex, int seqID) {
     if (seqID == at[atomIndex].getSeqID())
       return;
     if (atomSeqIDs == null)
@@ -935,7 +941,7 @@ abstract public class AtomCollection {
     if (bondingRadii == null) {
       bondingRadii = new float[at.length];
     } else if (bondingRadii.length < at.length) {
-      bondingRadii = (float[]) AU.ensureLength(bondingRadii, at.length);
+      bondingRadii = AU.ensureLengthA(bondingRadii, at.length);
     }
     bondingRadii[atomIndex] = radius;
     taintAtom(atomIndex, TAINT_BONDINGRADIUS);
@@ -1300,17 +1306,18 @@ abstract public class AtomCollection {
 
   
   /**
-   * get a list of potential H atom positions based on 
-   * elemental valence and formal charge
+   * get a list of potential H atom positions based on elemental valence and
+   * formal charge
    * 
    * @param bs
    * @param nTotal
-   * @param vConnect 
-   * @param flags [CALC_H_DOALL | CALC_H_JUSTC | CALC_H_HAVEH | CALC_H_QUICK
-   * @return     array of arrays of points added to specific atoms
+   * @param vConnect
+   * @param flags
+   *        [CALC_H_DOALL | CALC_H_JUSTC | CALC_H_HAVEH | CALC_H_QUICK
+   * @return array of arrays of points added to specific atoms
    */
-  public P3[][] calculateHydrogens(BS bs, int[] nTotal,
-                                            Lst<Atom> vConnect, int flags) {
+  public P3[][] calculateHydrogens(BS bs, int[] nTotal, Lst<Atom> vConnect,
+                                   int flags) {
     boolean doAll = ((flags & CALC_H_DOALL) == CALC_H_DOALL);
     boolean justCarbon = ((flags & CALC_H_JUSTC) == CALC_H_JUSTC);
     boolean isQuick = ((flags & CALC_H_QUICK) == CALC_H_QUICK);
@@ -1321,185 +1328,198 @@ abstract public class AtomCollection {
     P3[][] hAtoms = new P3[ac][];
     BS bsDeleted = vwr.slm.bsDeleted;
     P3 pt;
-    int nH = 0;
-    
+    int nH = nTotal[0] = 0;
+
     // just not doing aldehydes here -- all A-X-B bent == sp3 for now
-    if (bs != null)
-      for (int i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
-        if (bsDeleted != null && bsDeleted.get(i))
-          continue;
-        Atom atom = at[i];
-        int atomicNumber = atom.getElementNumber();
-        if (justCarbon && atomicNumber != 6)
-          continue;
-        float dHX = (atomicNumber <= 6 ? 1.1f // B, C
-            : atomicNumber <= 10 ? 1.0f       // N, O
-            : 1.3f);                          // S
-        switch (atomicNumber) {
-        case 7:
-        case 8:
-          dHX = 1.0f;
-          break;
-        case 6:
-        }
-        int n = (doAll || ignoreH || allowH ? atom.getCovalentHydrogenCount() : 0);
-        if (doAll && n > 0 || ignoreH && n == 0)
-          continue;
-        int nMissing = getMissingHydrogenCount(atom, false);
-        if (doAll && nMissing == 0)
-          continue;
-        if (!ignoreH)
-          n = nMissing;
-        
-        // TODO - NPE while working with model kit after deleting and adding and dragging atoms.
-        
-        int targetValence = aaRet[0];
-        int hybridization = aaRet[2];
-        int nBonds = aaRet[3] - (ignoreH ? n : 0);
-        if (nBonds == 0 && atom.isHetero())
-          continue; // no adding to water
-        hAtoms[i] = new P3[n];
-        int hPt = 0;
-        if (nBonds == 0) {
-          switch (n) {
-          case 4:
-            // methane
-            z.set(0.635f, 0.635f, 0.635f);
-            pt = P3.newP(z);
-            pt.add(atom);
-            hAtoms[i][hPt++] = pt;
-            if (vConnect != null)
-              vConnect.addLast(atom);
-            //$FALL-THROUGH$
-          case 3:
-            // nitrogen
-            z.set(-0.635f, -0.635f, 0.635f);
-            pt = P3.newP(z);
-            pt.add(atom);
-            hAtoms[i][hPt++] = pt;
-            if (vConnect != null)
-              vConnect.addLast(atom);
-            //$FALL-THROUGH$
-          case 2:
-            // oxygen
-            z.set(-0.635f, 0.635f, -0.635f);
-            pt = P3.newP(z);
-            pt.add(atom);
-            hAtoms[i][hPt++] = pt;
-            if (vConnect != null)
-              vConnect.addLast(atom);
-            //$FALL-THROUGH$
-          case 1:
-            z.set(0.635f, -0.635f, -0.635f);
-            pt = P3.newP(z);
-            pt.add(atom);
-            hAtoms[i][hPt++] = pt;
-            if (vConnect != null)
-              vConnect.addLast(atom);
-          }
-        } else {
-          switch (n) {
-          default:
-            break;
-          case 3: // three bonds needed RC
-            getHybridizationAndAxes(i, atomicNumber, z, x, "sp3b", false, true, isQuick);
-            pt = new P3();
-            pt.scaleAdd2(dHX, z, atom);
-            hAtoms[i][hPt++] = pt;
-            if (vConnect != null)
-              vConnect.addLast(atom);
-            getHybridizationAndAxes(i, atomicNumber, z, x, "sp3c", false, true, isQuick);
-            pt = new P3();
-            pt.scaleAdd2(dHX, z, atom);
-            hAtoms[i][hPt++] = pt;
-            if (vConnect != null)
-              vConnect.addLast(atom);
-            getHybridizationAndAxes(i, atomicNumber, z, x, "sp3d", false, true, isQuick);
-            pt = new P3();
-            pt.scaleAdd2(dHX, z, atom);
-            hAtoms[i][hPt++] = pt;
-            if (vConnect != null)
-              vConnect.addLast(atom);
-            break;
-          case 2:
-            // 2 bonds needed R2C or R-N or R2C=C or O
-            //                    or RC=C or C=C
-            boolean isEne = (hybridization == 2 || atomicNumber == 5 || nBonds == 1
-                && targetValence == 4 
-                || atomicNumber == 7 && isAdjacentSp2(atom));
-            getHybridizationAndAxes(i, atomicNumber, z, x, (isEne ? "sp2b"
-                : targetValence == 3 ? "sp3c" : "lpa"), false, true, isQuick);
-            pt = P3.newP(z);
-            pt.scaleAdd2(dHX, z, atom);
-            hAtoms[i][hPt++] = pt;
-            if (vConnect != null)
-              vConnect.addLast(atom);
-            getHybridizationAndAxes(i, atomicNumber, z, x, (isEne ? "sp2c"
-                : targetValence == 3 ? "sp3d" : "lpb"), false, true, isQuick);
-            pt = P3.newP(z);
-            pt.scaleAdd2(dHX, z, atom);
-            hAtoms[i][hPt++] = pt;
-            if (vConnect != null)
-              vConnect.addLast(atom);
-            break;
-          case 1:
-            // one bond needed R2B, R3C, R-N-R, R-O R=C-R R=N R-3-C
-            // nbonds ......... 2 .. 3 .. 2 ... 1 ... 2 .. 1 .. 1
-            // nval ........... 2 .. 3 .. 2 ... 1 ... 3 .. 2 .. 3
-            // targetValence .. 3 .. 4 .. 3 ... 2 ... 4 .. 3 .. 4
-            // tV - nbonds   .. 1    1    1     1     2    2    3
-            // ................ sp2c sp3d sp3d  sp3b  sp2c sp2b sp
-            switch (targetValence - nBonds) {
-            case 1:
-              // sp3 or Boron sp2 or N sp2
-              if (atomicNumber == 8 && atom == atom.group.getCarbonylOxygenAtom()) {
-                hAtoms[i] = null;
-                continue;
-              }
-              if (getHybridizationAndAxes(i, atomicNumber, z, x, 
-                  (hybridization == 2 || atomicNumber == 5 
-                  || atomicNumber == 6 &&  aaRet[1] == 1
-                  || atomicNumber == 7 
-                  && (atom.group.getNitrogenAtom() == atom & atom.getFormalCharge() == 0 || isAdjacentSp2(atom))
-                  ? "sp2c"
-                  : "sp3d"), true, false, isQuick) != null) {
-                pt = P3.newP(z);
-                pt.scaleAdd2(dHX, z, atom);
-                hAtoms[i][hPt++] = pt;
-                if (vConnect != null)
-                  vConnect.addLast(atom);
-              } else {
-                hAtoms[i] = new P3[0];
-              }
-              break;
-            case 2:
-              // sp2
-              getHybridizationAndAxes(i, atomicNumber, z, x, (targetValence == 4 ? "sp2c"
-                  : "sp2b"), false, false, isQuick);
-              pt = P3.newP(z);
-              pt.scaleAdd2(dHX, z, atom);
-              hAtoms[i][hPt++] = pt;
-              if (vConnect != null)
-                vConnect.addLast(atom);
-              break;
-            case 3:
-              // sp
-              getHybridizationAndAxes(i, atomicNumber, z, x, "spb", false, true, isQuick);
-              pt = P3.newP(z);
-              pt.scaleAdd2(dHX, z, atom);
-              hAtoms[i][hPt++] = pt;
-              if (vConnect != null)
-                vConnect.addLast(atom);
-              break;
-            }
-          }
-        }
-        nH += hPt;
+    if (bs == null) {
+      return hAtoms;
+    }
+    // check for unit cell ONLY if unit cell is showing
+    SymmetryInterface sym = vwr.getOperativeSymmetry();
+    if (sym != null && vwr.getObjectMad10(StateManager.OBJ_UNITCELL) == 0)
+      sym = null;
+    P3 ptTemp = (sym == null ? null : new P3());
+    for (int i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
+      if (bsDeleted != null && bsDeleted.get(i))
+        continue;
+      Atom atom = at[i];
+      int atomicNumber = atom.getElementNumber();
+      if (justCarbon && atomicNumber != 6)
+        continue;
+      float dHX = (atomicNumber <= 6 ? 1.1f // B, C
+          : atomicNumber <= 10 ? 1.0f // N, O
+              : 1.3f); // S
+      switch (atomicNumber) {
+      case 7:
+      case 8:
+        dHX = 1.0f;
+        break;
+      case 6:
       }
+      int n = (doAll || ignoreH || allowH ? atom.getCovalentHydrogenCount()
+          : 0);
+      if (doAll && n > 0 || ignoreH && n == 0)
+        continue;
+      int nMissing = getMissingHydrogenCount(atom, false);
+      if (doAll && nMissing == 0)
+        continue;
+      if (!ignoreH)
+        n = nMissing;
+
+      // TODO - NPE while working with model kit after deleting and adding and dragging atoms.
+
+      int targetValence = aaRet[0];
+      int hybridization = aaRet[2];
+      int nBonds = aaRet[3] - (ignoreH ? n : 0);
+      if (nBonds == 0 && atom.isHetero())
+        continue; // no adding to water
+      hAtoms[i] = new P3[n];
+      int hPt = 0;
+      if (nBonds == 0) {
+        switch (n) {
+        case 4:
+          // methane
+          z.set(0.635f, 0.635f, 0.635f);
+          pt = P3.newP(z);
+          pt.add(atom);
+          hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+          //$FALL-THROUGH$
+        case 3:
+          // nitrogen
+          z.set(-0.635f, -0.635f, 0.635f);
+          pt = P3.newP(z);
+          pt.add(atom);
+          hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+          //$FALL-THROUGH$
+        case 2:
+          // oxygen
+          z.set(-0.635f, 0.635f, -0.635f);
+          pt = P3.newP(z);
+          pt.add(atom);
+          hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+          //$FALL-THROUGH$
+        case 1:
+          z.set(0.635f, -0.635f, -0.635f);
+          pt = P3.newP(z);
+          pt.add(atom);
+          hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+        }
+      } else {
+        switch (n) {
+        default:
+          break;
+        case 3: // three bonds needed RC
+          getHybridizationAndAxes(i, atomicNumber, z, x, "sp3b", false, true,
+              isQuick, null);
+          pt = new P3();
+          pt.scaleAdd2(dHX, z, atom);
+          hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+          getHybridizationAndAxes(i, atomicNumber, z, x, "sp3c", false, true,
+              isQuick, null);
+          pt = new P3();
+          pt.scaleAdd2(dHX, z, atom);
+          hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+          getHybridizationAndAxes(i, atomicNumber, z, x, "sp3d", false, true,
+              isQuick, null);
+          pt = new P3();
+          pt.scaleAdd2(dHX, z, atom);
+          hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+          break;
+        case 2:
+          // 2 bonds needed R2C or R-N or R2C=C or O
+          //                    or RC=C or C=C
+          boolean isEne = (hybridization == 2 || atomicNumber == 5
+              || nBonds == 1 && targetValence == 4
+              || atomicNumber == 7 && isAdjacentSp2(atom));
+          getHybridizationAndAxes(i, atomicNumber, z, x,
+              (isEne ? "sp2b" : targetValence == 3 ? "sp3c" : "lpa"), false,
+              true, isQuick, null);
+          pt = P3.newP(z);
+          pt.scaleAdd2(dHX, z, atom);
+          hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+          getHybridizationAndAxes(i, atomicNumber, z, x,
+              (isEne ? "sp2c" : targetValence == 3 ? "sp3d" : "lpb"), false,
+              true, isQuick, null);
+          pt = P3.newP(z);
+          pt.scaleAdd2(dHX, z, atom);
+          hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+          break;
+        case 1:
+          // one bond needed R2B, R3C, R-N-R, R-O R=C-R R=N R-3-C
+          // nbonds ......... 2 .. 3 .. 2 ... 1 ... 2 .. 1 .. 1
+          // nval ........... 2 .. 3 .. 2 ... 1 ... 3 .. 2 .. 3
+          // targetValence .. 3 .. 4 .. 3 ... 2 ... 4 .. 3 .. 4
+          // tV - nbonds   .. 1    1    1     1     2    2    3
+          // ................ sp2c sp3d sp3d  sp3b  sp2c sp2b sp
+          switch (targetValence - nBonds) {
+          case 1:
+            // sp3 or Boron sp2 or N sp2
+            if (atomicNumber == 8
+                && atom == atom.group.getCarbonylOxygenAtom()) {
+              hAtoms[i] = null;
+              continue;
+            }
+            if (getHybridizationAndAxes(i, atomicNumber, z, x,
+                (hybridization == 2 || atomicNumber == 5
+                    || atomicNumber == 6 && aaRet[1] == 1
+                    || atomicNumber == 7
+                        && (atom.group.getNitrogenAtom() == atom
+                            & atom.getFormalCharge() == 0
+                            || isAdjacentSp2(atom)) ? "sp2c" : "sp3d"),
+                true, false, isQuick, null) != null) {
+              pt = P3.newP(z);
+              pt.scaleAdd2(dHX, z, atom);
+              hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+            }
+            break;
+          case 2:
+            // sp2
+            getHybridizationAndAxes(i, atomicNumber, z, x,
+                (targetValence == 4 ? "sp2c" : "sp2b"), false, false, isQuick,
+                null);
+            pt = P3.newP(z);
+            pt.scaleAdd2(dHX, z, atom);
+            hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+            break;
+          case 3:
+            // sp
+            getHybridizationAndAxes(i, atomicNumber, z, x, "spb", false, true,
+                isQuick, null);
+            pt = P3.newP(z);
+            pt.scaleAdd2(dHX, z, atom);
+            hPt = addH(hAtoms[i], hPt, pt, atom, vConnect, sym, ptTemp);
+            break;
+          }
+        }
+      }
+      if (hPt < n) {
+        P3[] a = new P3[hPt];
+        for (int j = 0; j < hPt; j++)
+          a[j] = hAtoms[i][j];
+        hAtoms[i] = a;
+      }
+      nH += hPt;
+    }
     nTotal[0] = nH;
     return hAtoms;
   }
 
+  private static int addH(P3[] hAtoms, int hPt, P3 pt, Atom atom,
+                          Lst<Atom> vConnect, SymmetryInterface sym,
+                          P3 ptTemp) {
+    if (sym != null) {
+      ptTemp.setT(pt);
+      sym.toFractional(ptTemp, false);
+      if (!sym.isWithinUnitCell(ptTemp, 1, 1, 1)) {
+        return hPt;
+      }
+    }
+    hAtoms[hPt++] = pt;
+    if (vConnect != null)
+      vConnect.addLast(atom);
+    return hPt;
+  }
+
   private boolean isAdjacentSp2(Atom atom) {
     Bond[] bonds = atom.bonds;
     for (int i = 0; i < bonds.length; i++) {
@@ -1568,7 +1588,7 @@ abstract public class AtomCollection {
   public String getHybridizationAndAxes(int atomIndex, int atomicNumber, V3 z, V3 x,
                                         String lcaoTypeRaw,
                                         boolean hybridizationCompatible,
-                                        boolean doAlignZ, boolean isQuick) {
+                                        boolean doAlignZ, boolean isQuick, T3 ref) {
 
     String lcaoType = (lcaoTypeRaw.length() > 0 && lcaoTypeRaw.charAt(0) == '-' ? lcaoTypeRaw
         .substring(1)
@@ -1603,13 +1623,13 @@ abstract public class AtomCollection {
     boolean isPlanar = false;
     V3 vTemp = new V3();
     if (nAttached >= 3) {
-      if (x.angle(v[1]) < almost180)
+      if (x.angle(v[1]) < (float) almost180)
         vTemp.cross(x, v[1]);
       else
         vTemp.cross(x, v[2]);
       vTemp.normalize();
       V3 vTemp2 = new V3();
-      if (v[1].angle(v[2]) < almost180)
+      if (v[1].angle(v[2]) < (float) almost180)
         vTemp2.cross(v[1], v[2]);
       else
         vTemp2.cross(x, v[2]);
@@ -1742,7 +1762,7 @@ abstract public class AtomCollection {
         // vRef is a pseudo-random vector
         // z is along the bond
         for (int i = attached[0].getBondCount(); --i >= 0;) {
-          if (attached[0].bonds[i].isCovalent()
+          if (attached[0].bonds[i].isCovalentNotPartial0()
               && attached[0].getBondedAtomIndex(i) != atom.i) {
             x.sub2(attached[0], attached[0].bonds[i].getOtherAtom(attached[0]));
             x.cross(z, x);
@@ -1775,9 +1795,35 @@ abstract public class AtomCollection {
       }
       // not "sp3" -- sp2 or lone pair
       vTemp.cross(x, z); //x and vTemp are now perpendicular to z
-      switch (attached[0].getCovalentBondCount()) {
+      int na = attached[0].getCovalentBondCount();
+      switch (na) {
+      case 3:
+        // special case, for example R2C=O oxygen
+        // look out for iterative calling
+    	  if (ref != attached[0]) {
+            getHybridizationAndAxes(attached[0].i, 0, x, vTemp, "pz", false,
+                doAlignZ, isQuick, atom);
+            vTemp.setT(x);
+            if (isSp2) { // align z as sp2 orbital
+              x.cross(x, z);
+              if (pt == 1)
+                x.scale(-1);
+              x.scale((float)sqrt3_2);
+              z.scaleAdd2(0.5f, z, x);
+            } else if (isSp) {
+              
+            } else {
+              vTemp.setT(z);
+              z.setT(x);
+            }
+            x.cross(vTemp, z);
+            break;
+    	  }
+        na = 2;
+        // skip to case 2
+        //$FALL-THROUGH$
       case 1:
-        if (attached[0].getValence() != 2) {
+        if (na == 1 && attached[0].getValence() != 2) {
           // C-t-C
           break;
         }
@@ -1795,7 +1841,7 @@ abstract public class AtomCollection {
           Atom a = null;
           isCumulated = !isCumulated;
           for (int i = 0; i < bonds.length; i++)
-            if (bonds[i].isCovalent()) {
+            if (bonds[i].isCovalentNotPartial0()) {
               a = bonds[i].getOtherAtom(a0);
               if (a != atom) {
                 vTemp.sub2(a, a0);
@@ -1815,7 +1861,7 @@ abstract public class AtomCollection {
           z.normalize();
           if (pt == 1)
             z.scale(-1);
-          z.scale(sqrt3_2);
+          z.scale((float)sqrt3_2);
           z.scaleAdd2(0.5f, x, z);
           if (isP) {
             vTemp.cross(z, x);
@@ -1828,25 +1874,6 @@ abstract public class AtomCollection {
           x.cross(vRef, x);
         }
         break;
-      case 3:
-        // special case, for example R2C=O oxygen
-        getHybridizationAndAxes(attached[0].i, 0, x, vTemp, "pz", false,
-            doAlignZ, isQuick);
-        vTemp.setT(x);
-        if (isSp2) { // align z as sp2 orbital
-          x.cross(x, z);
-          if (pt == 1)
-            x.scale(-1);
-          x.scale(sqrt3_2);
-          z.scaleAdd2(0.5f, z, x);
-        } else if (isSp) {
-          
-        } else {
-          vTemp.setT(z);
-          z.setT(x);
-        }
-        x.cross(vTemp, z);
-        break;
       }
       break;
     case 2:
@@ -1860,7 +1887,7 @@ abstract public class AtomCollection {
             ok = ((a = attached[1]).getCovalentBondCount() == 3);
           if (ok) {
             // special case, for example R2C=C=CR2 central carbon
-            getHybridizationAndAxes(a.i, 0, x, z, "pz", false, doAlignZ, isQuick);
+            getHybridizationAndAxes(a.i, 0, x, z, "pz", false, doAlignZ, isQuick, null);
             if (lcaoType.equals("px"))
               x.scale(-1);
             z.setT(v[0]);
@@ -2088,7 +2115,7 @@ abstract public class AtomCollection {
           x.sub2(attached[i], atom);
           x.normalize();
           x.scale(0.5f);
-          z.scaleAdd2(sqrt3_2, z, x);
+          z.scaleAdd2((float)sqrt3_2, z, x);
           pt = -1;
           break;
         case 1:
@@ -2166,7 +2193,7 @@ abstract public class AtomCollection {
       Bond[] bonds = atom.bonds;
       int n = 0;
       for (int i = 0; i < bonds.length; i++)
-        if (bonds[i].isCovalent()) {
+        if (bonds[i].isCovalentNotPartial0()) {
           Atom a = bonds[i].getOtherAtom(atom);
           if (!isQuick || a.getAtomicAndIsotopeNumber() != 1)
             attached[n++] = a;
@@ -2312,7 +2339,7 @@ abstract public class AtomCollection {
           int n = 0;
           Atom b;
           for (int j = bonds.length; --j >= 0 && n < 3;)
-            if (bonds[j].isCovalent()
+            if (bonds[j].isCovalentNotPartial0()
                 && (b = bonds[j].getOtherAtom(a)).getElementNumber() == 1)
               hs[n++ % 2] = b.i;
           if (n == 2) {
@@ -2882,20 +2909,18 @@ abstract public class AtomCollection {
     return bs;
   }
 
-
   public Lst<P3> generateCrystalClass(int atomIndex, P3 pt) {
-    SymmetryInterface sym = (atomIndex < 0 || atomIndex >= ac ? null
+    SymmetryInterface sym = (atomIndex < 0 || atomIndex >= ac ? vwr.getOperativeSymmetry()
         : at[atomIndex].getUnitCell());
     boolean isRandom = (pt != null && Float.isNaN(pt.x));
-    return (sym == null ? new Lst<P3>() : sym
+    Lst<P3> ret = (sym == null ? null : sym
         .generateCrystalClass(isRandom ? null : pt != null ? pt : at[atomIndex]));
-
+    return (ret == null ? new Lst<P3>() : ret);
   }
 
   public static boolean isDeleted(Atom atom) {
     return (atom == null || atom.isDeleted());
   }
 
-
 }
 
