@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-01-31 14:56:01 -0600 (Mon, 31 Jan 2022) $
- * $Revision: 22316 $
+ * $Date: 2023-01-07 08:24:29 -0600 (Sat, 07 Jan 2023) $
+ * $Revision: 22501 $
 
  *
  * Copyright (C) 2003-2005  The Jmol Development Team
@@ -95,7 +95,8 @@ public class Bond extends Edge {
     return (order & BOND_STEREO_MASK) != 0;
   }
 
-  boolean isPartial() {
+  @Override
+  public boolean isPartial() {
     return (order & BOND_PARTIAL_MASK) != 0;
   }
 
@@ -109,8 +110,8 @@ public class Bond extends Edge {
   }
   
   public int getValence() {
-    return (!isCovalent() ? 0
-        : isPartial() || is(BOND_AROMATIC) ? 1
+    return (!isCovalent() || order == BOND_PARTIAL01 ? 0
+        : is(BOND_AROMATIC) ? 1
         : order & 7);
   }
 
@@ -156,7 +157,7 @@ public class Bond extends Edge {
   }
   
   public boolean is(int bondType) {
-    return (order & ~BOND_NEW) == bondType;
+    return (order & BOND_RENDER_MASK) == bondType;
   }
 
   @Override
@@ -231,4 +232,9 @@ public class Bond extends Edge {
     return (i == 1 ? atom2 : atom1);
   }
 
+  public boolean isCovalentNotPartial0() {
+    return ((order & Edge.BOND_COVALENT_MASK) != 0
+        && order != Edge.BOND_PARTIAL01);
+  }
+
 }
