@@ -171,7 +171,7 @@ public final class ModelLoader {
       jbr = vwr.getJBR().setLoader(this);
     jmolData = (adapterModelCount == 0 ? (String) ms.getInfoM("jmolData") : null);
     fileHeader = (String) ms.getInfoM("fileHeader");
-    Lst<P3[]> steps = (Lst<P3[]>) ms.getInfoM("trajectorySteps");
+    Lst<P3[]> steps = (Lst<P3[]>) ms.getInfoM(JC.INFO_TRAJECTORY_STEPS);
     isTrajectory = (steps != null);
     if (isTrajectory)
       ms.trajectory = newTrajectory(ms, steps);
@@ -182,9 +182,9 @@ public final class ModelLoader {
     if (info != null) {
       info.remove("pdbNoHydrogens");
       info.remove("pdbAddHydrogens");
-      info.remove("trajectorySteps");
+      info.remove(JC.INFO_TRAJECTORY_STEPS);
       if (isTrajectory)
-        ms.vibrationSteps = (Lst<V3[]>) info.remove("vibrationSteps");
+        ms.vibrationSteps = (Lst<V3[]>) info.remove(JC.INFO_VIBRATION_STEPS);
       if (info.containsKey("highPrecision")) {
         // we must RESET this, because 'ZAP' has unset it in the script
         vwr.setBooleanProperty("legacyJavaFloat", true);
@@ -830,26 +830,7 @@ public final class ModelLoader {
         jbr.setHaveHsAlready(true);
       String name = iterAtom.getAtomName();
       int charge = (addH ? getPdbCharge(group3, name) : iterAtom.getFormalCharge());
-      
-      Atom atom = addAtom(isPdbThisModel, iterAtom.getSymmetry(),
-          iterAtom.getAtomSite() + siteBase,
-          isotope,
-          name,
-          charge, 
-          iterAtom.getPartialCharge(),
-          iterAtom.getTensors(), 
-          iterAtom.getOccupancy(), 
-          iterAtom.getBfactor(), 
-          iterAtom.getXYZ(),
-          iterAtom.getIsHetero(), 
-          iterAtom.getSerial(), 
-          iterAtom.getSeqID(),
-          group3,
-          iterAtom.getVib(), 
-          iterAtom.getAltLoc(),
-          iterAtom.getRadius(), 
-          iterAtom.getBondRadius()
-          );
+      Atom atom = addAtom(isPdbThisModel, iterAtom, name, isotope, siteBase, charge, group3); 
       if (haveBonds)
         htAtomMap.put(iterAtom.getUniqueID(), atom);
     }
@@ -943,12 +924,22 @@ public final class ModelLoader {
             : 0);
   }
 
-  private Atom addAtom(boolean isPDB, BS atomSymmetry, int atomSite, int atomicAndIsotopeNumber,
-                       String atomName, int formalCharge, float partialCharge,
-                       Lst<Object> tensors, float occupancy, float bfactor,
-                       P3 xyz, boolean isHetero, int atomSerial, int atomSeqID,
-                       String group3, V3 vib, char alternateLocationID,
-                       float radius, float bondRadius) {
+  private Atom addAtom(boolean isPDB, JmolAdapterAtomIterator iterAtom, String atomName, int atomicAndIsotopeNumber, int siteBase, int formalCharge, String group3) {    
+    BS atomSymmetry = iterAtom.getSymmetry();
+    int atomSite = iterAtom.getAtomSite() + siteBase;
+    float partialCharge = iterAtom.getPartialCharge();
+    Lst<Object> tensors = iterAtom.getTensors();
+    float occupancy = iterAtom.getOccupancy();
+    float bfactor = iterAtom.getBfactor();
+    P3 xyz = iterAtom.getXYZ();
+    boolean isHetero = iterAtom.getIsHetero();
+    boolean isNegDisorder = (iterAtom.getPart() < 0);
+    int atomSerial = iterAtom.getSerial();
+    int atomSeqID = iterAtom.getSeqID();
+    V3 vib = iterAtom.getVib();
+    char alternateLocationID = iterAtom.getAltLoc();
+    float radius = iterAtom.getRadius();
+    float bondRadius = iterAtom.getBondRadius();
     byte specialAtomID = 0;
     String atomType = null;
     if (atomName != null) {
@@ -969,8 +960,8 @@ public final class ModelLoader {
     }
     Atom atom = ms.addAtom(iModel, nullGroup, atomicAndIsotopeNumber, atomName,
         atomType, atomSerial, atomSeqID, atomSite, xyz, radius, vib, formalCharge,
-        partialCharge, occupancy, bfactor, tensors, isHetero, specialAtomID,
-        atomSymmetry, bondRadius);
+        partialCharge, occupancy, bfactor, tensors, isHetero, isNegDisorder,
+        specialAtomID, atomSymmetry, bondRadius);
     atom.altloc = alternateLocationID;
     return atom;
   }
