@@ -37,6 +37,17 @@ import javajs.util.SB;
 
 public class Text {
  
+  public final static int PYMOL_LABEL_OFFSET_JMOL= -1;
+  public final static int PYMOL_LABEL_OFFSET_ABS = 0;
+  public final static int PYMOL_LABEL_OFFSET_ANG = 0;
+  public final static int PYMOL_LABEL_OFFSET_REL = 1;
+  public final static int PYMOL_LABEL_OFFSET_PIX = 2; // and not -1
+
+  public final static int PYMOL_LABEL_OFFSET_ABS_ANG = 0;
+  public final static int PYMOL_LABEL_OFFSET_REL_ANG = PYMOL_LABEL_OFFSET_REL; 
+  public final static int PYMOL_LABEL_OFFSET_ABS_PIX = PYMOL_LABEL_OFFSET_PIX;
+  public final static int PYMOL_LABEL_OFFSET_REL_PIX = PYMOL_LABEL_OFFSET_REL | PYMOL_LABEL_OFFSET_PIX;
+  
   private Viewer vwr;
 
   public boolean doFormatText;
@@ -66,13 +77,73 @@ public class Text {
 
   public float barDistance;
 
+  public boolean isMeasure;
+  public boolean isEcho;
+  public P3 xyz;
+  public String target;
+  public String script;
+  public short colix;
+  public short bgcolix;
+  public int pointer;
+  public float fontScale;
 
+  public int align;
+  public int valign;
+  public int atomX, atomY, atomZ = Integer.MAX_VALUE;
+  public int movableX, movableY, movableZ; // Echo only
+  public int movableXPercent = Integer.MAX_VALUE; // Echo only
+  public int movableYPercent = Integer.MAX_VALUE; // Echo only
+  public int movableZPercent = Integer.MAX_VALUE; // Echo only
+
+  public int z = 1; // front plane
+  public int zSlab = Integer.MIN_VALUE; // z for slabbing purposes -- may be near an atom
+
+  private float xAdj, yAdj;
+
+  private float y0;
+
+  public P3 pointerPt; // for echo
+
+  public float[] pymolOffset;
+
+  protected int windowWidth;
+  protected int windowHeight;
+  public boolean adjustForWindow;
+  public float boxWidth;
+  public float boxHeight;
+  public float boxX;
+  public float boxY;
+
+  public int modelIndex = -1;
+  public boolean thisModelOnly;
+  public boolean visible = true;
+  public boolean hidden = false;
+
+  public float[] boxXY;
+
+  public float scalePixelsPerMicron;
+
+  public int barPixelsXYZ;
+
+  private float sppa;
+  
   public Text() {
     // public for reflection
     // requires .newLabel or .newEcho
     boxXY =  new float[5];
   }
 
+  /**
+   * 
+   * @param vwr
+   * @param font
+   * @param text
+   * @param colix
+   * @param bgcolix
+   * @param align
+   * @param scalePixelsPerMicron
+   * @return the new label
+   */
   static public Text newLabel(Viewer vwr, Font font, String text,
                               short colix, short bgcolix, int align, float scalePixelsPerMicron) {
     // for labels and hover
@@ -216,15 +287,20 @@ public class Text {
     else
       this.boxXY = boxXY;
     setWindow(vwr.gdata.width, vwr.gdata.height, scalePixelsPerMicron);
-    if (scalePixelsPerMicron != 0 && this.scalePixelsPerMicron != 0)
+    if (font.fontSizeAngstroms != 0 || scalePixelsPerMicron != 0 && this.scalePixelsPerMicron != 0) {
+      if (font.fontSizeAngstroms == 0) {
       setFontScale(scalePixelsPerMicron / this.scalePixelsPerMicron);
-    else if (fontScale != imageFontScaling)
+      } else {
+        setFontScale(sppa * font.fontSizeAngstroms / font.fontSizeNominal);
+      }
+    } else if (fontScale != imageFontScaling) {
       setFontScale(imageFontScaling);
+    }
     if (doFormatText) {
       text = (isEcho ? vwr.formatText(textUnformatted) : textUnformatted);
       recalc();
     } else {
-      if (textUnformatted != null && textUnformatted.startsWith("%SCALE")) {
+      if (textUnformatted != null && textUnformatted.startsWith(JC.scaleName)) {
         float[] ret = new float[2];
         text = vwr.getScaleText(textUnformatted.substring(6).trim(), vwr.antialiased, (xyz == null ? 15 : 8), ret);
         barPixels = (int) (ret[0] * (vwr.antialiased ? 2 : 1));
@@ -245,7 +321,7 @@ public class Text {
         // [1,2,3] are in Angstroms, not screen pixels
         float pixelsPerAngstrom = vwr.tm.scaleToScreen(z, 1000);
         float pz = pymolOffset[3];
-        float dz = (pz < 0 ? -1 : 1) * Math.max(pz == 0 ? 0.5f : 0, Math.abs(pz) - 1)
+        float dz = (pz < 0 ? -1 : 1) * Math.max(pz == 0 ? 0 : 0, Math.abs(pz) - 1)
             * pixelsPerAngstrom;
         z -= (int) dz;
         pixelsPerAngstrom = vwr.tm.scaleToScreen(z, 1000);
@@ -286,8 +362,12 @@ public class Text {
         // xAdj and yAdj are the adjustments for the box itself relative to the text 
         xAdj = (fontScale >= 2 ? 8 : 4);
         yAdj = -descent;
-        boxXY[0] = movableX - xAdj;
-        boxXY[1] = movableY - yAdj;
+        // a bit of a hack here.
+        // a bit of a hack here.
+//      boxXY[0] = movableX - xAdj;
+//      boxXY[1] = movableY - yAdj;
+      boxXY[0] = movableX - xAdj;
+      boxXY[1] = movableY - yAdj + (descent -ascent)/2 + 8; //  empirical only
         isAbsolute = true;
         boxYoff2 = -2; // empirical fudge factor
       } else {
@@ -465,12 +545,6 @@ public class Text {
     return w;
   }
 
-  private float xAdj, yAdj;
-
-  private float y0;
-
-  public P3 pointerPt; // for echo
-
   public void setXYA(float[] xy, int i) {
     if (i == 0) {
       xy[2] = boxX;
@@ -503,27 +577,6 @@ public class Text {
       s.append(" " + (10000f / scalePixelsPerMicron)); // Angstroms per pixel
   }
 
-  public boolean isMeasure;
-  public boolean isEcho;
-  public P3 xyz;
-  public String target;
-  public String script;
-  public short colix;
-  public short bgcolix;
-  public int pointer;
-  public float fontScale;
-
-  public int align;
-  public int valign;
-  public int atomX, atomY, atomZ = Integer.MAX_VALUE;
-  public int movableX, movableY, movableZ; // Echo only
-  public int movableXPercent = Integer.MAX_VALUE; // Echo only
-  public int movableYPercent = Integer.MAX_VALUE; // Echo only
-  public int movableZPercent = Integer.MAX_VALUE; // Echo only
-
-  public int z = 1; // front plane
-  public int zSlab = Integer.MIN_VALUE; // z for slabbing purposes -- may be near an atom
-
   // PyMOL-type offset
   // [mode, screenoffsetx,y,z (applied after tranform), positionOffsetx,y,z (applied before transform)]
 
@@ -548,36 +601,6 @@ public class Text {
 //   
 //   
 
-  public final static int PYMOL_LABEL_OFFSET_JMOL= -1;
-  public final static int PYMOL_LABEL_OFFSET_REL = 1;
-  public final static int PYMOL_LABEL_OFFSET_PIX = 2; // and not -1
-
-  public final static int PYMOL_LABEL_OFFSET_ABS_ANG = 0;
-  public final static int PYMOL_LABEL_OFFSET_REL_ANG = PYMOL_LABEL_OFFSET_REL; 
-  public final static int PYMOL_LABEL_OFFSET_ABS_PIX = PYMOL_LABEL_OFFSET_PIX;
-  public final static int PYMOL_LABEL_OFFSET_REL_PIX = PYMOL_LABEL_OFFSET_REL | PYMOL_LABEL_OFFSET_PIX;
-  
-  public float[] pymolOffset;
-
-  protected int windowWidth;
-  protected int windowHeight;
-  public boolean adjustForWindow;
-  public float boxWidth;
-  public float boxHeight;
-  public float boxX;
-  public float boxY;
-
-  public int modelIndex = -1;
-  public boolean thisModelOnly;
-  public boolean visible = true;
-  public boolean hidden = false;
-
-  public float[] boxXY;
-
-  public float scalePixelsPerMicron;
-
-  public int barPixelsXYZ;
-
   public void setScalePixelsPerMicron(float scalePixelsPerMicron) {
     fontScale = 0;//fontScale * this.scalePixelsPerMicron / scalePixelsPerMicron;
     this.scalePixelsPerMicron = scalePixelsPerMicron;
@@ -729,10 +752,11 @@ public class Text {
    * @param screen
    * @param zSlab
    * @param pTemp
-   * @param sppm
+   * @param sppa screen pixels per angstrom regardless of font scaling
    */
-  public void getPymolScreenOffset(P3 atomPt, P3i screen, int zSlab, P3 pTemp,
-                                   double sppm) {
+  public void getPymolScreenOffset(P3 atomPt, P3i screen, int zSlab, P3 pTemp, 
+                                   float sppa) {
+	this.sppa = sppa;
     boolean isPixel = isPymolOffsetPixels();
     boolean isRelative = isPymolOffsetRelative();
     if (atomPt != null && isRelative)
@@ -747,8 +771,6 @@ public class Text {
       screen.z += pymolOffset[3];
     }
     setXYZs(screen.x, screen.y, screen.z, zSlab);
-    // commented out; this next was the problem with setFontScaling TRUE and a 3d echo with offset
-    //      setScalePixelsPerMicron(sppm);
   }
 
   private boolean isPymolOffsetRelative() {
