@@ -33,7 +33,7 @@ public class TickInfo {
   }
 
   public String id = "";
-  public String type = " ";
+  public char type = ' ';
   public P3 ticks;
   public String[] tickLabelFormats;
   public P3 scale;
