@@ -57,7 +57,11 @@ public class AminoPolymer extends AlphaPolymer {
    *  
    */
   
-  
+  /**
+   * 
+   * @param monomers
+   * @param pt0
+   */
   AminoPolymer(Monomer[] monomers, int pt0) {
     super(monomers, pt0);
     type = TYPE_AMINO;
@@ -332,7 +336,7 @@ public class AminoPolymer extends AlphaPolymer {
     //
     //    AH args[0], CH args[1], CD args[2], DA args[3]
 
-    int energy = HBond.getEnergy(distOH, distCH, distCN, distON);
+    int energy = HBond.calcEnergy(distOH, distCH, distCN, distON);
 
     boolean isHbond = (energy < -500 
         && (!checkDistances || distCN > distCH && distOH <= 3.0f));
@@ -424,7 +428,7 @@ public class AminoPolymer extends AlphaPolymer {
         }
         end--;
         if (end >= start + 3) {
-          addStructureProtected(STR.HELIX, null, 0,
+          addStructureProtected(STR.HELIX, null, null,
               0, start, end);
         }
         start = end;
@@ -438,7 +442,7 @@ public class AminoPolymer extends AlphaPolymer {
         }
         end--;
         if (end >= start + 3) {
-          addStructureProtected(STR.HELIX, null, 0,
+          addStructureProtected(STR.HELIX, null, null,
               0, start, end);
         }
         start = end;
@@ -453,7 +457,7 @@ public class AminoPolymer extends AlphaPolymer {
         }
         end--;
         if (end >= start + 2) {
-          addStructureProtected(STR.SHEET, null, 0,
+          addStructureProtected(STR.SHEET, null, null,
               0, start, end);
         }
         start = end;
@@ -468,7 +472,7 @@ public class AminoPolymer extends AlphaPolymer {
         }
         end--;
         if (end >= start + 2) {
-          addStructureProtected(STR.TURN, null, 0,
+          addStructureProtected(STR.TURN, null, null,
               0, start, end);
         }
         start = end;
