@@ -779,6 +779,8 @@ public class BioExt {
     for (int i = 0; i < n; i++) {
       a1 = vCA.get(i);
       int polymerIndex = a1.group.getBioPolymerIndexInModel();
+      if (polymerIndex < 0)
+        continue; // lone MET ligand in 4mwb
       int monomerIndex = a1.group.getMonomerIndex();
       int bpt = monomerIndex;
       if (bpt < nEndMin)
@@ -1329,7 +1331,7 @@ public class BioExt {
           Lst<Atom> vConnections = new Lst<Atom>();
           vConnections.addLast(a);
           Atom b = vwr.ms.addAtom(a.mi, a.group, 1, "H3", null, 0, a.getSeqID(), 0, p[0],
-              Float.NaN, null, 0, 0, 1, 0, null, a.isHetero(), (byte) 0, null, Float.NaN);
+              Float.NaN, null, 0, 0, 1, 0, null, a.isHetero(), false, (byte) 0, null, Float.NaN);
           vwr.ms.bondAtoms(a, b, Edge.BOND_COVALENT_SINGLE, 
               vwr.ms.getDefaultMadFromOrder(Edge.BOND_COVALENT_SINGLE), null, 0, true, false);
           b.setMadAtom(vwr,  vwr.rd);
