@@ -31,10 +31,12 @@ import org.jmol.modelset.Structure;
 
 import javajs.util.Lst;
 import javajs.util.P3;
-import javajs.util.PT;
 import javajs.util.V3;
 
 import org.jmol.script.T;
+import org.jmol.shapebio.BioShape;
+import org.jmol.shapebio.BioShapeCollection;
+import org.jmol.viewer.JC;
 
 
 /**
@@ -51,10 +53,6 @@ import org.jmol.script.T;
  */
 public abstract class BioPolymer implements Structure {
 
-  protected BioPolymer() {
-    
-  }
-  
   public Model model;
 
   public Monomer[] monomers;
@@ -82,9 +80,10 @@ public abstract class BioPolymer implements Structure {
   protected final static int TYPE_CARBOHYDRATE = 3;
 
   public int cyclicFlag;
-  
-  protected void set(Monomer[] monomers) {
+
+  protected BioPolymer(Monomer[] monomers, boolean hasStructure) {
     this.monomers = monomers;
+    this.hasStructure = hasStructure;
     monomerCount = monomers.length;
     for (int i = monomerCount; --i >= 0;)
       monomers[i].setBioPolymer(this, i);
@@ -179,13 +178,27 @@ public abstract class BioPolymer implements Structure {
 
   public void setConformation(BS bsSelected) {
     Atom[] atoms = model.ms.at;
+    boolean updated = false;
     for (int i = monomerCount; --i >= 0;)
-      monomers[i].updateOffsetsForAlternativeLocations(atoms, bsSelected);
+      if (monomers[i].updateOffsetsForAlternativeLocations(atoms, bsSelected))
+        updated = true;
+    if (updated) {
     recalculateLeadMidpointsAndWingVectors();
+      for (int i = JC.SHAPE_MIN_SECONDARY; i < JC.SHAPE_MAX_SECONDARY; i++) {
+        BioShapeCollection s = (BioShapeCollection) model.ms.vwr.shm.shapes[i];
+        if (s == null)
+          continue;
+        for (int b = s.bioShapes.length; --b >= 0;) {
+          BioShape bi = s.bioShapes[b];
+          if (bi.bioPolymer == this)
+            bi.falsifyMesh();
+        }
+      }
+    }
   }
 
   private boolean invalidLead;
-  protected boolean invalidControl = false;
+  protected boolean invalidControl;
 
   public void recalculateLeadMidpointsAndWingVectors() {
     //System.out.println("biopo recalcLeadMP");
@@ -265,7 +278,7 @@ public abstract class BioPolymer implements Structure {
       leadMidpoints = new P3[monomerCount + 1];
       leadPoints = new P3[monomerCount + 1];
       wingVectors = new V3[monomerCount + 1];
-      sheetSmoothing = PT.FLOAT_MIN_SAFE;
+      sheetSmoothing = JC.FLOAT_MIN_SAFE;
     }
     if (reversed == null)
       reversed = BS.newN(monomerCount);
