@@ -287,7 +287,7 @@ public final class BioResolver implements Comparator<String[]> {
     Atom a = ms.at[iFirst];
     for (int i = 0; i < nH; i++)
       ms.addAtom(a.mi, a.group, 1, "H", null, 0, a.getSeqID(), 0, xyz,
-          Float.NaN, null, 0, 0, 1, 0, null, isHetero, (byte) 0, null, Float.NaN)
+          Float.NaN, null, 0, 0, 1, 0, null, isHetero, false, (byte) 0, null, Float.NaN)
           .delete(null);
   }
 
@@ -628,6 +628,8 @@ public final class BioResolver implements Comparator<String[]> {
     int bondCount = ms.bondCount;
     Bond[] bonds = ms.bo;
     for (int i = baseBondIndex; i < bondCount; i++) {
+      if (bonds[i] == null)
+        continue;
       Atom a1 = bonds[i].atom1;
       Atom a2 = bonds[i].atom2;
       Group g = a1.group;
