@@ -41,7 +41,7 @@ import javajs.util.P3;
 import org.jmol.viewer.JC;
 import org.jmol.script.T;
 
-
+import java.util.Arrays;
 import java.util.Map;
 
 /**
@@ -113,10 +113,10 @@ public abstract class Monomer extends Group {
   @Override
   public int getAtomIndex(String name, int offset) {
     if (bioPolymer != null) {
-      Group[] groups = bioPolymer.monomers;
+      Monomer[] groups = bioPolymer.monomers;
       int ipt = monomerIndex + offset;
       if (ipt >= 0 && ipt < groups.length) {
-        Group m = groups[ipt];
+        Monomer m = groups[ipt];
         if (offset == 1 && !m.isConnectedPrevious())
           return -1;
         if ("\0".equals(name))
@@ -308,7 +308,8 @@ public abstract class Monomer extends Group {
     return (structure instanceof ProteinStructure ? ((ProteinStructure)structure).type.getBioStructureTypeName(false) : "");
   }
 
-  final void updateOffsetsForAlternativeLocations(Atom[] atoms, BS bsSelected) {
+  final boolean updateOffsetsForAlternativeLocations(Atom[] atoms, BS bsSelected) {
+      boolean updated = false;
       for (int offsetIndex = offsets.length; --offsetIndex >= 0;) {
         int offset = offsets[offsetIndex] & 0xFF;
         if (offset == 255)
@@ -335,12 +336,13 @@ public abstract class Monomer extends Group {
                   && !atoms[iNew].getAtomName().equals(atom.getAtomName()))
             continue;
           offsets[offsetIndex] = (byte) offsetNew;
-          //System.out.println("Chain.udateOffsetsForAlternativeLocation " + atoms[iNew] + " was " + atom);
           atoms[iNew].nBackbonesDisplayed = atom.nBackbonesDisplayed;
+          updated = true;
           break;
         }
       }
       setLeadAtomIndex();
+      return updated;
   }
     
   final void getMonomerSequenceAtoms(BS bsInclude, BS bsResult) {
@@ -467,7 +469,6 @@ public abstract class Monomer extends Group {
     return haveCrossLink;
   }
   
-  @Override
   public boolean isConnectedPrevious() {
     return true; // but not nec. for carbohydrates... see 1k7c
   }
