@@ -25,9 +25,11 @@ package org.jmol.modelsetbio;
 
 public class PhosphorusPolymer extends BioPolymer {
 
+  /**
+   * @param monomers
+   */
   PhosphorusPolymer(Monomer[] monomers) {
-    set(monomers);
-    hasStructure = true;
+    super(monomers, true);
   }
 
 }
