@@ -41,7 +41,7 @@ public abstract class ProteinStructure implements Structure {
   STR subtype;
   String structureID;
   int strucNo;
-  int serialID;
+  String serialID;
   int strandCount = 1;
   int id;
 
@@ -57,7 +57,10 @@ public abstract class ProteinStructure implements Structure {
   private P3[] segments;
 
   protected ProteinStructure() {
-    id = ++ids;
+    incrementID();
+  }
+  protected void incrementID() {
+    id = ++ids;    
   }
   /**
    * 
