@@ -616,8 +616,8 @@ public final class Navigator extends JmolThread implements
         && tm.navZ < 0) {
       tm.navZ = 0;
     }
-    tm.rotateXRadians(JC.radiansPerDegree * -.02f * tm.navY, null);
-    tm.rotateYRadians(JC.radiansPerDegree * .02f * tm.navX, null);
+    tm.rotateXRadians((float) (JC.radiansPerDegree * -.02 * tm.navY), null);
+    tm.rotateYRadians((float) (JC.radiansPerDegree * .02 * tm.navX), null);
     P3 pt = tm.navigationCenter;
     P3 pts = new P3();
     tm.transformPt3f(pt, pts);
@@ -683,7 +683,7 @@ public final class Navigator extends JmolThread implements
         break;
       }
       if (isAltKey) {
-        tm.rotateXRadians(JC.radiansPerDegree * -.2f * multiplier,
+        tm.rotateXRadians((float) (JC.radiansPerDegree * -.2 * multiplier),
             null);
         tm.navMode = TransformManager.NAV_MODE_NEWXYZ;
         break;
@@ -715,7 +715,7 @@ public final class Navigator extends JmolThread implements
         break;
       }
       if (isAltKey) {
-        tm.rotateXRadians(JC.radiansPerDegree * .2f * multiplier,
+        tm.rotateXRadians((float) (JC.radiansPerDegree * .2 * multiplier),
             null);
         tm.navMode = TransformManager.NAV_MODE_NEWXYZ;
         break;
@@ -739,7 +739,7 @@ public final class Navigator extends JmolThread implements
         tm.navMode = TransformManager.NAV_MODE_NEWXY;
         break;
       }
-      tm.rotateYRadians(JC.radiansPerDegree * 3 * -.2f * multiplier,
+      tm.rotateYRadians((float) (JC.radiansPerDegree * 3 * -.2 * multiplier),
           null);
       tm.navMode = TransformManager.NAV_MODE_NEWXYZ;
       break;
@@ -758,7 +758,7 @@ public final class Navigator extends JmolThread implements
         tm.navMode = TransformManager.NAV_MODE_NEWXY;
         break;
       }
-      tm.rotateYRadians(JC.radiansPerDegree * 3 * .2f * multiplier,
+      tm.rotateYRadians((float) (JC.radiansPerDegree * 3 * .2 * multiplier),
           null);
       tm.navMode = TransformManager.NAV_MODE_NEWXYZ;
       break;
