@@ -1,7 +1,7 @@
 /* $RCSfile$
- * $Author: aherraez $
- * $Date: 2022-02-08 13:55:30 -0600 (Tue, 08 Feb 2022) $
- * $Revision: 22334 $
+ * $Author: hansonr $
+ * $Date: 2024-05-02 13:36:04 -0500 (Thu, 02 May 2024) $
+ * $Revision: 22623 $
  * AH 2022-02-08, one more term passed to GT localization
  *
  * Copyright (C) 2000-2022  The Jmol Development Team
@@ -74,7 +74,7 @@ public class MainPopupResourceBundle extends PopupResource {
 
       {   "fileMenu", "loadMenu saveMenu exportMenu SIGNEDJAVAcaptureMenuSPECIAL " },
           
-      {   "loadMenu", "SIGNEDloadFile SIGNEDloadUrl SIGNEDloadPdb SIGNEDloadScript - "
+      {   "loadMenu", "SIGNEDloadFile SIGNEDloadUrl SIGNEDloadPdb SIGNEDloadMol SIGNEDloadScript - "
           + "reload SIGNEDloadFileUnitCell" },       
       {   "saveMenu", "writeFileTextVARIABLE writeState writeHistory SIGNEDwriteJmol SIGNEDwriteIsosurface "} ,      
       {   "exportMenu", "SIGNEDNOGLwriteGif SIGNEDNOGLwriteJpg SIGNEDNOGLwritePng " +
@@ -208,17 +208,19 @@ public class MainPopupResourceBundle extends PopupResource {
 
       {   "pickingMenu",
           "pickOff pickCenter pickIdent pickLabel pickAtom "
-              + "pickMolecule pickElement - pickSpin - modelKitMode - PDBpickChain PDBpickGroup SYMMETRYpickSite" },
+              + "pickMolecule pickElement - dragAtom dragMolecule - pickSpin - modelKitMode - PDBpickChain PDBpickGroup SYMMETRYpickSite" },
 
       {   "computationMenu",
-          "minimize modelkit"
+          "minimize"
               /* calculateVolume*/ },
 
               
       {   "showMenu",
           "showHistory showFile showFileHeader - "
               + "showOrient showMeasure - "
-              + "showSpacegroup showState SYMMETRYshowSymmetry UNITCELLshow - showIsosurface showMo - extractMOL" },
+              + "showSpacegroup showState SYMMETRYshowSymmetry UNITCELLshow - "
+              + "showIsosurface showMo - "
+              + "modelkit extractMOL" },
 
       {    "SIGNEDJAVAcaptureMenuSPECIAL", "SIGNEDJAVAcaptureRock SIGNEDJAVAcaptureSpin - SIGNEDJAVAcaptureBegin SIGNEDJAVAcaptureEnd SIGNEDJAVAcaptureOff SIGNEDJAVAcaptureOn SIGNEDJAVAcaptureFpsSPECIAL SIGNEDJAVAcaptureLoopingSPECIAL" },
 
@@ -465,7 +467,8 @@ public class MainPopupResourceBundle extends PopupResource {
         "vectorOn", null,
         "spinOn", null,
         "on", null,
-        "SIGNEDloadPdb", GT.$("Open from PDB"),      
+        "SIGNEDloadPdb", GT.$("Get PDB file"),
+        "SIGNEDloadMol", GT.$("Get MOL file"),
         "SIGNEDloadFile", GT.$("Open local file"),      
         "SIGNEDloadScript", GT.$("Open script"),      
         "SIGNEDloadUrl", GT.$("Open URL"),      
@@ -516,6 +519,8 @@ public class MainPopupResourceBundle extends PopupResource {
         "structure#PDB", null,
         "selectMenuText", GT.$("Select ({0})"),
         "pickAtom", GT.$("Select atom"),
+        "dragAtom", GT.$("Drag atom"),
+        "dragMolecule", GT.$("Drag molecule"),
         "PDBpickChain", GT.$("Select chain"),
         "pickElement", GT.$("Select element"),
         "PDBpickGroup", GT.$("Select group"),
@@ -905,6 +910,8 @@ public class MainPopupResourceBundle extends PopupResource {
       { "pickIdent", "set picking ident" },
       { "pickLabel", "set picking label" },
       { "pickAtom", "set picking atom" },
+      { "dragAtom", "set picking dragAtom" },
+      { "dragMolecule", "set picking dragMolecule" },
       { "PDBpickChain", "set picking chain" },
       { "pickElement", "set picking element" },
       { "modelKitMode", "set modelKitMode" },
@@ -928,7 +935,8 @@ public class MainPopupResourceBundle extends PopupResource {
       { "showState", "console on;show state" },
       
       { "reload", "load \"\"" },
-      { "SIGNEDloadPdb", "load ?PdbId?" },      
+      { "SIGNEDloadPdb", JC.getMenuScript("openPDB") },      
+      { "SIGNEDloadMol", JC.getMenuScript("openMOL") },      
       { "SIGNEDloadFile", "load ?" },      
       { "SIGNEDloadUrl", "load http://?" },      
       { "SIGNEDloadFileUnitCell", "load ? {1 1 1}" },      
