@@ -196,7 +196,7 @@ public class MOCalculation extends QuantumCalculation {
         Logger.info("Normalization of contractions (NWCHEM)");
       }        
     }
-    Logger.info("Normalizing AOs: " + type + " slaters:" + (slaters != null));
+    //Logger.info("Normalizing AOs: " + type + " slaters:" + (slaters != null));
   }
 
   @Override
@@ -334,7 +334,7 @@ public class MOCalculation extends QuantumCalculation {
     //System.out.println("shell " + iShell + " type " + basisType);
     if (atomIndex != lastAtom && (thisAtom = qmAtoms[atomIndex]) != null)
       thisAtom.setXYZ(this, true);
-    if (!setCoeffs(shell[1], true))
+    if (!allowType(basisType) || !setCoeffs(shell[1], true))
       return;
     if (havePoints)
       setMinMax(-1);
@@ -378,7 +378,7 @@ public class MOCalculation extends QuantumCalculation {
    * @return true if implemented
    */
   private boolean addHighL(int basisType) {
-    if (basisType >= QS.GS && highLEnabled[basisType] == 0)
+    if (!allowType(basisType))
       return false;
     DataAdder adder = dataAdders[basisType];
     switch (dataAdderOK[basisType]) {
@@ -397,6 +397,10 @@ public class MOCalculation extends QuantumCalculation {
     dataAdderOK[basisType] = -1;
     return false;
   }
+  
+  private boolean allowType(int basisType) {
+	return (basisType < QS.GS || highLEnabled[basisType] != 0);
+  }
 
   private void addValuesSquared(float occupancy) {
     for (int ix = nX; --ix >= 0;) {
@@ -459,11 +463,8 @@ public class MOCalculation extends QuantumCalculation {
       moCoeff += map.length;
       return false;
     }
-    for (int i = 0; i < map.length; i++) {
-      if (map[i] + moCoeff >= moCoefficients.length)
-        System.out.println("OHOH");
+    for (int i = 0; i < map.length; i++)
       isOK |= ((coeffs[i] = moCoefficients[map[i] + moCoeff++]) != 0);
-    }
     isOK &= (coeffs[0] != Integer.MIN_VALUE);
     if (isOK && doDebug && isProcess)
       dumpInfo(type);
@@ -889,7 +890,6 @@ public class MOCalculation extends QuantumCalculation {
     int c = slater.z;
     int d = slater.r;
     //  System.out.println("MOCALC " + slaterIndex + " atomNo=" + (atomIndex+1) + "\tx^" + a + " y^"+ b + " z^" + c + " r^" + d + "\tzeta=" + (-minuszeta) + "\tcoef=" + coef);
-          //+ " minmax " + xMin + " " + xMax + " " + yMin + " " + yMax + " " + zMin + " " + zMax
     if (a == -2) /* if dz2 */
       for (int ix = xMax; --ix >= xMin;) {
         double dx2 = X2[ix];
@@ -1047,7 +1047,8 @@ public class MOCalculation extends QuantumCalculation {
 
   private void dumpInfo(int shell) {
     if (doShowShellType) {
-      Logger.debug("\n\t\t\tprocessShell: " + shell + " type="
+      if (Logger.debugging)
+        Logger.debug("\n\t\t\tprocessShell: " + shell + " type="
           + QS.getQuantumShellTag(shell) + " nGaussians="
           + nGaussians + " atom=" + atomIndex);
       doShowShellType = false;
@@ -1057,7 +1058,8 @@ public class MOCalculation extends QuantumCalculation {
       for (int ig = 0; ig < nGaussians; ig++) {
         double alpha = gaussians[gaussianPtr + ig][0];
         double c1 = gaussians[gaussianPtr + ig][1];
-        Logger.debug("\t\t\tGaussian " + (ig + 1) + " alpha=" + alpha + " c="
+        if (Logger.debugging)
+          Logger.debug("\t\t\tGaussian " + (ig + 1) + " alpha=" + alpha + " c="
             + c1);
       }
     }
@@ -1065,6 +1067,7 @@ public class MOCalculation extends QuantumCalculation {
       for (int i = 0; i < map.length; i++) {
         int n = map[i] + moCoeff - map.length + i + 1;
         double c = coeffs[i];
+        if (Logger.debugging)
           Logger.debug("MO coeff " + (so == null ? "?" : so[i]) + " "
               + n + "\t" + c + "\t" + thisAtom.atom);
       
@@ -1103,7 +1106,7 @@ public class MOCalculation extends QuantumCalculation {
     float volume = stepBohr[0] * stepBohr[1] * stepBohr[2]; 
         // / bohr_per_angstrom / bohr_per_angstrom / bohr_per_angstrom;
     integration *= volume;
-    Logger.info("Integrated density = " + integration);
+    Logger.info("Integrated density = " + integration + " for volume " + (volume * nX * nY * nZ/ bohr_per_angstrom / bohr_per_angstrom / bohr_per_angstrom) + " Ang^3 steps " + nX + " " + nY + " " + nZ);
   }
 
 }
