@@ -39,6 +39,7 @@ import java.util.Map;
 
 import javajs.util.BS;
 import javajs.util.Lst;
+import javajs.util.SB;
 
 import org.jmol.modelset.Atom;
 import org.jmol.viewer.JC;
@@ -260,7 +261,7 @@ public class NMRNoeMatrix {
 //
     BS bsH = null;
     try {
-      bsH = (bsMol.cardinality() == 0 ? new BS() : viewer.getSmartsMatch("[H]",
+      bsH = (bsMol.isEmpty() ? new BS() : viewer.getSmartsMatch("[H]",
           bsMol));
     } catch (Exception e1) {
       // not possible - the SMARTS expression is valid.
@@ -624,8 +625,8 @@ public class NMRNoeMatrix {
   
   @Override
   public String toString() {
-    StringBuffer sb;
-    sb = new StringBuffer();
+    SB sb;
+    sb = new SB();
     for (i = 0; i < nHAtoms; i++) {
       for (j = 0; j < nHAtoms; j++) {
         sb.append(nf.format(noeM[i][j]) + "\t");
@@ -638,11 +639,10 @@ public class NMRNoeMatrix {
   }
 
   public String toStringNormRow() {
-    StringBuffer sb;
     NumberFormat nf = NumberFormat.getInstance();
     nf.setMinimumFractionDigits(4);
     nf.setMaximumFractionDigits(4);
-    sb = new StringBuffer();
+    SB sb = new SB();
     for (i = 0; i < nHAtoms; i++) {
       for (j = 0; j < nHAtoms; j++) {
         double val = noeM[i][j] / noeM[i][i];
