@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2023-01-05 08:42:06 -0600 (Thu, 05 Jan 2023) $
- * $Revision: 22500 $
+ * $Date: 2024-08-15 08:50:13 -0500 (Thu, 15 Aug 2024) $
+ * $Revision: 22630 $
 
  *
  * Copyright (C) 2002-2005  The Jmol Development Team
@@ -103,12 +103,13 @@ public class SticksRenderer extends FontLineShapeRenderer {
         for (int i = bsForPass2.nextSetBit(0); i >= 0; i = bsForPass2
             .nextSetBit(i + 1)) {
           bond = bonds[i];
-          renderBond();
+          if (bond != null)
+            renderBond();
         }
     } else {
       for (int i = ms.bondCount; --i >= 0;) {
         bond = bonds[i];
-        if ((bond.shapeVisibilityFlags & myVisibilityFlag) != 0 && renderBond()) {
+        if (bond != null && (bond.shapeVisibilityFlags & myVisibilityFlag) != 0 && renderBond()) {
           needTranslucent = true;
           bsForPass2.set(i);
         }
@@ -121,7 +122,7 @@ public class SticksRenderer extends FontLineShapeRenderer {
     useBananas = (vwr.getBoolean(T.multiplebondbananas) && !isPymol);
     // negative spacing is relative, depending upon atom-atom distance;
     // positive spacing is absolute, for fixed in-plane (radiusFactor > 0) or perp-plane (radiusFactor < 0)
-    multipleBondSpacing = (isPymol ? 0.15f : vwr
+    multipleBondSpacing = (isPymol ? 0.26f : vwr
         .getFloat(T.multiplebondspacing));
     // negative radius factor indicates perpendicular fixed double bond
     multipleBondRadiusFactor = (isPymol ? 0.4f : vwr
