@@ -192,7 +192,7 @@ public class DrawRenderer extends MeshRenderer {
       nPoints = setArc(vertices[0], vertices[1], ptRef, nDegreesOffset, theta,
           fractionalOffset, dmesh.scale);
       if (dmesh.isVector && !dmesh.noHead) {
-        renderArrowHead(pt0, pt1, 0.3f, false, false, dmesh.isBarb);
+        renderArrowWithHead(pt0, pt1, 0.3f, false, false, dmesh.isBarb);
         tm.transformPtScr(pt1f, screens[nPoints - 1]);
         tm.transformPtScrT3(pt1f, p3Screens[nPoints - 1]);
       }
@@ -200,7 +200,7 @@ public class DrawRenderer extends MeshRenderer {
       break;
     case ARROW:
       if (!isCurved) {
-        renderArrowHead(vertices[0], vertices[1], 0, false, true, dmesh.isBarb);
+        renderArrowWithHead(vertices[0], vertices[1], 0, false, true, dmesh.isBarb);
         return;
       }
       int nHermites = 5;
@@ -211,7 +211,7 @@ public class DrawRenderer extends MeshRenderer {
           vertices[vertexCount - 2], vertices[vertexCount - 1],
           vertices[vertexCount - 1], vertices[vertexCount - 1],
           controlHermites, 0, nHermites, true);
-      renderArrowHead(controlHermites[nHermites - 2],
+      renderArrowWithHead(controlHermites[nHermites - 2],
           controlHermites[nHermites - 1], 0, false, false, dmesh.isBarb);
       break;
     }
@@ -409,7 +409,7 @@ public class DrawRenderer extends MeshRenderer {
       g3d.drawDashedLineBits(8, 4, pt0, pt1);
     else
       g3d.fillCylinderBits(GData.ENDCAPS_FLAT, diameter, pt0, pt1);
-    renderArrowHead(pt0, pt1, 0, true, false, false);
+    renderArrowWithHead(pt0, pt1, 0, true, false, false);
   }
 
   private final P3 pt0f = new P3();
@@ -418,10 +418,10 @@ public class DrawRenderer extends MeshRenderer {
   private P3 s1f;
   private P3 s2f;
 
-  private void renderArrowHead(T3 pt1, T3 pt2, float factor2,
+  private void renderArrowWithHead(T3 pt1, T3 pt2, float factor2,
                                boolean isTransformed, boolean withShaft,
                                boolean isBarb) {
-    if (dmesh.noHead)
+    if (dmesh.noHead && !withShaft)
       return;
     if (s0f == null) {
       s0f = new P3();
@@ -439,12 +439,17 @@ public class DrawRenderer extends MeshRenderer {
     float d = pt0f.distance(pt2f);
     if (d == 0)
       return;
+    float headWidth = (width > 0 && !dmesh.noHead ? width * 3 : 0);
     vTemp.sub2(pt2f, pt0f);
     vTemp.normalize();
-    vTemp.scale(fScale / 5);
+    vTemp.scale(Math.min(headWidth == 0 ? fScale : headWidth*1.5f, fScale) / 5); // 1/10
     if (!withShaft)
       pt2f.add(vTemp);
     vTemp.scale(5);
+    float len = vTemp.length();
+    if (len > headWidth * 1.5f)
+        vTemp.scale(headWidth * 1.5f/len);
+    ///  pt0====pt1>>>>pt2
     pt1f.sub2(pt2f, vTemp);
     if (isTransformed) {
       s1f.setT(pt1f);
@@ -466,7 +471,7 @@ public class DrawRenderer extends MeshRenderer {
     }
     if (diameter < 1)
       diameter = 1;
-    if (headDiameter > 2)
+    if (headDiameter > 2 && !dmesh.noHead)
       g3d.fillConeScreen3f(GData.ENDCAPS_FLAT, headDiameter, s1f, s2f,
           isBarb);
     if (withShaft)
