@@ -38,7 +38,6 @@ import org.jmol.util.Normix;
 import org.jmol.viewer.JC;
 
 import javajs.util.P3;
-import javajs.util.PT;
 import javajs.util.T3;
 import javajs.util.V3;
 
@@ -168,7 +167,7 @@ public class IsosurfaceRenderer extends MeshRenderer {
           && imesh.jvxlData.isSlabbable) {
         P3[] points = imesh.jvxlData.boundingBox;
         float z0 = Float.MAX_VALUE;
-        float z1 = PT.FLOAT_MIN_SAFE;
+        float z1 = JC.FLOAT_MIN_SAFE;
         for (int i = points.length; --i >= 0;) {
           pt2f.setT(points[i]);
           tm.transformPt3f(pt2f, pt2f);
@@ -305,7 +304,7 @@ public class IsosurfaceRenderer extends MeshRenderer {
       int cX = (showNumbers ? vwr.getScreenWidth() / 2 : 0);
       int cY = (showNumbers ? vwr.getScreenHeight() / 2 : 0);
       if (showNumbers)
-        vwr.gdata.setFontFid(vwr.gdata.getFontFidFS("Monospaced", 24));
+        vwr.gdata.setFontBold("Monospaced", 24);
       for (int i = (!imesh.hasGridPoints || imesh.firstRealVertex < 0 ? 0
           : imesh.firstRealVertex); i < vertexCount; i += incr) {
         if (vertexValues != null && Float.isNaN(vertexValues[i]) || frontOnly
@@ -529,7 +528,7 @@ public class IsosurfaceRenderer extends MeshRenderer {
   private void renderNormals() {
     if (!g3d.setC(C.copyColixTranslucency(mesh.colix, C.WHITE)))
       return;
-    vwr.gdata.setFontFid(vwr.gdata.getFontFidFS("Monospaced", 24));
+    vwr.gdata.setFontBold("Monospaced", 24);
     V3[] vertexVectors = Normix.getVertexVectors();
     for (int i = vertexCount; --i >= 0;) {
       if (vertexValues != null && Float.isNaN(vertexValues[i]))
