@@ -1,6 +1,6 @@
 /* $Author: hansonr $
-* $Date: 2023-01-05 08:42:06 -0600 (Thu, 05 Jan 2023) $
-* $Revision: 22500 $
+* $Date: 2024-08-06 09:08:14 -0400 (Tue, 06 Aug 2024) $
+* $Revision: 22629 $
 *
 * Copyright (C) 2002-2005  The Jmol Development Team
 *
@@ -282,6 +282,8 @@ public class ScriptCompiler extends ScriptTokenParser {
             script
                 .substring(ichToken + JC.STATE_VERSION_STAMP.length(), ptSemi)
                 .trim());
+    } else {
+        haveENDIF = (script.indexOf("endif") >= 0);
     }
     cchScript = script.length();
 
@@ -448,7 +450,7 @@ public class ScriptCompiler extends ScriptTokenParser {
               cchToken = 0;
               continue;
             }
-            if (lookingAtImpliedString(true, true, true))
+            if (lookingAtImpliedString(true, true, true, false))
               ichEnd = ichToken + cchToken;
           }
           return commandExpected();
@@ -1247,7 +1249,6 @@ public class ScriptCompiler extends ScriptTokenParser {
             String strFormat = script.substring(ichToken, ichToken + cchToken);
             T token = T.getTokenFromName(strFormat.toLowerCase());
             switch (token == null ? T.nada : token.tok) {
-            case T.var:
             case T.menu:
             case T.orientation:
             case T.append:
@@ -1257,6 +1258,7 @@ public class ScriptCompiler extends ScriptTokenParser {
               if (nTokens != 1)
                 return ERROR;
               //$FALL-THROUGH$
+            case T.var:
             case T.data:
             case T.file:
             case T.spacegroup:
@@ -1291,12 +1293,14 @@ public class ScriptCompiler extends ScriptTokenParser {
         }
       }
       if (!iHaveQuotedString
-          && lookingAtImpliedString(tokCommand == T.show, tokCommand == T.load,
-              nTokens > 1 || tokCommand != T.script && tokCommand != T.macro)) {
+          && lookingAtImpliedString(
+        		  tokCommand == T.show, 
+        		  tokCommand == T.load,
+              nTokens > 1 || tokCommand != T.script && tokCommand != T.macro, false)) {
         String str = script.substring(ichToken, ichToken + cchToken);
         if (tokCommand == T.script) {
           if (str.startsWith("javascript:")) {
-            lookingAtImpliedString(true, true, true);
+            lookingAtImpliedString(true, true, true, false);
             str = script.substring(ichToken, ichToken + cchToken);
           } else if (str.toUpperCase().indexOf(".PUSH(") >= 0) {
             cchToken = 0;
@@ -1320,6 +1324,17 @@ public class ScriptCompiler extends ScriptTokenParser {
         return CONTINUE;
       }
       break;
+    case T.modelkitmode:
+      if (nTokens == 2 && lastToken.tok == T.spacegroup) {
+        if (lookingAtImpliedString(false, false, false, true)) {
+          if (script.charAt(ichToken + cchToken - 1) == ';')
+            --cchToken;
+          String s = script.substring(ichToken, ichToken + cchToken);
+          addTokenToPrefix(T.o(T.string, s));
+          return CONTINUE;
+        }        
+      }
+      break;
     case T.write:
       // write image 300 300 filename
       // write script filename
@@ -1333,7 +1348,7 @@ public class ScriptCompiler extends ScriptTokenParser {
           iHaveQuotedString = true;
           return OK;
         }
-        if (lookingAtImpliedString(true, true, true)) {
+        if (lookingAtImpliedString(true, true, true, false)) {
           String str = script.substring(ichToken, ichToken + cchToken);
           int pt = str.indexOf(" as ");
           if (pt > 0)
@@ -1351,7 +1366,7 @@ public class ScriptCompiler extends ScriptTokenParser {
     // possibly script
     implicitString &= (nTokens == 1);
     if (implicitString && !((tokCommand == T.script || tokCommand == T.macro)
-        && iHaveQuotedString) && lookingAtImpliedString(true, true, true)) {
+        && iHaveQuotedString) && lookingAtImpliedString(true, true, true, false)) {
       String str = script.substring(ichToken, ichToken + cchToken);
       if (tokCommand == T.label
           && PT.isOneOf(str.toLowerCase(), ";on;off;hide;display;"))
@@ -1433,7 +1448,7 @@ public class ScriptCompiler extends ScriptTokenParser {
       BS bs = lookingAtBitset();
       if (bs != null) {
         addTokenToPrefix(
-            T.o(T.bitset, isBondOrMatrix ? BondSet.newBS(bs, null) : bs));
+            T.o(T.bitset, isBondOrMatrix ? BondSet.newBS(bs) : bs));
         return CONTINUE;
       }
       if (isBondOrMatrix) {
@@ -1546,6 +1561,10 @@ public class ScriptCompiler extends ScriptTokenParser {
       return CONTINUE;
     case T.minusMinus:
     case T.plusPlus:
+      if (nTokens == 0) {
+        tokInitialPlusPlus = theToken.tok;
+        return CONTINUE;
+      }
       if (afterWhite == ichToken || afterMath == ichToken)
         theToken = T.tv(theToken.tok, -1, theToken.value);
       if (!isNewSet && nTokens == 1)
@@ -1722,8 +1741,8 @@ public class ScriptCompiler extends ScriptTokenParser {
   }
 
   private boolean checkNewSetCommand() {
-    String name = ltoken.get(0).value.toString();
-    if (!isContextVariable(name.toLowerCase()))
+    String name = (nTokens == 0 ? "" : ltoken.get(0).value.toString());
+    if (nTokens > 0 && !isContextVariable(name.toLowerCase()))
       return false;
     T t = setNewSetCommand(false, name);
     setCommand(T.tokenSet);
@@ -2061,7 +2080,7 @@ public class ScriptCompiler extends ScriptTokenParser {
           setBraceCount = 0;
           break;
         }
-        if (theTok != T.identifier && theTok != T.andequals
+        if (theTok != T.translucent && theTok != T.identifier && theTok != T.andequals
             && theTok != T.define && (!T.tokAttr(theTok, T.setparam))) {
           if (isNewSet)
             commandExpected();
@@ -2730,12 +2749,12 @@ public class ScriptCompiler extends ScriptTokenParser {
    *        command
    * @param allowSptParen
    *        specifically for script/load command, first parameter xxx.spt(3,4,4)
-   * 
-   * @return true or false
+   * @param allowSemicolon special, just for MODELKIT SPACEGROUP
+   * @return true to handle as string, false to continue processing
    */
   private boolean lookingAtImpliedString(boolean allowSpace,
                                          boolean allowEquals,
-                                         boolean allowSptParen) {
+                                         boolean allowSptParen, boolean allowSemicolon) {
     int ichT = ichToken;
     char ch = script.charAt(ichT);
     boolean isID = (lastToken.tok == T.id);
@@ -2746,21 +2765,25 @@ public class ScriptCompiler extends ScriptTokenParser {
         .charAt(ichT + 1) == '{');
     if (isMath && (isID || !passVariableToString))
       return false;
-    //    if (isMath && passVariableToString) {
-    //      // zip past math expression untested.
-    //      ichT = Txt.ichMathTerminator(script, ichToken + 1, cchScript);
-    //      return (!isID && ichT != cchScript && (cchToken = ichT + 1 - ichToken) > 0);
-    //    }
-    //    if (isMath && !passVariableToString)
-    //      return false;
     // check implicit string for math expression here
     int ptSpace = -1;
     int ptLastChar = -1;
     // look ahead to \n, \r, terminal ;, or }
     boolean isOK = true;
     int parenpt = 0;
-    while (isOK && !eol(ch = charAt(ichT))) {
+    while (isOK && (!eol(ch = charAt(ichT)) || allowSemicolon && ch == ';')) {
       switch (ch) {
+      case ';':
+        // only MODELKIT SPACEGROUP 100:a,b,c;1/2,0,0 where ";" is followed by a digit or -
+        if (ichT + 5 > cchScript
+            || ichT + 2 < cchScript && 
+            ( ".01234567890-".indexOf(script.charAt(ichT + 1)) < 0
+            || script.charAt(ichT + 2) =='-')) {
+          //xxxxx;--x or xxxx; followed by anything other than a number
+          isOK = false;
+          continue;
+        }
+        break;
       case '(':
         if (!allowSptParen) {
           // script command
@@ -2802,10 +2825,14 @@ public class ScriptCompiler extends ScriptTokenParser {
       ++ichT;
     }
     // message/echo/label @x
-    // message/echo/label @{.....}
-    // message/echo/label @{....} testing  NOT ok
-    // message/echo/label @x bananas OK -- "@x bananas"
+    // message/echo/label @{...}
+    // message/echo/label @{...} testing -- ok -- "@{...} testing"
+    // message/echo/label @x bananas -- OK -- "@x bananas"
     // {... message/echo label ok }  
+    if (isVariable && (ptSpace < 0 || ptSpace > ptLastChar)) {
+      // trailing space -- consider this NOT a string and process the variable
+      return false;
+    }
     if (allowSpace)
       ichT = ptLastChar + 1;
     else if (ptSpace > 0)
