@@ -102,12 +102,11 @@ public class ScriptManager implements JmolScriptManager {
     interruptQueueThreads();
   }
 
-  @Override
-  public String addScript(String strScript, boolean isQuiet) {
-    return (String) addScr("String", strScript, "", isQuiet);
+  private String addScript(String strScript, Object[] params, boolean isQuiet) {
+    return (String) addScr("String", strScript, params, "", isQuiet);
   }
 
-  private Object addScr(String returnType, String strScript, String statusList,
+  private Object addScr(String returnType, String strScript, Object[] params, String statusList, 
                         boolean isQuiet) {
     /**
      * @j2sNative this.useCommandWatcherThread = false;
@@ -124,7 +123,7 @@ public class ScriptManager implements JmolScriptManager {
     if (commandWatcherThread != null && strScript.indexOf("/*SPLIT*/") >= 0) {
       String[] scripts = PT.split(strScript, "/*SPLIT*/");
       for (int i = 0; i < scripts.length; i++)
-        addScr(returnType, scripts[i], statusList, isQuiet);
+        addScr(returnType, scripts[i], params, statusList, isQuiet);
       return "split into " + scripts.length + " sections for processing";
     }
     boolean useCommandThread = (commandWatcherThread != null
@@ -138,6 +137,7 @@ public class ScriptManager implements JmolScriptManager {
     //    scriptItem.addLast(Boolean.FALSE);
     scriptItem.addLast(isQuiet ? Boolean.TRUE : Boolean.FALSE);
     scriptItem.addLast(Integer.valueOf(useCommandThread ? -1 : 1));
+    scriptItem.addLast(params);
     scriptQueue.addLast(scriptItem);
     //if (Logger.debugging)
     //  Logger.info("ScriptManager queue size=" + scriptQueue.size() + " scripts; added: " 
@@ -289,6 +289,13 @@ public class ScriptManager implements JmolScriptManager {
 
   @Override
   public void queueThreadFinished(int pt) {
+    if (pt < 0) {
+      queueThreadFinished(0);
+      queueThreadFinished(1);
+      return;
+    }
+    if (queueThreads[pt] == null)
+      return;
     //System.out.println("queuethread " + pt + " done");
     queueThreads[pt].interrupt();
     scriptQueueRunning[pt] = false;
@@ -311,6 +318,11 @@ public class ScriptManager implements JmolScriptManager {
 
   @Override
   public String evalFile(String strFilename) {
+    return evalFileArgs(strFilename, null);
+  }
+  
+  @Override
+  public String evalFileArgs(String strFilename, String args) {
     // app -s flag
     int ptWait = strFilename.indexOf(" -noqueue"); // for TestScripts.java
     if (ptWait >= 0) {
@@ -318,7 +330,9 @@ public class ScriptManager implements JmolScriptManager {
           "script " + PT.esc(strFilename.substring(0, ptWait)), "", false,
           false);
     }
-    return addScript("script " + PT.esc(strFilename), false);
+    // app -s flag and app -A flag
+    return addScript("script " + PT.esc(strFilename) + (args == null ? "" : "(" + args + ")"), null, false);
+    
   }
 
   private int scriptIndex;
@@ -328,12 +342,21 @@ public class ScriptManager implements JmolScriptManager {
   public Object evalStringWaitStatusQueued(String returnType, String strScript,
                                            String statusList, boolean isQuiet,
                                            boolean isQueued) {
+    return evalStringWaitParamsStatusQueued(returnType, strScript, null, statusList, isQuiet, isQueued);
+  }
+  
+  private Object evalStringWaitParamsStatusQueued(String returnType, String strScript,
+                                               Object[] params,
+                                               String statusList,
+                                               boolean isQuiet, boolean isQueued) {
     // from the scriptManager or scriptWait()
     if (strScript == null)
       return null;
     String str = checkScriptExecution(strScript, false);
     if (str != null)
       return str;
+    if (vwr.checkConsoleScript(strScript)) 
+      return null;
     SB outputBuffer = (statusList == null || statusList.equals("output")
         ? new SB()
         : null);
@@ -354,7 +377,8 @@ public class ScriptManager implements JmolScriptManager {
     vwr.setErrorMessage(null, null);
     // 14.11.0 need to use a new eval for each Jmol.scriptWait() or else we can
     // run into the problem when that is used in a callback that eval.aatokens is overridden
-    ScriptEval eval = (isQueued ? this.eval : newScriptEvaluator());
+    ScriptEval eval = (isQueued && params == null ? this.eval : newScriptEvaluator());
+    
     boolean isOK = eval.compileScriptString(strScript, isQuiet);
     String strErrorMessage = eval.getErrorMessage();
     String strErrorMessageUntranslated = eval.getErrorMessageUntranslated();
@@ -364,7 +388,7 @@ public class ScriptManager implements JmolScriptManager {
       isScriptQueued = isQueued;
       if (!isQuiet)
         vwr.setScriptStatus(null, strScript, -2 - (++scriptIndex), null);
-      eval.evaluateCompiledScript(vwr.isSyntaxCheck, vwr.isSyntaxAndFileCheck,
+      eval.evaluateCompiledScript(params, vwr.isSyntaxCheck, vwr.isSyntaxAndFileCheck,
           historyDisabled, vwr.listCommands, outputBuffer, isQueued);
     } else {
       vwr.scriptStatus(strErrorMessage);
@@ -399,7 +423,7 @@ public class ScriptManager implements JmolScriptManager {
     int pt = str.indexOf(JC.SCRIPT_GUI);
     if (pt >= 0)
       str = str.substring(0, pt);
-    else if ((pt = str.indexOf(JC.SCRIPT_EXT)) >= 0)
+    if ((pt = str.indexOf(JC.SCRIPT_EXT)) >= 0)
       str = str.substring(0, pt);
 
     if (checkResume(str))
@@ -436,6 +460,12 @@ public class ScriptManager implements JmolScriptManager {
   @Override
   public String evalStringQuietSync(String strScript, boolean isQuiet,
                                     boolean allowSyncScript) {
+    return evalStringParamsQuietSync(strScript, null, isQuiet, allowSyncScript);
+  }
+    
+  private String evalStringParamsQuietSync(String strScript, Object[] params, boolean isQuiet,
+                                      boolean allowSyncScript) {
+
     // central point for all incoming script processing
     // all menu items, all mouse movement -- everything goes through this method
     // by setting syncScriptTarget = ">" the user can direct that all scripts
@@ -447,7 +477,7 @@ public class ScriptManager implements JmolScriptManager {
       vwr.syncScript(strScript + " #NOSYNC;", null, 0);
     if (eval.isPaused() && strScript.charAt(0) != '!')
       strScript = '!' + PT.trim(strScript, "\n\r\t ");
-    boolean isInsert = (strScript.length() > 0 && strScript.charAt(0) == '!');
+    boolean isInsert = (params == null && strScript.length() > 0 && strScript.charAt(0) == '!');
     if (isInsert)
       strScript = strScript.substring(1);
     String msg = checkScriptExecution(strScript, isInsert);
@@ -460,9 +490,9 @@ public class ScriptManager implements JmolScriptManager {
       return "!" + strScript;
     }
     vwr.setInsertedCommand("");
-    if (isQuiet)
+    if (isQuiet && params == null)
       strScript += JC.SCRIPT_EDITOR_IGNORE;
-    return addScript(strScript,
+    return addScript(strScript, params,
         isQuiet && !vwr.getBoolean(T.messagestylechime));
   }
 
@@ -749,7 +779,7 @@ public class ScriptManager implements JmolScriptManager {
   public BS addHydrogensInline(BS bsAtoms, Lst<Atom> vConnections, P3[] pts,
                                Map<String, Object> htParams)
       throws Exception {
-    int iatom = bsAtoms.nextSetBit(0);
+    int iatom = (bsAtoms == null ? -1 : bsAtoms.nextSetBit(0));
     if (htParams == null)
       htParams = new Hashtable<String, Object>();
     int modelIndex = (iatom < 0 ? vwr.am.cmi : vwr.ms.at[iatom].mi);
@@ -757,16 +787,9 @@ public class ScriptManager implements JmolScriptManager {
       modelIndex = vwr.ms.mc - 1;
     htParams.put("appendToModelIndex", Integer.valueOf(modelIndex));
     boolean siteFixed = (htParams.containsKey("fixedSite"));
-//    if (!vwr.ms.isAtomInLastModel(iatom))
-//      return new BS();
-
-    // must be added to the LAST data set only
-
     BS bsA = vwr.getModelUndeletedAtomsBitSet(modelIndex);
     boolean wasAppendNew = vwr.g.appendNew;
     vwr.g.appendNew = false;
-    // BitSet bsB = getAtomBits(Token.hydrogen, null);
-    // bsA.andNot(bsB);
     int atomno = 0;
     for (int i = bsA.nextSetBit(0); i >= 0; i = bsA.nextSetBit(i + 1)) {
       int an = vwr.ms.at[i].getAtomNumber();
@@ -784,13 +807,18 @@ public class ScriptManager implements JmolScriptManager {
     SB sb = new SB();
     sb.appendI(pts.length).append("\n").append(JC.ADD_HYDROGEN_TITLE)
         .append("#noautobond").append("\n");
+    String sym = (String) htParams.get("element");
+    sym = (sym == null ? "H" : sym) + " ";
     for (int i = 0; i < pts.length; i++)
-      sb.append("H ").appendF(pts[i].x).append(" ").appendF(pts[i].y)
+      sb.append(sym).appendF(pts[i].x).append(" ").appendF(pts[i].y)
           .append(" ").appendF(pts[i].z).append(" - - - - ").appendI(++atomno)
           .appendC('\n');    
+    boolean wasRefreshing = vwr.getBoolean(T.refreshing);
+    vwr.setBooleanProperty("refreshing",false);
     vwr.openStringInlineParamsAppend(sb.toString(), htParams, true);
     if (sbConnect.length() > 0)
       vwr.runScript(sbConnect.toString());
+    vwr.setBooleanProperty("refreshing", wasRefreshing);
     BS bsB = vwr.getModelUndeletedAtomsBitSet(modelIndex);
     bsB.andNot(bsA);
     vwr.g.appendNew = wasAppendNew;
@@ -802,4 +830,26 @@ public class ScriptManager implements JmolScriptManager {
     return bsB;
   }
 
+  @Override
+  public void evalCallback(String strScript, Object[] params, boolean doWait) {
+    // note that the isScriptQueued last parameter TRUE here
+    // is just for JavaScript executing a jmolScript: callback
+    // so that it displays on the console.
+    if (doWait) {
+      evalStringWaitParamsStatusQueued("String", strScript, params, "", true, true);
+    } else {
+      evalStringParamsQuietSync(strScript, params, true, true);
+    }
+  }
+
+  public void runScriptFromThread(Lst<Object> scriptItem) {
+    String script = (String) scriptItem.get(0);
+    String statusList = (String) scriptItem.get(1);
+    String returnType = (String) scriptItem.get(2);
+    boolean isQuiet = ((Boolean) scriptItem.get(3)).booleanValue();
+    Object[] params = (Object[]) scriptItem.get(5);
+    evalStringWaitParamsStatusQueued(returnType, script, params, statusList, isQuiet,
+        true);
+  }
+
 }
