@@ -534,7 +534,8 @@ public class ScriptMathProcessor {
         && (!isLeftOp || tok0 == T.propselector
             && (op.tok == T.propselector || op.tok == T.leftsquare))
         // ...and previous operator has equal or higher precedence
-        && T.getPrecedence(tok0) >= T.getPrecedence(op.tok)
+        // ...except for !<matrix>, which ALWAYS operators first
+        && checkPrecedence(tok0, op.tok)
         // ...and this is not x - - y, because unary minus operates from
         //   right to left.
         && (tok0 != T.unaryMinus || op.tok != T.unaryMinus)) {
@@ -719,6 +720,23 @@ public class ScriptMathProcessor {
     return true;
   }
 
+  /**
+   * !matrix ALWAYS operates first
+   * @param tok0
+   * @param tok
+   * @return true to operate on tok0 first
+   */
+  private boolean checkPrecedence(int tok0, int tok) {
+    if (tok0 == T.opNot && xPt >= 0) {
+      switch (xStack[xPt].tok) {
+      case T.matrix3f:
+      case T.matrix4f:
+        return true;
+      }
+    }
+    return T.getPrecedence(tok0) >= T.getPrecedence(tok);
+  }
+
   private boolean checkSkip(T op, int tok0) {
     switch (op.tok) {
     case T.leftparen:
@@ -890,21 +908,29 @@ public class ScriptMathProcessor {
 
     // check for a[3][2]
     if (op.tok == T.opEQ
-        && (isArrayItem && squareCount == 0 && equalCount == 1 && oPt < 0 || oPt >= 0
-            && oStack[oPt] == null))
+        && (isArrayItem && squareCount == 0 && equalCount == 1 && oPt < 0
+            || oPt >= 0 && oStack[oPt] == null))
       return true;
 
     SV x2;
-    switch (op.tok) {
+    out: switch (op.tok) {
     case T.minusMinus:
     case T.plusPlus:
-      if (xPt >= 0 && xStack[xPt].canIncrement()) {
+      // only allow for int and dec; matrix is ignored, others fail
+      switch (xPt >= 0 ? xStack[xPt].tok : T.nada) {
+      case T.integer:
+      case T.decimal:
         x2 = xStack[xPt--];
         wasX = false;
-        break;
+        break out;
+      case T.matrix4f:
+      case T.matrix3f:
+        // ignore
+        return true;
       }
       //$FALL-THROUGH$
     default:
+      //
       x2 = getX();
       break;
     }
@@ -922,13 +948,13 @@ public class ScriptMathProcessor {
         //System.out.println("ptx="+ ptx + " " + pto);
         if (ptx < pto) {
           // x++ must make a copy first
-          x1 = SV.copySafely(x2);
+          x1 = new SV().setv(x2);
         }
         if (!x2.increment(op.tok == T.plusPlus ? 1 : -1))
           return false;
         if (ptx > pto) {
-          // ++x must make a copy after
-          x1 = SV.copySafely(x2);
+          // ++x  MUST make a copy after
+          x1 = new SV().setv(x2);
         }
       }
       wasX = false;
