@@ -13,6 +13,8 @@ import org.jmol.util.Logger;
 import javajs.util.BS;
 import javajs.util.CU;
 import javajs.util.Lst;
+import javajs.util.M3;
+import javajs.util.M4;
 import javajs.util.Measure;
 import javajs.util.P3;
 import javajs.util.P4;
@@ -21,6 +23,7 @@ import javajs.util.Quat;
 import javajs.util.SB;
 import javajs.util.T3;
 import javajs.util.V3;
+import javajs.util.V3d;
 
 
 /**
@@ -270,7 +273,7 @@ abstract public class ScriptParam extends ScriptError {
     if (checkToken(i)) {
       switch (getToken(i).tok) {
       case T.unitcell:
-        return getUnitCellCenter();
+        return vwr.getUnitCellCenter();
       case T.dollarsign:
         String id = objectNameParameter(++i);
         int index = Integer.MIN_VALUE;
@@ -305,21 +308,6 @@ abstract public class ScriptParam extends ScriptError {
     return center;
   }
 
-  public P3 getUnitCellCenter() {
-    P3 center = new P3();
-    SymmetryInterface uc = vwr.getCurrentUnitCell();
-    if (uc != null) {
-      P3[] pts = uc.getUnitCellVerticesNoOffset();
-      P3 off = uc.getCartesianOffset();
-      for (int j = 0; j < 8; j++) {
-        center.add(pts[j]);
-        center.add(off);
-      }
-    }
-    center.scale(1f/8);
-    return center;
-  }
-
   public P4 planeParameter(int i, boolean isBest) throws ScriptException {
     V3 vTemp = new V3();
     V3 vTemp2 = new V3();
@@ -406,14 +394,23 @@ abstract public class ScriptParam extends ScriptError {
             // best plane [array]
             bestPoints = getPointArray(i, -1, false);
           } else {
-            Lst<P3> list = getPointOrCenterVector(getToken(i));
-            int n = list.size();
-            if (n != 3)
-              invArg();
-            pt1 = list.get(0);
-            pt2 = list.get(1);
-            pt3 = list.get(2);
-            have3 = true;
+              try {
+                Lst<P3> list = getPointOrCenterVector(getToken(i));
+                int n = list.size();
+                if (n != 3)
+                  invArg();
+                pt1 = list.get(0);
+                pt2 = list.get(1);
+                pt3 = list.get(2);
+                have3 = true;
+              } catch (Exception e) {
+                SymmetryInterface sym = vwr.getCurrentUnitCell();
+                if (sym == null)
+                  invArg();
+                plane = new P4();
+                plane.setT(P3.newA(floatParameterSet(i + 1, 3, 3)));
+                vwr.toCartesian(plane, true);
+              }
           }
         }
       }
@@ -1506,6 +1503,49 @@ abstract public class ScriptParam extends ScriptError {
     return (pt instanceof P4 ? (P4) pt : null);
   }
 
+  public static Lst<P3> transformPoints(Lst<P3> vPts, M4 m4, P3 center) {
+    Lst<P3> v = new  Lst<P3>();
+    for (int i = 0; i < vPts.size(); i++) {
+      P3 pt = P3.newP(vPts.get(i));
+      pt.sub(center);
+      m4.rotTrans(pt);
+      pt.add(center);
+      v.addLast(pt);
+    }
+    return v;
+  }
+
+  /**
+   * Fills a 4x4 matrix with rotation-translation of mapped points A to B.
+   * If centerA is null, this is a standard 4x4 rotation-translation matrix;
+   * otherwise, this 4x4 matrix is a rotation around a vector through the center of ptsA,
+   * and centerA is filled with that center; 
+   * Prior to Jmol 14.3.12_2014.02.14, when used from the JmolScript compare() function,
+   * this method returned the second of these options instead of the first.
+   * 
+   * @param ptsA
+   * @param ptsB
+   * @param m  4x4 matrix to be returned 
+   * @param centerA return center of rotation; if null, then standard 4x4 matrix is returned
+   * @return stdDev
+   */
+  public static double getTransformMatrix4(Lst<P3> ptsA, Lst<P3> ptsB, M4 m,
+                                          P3 centerA) {
+    P3[] cptsA = Measure.getCenterAndPoints(ptsA);
+    P3[] cptsB = Measure.getCenterAndPoints(ptsB);
+    float[] retStddev = new float[2];
+    Quat q = Measure.calculateQuaternionRotation(new P3[][] { cptsA, cptsB },
+        retStddev);
+    M3 r = q.getMatrix();
+    if (centerA == null)
+      r.rotate(cptsA[0]);
+    else
+      centerA.setT(cptsA[0]);
+    V3 t = V3.newVsub(cptsB[0], cptsA[0]);
+    m.setMV(r, t);
+    return retStddev[1];
+  }
+
   /**
    * @param params
    * @param isCallback unused to date  
