@@ -150,6 +150,20 @@ public abstract class ScriptExt {
     return translucentLevel;
   }
 
+  /**
+   * 
+   * @param shapeID
+   * @param colorArgb
+   * @param translucentLevel
+   * @param intScale
+   * @param doSet
+   * @param data
+   * @param iptDisplayProperty
+   *        pointer to mesh nofill....; if default is meshNoFill, then this
+   *        number is -1 - ipt
+   * @param bs
+   * @throws ScriptException
+   */
   protected void finalizeObject(int shapeID, int colorArgb,
                                 float translucentLevel, int intScale,
                                 boolean doSet, Object data,
@@ -165,6 +179,12 @@ public abstract class ScriptExt {
        if (intScale != 0) {
          setShapeProperty(shapeID, "scale", Integer.valueOf(intScale));
        }
+       if (iptDisplayProperty < 0) {
+         // unitcell and boundbox default to mesh nofill for Jmol 16.2.3
+         iptDisplayProperty = -1 - iptDisplayProperty;
+         setShapeProperty(shapeID, "token", Integer.valueOf(T.mesh));
+         setShapeProperty(shapeID, "token", Integer.valueOf(T.nofill));
+       }
        if (iptDisplayProperty > 0) {
          if (!e.setMeshDisplayProperty(shapeID, iptDisplayProperty, 0))
            invArg();
