@@ -175,8 +175,7 @@ public abstract class AtomShape extends Shape {
       }
       return;
     }
-    if (propertyName == "deleteModelAtoms") {
-      Atom[] atoms = (Atom[]) ((Object[]) value)[1];
+    if (propertyName == JC.PROP_DELETE_MODEL_ATOMS) {
       int[] info = (int[]) ((Object[]) value)[2];
       int firstAtomDeleted = info[1];
       int nAtomsDeleted = info[2];
@@ -229,15 +228,6 @@ public abstract class AtomShape extends Shape {
     }
   }
 
-  /**
-   * @param i  
-   * @return script, but only for Measures
-   */
-  public String getInfoAsString(int i) {
-    // only in Measures
-    return null;
-  }
-
   @Override
   public String getShapeState() {
    // implemented in StateCreator, not here
