@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-03-27 18:31:37 -0500 (Sun, 27 Mar 2022) $
- * $Revision: 22381 $
+ * $Date: 2024-04-14 22:04:09 -0500 (Sun, 14 Apr 2024) $
+ * $Revision: 22612 $
  *
  * Copyright (C) 2002-2006  Miguel, Jmol Development, www.jmol.org
  *
@@ -180,10 +180,14 @@ public class Axes extends FontLineShape {
 
   @Override
   public Object getProperty(String property, int index) {
-    if (property == "origin")
-      return fixedOrigin;
+    if (property == "originPoint")
+      return originPoint;
+    if (property == "axisPoints")
+      return axisPoints;
     if (property == "axesTypeXY")
       return (axisXY.z == 0 ? Boolean.FALSE : Boolean.TRUE);
+    if (property == "origin")
+      return fixedOrigin;
     return null;
   }
 
