@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-03-10 17:02:09 -0600 (Thu, 10 Mar 2022) $
- * $Revision: 22364 $
+ * $Date: 2024-03-15 17:42:21 -0500 (Fri, 15 Mar 2024) $
+ * $Revision: 22610 $
 
  *
  * Copyright (C) 2002-2005  The Jmol Development Team
@@ -30,6 +30,7 @@ import org.jmol.c.PAL;
 import javajs.util.BS;
 import org.jmol.modelset.Atom;
 import org.jmol.util.C;
+import org.jmol.viewer.JC;
 
 public class Balls extends AtomShape {
 
@@ -77,6 +78,7 @@ public class Balls extends AtomShape {
             || pid != PAL.NONE.id);
         atom.paletteID = pid;
       }
+      vwr.setModelkitPropertySafely(JC.MODELKIT_UPDATE_ATOM_KEYS, bs);
       return;
     }
     if ("colorValues" == propertyName) {
