@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2024-03-15 17:42:21 -0500 (Fri, 15 Mar 2024) $
- * $Revision: 22610 $
+ * $Date: 2024-09-03 12:14:46 -0500 (Tue, 03 Sep 2024) $
+ * $Revision: 22631 $
  *
  * Copyright (C) 2002-2005  The Jmol Development Team
  *
@@ -66,9 +66,9 @@ public class Echo extends TextShape {
   public void setProperty(String propertyName, Object value, BS bs) {
 
     if ("target" == propertyName) {
-      if ("%SCALE".equals(value)) {
+      if (JC.scaleName.equals(value)) {
         currentObject = scaleObject;
-        thisID = "%SCALE";
+        thisID = JC.scaleName;
         if (currentObject != null)
         return;
       }
@@ -77,8 +77,10 @@ public class Echo extends TextShape {
         propertyName = "thisID";
       } else if (target != "none" && target != "all") {
         isAll = false;
-        Text text = (thisID == "%SCALE" ? scaleObject : objects.get(target));
-        if (text == null) {
+        boolean haveScale = (scaleObject != null);
+        boolean isScale = (thisID == JC.scaleName);
+        Text text = (isScale ? scaleObject : objects.get(target));
+        if (text == null || text == scaleObject) {
           int valign = JC.ECHO_XY;
           int halign = JC.TEXT_ALIGN_LEFT;
           if ("top" == target) {
@@ -96,10 +98,16 @@ public class Echo extends TextShape {
           //              && scaleObject.align == halign) {
           //            text = scaleObject;
           //          } else {
+
+          if (text != null && text == scaleObject) {
+            text.valign = valign;
+            text.align = halign;
+          } else {
+            // scale
           text = Text.newEcho(vwr, vwr.gdata.getFont3DFS(FONTFACE, FONTSIZE),
               target, COLOR, valign, halign, 0);
           text.adjustForWindow = true;
-          if (thisID == "%SCALE") {
+          if (thisID == JC.scaleName) {
             scaleObject = text;
           } else {
             objects.put(target, text);
@@ -107,6 +115,8 @@ public class Echo extends TextShape {
               text.thisModelOnly = true;
             }
           }
+          }
+          if (!isScale || !haveScale) {
           if (currentFont != null)
             text.setFont(currentFont, true);
           if (currentColor != null)
@@ -117,10 +127,10 @@ public class Echo extends TextShape {
             text.setTranslucent(currentTranslucentLevel, false);
           if (currentBgTranslucentLevel != 0)
             text.setTranslucent(currentBgTranslucentLevel, true);
-          //          }
+          }
         }
         currentObject = text;
-        if (thisID != "%SCALE")
+        if (thisID != JC.scaleName)
           thisID = null;
         return;
       }
@@ -134,7 +144,7 @@ public class Echo extends TextShape {
         return;
       }
       String target = (String) value;
-      if (target == "%SCALE") {
+      if (target == JC.scaleName) {
         currentObject = scaleObject;
         thisID = target;
       } else {
@@ -145,9 +155,9 @@ public class Echo extends TextShape {
       return;
     }
 
-    if ("%SCALE" == propertyName) {
+    if (JC.scaleName == propertyName) {
       currentObject = scaleObject = (Text) value;
-      thisID = "%SCALE";
+      thisID = JC.scaleName;
       return;
     }
 
@@ -172,8 +182,8 @@ public class Echo extends TextShape {
     }
 
     if ("text" == propertyName) {
-      if (((String) value).startsWith("%SCALE")) {
-        thisID = "%SCALE";
+      if (((String) value).startsWith(JC.scaleName)) {
+        thisID = JC.scaleName;
         setPropTS("text", value, null);
         scaleObject = currentObject;
         if (scaleObject != null
@@ -210,6 +220,7 @@ public class Echo extends TextShape {
         }
         currentObject.setXYZ((P3) value, true);
       }
+      return;
     }
 
     if ("scale" == propertyName) {
@@ -284,7 +295,7 @@ public class Echo extends TextShape {
 
     if ("%zpos" == propertyName) {
       if (currentObject != null) {
-        currentObject.setXYZ(null, true);
+        //currentObject.setXYZ(null, true);
         currentObject.setMovableZPercent(((Integer) value).intValue());
       }
       return;
@@ -328,7 +339,7 @@ public class Echo extends TextShape {
     if ("currentTarget" == property) {
       return (currentObject != null && (data[0] = currentObject.target) != null);
     }
-    if (property == "%SCALE") {
+    if (property == JC.scaleName) {
       data[0] = scaleObject;
       return (data[0] != null);
     }
