@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-10-25 13:29:09 -0500 (Tue, 25 Oct 2022) $
- * $Revision: 22480 $
+ * $Date: 2024-05-02 13:36:04 -0500 (Thu, 02 May 2024) $
+ * $Revision: 22623 $
  *
  * Copyright (C) 2003-2005  The Jmol Development Team
  *
@@ -27,6 +27,7 @@ package org.jmol.shape;
 
 import org.jmol.i18n.GT;
 import org.jmol.util.Font;
+import org.jmol.viewer.Viewer;
 
 import javajs.util.BS;
 
@@ -40,7 +41,7 @@ public class Frank extends Shape {
   final static int defaultFontSize = 16;
   public final static int frankMargin = 4;
 
-  public String frankString = "Jmol";
+  public static String frankString = "Jmol";
   Font currentMetricsFont3d;
   public Font baseFont3d;
   public int frankWidth;
@@ -56,6 +57,10 @@ public class Frank extends Shape {
   public void initShape() {
     myType = "frank";
     baseFont3d = font3d = vwr.gdata.getFont3DFSS(defaultFontName, defaultFontStyle, defaultFontSize);
+    if (Viewer.isJS || Viewer.isSwingJS)
+      frankString = "JSmol";
+    else if (Viewer.isDoublePrecision)
+      frankString = "JmolD";
     calcMetrics();
   }
 
@@ -90,10 +95,6 @@ public class Frank extends Shape {
   }
   
   void calcMetrics() {
-    if (vwr.isJS)
-      frankString = "JSmol";
-    else if (vwr.isSignedApplet)
-      frankString = "Jmol_S";
     if (font3d == currentMetricsFont3d) 
       return;
     currentMetricsFont3d = font3d;
