@@ -111,7 +111,7 @@ public class Hover extends TextShape {
       return;
     }
 
-    if (propertyName == "deleteModelAtoms") {
+    if (propertyName == JC.PROP_DELETE_MODEL_ATOMS) {
       if (atomFormats != null) {
         int firstAtomDeleted = ((int[])((Object[])value)[2])[1];
         int nAtomsDeleted = ((int[])((Object[])value)[2])[2];
