@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-10-21 12:31:18 -0500 (Fri, 21 Oct 2022) $
- * $Revision: 22475 $
+ * $Date: 2024-10-08 18:58:53 -0500 (Tue, 08 Oct 2024) $
+ * $Revision: 22635 $
  *
  * Copyright (C) 2002-2005  The Jmol Development Team
  *
@@ -170,6 +170,9 @@ public class Labels extends AtomShape {
             && i < ac; i = bs.nextSetBit(i + 1))
           setLabel(tokens, strLabel, i, !isPicked);
       }
+      if (vwr.getModelkitPropertySafely(null) == Boolean.TRUE) {
+        vwr.shm.notifyAtoms(JC.PROP_ATOMS_LABELED, new BS[] { bs, null });
+      }
       return;
     }
 
