@@ -147,10 +147,15 @@ public abstract class MeshCollection extends Shape {
 
   @Override
   public void initShape() {
-    colix = C.ORANGE;
-    color = 0xFFFFFFFF;
+    setMeshColor();
   }
   
+  protected void setMeshColor() {
+   colix = C.ORANGE;
+   color = 0xFFFFFFFF;
+  }
+
+  
  @SuppressWarnings("unchecked")
  protected void setPropMC(String propertyName, Object value, BS bs) {
 
@@ -252,6 +257,7 @@ public abstract class MeshCollection extends Shape {
       switch (tok) {
       case T.display:
       case T.on:
+      case T.only:
       case T.frontlit:
       case T.backlit:
       case T.fullylit:
@@ -347,6 +353,13 @@ public abstract class MeshCollection extends Shape {
   } 
   
   protected void setTokenProperty(int tokProp, boolean bProp, boolean testD) {
+    if (tokProp == T.only) {
+      if (meshCount == 0)
+        return;
+      for (int i = 0; i < meshCount; i++)
+        meshes[i].visible = false;
+      tokProp = T.on;
+    }
     if (currentMesh == null) {
       String key = (explicitID && PT.isWild(previousMeshID) ? previousMeshID : null);
       Lst<Mesh> list = getMeshList(key, false);
@@ -416,12 +429,25 @@ public abstract class MeshCollection extends Shape {
       return true;
 
     }
+    if (property == "points") {
+      Mesh m = getMesh((String) data[0]);
+      if (m == null)
+        return false;
+      BS bs = m.getVisibleVertexBitSet();
+      P3[] pts = new P3[bs.cardinality()];
+      for (int p = 0, i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
+        pts[p++] = (P3) m.vs[i];
+      }
+      data[1] = pts;
+      return true;
+    }
     if (property == "checkID") {
       String key = (String) data[0];
       Lst<Mesh> list = getMeshList(key, true);
-      if (list.size() == 0)
+      Mesh m;
+      if (list.size() == 0 || (m = list.get(0)) == null)
         return false;
-      data[1] = list.get(0).thisID;
+      data[1] = m.thisID;
       return true;
     }
     if (property == "index") {
@@ -459,7 +485,9 @@ public abstract class MeshCollection extends Shape {
     String id;
     // important that this counts down because sometimes
     // we want just the MOST RECENT mesh.
-    for (int i = meshCount; --i >= 0;)
+    for (int i = meshCount; --i >= 0;) {
+//      if (justOne)
+//        System.out.println("MC  " + i + "/" + meshCount + " " + key + " " +  meshes[i].thisID + " " + Thread.currentThread());
       if (key == null
           || (id = meshes[i].thisID.toUpperCase()).equals(key) 
           || isWild && PT.isMatch(id, key, true, true)) {
@@ -467,6 +495,7 @@ public abstract class MeshCollection extends Shape {
         if (justOne)
           break;
       }
+    }
     return list;
   }
 
