@@ -1,3 +1,4 @@
+
 /* $RCSfile$
  * $Author: hansonr $
  * $Date: 2006-09-13 00:06:10 -0500 (Wed, 13 Sep 2006) $
@@ -39,6 +40,7 @@ import org.jmol.modelset.Text;
 import org.jmol.util.C;
 import org.jmol.util.Font;
 import org.jmol.util.Logger;
+import org.jmol.viewer.JC;
 
 public abstract class TextShape extends Shape {
 
@@ -117,14 +119,21 @@ public abstract class TextShape extends Shape {
         objects = new Hashtable<String, Text>();
         isAll = false;
         currentObject = null;
-      }
-      if (currentObject == null) {
         return;
       }
-
-      objects.remove(currentObject.target);
-      currentObject = null;
-      return;
+      if (currentObject != null) {
+        objects.remove(currentObject.target);
+        currentObject = null;
+      } else if (thisID != null) {
+        Iterator<Text> e = objects.values().iterator();
+        while (e.hasNext()) {
+          Text text = e.next();
+          if (isAll
+              || PT.isMatch(text.target.toUpperCase(), thisID, true, true)) {
+            e.remove();
+          }
+        }
+      }
     }
 
     if ("model" == propertyName) {
@@ -209,7 +218,7 @@ public abstract class TextShape extends Shape {
       return;
     }
 
-    if (propertyName == "deleteModelAtoms") {
+    if (propertyName == JC.PROP_DELETE_MODEL_ATOMS) {
       int modelIndex = ((int[]) ((Object[]) value)[2])[0];
       Iterator<Text> e = objects.values().iterator();
       while (e.hasNext()) {
@@ -242,7 +251,10 @@ public abstract class TextShape extends Shape {
   public void setModelVisibilityFlags(BS bsModels) {
     if (!isHover)
       for (Text t : objects.values())
-        t.visible = (t.modelIndex < 0 || bsModels.get(t.modelIndex));
+        t.visible = (t.modelIndex < 0 
+            || bsModels.get(t.modelIndex)
+            && (!t.thisModelOnly || bsModels.cardinality() == 1 && t.modelIndex == vwr.am.cmi)
+            );
   }
 
   @Override
