@@ -26,9 +26,13 @@ package org.jmol.shapebio;
 
 public class Cartoon extends Rockets {
 
+
+  /**
+   * @j2sOverride
+   */
   @Override
   public void initShape() {
-    super.initShape();
+    setTurn();
     madDnaRna = 1000;
   }
 }
