@@ -9,6 +9,8 @@ import javajs.util.M4;
 import javajs.util.Measure;
 import javajs.util.P3;
 import javajs.util.P4;
+import javajs.util.PT;
+import javajs.util.SB;
 import javajs.util.T3;
 import javajs.util.V3;
 
@@ -24,7 +26,6 @@ import org.jmol.util.Elements;
 import org.jmol.util.Escape;
 import org.jmol.util.Logger;
 import org.jmol.util.MeshCapper;
-import org.jmol.util.Node;
 import org.jmol.util.Normix;
 import org.jmol.util.Point3fi;
 import org.jmol.viewer.JC;
@@ -170,7 +171,10 @@ public class Polyhedron {
         o = lst.get(i);
         vertices[i] = (isSV ? SV.ptValue((SV) o) : (P3) o);
       }
-      o = info.get("elemNos");
+      o = info.get("explodeOffset");
+      if (o != null)
+        setZeroOffset(((Number) o).floatValue());
+     o = info.get("elemNos");
       if (o != null) {
         lst = (isSV ? ((SV)o).getList() : (Lst<?>) o);
         for (int i = nVertices; --i >= 0;) {
@@ -214,6 +218,8 @@ public class Polyhedron {
       }
       o = info.get("bsFlat");
       bsFlat = (o == null ? new BS() : isSV ? SV.getBitSet((SV)o, false) : (BS) o);
+      if (info.containsKey("volume"))
+        info.put("volume", getVolume());
     } catch (Exception e) {
       return null;
     }
@@ -254,7 +260,7 @@ public class Polyhedron {
     for (int i = 0; i < nv; i++)
       pts[i] = P3.newP(vertices[i]);
     info.put("vertices", pts);
-    info.put("elemNos", getElemNos());
+    info.put("elemNos", getElemNos(true));
 
     if (id == null) {
       info.put("atomIndex", Integer.valueOf(centralAtom.i));
@@ -289,11 +295,11 @@ public class Polyhedron {
       int[] indices = new int[nVertices];
       for (int i = nVertices; --i >= 0;) {
         P3 pt = vertices[i];
-        boolean isNode = pt instanceof Node;
-        names[i] = (isNode ? ((Node) pt).getAtomName()
+        boolean isNode = pt instanceof Atom;
+        names[i] = (isNode ? ((Atom) pt).getAtomName()
             : pt instanceof Point3fi ? Elements
                 .elementSymbolFromNumber(((Point3fi) pt).sD) : "");
-        indices[i] = (isNode ? ((Node) pt).getIndex() : -1);
+        indices[i] = (isNode ? ((Atom) pt).getIndex() : -1);
       }
       info.put("atomNames", names);
       info.put("vertexIndices", indices);
@@ -363,14 +369,27 @@ public class Polyhedron {
 
   private int[] elemNos;
   
-  public int[] getElemNos() {
-    if (elemNos == null) {      
-      elemNos = new int[nVertices];
+  void setPointScale(float scale) {
+    pointScale = scale;
+    elemNos = null;
+  }
+
+  public int[] getElemNos(boolean forInfo) {
+    if (forInfo) {
+      int[] a = new int[nVertices];
       for (int i = 0; i < nVertices; i++) {
         P3 pt = vertices[i];
-        elemNos[i] = (pt instanceof Node ? ((Node) pt).getElementNumber()
+        a[i] = (pt instanceof Atom ? ((Atom) pt).getElementNumber()
             : pt instanceof Point3fi ? ((Point3fi) pt).sD : -2);
       }
+      return a;
+    }
+    if (elemNos == null)
+      elemNos = new int[nVertices];
+    for (int i = 0; i < nVertices; i++) {
+      P3 pt = vertices[i];
+      elemNos[i] = (pt instanceof Atom ? ((Atom) pt).getAtomicAndIsotopeNumber()
+          : pt instanceof Point3fi ? ((Point3fi) pt).sD : -2);
     }
     return elemNos;
   }
@@ -400,15 +419,15 @@ public class Polyhedron {
       // first time through includes all atoms as atoms
       for (int i = pts.length; --i >= 0;)
         pts[i] = vertices[i];
-      pointGroup = vwr.getSymTemp().setPointGroup(null, null, pts, null,
-          false, vwr.getFloat(T.pointgroupdistancetolerance),
-          vwr.getFloat(T.pointgrouplineartolerance), pts.length, true);
+      pointGroup = vwr.getSymTemp().setPointGroup(vwr, null, null, pts,
+          null, false,
+          vwr.getFloat(T.pointgroupdistancetolerance), vwr.getFloat(T.pointgrouplineartolerance), pts.length, true);
       // second time through includes all atoms as points only
       for (int i = pts.length; --i >= 0;)
         pts[i] = P3.newP(vertices[i]);
-      pointGroupFamily = vwr.getSymTemp().setPointGroup(null, null, pts,
-          null, false, vwr.getFloat(T.pointgroupdistancetolerance),
-          vwr.getFloat(T.pointgrouplineartolerance), pts.length, true);
+      pointGroupFamily = vwr.getSymTemp().setPointGroup(vwr, null, null,
+          pts, null, false,
+          vwr.getFloat(T.pointgroupdistancetolerance), vwr.getFloat(T.pointgrouplineartolerance), pts.length, true);
     }
     return (center == null ? centralAtom : center) + "    \t"
         + pointGroup.getPointGroupName() + "\t"
@@ -500,5 +519,40 @@ public class Polyhedron {
     for (int i = vertices.length; --i >= 0;)
       vertices[i].add(value);
   }
+  
+  P3[] v0;
+  
+  public void setZeroOffset(float value) {
+    if (id == null || center == null || value == 0)
+      return;
+    float d = center.length();
+    if (d < 0.0001f)
+      return;
+    P3 v = P3.newP(center);
+    v.scale(value / d);
+    setOffset(v);
+  }
+
+
+  public void list(SB sb) {
+    if (id == null) {
+      sb.append(" atomIndex:" + centralAtom.i);
+      sb.append(" atomName:" + centralAtom.getAtomName());
+      sb.append(" element:" + centralAtom.getElementSymbol());
+    } else {
+      sb.append(" id:" + id);
+      sb.append("; center:" + PT.sprintf("{%6.3p %6.3p %6.3p}", "p", new Object[] { center }))
+        .append("; visible:" + visible);
+    }
+    sb.append("; model:" + modelIndex)
+    .append("; vertices:" + nVertices)
+    .append("; faces:" + faces.length)
+    .append("; volume:" + PT.formatD(getVolume().doubleValue(), 1, 3, false, false));
+    if (scale != 1)
+        sb.append("; scale:" + scale);
+    sb.append("\n");
+  }
+
+
 
 }
