@@ -426,7 +426,7 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
 
     if ("offset" == propertyName) {
       P3 offset = P3.newP((P3) value);
-      if (offset.equals(JC.center))
+      if (offset.lengthSquared() == 0)
         offset = null;
       if (thisMesh != null) {
         thisMesh.rotateTranslate(null, offset, true);
@@ -1148,13 +1148,14 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
             + encodeColor(imesh.jvxlData.minColorIndex) + " "
             + encodeColor(imesh.jvxlData.maxColorIndex));
       }
-      if (imesh.vertexColorMap != null)
+      if (imesh.vertexColorMap != null) {
         for (Map.Entry<String, BS> entry : imesh.vertexColorMap.entrySet()) {
           BS bs = entry.getValue();
           if (!bs.isEmpty())
             appendCmd(sb, "color " + myType + " " + Escape.eBS(bs)
                 + " " + entry.getKey());
         }
+      }
     }
   }
 
