@@ -77,8 +77,6 @@ public class IsosurfaceMesh extends Mesh {
 
   /**
    * @param vwr 
-   * @XXXXj2sIgnoreSuperConstructor
-   * 
    * @param thisID
    * @param colix
    * @param index
@@ -906,8 +904,7 @@ public class IsosurfaceMesh extends Mesh {
     return (unitCell != null
         || (unitCell = vwr.ms.am[modelIndex].biosymmetry) != null
         || (unitCell = vwr.ms.getUnitCell(modelIndex)) != null
-        || oabc != null && (unitCell = Interface.getSymmetry(vwr, "symmetry").getUnitCell(
-            oabc, true, null)) != null ? unitCell : null);
+        || oabc != null && (unitCell = vwr.getSymTemp().getUnitCell(oabc, true, null)) != null ? unitCell : null);
   }
 
   void fixLattice() {
@@ -1010,7 +1007,7 @@ public class IsosurfaceMesh extends Mesh {
 
   float[] getDataMinMax() { 
     float min = Float.MAX_VALUE;
-    float max = Float.MIN_VALUE;
+    float max = -Float.MAX_VALUE;
     for (int i = vvs.length; --i >= 0;) {
       float v = vvs[i];
       if (v < min)
