@@ -60,6 +60,7 @@ public class MolecularOrbital extends Isosurface {
   private Float moCutoff;
   private Float moResolution;
   private Float moScale;
+  private BS moSelection;
   private Integer moColorPos;
   private Integer moColorNeg;
   private Integer moMonteCarloCount;
@@ -143,6 +144,11 @@ public class MolecularOrbital extends Isosurface {
       return;
     }
 
+    if ("select" == propertyName) {
+      thisModel.put("moSelection", value);
+      return;
+    }
+
     if ("squareData" == propertyName) {
       if (value == Boolean.TRUE)
         thisModel.put("moSquareData", Boolean.TRUE);
@@ -476,6 +482,7 @@ public class MolecularOrbital extends Isosurface {
     thisModel.put("moCutoff", Float.valueOf(moCutoff.floatValue()));
     moResolution = (Float) thisModel.get("moResolution");
     moScale = (Float) thisModel.get("moScale");
+    moSelection = (BS) thisModel.get("moSelection");
     moColorPos = (Integer) thisModel.get("moColorPos");
     moColorNeg = (Integer) thisModel.get("moColorNeg");
     moSquareData = (Boolean) thisModel.get("moSquareData");
@@ -501,6 +508,8 @@ public class MolecularOrbital extends Isosurface {
     getSettings(strID);
     if (moScale != null)
       setPropI("scale", moScale, null);
+    if (moSelection != null)
+      setPropI("select", moSelection, null);
     if (moResolution != null)
       setPropI("resolution", moResolution, null);
     if (moPlane != null) {
@@ -573,6 +582,11 @@ public class MolecularOrbital extends Isosurface {
             + moCutoff);
       if (moScale != null)
         appendCmd(s, myType + " scale " + moScale);
+      if (moSelection != null) {
+        s.append("try{/*16.2*/\n"); // catch for prev. versions
+        appendCmd(s, myType + " select " +  moSelection);
+        s.append("}catch{};\n");
+      }
       if (moMonteCarloCount != null)
         appendCmd(s, myType + " points " + moMonteCarloCount + " " + moRandomSeed);
       if (moResolution != null)
@@ -601,6 +615,9 @@ public class MolecularOrbital extends Isosurface {
       }
       if (moTranslucency != null)
         appendCmd(s, myType + " translucent " + moTranslucentLevel);
+      if (thisModel == null) {
+        System.out.println("MolecularOrbital ???");
+      }
       appendCmd(s, ((IsosurfaceMesh) thisModel.get("mesh")).getState(myType));
     }
     return s.toString();
