@@ -38,7 +38,7 @@ class PolyhedronStereoSorter implements Comparator<Object[]> {
   private V3 align1 = new V3();
   private V3 align2 = new V3();
 
-  private static final float MIN_ALIGNED = (float) (10f/180*Math.PI);
+  private static final double MIN_ALIGNED = (float) (10/180*Math.PI);
 
   /**
    * check alignment, within 10 degrees is considered aligned.
@@ -52,7 +52,7 @@ class PolyhedronStereoSorter implements Comparator<Object[]> {
     align1.sub2(pt1, pt2);
     align2.sub2(pt2, pt3);
     float angle = align1.angle(align2);
-    return (angle < MIN_ALIGNED);
+    return (angle < (float) MIN_ALIGNED);
   }
 
 
