@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2023-01-25 16:14:30 -0600 (Wed, 25 Jan 2023) $
- * $Revision: 22508 $
+ * $Date: 2024-09-03 12:14:46 -0500 (Tue, 03 Sep 2024) $
+ * $Revision: 22631 $
  *
  * Copyright (C) 2005  The Jmol Development Team
  *
@@ -871,7 +871,7 @@ public class SmilesAtom extends P3 implements Node {
 
   @Override
   public float getFloatProperty(String property) {
-    if (property == "property_atomclass") // == is OK here.  
+    if (property == "property_atomclass" && atomClass != 0) // == is OK here.  
       return atomClass;
     return Float.NaN;
   }
