@@ -1002,6 +1002,8 @@ public class SmilesGenerator {
     int valence = atom.getValence();
     float osclass = (openSMILES ? ((Node) atom)
         .getFloatProperty("property_atomclass") : Float.NaN);
+    if (osclass == 0)
+      osclass = Float.NaN;
     String atomName = atom.getAtomName();
     String groupType = ((Node) atom).getBioStructureTypeName();
     // for bioSMARTS we provide the connecting atom if 
