@@ -108,6 +108,7 @@ public class SmilesMatcher implements SmilesMatcherInterface {
   private final static int MODE_ARRAY        = 0x02;
   private final static int MODE_MAP          = 0x03;
   private static final int MODE_ATROP        = 0x04;
+  private final static int MODE_BOOLEAN      = 0x05;
 
   private boolean okMF = true;
 
@@ -137,12 +138,11 @@ public class SmilesMatcher implements SmilesMatcherInterface {
     //   H 5 C 4 N 2   (incorrect)
     SmilesSearch search = SmilesParser.newSearch("/nostereo/"+pattern, isSmarts, true);
     search.createTopoMap(null);
-    search.nodes = search.targetAtoms;
+    search.nodes = search.target.nodes;
     return search.getMolecularFormula(!isSmarts, null, isEmpirical);
   }
 
   private void clearExceptions() {
-    okMF = true;
     InvalidSmilesException.clear();
   }
 
@@ -212,11 +212,12 @@ public class SmilesMatcher implements SmilesMatcherInterface {
     for (int i = array.length; --i >= 0;) {
       int[] a = array[i];
       for (int j = a.length; --j >= 0;)
-        a[j] = ((SmilesAtom) search.targetAtoms[a[j]]).mapIndex;
+        a[j] = ((SmilesAtom) search.target.nodes[a[j]]).mapIndex;
     }
     return array;
   }
 
+
   @Override
   public Node[] getAtoms(String target)
       throws Exception {
@@ -224,7 +225,7 @@ public class SmilesMatcher implements SmilesMatcherInterface {
     target = SmilesParser.cleanPattern(target);
     SmilesSearch search = SmilesParser.newSearch(target, false, true);
     search.createTopoMap(new BS());
-    return search.targetAtoms;
+    return search.target.nodes;
   }
 
 
@@ -286,16 +287,18 @@ public class SmilesMatcher implements SmilesMatcherInterface {
    * 
    * @param pattern
    *        SMILES or SMARTS pattern.
-   * @param atoms
+   * @param target
    * @param ac
    * @param bsSelected
+   * @param flags
    * @return BitSet indicating which atoms match the pattern.
    */
 
   @Override
-  public BS getSubstructureSet(String pattern, Node[] atoms, int ac, BS bsSelected, int flags) throws Exception {
+  public BS getSubstructureSet(Object pattern, Object target, int ac, BS bsSelected, int flags) throws Exception {
+    Node[] atoms = (target instanceof SmilesSearch ? null : (Node[]) target);
     return (BS) matchPriv(pattern, atoms, ac, bsSelected, null, true,
-        flags | SmilesParser.getFlags(pattern), MODE_BITSET, null);
+        flags | SmilesParser.getFlags(pattern.toString()), MODE_BITSET, (atoms == null ? (SmilesSearch) target : null));
   }
 
   /**
@@ -312,9 +315,7 @@ public class SmilesMatcher implements SmilesMatcherInterface {
     int flags = (JC.SMILES_TYPE_SMARTS | JC.SMILES_AROMATIC_MMFF94);
     search = sp.parse("");
     search.exitFirstMatch = false;
-    search.targetAtoms = atoms;
-    search.targetAtomCount = Math.abs(ac);
-    search.setSelected(bsSelected);
+    search.target.setAtoms(atoms, Math.abs(ac), bsSelected);
     search.flags = flags;
     search.getRingData(vRings, true, true);
     search.asVector = false;
@@ -465,95 +466,22 @@ public class SmilesMatcher implements SmilesMatcherInterface {
         flags, MODE_MAP, null);
   }
 
-  @SuppressWarnings({ "unchecked" })
-  private Object matchPriv(String pattern, Node[] atoms, int ac, BS bsSelected,
+  private Object matchPriv(Object pattern, Node[] atoms, int ac, BS bsSelected,
                            BS bsAromatic, boolean doTestAromatic, int flags,
                            int mode, SmilesSearch searchTarget)
       throws Exception {
     clearExceptions();
     try {
+      boolean isCompiled = (pattern instanceof SmilesSearch);
+      if (isCompiled)
+        flags |= JC.SMILES_TYPE_SMARTS;
       boolean isSmarts = ((flags
           & JC.SMILES_TYPE_SMARTS) == JC.SMILES_TYPE_SMARTS);
       // Note that additional flags are set when the pattern is parsed.
-      SmilesSearch search = SmilesParser.newSearch(pattern, isSmarts, false);
-      boolean isTopo = ((flags
-          & JC.SMILES_GEN_TOPOLOGY) == JC.SMILES_GEN_TOPOLOGY);
-
-      if (searchTarget != null) {
-        search.haveTopo = true;
-        bsAromatic = new BS();
-        searchTarget.setFlags(searchTarget.flags | SmilesParser.getFlags(pattern));
-        searchTarget.createTopoMap(bsAromatic);
-        atoms = searchTarget.targetAtoms;
-        ac = searchTarget.targetAtoms.length;
-        if (isSmarts) {
-          int[] a1 = searchTarget.elementCounts;
-          int[] a2 = search.elementCounts;
-          // skip 0 here -- it is wild cards a, [...], *
-          for (int i = Math.max(searchTarget.elementNumberMax, search.elementNumberMax); i > 0; i--) {
-            if (a1[i] < a2[i]) {
-              okMF = false;
-              break;
-            }
-          }
-        } else {
-          String mf = (isTopo ? null : search.getMolecularFormulaImpl(true, null, false));
-          String s = searchTarget.getMolecularFormulaImpl(true, null, false);
-          okMF = (mf == null || mf.equals(s));
-          if (!okMF) {
-            System.out.println("\n" + pattern + "\n" + mf + " \n" + s );
-            s = searchTarget.getMolecularFormulaImpl(true, null, false);
-          }
-        }
-        searchTarget.mf = search.mf = null;
-      }
-      if (okMF) {
-        if (!isSmarts && !search.patternAromatic) {
-          if (bsAromatic == null)
-            bsAromatic = new BS();
-          search.normalizeAromaticity(bsAromatic);
-          search.isNormalized = true;
-        }
-        search.targetAtoms = atoms;
-        search.targetAtomCount = ac;
-        search.setSelected(bsSelected);
-        if (ac != 0 && (bsSelected == null || !bsSelected.isEmpty())) {
-          boolean is3D = !(atoms[0] instanceof SmilesAtom);
-          search.getSelections();
-          if (!doTestAromatic)
-            search.bsAromatic = bsAromatic;
-          search.setRingData(null, null, is3D || doTestAromatic);
-          search.exitFirstMatch = ((flags
-              & JC.SMILES_FIRST_MATCH_ONLY) == JC.SMILES_FIRST_MATCH_ONLY);
-          search.mapUnique = ((flags
-              & JC.SMILES_MAP_UNIQUE) == JC.SMILES_MAP_UNIQUE);
-        }
-      }
-      switch (mode) {
-      case MODE_BITSET:
-        search.asVector = false;
-        return (okMF ? search.search() : new BS());
-      case MODE_ARRAY:
-        if (!okMF)
-          return new BS[0];//Lst<BS>();
-        search.asVector = true;
-        Lst<BS> vb = (Lst<BS>) search.search();
-        return vb.toArray(new BS[vb.size()]);
-      case MODE_ATROP:
-        if (!okMF)
-          return "";
-        search.exitFirstMatch = true;
-        search.setAtropicity = true;
-        search.search();
-        return search.atropKeys;
-      case MODE_MAP:
-        if (!okMF)
-          return new int[0][0];
-        search.getMaps = true;
-        search.setFlags(flags | search.flags); // important for COMPARE command - no stereochem
-        Lst<int[]> vl = (Lst<int[]>) search.search();
-        return vl.toArray(AU.newInt2(vl.size()));
-      }
+      SmilesSearch search = (isCompiled ? (SmilesSearch) pattern : SmilesParser.newSearch(pattern == null ? null : pattern.toString(), isSmarts, false));
+      if (searchTarget != null)
+        searchTarget.setFlags(searchTarget.flags | SmilesParser.getFlags(pattern.toString()));
+      return matchPattern(search, atoms, ac, bsSelected, bsAromatic, doTestAromatic, flags, mode, searchTarget);
     } catch (Exception e) {
       if (Logger.debugging)
         e.printStackTrace();
@@ -561,6 +489,118 @@ public class SmilesMatcher implements SmilesMatcherInterface {
         clearExceptions();
       throw new InvalidSmilesException(InvalidSmilesException.getLastError());
     }
+  }
+
+  private Object matchPattern(SmilesSearch search, Node[] atoms, int ac,
+                              BS bsSelected, BS bsAromatic,
+                              boolean doTestAromatic, int flags, int mode,
+                              SmilesSearch searchTarget)
+      throws InvalidSmilesException {
+    boolean isSmarts = ((flags
+        & JC.SMILES_TYPE_SMARTS) == JC.SMILES_TYPE_SMARTS);
+    //    boolean isTopo = ((flags
+    //        & JC.SMILES_GEN_TOPOLOGY) == JC.SMILES_GEN_TOPOLOGY);
+    //
+    okMF = true;
+    if (searchTarget != null) {
+      if (searchTarget.targetSet) {
+        search.setTarget(searchTarget);
+      } else {
+        search.haveSmilesTarget = true;
+        bsAromatic = new BS();
+        searchTarget.createTopoMap(bsAromatic);
+        atoms = searchTarget.target.nodes;
+        ac = searchTarget.target.nodes.length;
+        if (isSmarts) {
+          int[] a1 = searchTarget.elementCounts;
+          int[] a2 = search.elementCounts;
+          // skip 0 here -- it is wild cards a, [...], *
+          int n = search.elementNumberMax;
+          if (n <= searchTarget.elementNumberMax) {
+            // includes H
+            for (int i = 1; i <= n; i++) {
+              if (a1[i] < a2[i]) {
+                okMF = false;
+                break;
+              }
+            }
+          } else {
+            okMF = false;
+          }
+        } else {
+          int[] mf = search.getMFArray(true, null, false);
+          int[] mft = searchTarget.getMFArray(true, null, false);
+          int n = searchTarget.elementNumberMax;
+          if (n == search.elementNumberMax) {
+            // does NOT include H
+            for (int i = 2; i <= n; i++) {
+              if (mf[i] != mft[i]) {
+                okMF = false;
+                break;
+              }
+            }
+          } else {
+            okMF = false;
+          }
+        }
+      }
+    }
+    if (okMF) {
+      if (!isSmarts && !search.patternAromatic) {
+        if (bsAromatic == null)
+          bsAromatic = new BS();
+        search.normalizeAromaticity(bsAromatic);
+        search.isNormalized = true;
+      }
+      if (!search.targetSet)
+        search.target.setAtoms(atoms, ac, bsSelected);
+      if (search.targetSet
+          || ac != 0 && (bsSelected == null || !bsSelected.isEmpty())) {
+        boolean is3D = search.targetSet || !(atoms[0] instanceof SmilesAtom);
+        search.getSelections();
+        if (!doTestAromatic)
+          search.target.bsAromatic = bsAromatic;
+        if (!search.target.hasRingData(flags))
+          search.setRingData(null, null,
+              is3D || doTestAromatic || search.patternAromatic);
+        search.exitFirstMatch = ((flags
+            & JC.SMILES_FIRST_MATCH_ONLY) == JC.SMILES_FIRST_MATCH_ONLY);
+        search.mapUnique = ((flags
+            & JC.SMILES_MAP_UNIQUE) == JC.SMILES_MAP_UNIQUE);
+      }
+    }
+    switch (mode) {
+    case MODE_BITSET:
+      search.asVector = false;
+      return (okMF ? search.search() : new BS());
+    case MODE_ARRAY:
+      if (!okMF)
+        return new BS[0];//Lst<BS>();
+      search.asVector = true;
+      @SuppressWarnings("unchecked") Lst<BS> vb = (Lst<BS>) search.search();
+      return vb.toArray(new BS[vb.size()]);
+    case MODE_ATROP:
+      if (!okMF)
+        return "";
+      search.exitFirstMatch = true;
+      search.setAtropicity = true;
+      search.search();
+      return search.atropKeys;
+    case MODE_MAP:
+      if (!okMF)
+        return new int[0][0];
+      search.getMaps = true;
+      search.setFlags(flags | search.flags); // important for COMPARE command - no stereochem
+      @SuppressWarnings("unchecked")
+      Lst<int[]> vl = (Lst<int[]>) search.search();
+      return vl.toArray(AU.newInt2(vl.size()));
+    case MODE_BOOLEAN:
+      if (!okMF)
+        return Boolean.FALSE;
+      search.retBoolean = true;
+      search.setFlags(flags | search.flags); // important for COMPARE command - no stereochem
+      return search.search();
+    }
     return null;
   }
 
@@ -571,6 +611,29 @@ public class SmilesMatcher implements SmilesMatcherInterface {
 
   @Override
   public int[][] getMapForJME(String jme, Atom[] at, BS bsAtoms) {
+    try {
+      SmilesSearch molecule = jmeToMolecule(jme);
+      BS bs = BSUtil.newBitSet2(0, molecule.ac);
+      String s = getSmiles(molecule.patternAtoms, molecule.ac, bs, null,
+          JC.SMILES_TYPE_SMARTS | JC.SMILES_IGNORE_STEREOCHEMISTRY);
+      int[][] map = getCorrelationMaps(s, molecule.patternAtoms, molecule.ac, bs,
+          JC.SMILES_TYPE_SMARTS | JC.SMILES_FIRST_MATCH_ONLY
+              | JC.SMILES_IGNORE_STEREOCHEMISTRY);
+      int[][] map2 = getCorrelationMaps(s, at, bsAtoms.cardinality(), bsAtoms,
+          JC.SMILES_TYPE_SMARTS | JC.SMILES_FIRST_MATCH_ONLY
+              | JC.SMILES_IGNORE_STEREOCHEMISTRY);
+      //System.out.println(s);
+      //System.out.println(jme);
+      //System.out.println(PT.toJSON(null,  map));
+      //System.out.println(PT.toJSON(null,  map2));
+      return new int[][] { map[0], map2[0] };
+    } catch (Exception e) {
+      e.printStackTrace();
+    }
+    return null;
+  }
+
+  public static SmilesSearch jmeToMolecule(String jme) throws InvalidSmilesException {
     SmilesSearch molecule = new SmilesSearch();
     String[] tokens = PT.getTokens(jme);
     int nAtoms = PT.parseInt(tokens[0]);
@@ -582,7 +645,8 @@ public class SmilesMatcher implements SmilesMatcherInterface {
       int ic = sa.indexOf("+");
       int charge = 0;
       if (ic >= 0) {
-       charge = (ic == sa.length() - 1 ? 1 : PT.parseInt(sa.substring(ic + 1)));
+        charge = (ic == sa.length() - 1 ? 1
+            : PT.parseInt(sa.substring(ic + 1)));
       } else if ((ic = sa.indexOf("-")) >= 0) {
         charge= PT.parseInt(sa.substring(ic));
       }
@@ -610,26 +674,84 @@ public class SmilesMatcher implements SmilesMatcherInterface {
       new SmilesBond(a1, a2, order, false).index = i;
       
     }
-
-    String s = "";
-    try {
-      molecule.isSmarts = true;
-      molecule.set();
-      BS bs = BSUtil.newBitSet2(0, nAtoms);
-      s = getSmiles(molecule.patternAtoms, molecule.ac, bs, null, JC.SMILES_TYPE_SMARTS|JC.SMILES_IGNORE_STEREOCHEMISTRY);
-      int[][] map = getCorrelationMaps(s, 
-          molecule.patternAtoms, nAtoms, bs, JC.SMILES_TYPE_SMARTS |JC.SMILES_FIRST_MATCH_ONLY|JC.SMILES_IGNORE_STEREOCHEMISTRY);
-      int[][] map2 = getCorrelationMaps(s, 
-          at, bsAtoms.cardinality(), bsAtoms, JC.SMILES_TYPE_SMARTS |JC.SMILES_FIRST_MATCH_ONLY|JC.SMILES_IGNORE_STEREOCHEMISTRY);
-//      System.out.println(s);
-//      System.out.println(jme);
-//      System.out.println(PT.toJSON(null,  map));
-//      System.out.println(PT.toJSON(null,  map2));
-      return new int[][] {map[0], map2[0]};
-    } catch (Exception e) {
-      e.printStackTrace();
-    }
-    return null;
+    molecule.isSmarts = true;
+    molecule.set();
+    return molecule;
   }
 
+  @Override
+  public String getSmilesFromJME(String jme) {
+    try {
+      SmilesSearch molecule = jmeToMolecule(jme);
+      BS bs = BSUtil.newBitSet2(0, molecule.ac);
+      return getSmiles(molecule.patternAtoms, molecule.ac, bs, null,
+          JC.SMILES_TYPE_SMILES);
+    } catch (Exception e) {
+      return null;
+    }
+  }
+
+  @Override
+  public Object compileSmartsPattern(String pattern) throws Exception {
+    pattern = SmilesParser.cleanPattern(pattern);
+    return SmilesParser.newSearch(pattern, true, false);
+  }
+
+  @Override
+  public Object compileSearchTarget(Node[] atoms, int atomCount, BS bsSelected) {
+    SmilesSearch ss = new SmilesSearch();
+    ss.target.setAtoms(atoms, atomCount, bsSelected);
+    ss.targetSet = true;
+    return ss;
+  }
+
+  /**
+   * Look for pattern in each smilesSet string.
+   * 
+   * @pattern to look for, probably SMARTS
+   * @smilesSet array of target strings
+   * @flags
+   * @return int array of same length as smiles set with 1 = match found, 0 =
+   *         not found, and -1 meaning a parsing or searching error.
+   * 
+   */
+  @Override
+  public int[] hasStructure(String pattern, String[] smilesSet, int flags)
+      throws Exception {
+    int[] ret = new int[smilesSet.length];
+    if ((flags & JC.SMILES_TYPE_SMILES) != JC.SMILES_TYPE_SMILES) {
+      // accept SMILES/SMARTS flags default as SMARTS
+      flags = flags | JC.SMILES_TYPE_SMARTS;
+    }
+    clearExceptions();
+    pattern = SmilesParser.cleanPattern(pattern);
+    try {
+      // Note that additional flags are set when the pattern is parsed.
+      SmilesSearch search = SmilesParser.newSearch(pattern, true, false);
+      for (int i = 0; i < smilesSet.length; i++) {
+        String smiles = SmilesParser.cleanPattern(smilesSet[i]);
+        SmilesSearch searchTarget = SmilesParser.newSearch(smiles, false, true); /// smiles chirality is fixed here
+        searchTarget
+            .setFlags(searchTarget.flags | SmilesParser.getFlags(pattern));
+        try {
+          clearExceptions();
+          ret[i] = (matchPattern(search, null, 0, null, null, false,
+              flags | JC.SMILES_FIRST_MATCH_ONLY, MODE_BOOLEAN,
+              searchTarget) == Boolean.TRUE ? 1 : 0);
+        } catch (Exception e) {
+          ret[i] = -1; // failed
+          e.printStackTrace();
+        }
+      }
+    } catch (Exception e) {
+      if (Logger.debugging)
+        e.printStackTrace();
+      if (InvalidSmilesException.getLastError() == null)
+        clearExceptions();
+      throw new InvalidSmilesException(InvalidSmilesException.getLastError());
+    }
+    return ret;
+  }
+
+
 }
