@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-08-07 17:43:09 -0500 (Sun, 07 Aug 2022) $
- * $Revision: 22451 $
+ * $Date: 2023-03-08 11:08:25 -0600 (Wed, 08 Mar 2023) $
+ * $Revision: 22511 $
  *
  * Copyright (C) 2005  The Jmol Development Team
  *
@@ -128,6 +128,8 @@ public class SmilesParser {
     if (pattern == null)
       throw new InvalidSmilesException("expression must not be null");
     SmilesSearch search = new SmilesSearch();
+    if (isSmarts && !isTarget)
+      search.pattern0 = pattern; // for toString() only
     if (pattern.indexOf("$(select") >= 0) // must do this before cleaning
       pattern = parseNested(search, pattern, "select");
     int[] ret = new int[1];
@@ -279,6 +281,7 @@ public class SmilesParser {
     search.setTop(parent);
     search.isSmarts = isSmarts;
     search.pattern = pattern;
+    search.pattern0 = parent.pattern0;
     search.setFlags(flags);
     if (pattern.indexOf("$(") >= 0)
       pattern = parseNested(search, pattern, "");
@@ -527,7 +530,7 @@ public class SmilesParser {
                 ch2 = '\0';
             // guess at some ambiguous SEARCH strings:
             if (ch2 != '\0'
-                && "NA CA BA PA SC AC".indexOf(pattern.substring(index,
+                && "NA CA BA PA SC AC Na Ca Ba Pa Sc Ac".indexOf(pattern.substring(index,
                     index + 2)) >= 0) {
               //System.out.println("Note: " + ch + ch2 + " NOT interpreted as an element");
               ch2 = '\0';
@@ -576,7 +579,7 @@ public class SmilesParser {
       SmilesBond bond0 = connections.get(r);
       if (bond0 == null) {
         connections.put(r, bond);
-        search.top.ringCount++;
+        search.target.ringCount++;
         return;
       }
       connections.remove(r);
@@ -590,7 +593,9 @@ public class SmilesParser {
     switch (bond.order) {
     case SmilesBond.TYPE_UNKNOWN:
       bond.order = (bond0.order != SmilesBond.TYPE_UNKNOWN ? bond0.order
-          : isSmarts || currentAtom.isAromatic && bond0.atom1.isAromatic ? SmilesBond.TYPE_ANY
+          : isSmarts 
+          || currentAtom.isAromatic && bond0.atom1.isAromatic 
+          ? SmilesBond.TYPE_ANY
               : Edge.BOND_COVALENT_SINGLE);
       break;
     case Edge.BOND_STEREO_NEAR:
