@@ -70,6 +70,7 @@ public class SpaceGroupFinder {
   private float[] unitCellParams;
   private float slop;
 
+  private boolean isCalcOnly;
   private boolean isAssign;
   private boolean isUnknown;
   private boolean checkSupercell;
@@ -78,7 +79,6 @@ public class SpaceGroupFinder {
  
   private BS bsPoints0;
   private BS bsAtoms;
-//  private BS atoms0;
   private BS targets;
 
   private T3 origin;
@@ -87,8 +87,6 @@ public class SpaceGroupFinder {
   private P3 scaling;
   private P3 pTemp = new P3();
  
-//  private M4 trm;
-  
   private int isg;  
   
   public SpaceGroupFinder() {
@@ -124,12 +122,13 @@ public class SpaceGroupFinder {
                         final float[] unitCellParams, final T3 origin, final T3[] oabc0,
                         final SymmetryInterface uci, final int flags) {
     this.vwr = vwr;
-//    this.atoms0 = atoms0;
     xyzList = xyzList0;
     this.unitCellParams = unitCellParams;
     this.origin = origin;
     oabc = oabc0;
     uc = (Symmetry) uci;
+    System.out.println(xyzList);
+    isCalcOnly = ((flags & JC.SG_CALC_ONLY) != 0);
     isAssign = ((flags & JC.SG_IS_ASSIGN) != 0);
     checkSupercell = ((flags & JC.SG_CHECK_SUPERCELL) != 0);
     asString = ((flags & JC.SG_AS_STRING) != 0);
@@ -153,14 +152,15 @@ public class SpaceGroupFinder {
     scaling = P3.new3(1, 1, 1);
     String name;
     BS basis;
-    //trm = null;
     isUnknown = true;
     // figure out the space group
     boolean isITA = (xyzList != null
         && xyzList.toUpperCase().startsWith("ITA/"));
-    boolean isHall = (xyzList != null && !isITA && 
-        (xyzList.startsWith("[") || xyzList.startsWith("Hall:")));
-    if (isITA || isAssign && isHall) {
+    boolean isHall = (xyzList != null && !isITA
+        && (xyzList.startsWith("[") || xyzList.startsWith("Hall:")));
+    
+    if (isAssign && isHall 
+        || !isHall && (isITA || (isITA = checkWyckoffHM()))) {
       isUnknown = false;  
     if (isITA) {
       xyzList = PT.rep(xyzList.substring(4), " ", "");
@@ -176,7 +176,8 @@ public class SpaceGroupFinder {
     } else if (oabc != null || isHall) {
       //      isUnknown = false;
       name = xyzList;
-      sg = SpaceGroup.createSpaceGroupN(name);
+      if (name != null)
+        sg = SpaceGroup.createSpaceGroupN(name, isHall);
       isUnknown = (sg == null);
       if (isHall && !isUnknown)
         return sg.dumpInfoObj();
@@ -192,7 +193,7 @@ public class SpaceGroupFinder {
       if (sg == null
           && (sg = SpaceGroup.determineSpaceGroupNA(xyzList,
               unitCellParams)) == null
-          && (sg = SpaceGroup.createSpaceGroupN(xyzList)) == null)
+          && (sg = SpaceGroup.createSpaceGroupN(xyzList, false)) == null)
         return null;
       basis = new BS();
       name = sg.asString();
@@ -208,7 +209,7 @@ public class SpaceGroupFinder {
         uc.transformUnitCell(uci.replaceTransformMatrix(null));
       }
     } else {
-      // this method is used to build basisk as well, 
+      // this method is used to build basis as well, 
       // even if we already have the space groupn
       Object ret = findGroupByOperations();
       if (!isAssign || !(ret instanceof SpaceGroup))
@@ -219,16 +220,18 @@ public class SpaceGroupFinder {
       for (int i = targets.nextSetBit(0); i >= 0; i = targets.nextSetBit(i + 1))
         basis.clear(atoms[i].index);
       int nb = basis.cardinality();
-      String msg = name + (atoms0 == null ? ""
-          : "\nbasis is " + nb + " atom" + (nb == 1 ? "" : "s") + ": " + basis);
-      System.out.println(msg);
-      if (asString)
-        return msg;
+      if (!isCalcOnly) {
+        String msg = name + (atoms0 == null || nb == 0 ? ""
+          : "\nbasis is " +  nb + " atom" + (nb == 1 ? "" : "s") + ": " + basis);
+        System.out.println("SpaceGroupFinder: " + msg);
+        if (asString)
+          return msg;
+      }
     }
 
     // supplement SpaceGroup info map with additional information
     Map<String, Object> map = (Map<String, Object>) sg.dumpInfoObj();
-    if (uc != null)
+    if (uc != null && !isCalcOnly)
       System.out.println("unitcell is " + uc.getUnitCellInfo(true));
     if (!isAssign) {
       BS bs1 = BS.copy(bsPoints0);
@@ -249,16 +252,32 @@ public class SpaceGroupFinder {
   }
 
 
+  private boolean checkWyckoffHM() {
+    if (xyzList != null && xyzList.indexOf(",") < 0) {
+      //could be H-M -- check for odd case
+      String clegId = SpaceGroup.convertWyckoffHMCleg(xyzList, null);
+      if (clegId != null) {
+        xyzList = "ITA/" + clegId;
+        return true;
+      }
+    }
+    return false;
+  }
+
+
   @SuppressWarnings("unchecked")
   private SpaceGroup setITA(boolean isHall) {
+    // TODO - will need to adjust this for special (non-space) groups
     String name = null;
     Map<String, Object> sgdata = null;
     int pt = xyzList.lastIndexOf(":");
-    boolean hasTransform = (pt > 0 && xyzList.indexOf(",") > pt);
+    int pt2 = xyzList.indexOf(",");
+    boolean hasTransform = (pt > 0 && pt2 > pt);
+    String clegId = null;
     // here we have said ITA/40:b  because we want the ITA variation
+    // but that is not going to be documented! 
     boolean isJmolCode = (pt > 0 && !hasTransform);
     String transform = null;
-    String clegId = null;
     if (hasTransform) {
       name = transform = uc.staticCleanTransform(xyzList.substring(pt + 1));
       xyzList = xyzList.substring(0, pt);
@@ -275,6 +294,10 @@ public class SpaceGroupFinder {
       pt = -1;
     }
     String itano = xyzList;
+    if (SpaceGroup.getExplicitSpecialGroupType(itano) > SpaceGroup.TYPE_SPACE) {
+      itano = itano.substring(2);
+      pt -= 2;
+    }
     boolean isITADotSetting = (pt > 0);
     if (!isJmolCode && !isHall && !hasTransform && !isITADotSetting
         && PT.parseInt(itano) != Integer.MIN_VALUE)
@@ -287,8 +310,8 @@ public class SpaceGroupFinder {
       if (genPos == null)
         return null;
     } else {
-      name = (hasTransform ? transform : itaIndex);
-      sg = SpaceGroup.getSpaceGroupFromJmolClegOrITA(hasTransform ? clegId : itaIndex);
+      name = (hasTransform ? transform : itaIndex);// p/2 here for itaIndex?
+      sg = SpaceGroup.getSpaceGroupFromJmolClegOrITA(vwr, hasTransform ? clegId : itaIndex);
       Object o = uc.getSpaceGroupJSON(vwr, "ITA", itaIndex, 0);
     if (o == null || o instanceof String) {
       return null;
@@ -307,6 +330,7 @@ public class SpaceGroupFinder {
         }
       }
         // "more" type, from wp-list, does note contain gp or wpos
+        // also no jmolId for special groups
         if (sgdata == null || !sgdata.containsKey("jmolId")) {
         if (isJmolCode) {
           // trying to get an ITA from a Jmol code with ITA like ITA/12:abc
@@ -335,10 +359,10 @@ public class SpaceGroupFinder {
 
     }
     if (sg != null && transform == null) {
-      sg = SpaceGroup.createITASpaceGroup(genPos, sg);
+      sg = SpaceGroup.createITASpaceGroup(sg.groupType, genPos, sg);
       return sg;
     }
-    sg = SpaceGroup.transformSpaceGroup(null, sg, genPos,
+    sg = SpaceGroup.transformSpaceGroup(sg == null ? SpaceGroup.TYPE_SPACE : sg.groupType, null, sg, genPos,
         (hasTransform ? transform : null),
         (hasTransform ? new M4() : null));
     if (sg == null)
@@ -349,12 +373,14 @@ public class SpaceGroupFinder {
         transform = (String) sgdata.get("trm");
         String hm = (String) sgdata.get("hm");
         sg.setHMSymbol(hm);
+      } else {
+        sg.setITATableNames(null, itano, null, transform);
       }
       name = null;
       System.out.println("SpaceGroupFinder: new setting: " + sg.asString());
     }
     return sg;
-    }
+  }
     
 
 
@@ -366,7 +392,7 @@ public class SpaceGroupFinder {
     try {
       if (isUnknown) {
         if (bsOpGroups == null)
-          loadData(vwr, this);
+          loadData(vwr);
       } else {
         bsGroups.set(0);
       }
@@ -525,6 +551,7 @@ public class SpaceGroupFinder {
         bsPoints.clearAll();
         bsPoints.or(bsPoints0);
         targeted.clearAll();
+        boolean allInvariant = true;
         for (int i = bsPoints.nextSetBit(0); i >= 0; i = bsPoints
             .nextSetBit(i + 1)) {
           bsPoints.clear(i);
@@ -537,6 +564,7 @@ public class SpaceGroupFinder {
             break;
           }
           if (j >= 0 && i != j) {
+            allInvariant = false;
             targeted.set(j);
           }
         }
@@ -552,16 +580,18 @@ public class SpaceGroupFinder {
             //System.out.println("targeted=" + targeted);
             //System.out.println("targets=" + targets);
             //reduce the number of possible groups to groups having this operation
-            bsGroups.and(myGroups);
-            // reduce the number of operations to check to only those NOT common to 
-            // all remaining groups;
-            temp1.setBits(1, OP_COUNT);
-            for (int i = bsGroups.nextSetBit(0); i >= 0; i = bsGroups
-                .nextSetBit(i + 1)) {
-              temp1.and(bsGroupOps[i]);
+            if (!allInvariant) {
+              bsGroups.and(myGroups);
+              // reduce the number of operations to check to only those NOT common to 
+              // all remaining groups;
+              temp1.setBits(1, OP_COUNT);
+              for (int i = bsGroups.nextSetBit(0); i >= 0; i = bsGroups
+                  .nextSetBit(i + 1)) {
+                temp1.and(bsGroupOps[i]);
+              }
+              uncheckedOps.or(temp1);
+              bsOps.andNot(temp1);
             }
-            uncheckedOps.or(temp1);
-            bsOps.andNot(temp1);
           } else {
             // iop was not found
             // clear all groups that require this operation
@@ -607,6 +637,7 @@ public class SpaceGroupFinder {
             //System.out.println("test4 opsc= " + opsChecked.cardinality() + " " + opsChecked);
             bsPoints.andNot(targets);
             if (!checkBasis(uc, uncheckedOps, bsPoints, targets)) {
+              System.out.println("failed checkBasis");
               isg = 0;
             }
             //System.out.println("test2b targets " + targets.cardinality() + " " + targets);
@@ -625,22 +656,33 @@ public class SpaceGroupFinder {
           + bsGroups + " " + bsOps);
       for (int i = bsGroups.nextSetBit(0); i >= 0; i = bsGroups
           .nextSetBit(i + 1)) {
-        System.out.println(SpaceGroup.nameToGroup.get(groupNames[i]));
+        System.out.println("SpaceGroupFinder found " + SpaceGroup.nameToGroup.get(groupNames[i]));
       }
-      if (n != 1)
-        return null;
-      sg = SpaceGroup.nameToGroup.get(groupNames[isg]);
+      if (n != 1) {
+    	  // multiple space groups are poosible when
+    	  // the only atoms are on special positions.
+    	  // for example, a single atom at the origin.
+        isg = bsGroups.length() - 1;
+        if (isg < 0)
+          return null;
+      }
+      sg = nameToGroup(groupNames[isg]);
     }
     return sg;
   }
 
+  private static SpaceGroup nameToGroup(String name) {
+    int pt = (name.charAt(0) != '0' ?  0 : name.charAt(1) != '0' ? 1 : 2);
+    return  SpaceGroup.nameToGroup.get(name.substring(pt));
+  }
+
   private static Symmetry setSpaceGroupAndUnitCell(SpaceGroup sg, float[] params,
                                            T3[] oabc, boolean allowSame) {
     Symmetry sym = new Symmetry();
     sym.setSpaceGroupTo(sg);
     if (oabc == null) {
     float[] newParams = new float[6];
-    if (!UnitCell.createCompatibleUnitCell(sg, params, newParams, allowSame)) {
+    if (!sg.createCompatibleUnitCell(params, newParams, allowSame)) {
       newParams = params;
     }
     sym.setUnitCellFromParams(newParams, false, Float.NaN);
@@ -700,8 +742,8 @@ public class SpaceGroupFinder {
       //      if (bs.isEmpty())
       //        return;
       // added
-      bs.or(bsPoints);
       SymmetryOperation op = getOp(iop);
+      bs.or(bsPoints);
       for (int i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
         int j = findEquiv(uc, -1, op, i, bs, pTemp, false);
         if (j < 0)
@@ -929,14 +971,14 @@ public class SpaceGroupFinder {
     if (groups.isEmpty()) {
       // if assigning, we must assume that this is a non-standard unknown setting 
       // and the unit cell is OK. We just define the space group as is.
-      return (isAssign ? SpaceGroup.createSpaceGroupN(xyzList) : null);
+      return (isAssign ? SpaceGroup.createSpaceGroupN(xyzList, true) : null);
     }
     if (isEqual) {
       for (int n = ops.length, i = groups.nextSetBit(0); i >= 0; i = groups
           .nextSetBit(i + 1)) {
         if (bsGroupOps[i].cardinality() == n) {
           if (isAssign) {
-            return SpaceGroup.createSpaceGroupN(groupNames[i]);
+            return SpaceGroup.createSpaceGroupN(groupNames[i], true);
           }
           return SpaceGroup.getInfo(null, groupNames[i], unitCellParams, true,
               false);
@@ -1144,17 +1186,17 @@ public class SpaceGroupFinder {
   }
 
   public static void main(String[] args) {
-    if (loadData(null, new SpaceGroupFinder()))
+    if (loadData(null))
       System.out.println("OK");
   }
 
-  private static boolean loadData(Viewer vwr, Object me) {
+  private static boolean loadData(Viewer vwr) {
     try {
-      groupNames = getList(vwr, me, null, "sggroups_ordered.txt");
+      groupNames = getList(vwr, null, "sggroups_ordered.txt");
       GROUP_COUNT = groupNames.length;
-      opXYZ = getList(vwr, me, null, "sgops_ordered.txt");
+      opXYZ = getList(vwr, null, "sgops_ordered.txt");
       OP_COUNT = opXYZ.length;
-      String[] map = getList(vwr, me, new String[OP_COUNT], "sgmap.txt");
+      String[] map = getList(vwr, new String[OP_COUNT], "sgmap.txt");
       bsGroupOps = new BS[GROUP_COUNT];
       bsOpGroups = new BS[OP_COUNT];
       for (int j = 0; j < GROUP_COUNT; j++)
@@ -1185,10 +1227,10 @@ public class SpaceGroupFinder {
     }
   }
 
-  private static String[] getList(Viewer vwr, Object me, String[] list,
+  private static String[] getList(Viewer vwr, String[] list,
                                   String fileName)
       throws IOException {
-    rdr = FileManager.getBufferedReaderForResource(vwr, me,
+    rdr = FileManager.getBufferedReaderForResource(vwr, SpaceGroupFinder.class,
         "org/jmol/symmetry/", "sg/" + fileName);
     if (list == null) {
       Lst<String> l = new Lst<String>();
@@ -1204,6 +1246,7 @@ public class SpaceGroupFinder {
         list[i] = rdr.readLine();
     }
     rdr.close();
+    System.out.println("SGF read " + list.length  + " records for " + fileName);
     return list;
   }
 
