@@ -87,8 +87,12 @@ public class Symmetry implements SymmetryInterface {
   private static Map<String, Object> aflowStructures;
   private static Map<String, Object>[] itaData;
   private static Map<String, Object>[] itaSubData;
-  private static Lst<Object> allDataITA;
+  private static Map<String, Object>[] planeData, layerData, rodData, friezeData;
+  // TODO: plane and subperiodic subgroup info
+  private static Map<String, Object>[] planeSubData, layerSubData, rodSubData, friezeSubData;
+  private static Lst<Object> allDataITA, allPlaneData, allLayerData, allRodData, allFriezeData;
   private static WyckoffFinder wyckoffFinder;
+  private static CLEG clegInstance;
   
   public SpaceGroup spaceGroup;
   public UnitCell unitCell;
@@ -101,6 +105,15 @@ public class Symmetry implements SymmetryInterface {
   private SymmetryDesc desc;
   private M4 transformMatrix;
 
+  @Override
+  public String[] getSymopList(boolean doNormalize) {
+    int n = spaceGroup.operationCount;
+    String[] list = new String[n];
+    for (int i = 0; i < n; i++)
+      list[i] = "" + getSpaceGroupXyz(i, doNormalize);
+    return list;
+  }
+
   @Override
   public boolean isBio() {
     return isBio;
@@ -175,32 +188,70 @@ public class Symmetry implements SymmetryInterface {
     return spaceGroup;
   }
 
+  @SuppressWarnings("unchecked")
   @Override
   public Object getSpaceGroupInfoObj(String name, Object params, boolean isFull,
                                      boolean addNonstandard) {
-    boolean isNameToXYZList = false;
+    boolean isNumOrTrm = false;
     switch (name) {
     case "list":
-      return getSpaceGroupList((Viewer) params);
+      // from spacegroup(n, "list")
+      return getSpaceGroupList((Integer) params);
     case "opsCtr":
       return spaceGroup.getOpsCtr((String) params);
-    case "nameToXYZList": 
-      isNameToXYZList = true;
-      //$FALL-THROUGH$
-    case "itaIndex":
     case "itaTransform":
     case "itaNumber":
+      isNumOrTrm = true;
+      //$FALL-THROUGH$
+    case "nameToXYZList": 
+    case "itaIndex":
+    case "hmName":
       SpaceGroup sg = null;
       if (params != null) {
-        sg = SpaceGroup.determineSpaceGroupN((String) params);
-        if (sg == null && isNameToXYZList)
-          sg = SpaceGroup.createSpaceGroupN((String) params);
+        String s = (String) params;
+        if (s.endsWith("'")) {
+          // Jmol-specific Wyckoff type names get cleg
+          s = SpaceGroup.convertWyckoffHMCleg(s, null);
+          if (isNumOrTrm && s != null) {
+            int pt = s.indexOf(":");
+            return ("itaNumber".equals(name) ? s.substring(0, pt) : s.substring(pt + 1));
+          }
+          return null;
+        }
+        if (s.length() > 1 && s.charAt(1) == '/') {
+          // get first item if nnn and not nnn.m
+          if (s.indexOf('.') < 0  && s.indexOf(":") < 0 && PT.isDigit(s.charAt(2))) {
+            s += ".";
+          }
+          Map<String, Object> info = (Map<String, Object>) getSpaceGroupJSON(vwr, "ITA", s, 0);
+          switch (info == null ? "" : name) {
+          case "itaData":
+            return info;
+          case "hmName":
+            return info.get("hm");
+          case "nameToXYZList":
+            return info.get("gp");
+          case "itaIndex":
+            return "" + info.get("sg") + "." + info.get("set");
+          case "itaTransform":
+            return info.get("trm");
+          case "itaNumber": // as String here
+            return "" + info.get("sg");
+          }
+          return null;
+          
+        }
+        sg = SpaceGroup.determineSpaceGroupN(s);
+        if (sg == null && "nameToXYZList".equals(name))
+          sg = SpaceGroup.createSpaceGroupN(s, true);
       } else if (spaceGroup != null) {
         sg = spaceGroup;
       } else if (symmetryInfo != null) {
         sg = symmetryInfo.getDerivedSpaceGroup();
       }
       switch (sg == null ? "" : name) {
+      case "hmName":
+        return sg.getHMName();
       case "nameToXYZList":
         Lst<Object> genPos = new Lst<Object>();
         sg.setFinalOperations();
@@ -223,20 +274,22 @@ public class Symmetry implements SymmetryInterface {
   }
 
   @SuppressWarnings("unchecked")
-  private String getSpaceGroupList(Viewer vwr) {
+  private String getSpaceGroupList(Integer sg0) {
     SB sb = new SB();
     Lst<Object> list = (Lst<Object>) getSpaceGroupJSON(vwr, "ITA", "ALL", 0);
     for (int i = 0, n = list.size(); i < n; i++) {
       Map<String, Object> map = (Map<String, Object>) list.get(i);
-      sb.appendO(map.get("sg")).appendC('.').appendO(map.get("set"))
-        .appendC('\t').appendO(map.get("hm")).appendC('\t').appendO(map.get("sg")).appendC(':').appendO(map.get("trm")).appendC('\n');
+      Integer sg = (Integer) map.get("sg");
+      if (sg0 == null || sg.equals(sg0))
+        sb.appendO(sg).appendC('.').appendO(map.get("set"))
+          .appendC('\t').appendO(map.get("hm")).appendC('\t').appendO(map.get("sg")).appendC(':').appendO(map.get("trm")).appendC('\n');
     }
     return sb.toString();
   }
 
   @Override
   public Object getLatticeDesignation() {
-    return spaceGroup.getLatticeDesignation();
+    return spaceGroup.getShelxLATTDesignation();
   }
 
   @Override
@@ -245,12 +298,15 @@ public class Symmetry implements SymmetryInterface {
                                  boolean doNormalize, String filterSymop) {
     if (name != null && (name.startsWith("bio") || name.indexOf(" *(") >= 0)) // filter SYMOP
       spaceGroup.setName(name);
+    boolean doCalculate = "unspecified!".equals(name);
+    if (doCalculate)
+      filterSymop = "calculated";
     if (filterSymop != null) {
       Lst<SymmetryOperation> lst = new Lst<SymmetryOperation>();
-      lst.addLast(spaceGroup.operations[0]);
+      lst.addLast(spaceGroup.matrixOperations[0]);
       for (int i = 1; i < spaceGroup.operationCount; i++)
-        if (filterSymop.contains(" " + (i + 1) + " "))
-          lst.addLast(spaceGroup.operations[i]);
+        if (doCalculate || filterSymop.contains(" " + (i + 1) + " "))
+          lst.addLast(spaceGroup.matrixOperations[i]);
       spaceGroup = SpaceGroup.createSpaceGroup(-1,
           name + " *(" + filterSymop.trim() + ")", lst, -1);
     }
@@ -260,9 +316,9 @@ public class Symmetry implements SymmetryInterface {
 
   @Override
   public M4 getSpaceGroupOperation(int i) {
-    return (spaceGroup == null || spaceGroup.operations == null // bio 
-        || i >= spaceGroup.operations.length ? null
-            : spaceGroup.finalOperations == null ? spaceGroup.operations[i]
+    return (spaceGroup == null || spaceGroup.matrixOperations == null // bio 
+        || i >= spaceGroup.matrixOperations.length ? null
+            : spaceGroup.finalOperations == null ? spaceGroup.matrixOperations[i]
                 : spaceGroup.finalOperations[i]);
   }
 
@@ -275,7 +331,7 @@ public class Symmetry implements SymmetryInterface {
   public void newSpaceGroupPoint(P3 pt, int i, M4 o, int transX,
                                  int transY, int transZ, P3 retPoint) {
     if (o == null && spaceGroup.finalOperations == null) {
-      SymmetryOperation op = spaceGroup.operations[i];
+      SymmetryOperation op = spaceGroup.matrixOperations[i];
       // temporary spacegroups don't have to have finalOperations
       if (!op.isFinalized)
         op.doFinalize();
@@ -294,7 +350,7 @@ public class Symmetry implements SymmetryInterface {
 
   @Override
   public int getSpinOp(int op) {
-    return spaceGroup.operations[op].getMagneticOp();
+    return spaceGroup.matrixOperations[op].getMagneticOp();
   }
 
   @Override
@@ -309,7 +365,7 @@ public class Symmetry implements SymmetryInterface {
 
   @Override
   public Matrix getOperationRsVs(int iop) {
-    return (spaceGroup.finalOperations == null ? spaceGroup.operations
+    return (spaceGroup.finalOperations == null ? spaceGroup.matrixOperations
         : spaceGroup.finalOperations)[iop].rsvs;
   }
 
@@ -328,8 +384,8 @@ public class Symmetry implements SymmetryInterface {
   }
 
   @Override
-  public String getSpaceGroupNameType(String type) {
-    return (spaceGroup == null ? null : spaceGroup.getNameType(type, this));
+  public String geCIFWriterValue(String type) {
+    return (spaceGroup == null ? null : spaceGroup.getCIFWriterValue(type, this));
   }
 
   @Override
@@ -346,7 +402,7 @@ public class Symmetry implements SymmetryInterface {
 
   @Override
   public String getIntTableIndex() {
-    return (symmetryInfo != null ? symmetryInfo.intlTableIndex
+    return (symmetryInfo != null ? symmetryInfo.intlTableIndexNdotM
         : spaceGroup == null ? null : spaceGroup.getItaIndex());
   }
 
@@ -357,12 +413,14 @@ public class Symmetry implements SymmetryInterface {
   }
 
   @Override
-  public String getIntTableNumberFull() {
-    return (symmetryInfo != null ? symmetryInfo.intlTableJmolID
-        : spaceGroup == null ? null
-            : spaceGroup.jmolId != null
-                ? spaceGroup.jmolId
-                : spaceGroup.itaNumber);
+  public String getSpaceGroupClegId() {
+    return (symmetryInfo != null ? symmetryInfo.getClegId() : spaceGroup.getClegId());
+  }
+
+  @Override
+  public String getSpaceGroupJmolId() {
+    return (symmetryInfo != null ? symmetryInfo.intlTableJmolId
+        : spaceGroup == null ? null : spaceGroup.jmolId);
   }
   
   @Override
@@ -392,10 +450,10 @@ public class Symmetry implements SymmetryInterface {
   @Override
   public int getSpaceGroupOperationCount() {
     return (symmetryInfo != null && symmetryInfo.symmetryOperations != null ? // null here for PDB 
-            symmetryInfo.symmetryOperations.length
-        : spaceGroup != null && spaceGroup.finalOperations != null
-            ? spaceGroup.finalOperations.length
-            : 0);
+        symmetryInfo.symmetryOperations.length
+        : spaceGroup != null ? (spaceGroup.finalOperations != null
+            ? spaceGroup.finalOperations.length 
+            : spaceGroup.operationCount) : 0);
   }
 
   @Override
@@ -535,8 +593,13 @@ public class Symmetry implements SymmetryInterface {
   }
 
   @Override
-  public P3 getFractionalOffset() {
-    return unitCell.getFractionalOffset();
+  public P3 getFractionalOffset(boolean onlyIfFractional) {
+    P3 offset = unitCell.getFractionalOffset();
+    return (onlyIfFractional 
+        && offset != null
+        && offset.x == (int) offset.x
+        && offset.y == (int) offset.y 
+        && offset.z == (int) offset.z ? null : offset);
   }
 
   @Override
@@ -574,6 +637,13 @@ public class Symmetry implements SymmetryInterface {
     return unitCell.getCanonicalCopy(scale, withOffset);
   }
 
+  @Override
+  public P3[] getCanonicalCopyTrimmed(P3 frac, float scale) {
+    return unitCell.getCanonicalCopyTrimmed(frac, scale);
+  }
+
+
+
   @Override
   public float getUnitCellInfoType(int infoType) {
     return unitCell.getInfo(infoType);
@@ -634,7 +704,8 @@ public class Symmetry implements SymmetryInterface {
       boolean isOneMolecule = (molecules[moleculeCount
           - 1].firstAtomIndex == modelSet.am[atoms[iAtom0].mi].firstAtomIndex);
       P3 center = new P3();
-      boolean centroidPacked = (minmax[6] == 1);
+      float packing = minmax[6] / 100f;
+      boolean centroidPacked = (packing != 0);
       nextMol: for (int i = moleculeCount; --i >= 0
           && bsAtoms.get(molecules[i].firstAtomIndex);) {
         BS bs = molecules[i].atomList;
@@ -643,7 +714,7 @@ public class Symmetry implements SymmetryInterface {
         for (int j = bs.nextSetBit(0); j >= 0; j = bs.nextSetBit(j + 1)) {
           if (isOneMolecule || centroidPacked) {
             center.setT(atoms[j]);
-            if (isNotCentroid(center, 1, minmax, centroidPacked)) {
+            if (isNotCentroid(center, 1, minmax, packing)) {
               if (isOneMolecule)
                 bsDelete.set(j);
             } else if (!isOneMolecule) {
@@ -654,7 +725,7 @@ public class Symmetry implements SymmetryInterface {
             n++;
           }
         }
-        if (centroidPacked || n > 0 && isNotCentroid(center, n, minmax, false))
+        if (centroidPacked || n > 0 && isNotCentroid(center, n, minmax, 0))
           bsDelete.or(bs);
       }
       return bsDelete;
@@ -664,23 +735,27 @@ public class Symmetry implements SymmetryInterface {
   }
 
   private boolean isNotCentroid(P3 center, int n, int[] minmax,
-                                boolean centroidPacked) {
+                                float packing) {
     center.scale(1f / n);
     toFractional(center, false);
     // we have to disallow just a tiny slice of atoms due to rounding errors
     // so  -0.000001 is OK, but 0.999991 is not.
-    if (centroidPacked)
-      return (center.x + 0.000005d <= minmax[0]
-          || center.x - 0.000005d > minmax[3]
-          || center.y + 0.000005d <= minmax[1]
-          || center.y - 0.000005d > minmax[4]
-          || center.z + 0.000005d <= minmax[2]
-          || center.z - 0.000005d > minmax[5]);
+    if (packing != 0) {
+      float d = (packing >= 0 ? packing : 0.000005f);
+      return (center.x + d <= minmax[0]
+          || center.x - d > minmax[3]
+          || center.y + d <= minmax[1]
+          || center.y - d > minmax[4]
+          || center.z + d <= minmax[2]
+          || center.z - d > minmax[5]);
+    }
 
-    return (center.x + 0.000005d <= minmax[0] || center.x + 0.00005d > minmax[3]
-        || center.y + 0.000005d <= minmax[1] || center.y + 0.00005d > minmax[4]
-        || center.z + 0.000005d <= minmax[2]
-        || center.z + 0.00005d > minmax[5]);
+    return (center.x + 0.000005f <= minmax[0] 
+         || center.x + 0.00005f > minmax[3]
+        || center.y + 0.000005f <= minmax[1] 
+        || center.y + 0.00005f > minmax[4]
+        || center.z + 0.000005f <= minmax[2]
+        || center.z + 0.00005f > minmax[5]);
   }
 
   // info
@@ -713,8 +788,9 @@ public class Symmetry implements SymmetryInterface {
                                                float[] cellParams) {
     boolean isForModel = (sgName == null);
     if (sgName == null) {
-      Map<String, Object> info = modelSet
-          .getModelAuxiliaryInfo(modelSet.vwr.am.cmi);
+      if (modelIndex < 0)
+        modelIndex = vwr.am.cmi;
+      Map<String, Object> info = modelSet.getModelAuxiliaryInfo(modelIndex);
       if (info != null)
         sgName = (String) info.get(JC.INFO_SPACE_GROUP);
     }
@@ -756,7 +832,7 @@ public class Symmetry implements SymmetryInterface {
   @Override
   public boolean getState(ModelSet ms, int modelIndex, SB commands) {
 	boolean isAssigned = (ms.getInfo(modelIndex, JC.INFO_SPACE_GROUP_ASSIGNED) != null);
-    T3 pt = getFractionalOffset();
+    T3 pt = getFractionalOffset(false);
     boolean loadUC = false;
     if (pt != null && (pt.x != 0 || pt.y != 0 || pt.z != 0)) {
       commands.append("; set unitcell ").append(Escape.eP(pt));
@@ -770,6 +846,9 @@ public class Symmetry implements SymmetryInterface {
     }
     String sg = (String) ms.getInfo(modelIndex, JC.INFO_SPACE_GROUP);
     if (isAssigned && sg != null) {
+      int ipt = sg.indexOf("#");
+      if (ipt >= 0)
+        sg = sg.substring(ipt + 1);
       // first one may not be read, but it is important to have it
       // in case there is an issue with assigning the spacegroup
       String cmd = "\n UNITCELL "
@@ -926,7 +1005,7 @@ public class Symmetry implements SymmetryInterface {
     if (sg instanceof SpaceGroup) {
       spaceGroup = (SpaceGroup) sg;
     } else {
-      spaceGroup = SpaceGroup.getSpaceGroupFromJmolClegOrITA(sg.toString());
+      spaceGroup = SpaceGroup.getSpaceGroupFromJmolClegOrITA(vwr, sg.toString());
     }
   }
 
@@ -969,7 +1048,17 @@ public class Symmetry implements SymmetryInterface {
     M4[] ops = getSymmetryOperations();
     return (ops == null || unitCell == null ? null
         : unitCell.getEquivPoints(pt, flags, ops,
-            pts == null ? new Lst<P3>() : pts, 0, 0, 0));
+            pts == null ? new Lst<P3>() : pts, 0, 0, 0, getPeriodicity()));
+  }
+
+  @Override
+  public int getPeriodicity() {
+    return (spaceGroup == null ? 0x7 : spaceGroup.periodicity);
+  }
+
+  @Override
+  public int getDimensionality() {
+    return (spaceGroup == null ? 3 : spaceGroup.nDim);
   }
 
   @Override
@@ -1001,7 +1090,7 @@ public class Symmetry implements SymmetryInterface {
     int dup0 = (opsCtr == null ? n0 : check0);
     if (ops != null || unitCell != null) {
       for (int i = nInitial; i < n; i++) {
-        unitCell.getEquivPoints(pts.get(i), flags, ops, pts, check0, n0, dup0);
+        unitCell.getEquivPoints(pts.get(i), flags, ops, pts, check0, n0, dup0, getPeriodicity());
       }
     }
     // now remove the starting points, checking to see if perhaps our
@@ -1064,8 +1153,12 @@ public class Symmetry implements SymmetryInterface {
     SpaceGroup sg = spaceGroup;
     if (sg == null && symmetryInfo != null) {
       sg = SpaceGroup.determineSpaceGroupN(symmetryInfo.sgName);
-      if (sg == null)
-        sg = SpaceGroup.getSpaceGroupFromJmolClegOrITA(symmetryInfo.intlTableJmolID);
+      if (sg == null) {
+        String id = getSpaceGroupJmolId(); 
+        if (id == null)
+          id = getSpaceGroupClegId();
+        sg = SpaceGroup.getSpaceGroupFromJmolClegOrITA(vwr, id);
+      }
     }
     if (sg == null || sg.itaNumber == null) {
       // maybe an unusual setting
@@ -1075,29 +1168,27 @@ public class Symmetry implements SymmetryInterface {
       // attempt to make these not very close to any special position
       // this point tested in every standard setting and found to be excellent
       p = P3.new3(0.53f, 0.20f, 0.16f);
-    } else {
+    } else if (!"L".equals(letter)){
       p = P3.newP(p);
       unitCell.toFractional(p, false);
       unitCell.unitize(p);
     }
-    if (wyckoffFinder == null) {
-      wyckoffFinder = (WyckoffFinder) Interface
-          .getInterface("org.jmol.symmetry.WyckoffFinder", null, "symmetry");
-    }
+    
     try {
-      WyckoffFinder w = wyckoffFinder.getWyckoffFinder(vwr,
+      WyckoffFinder w = getWyckoffFinder().getWyckoffFinder(vwr,
           sg);
       boolean withMult = (letter != null && letter.charAt(0) == 'M');
       if (withMult) {
         letter = (letter.length() == 1 ? null : letter.substring(1));
       }
       int mode = (letter == null ? WyckoffFinder.WYCKOFF_RET_LABEL 
+          : "L".equals(letter) ? WyckoffFinder.WYCKOFF_RET_ALL_ARRAY 
           : letter.equalsIgnoreCase("coord") ? WyckoffFinder.WYCKOFF_RET_COORD 
           : letter.equalsIgnoreCase("coords") 
             ? WyckoffFinder.WYCKOFF_RET_COORDS 
           : letter.endsWith("*") ? (int) letter.charAt(0) : 0);
       if (mode != 0) {
-        return (w == null ? "?" : w.getInfo(unitCell, p, mode, withMult));
+        return (w == null ? "?" : w.getInfo(unitCell, p, mode, withMult, vwr.is2D()));
       }
       if (w.findPositionFor(p, letter) == null)
         return null;
@@ -1109,6 +1200,14 @@ public class Symmetry implements SymmetryInterface {
     }
   }
 
+  private WyckoffFinder getWyckoffFinder() {
+    if (wyckoffFinder == null) {
+      wyckoffFinder = (WyckoffFinder) Interface
+          .getInterface("org.jmol.symmetry.WyckoffFinder", null, "symmetry");
+    }
+    return wyckoffFinder;
+  }
+
   /**
    * @param fracA
    * @param fracB
@@ -1182,6 +1281,8 @@ public class Symmetry implements SymmetryInterface {
   @Override
   public Object getSubgroupJSON(Viewer vwr, int itaFrom, int itaTo, int index1,
                                 int index2) {
+    if (vwr == null)
+      vwr = this.vwr;
     boolean allSubsMap = (itaTo < 0);
     boolean asIntArray = (itaTo == 0 && index1 == 0);
     boolean asSSIntArray = (itaTo == 0 && index1 < 0);
@@ -1260,11 +1361,11 @@ public class Symmetry implements SymmetryInterface {
             whereList.addLast(o);
             continue;
           }
-          Lst<Object> trms = (Lst<Object>) o.get("trm");
+          Lst<Object> trms = (Lst<Object>) o.get("trms");
           n = trms.size();
           if (index2 < 1 || index2 > n)
             return null;
-          return ((String) trms.get(index2 - 1)).substring(2);
+          return ((Map<String, Object>)trms.get(index2 - 1)).get("trm");
         }
         if (isWhereList && !whereList.isEmpty()) {
           return whereList;
@@ -1286,40 +1387,55 @@ public class Symmetry implements SymmetryInterface {
 
   @SuppressWarnings("unchecked")
   @Override
-  public Object getSpaceGroupJSON(Viewer vwr, String name, Object data,
+  public Object getSpaceGroupJSON(Viewer vwr, String name, String data,
                                   int index) {
+    if (vwr == null)
+      vwr = this.vwr;
+    boolean isSetting = name.equals("setting");
     boolean isSettings = name.equals("settings");
+    boolean isAFLOW = name.equalsIgnoreCase("AFLOW");
     boolean isSubgroups = !isSettings && name.equals("subgroups");
-    boolean isThis = ((isSettings || isSubgroups)
+    boolean isThis = ((isSetting || isSettings || isSubgroups)
         && index == Integer.MIN_VALUE);
-    String s0 = (!isSettings && !isSubgroups ? name
+    String s0 = (!isSettings && !isSetting && !isSubgroups? name
         : isThis ? getSpaceGroupName() : "" + index);
     try {
       int itno;
+      int specialType = (data == null ? SpaceGroup.TYPE_SPACE : SpaceGroup.getExplicitSpecialGroupType(data));
+      if (specialType > SpaceGroup.TYPE_SPACE)
+        data = data.substring(2); 
       String tm = null;
       boolean isTM, isInt;
       String sgname;
-      if (isSettings || isSubgroups) {
+      if (isSetting && data == null || isSettings || isSubgroups) {
         isTM = false;
         isInt = true;
-        sgname = (isSettings ? (String) data : null);
+        sgname = (isSetting ? data : null);
         if (isThis) {
+          // special TODO
           itno = PT.parseInt(getIntTableNumber());
-          if (isSettings) {
+          if (isSetting || isSettings) {
             if (spaceGroup == null) {
               SpaceGroup sg = symmetryInfo.getDerivedSpaceGroup();
               if (sg == null)
                 return new Hashtable<String, Object>();
               sgname = sg.jmolId;
             } else {
-              sgname = getIntTableNumberFull();
+              sgname = getSpaceGroupClegId();
+              if (isSetting) {
+                tm = sgname.substring(sgname.indexOf(":") + 1);
+              }  else if (isSettings) {
+                index = 0;
+              }
             }
           }
         } else {
           itno = index;
         }
       } else {
-        sgname = (String) data;
+        if (!isAFLOW)
+          index = 0;
+        sgname = data;
         // tm allow for both 4(a,b,...) and 4:a,b,..., or, technically, 4(a,b,....
         int pt = sgname.indexOf("(");
         if (pt < 0)
@@ -1339,9 +1455,12 @@ public class Symmetry implements SymmetryInterface {
           sgname = sgname.substring(0, pt);
         }
       }
-      if (isInt && (itno > 230 || (isSettings ? itno < 1 : itno < 0)))
+      
+      
+      if (isInt && (itno > SpaceGroup.getMax(specialType) || (isSettings || isSetting ? itno < 1 : itno < 0)))
         throw new ArrayIndexOutOfBoundsException(itno);
       if (isSubgroups) {
+        // special TODO
         if (itaSubData == null)
           itaSubData = new Map[230];
         Map<String, Object> resource = itaSubData[itno - 1];
@@ -1351,39 +1470,30 @@ public class Symmetry implements SymmetryInterface {
         if (resource != null) {
           return resource;
         }
-      } else if (isSettings || name.equalsIgnoreCase("ITA")) {
+      } else if (isSetting || isSettings || name.equalsIgnoreCase("ITA")) {
         if (itno == 0) {
-          if (allDataITA == null)
-            allDataITA = (Lst<Object>) getResource(vwr, "sg/json/ita_all.json");
-          return allDataITA;
+          return getAllITAData(vwr, specialType, true);
         }
-        if (itaData == null)
-          itaData = new Map[230];
-        Map<String, Object> resource = itaData[itno - 1];
-        if (resource == null)
-          itaData[itno - 1] = resource = (Map<String, Object>) getResource(vwr,
-              "sg/json/ita_" + itno + ".json");
+        Map<String, Object> resource = getITResource(vwr, specialType, itno, data);
         if (resource != null) {
           if (index == 0 && tm == null)
-            return resource;
+            return (isSettings ? resource.get("its") : resource);
           Lst<Object> its = (Lst<Object>) resource.get("its");
           if (its != null) {
             if (isSettings && !isThis) {
               return its;
             }
             int n = its.size();
-            int i0 = (isInt && !isThis ? index : n);
+            int i0 = (isSetting ? Math.max(index, 1) : isInt && !isThis ? index : n);
             if (i0 > n)
               return null;
+            if (isSetting)
+              return its.get(i0 - 1);
             Map<String, Object> map = null;
             for (int i = i0; --i >= 0;) {
               map = (Map<String, Object>) its.get(i);
-              if (i == index - 1
-                  || (tm == null ? sgname.equals(map.get("jmolId"))
-                      : tm.equals(map.get("trm")))) {
-                System.out.println(tm);
-                System.out.println(map);
-
+              if (i == index - 1 || 
+                  (tm == null ? sgname.equals(map.get("jmolId")) : tm.equals(map.get("trm")))) {
                 if (!map.containsKey("more")) {
                   return map;
                 }
@@ -1392,12 +1502,13 @@ public class Symmetry implements SymmetryInterface {
               map = null;
             }
             if (map != null) {
-              return SpaceGroup.fillMoreData(map, (String) map.get("clegId"), itno,
-                  (Map<String, Object>) its.get(0));
+              // "more" was found -- this is a minimal Wyckoff-only setting
+              return SpaceGroup.fillMoreData(vwr, map, data, itno, (Map<String, Object>) its.get(0));
             }
+            // TODO: create entries for unregistered settings?
           }
         }
-      } else if (name.equalsIgnoreCase("AFLOW") && tm == null) {
+      } else if (isAFLOW && tm == null) {
         if (aflowStructures == null)
           aflowStructures = (Map<String, Object>) getResource(vwr,
               "sg/json/aflow_structures.json");
@@ -1435,9 +1546,98 @@ public class Symmetry implements SymmetryInterface {
     }
   }
   
-  private Object getResource(Viewer vwr, String resource) {
+  @SuppressWarnings("unchecked")
+  static Map<String, Object> getITResource(Viewer vwr, int type, int itno,
+                                           String hmName) {
+    if (type == SpaceGroup.TYPE_SPACE) {
+      if (itaData == null)
+        itaData = new Map[230];
+      Map<String, Object> resource = itaData[itno - 1];
+      if (resource == null)
+        itaData[itno - 1] = resource = (Map<String, Object>) getResource(vwr,
+            "sg/json/ita_" + itno + ".json");
+      return resource;
+    }
+    Map<String, Object>[] data = (Map<String, Object>[]) getAllITAData(vwr,
+        type, false);
+    if (itno > 0)
+      return data[itno - 1];
+    // match HM name
+    for (int i = 0, n = data.length; i < n; i++) {
+      Lst<Object> list = (Lst<Object>) data[i].get("its");
+      for (int j = list.size(); --j >= 0;) {
+        Map<String, Object> map = (Map<String, Object>) list.get(j);
+        String hm = (String) map.get("hm");
+        if (SpaceGroup.hmEquals(hm, hmName, type))
+          return map;
+      }
+    }
+    return null;
+  }
+
+  @SuppressWarnings("unchecked")
+  static Object getAllITAData(Viewer vwr, int type, boolean isAll) {
+    switch (type) {
+    case SpaceGroup.TYPE_SPACE:
+      if (allDataITA == null)
+        allDataITA = (Lst<Object>) getResource(vwr, "sg/json/ita_all.json");
+      return allDataITA;
+    default:
+      String name = "sg/json/it" + (type == SpaceGroup.TYPE_PLANE ? "a" : "e")
+          + "_all_" + SpaceGroup.getSpecialGroupName(type) + ".json";
+      switch (type) {
+      case SpaceGroup.TYPE_PLANE:
+        if (allPlaneData == null) {
+          allPlaneData = (Lst<Object>) getResource(vwr, name);
+          planeData = createSpecialData(type, allPlaneData);
+        }
+        return (isAll ? allPlaneData : planeData);
+      case SpaceGroup.TYPE_LAYER:
+        if (allLayerData == null) {
+          allLayerData = (Lst<Object>) getResource(vwr, name);
+          layerData = createSpecialData(type, allLayerData);
+        }
+        return (isAll ? allLayerData : layerData);
+      case SpaceGroup.TYPE_ROD:
+        if (allRodData == null) {
+          allRodData = (Lst<Object>) getResource(vwr, name);
+          rodData = createSpecialData(type, allRodData);
+        }
+        return (isAll ? allRodData : rodData);
+      case SpaceGroup.TYPE_FRIEZE:
+        if (allFriezeData == null) {
+          allFriezeData = (Lst<Object>) getResource(vwr, name);
+          friezeData = createSpecialData(type, allFriezeData);
+        }
+        return (isAll ? allFriezeData : friezeData);
+      }
+    }
+    return null;
+  }
+
+  @SuppressWarnings({ "rawtypes", "unchecked" })
+  private static Map<String, Object>[] createSpecialData(int type, Lst<Object> data) {
+    int n = SpaceGroup.getMax(type);
+    Map<String, Object>[] list = new Map[n];
+    for (int i = 0; i < n; i++) {
+      list[i] = new Hashtable<String, Object>();
+      list[i].put("sg", Integer.valueOf(i + 1));
+      list[i].put("its", new Lst<Map<String, Object>>());
+    }
+    for (int i = 0, nd = data.size(); i < nd; i++) {
+      Map<String, Object> map = (Map<String, Object>) data.get(i);
+      int sg = ((Integer) map.get("sg")).intValue();
+      ((Lst<Map<String, Object>>)list[sg - 1].get("its")).addLast(map);
+    }
+    for (int i = 0; i < n; i++) {
+      list[i].put("n", Integer.valueOf(((Lst) list[i].get("its")).size()));
+    }
+    return list;    
+  }
+
+  private static Object getResource(Viewer vwr, String resource) {
     try {
-      BufferedReader r = FileManager.getBufferedReaderForResource(vwr, this,
+      BufferedReader r = FileManager.getBufferedReaderForResource(vwr, Symmetry.class,
           "org/jmol/symmetry/", resource);
       String[] data = new String[1];
       if (Rdr.readAllAsString(r, Integer.MAX_VALUE, false, data, 0)) {
@@ -1461,7 +1661,7 @@ public class Symmetry implements SymmetryInterface {
 
   @Override
   public boolean fixUnitCell(float[] params) {
-    return UnitCell.createCompatibleUnitCell(spaceGroup, params, null, true);
+    return spaceGroup.createCompatibleUnitCell(params, null, true);
   }
 
 
@@ -1544,7 +1744,7 @@ public class Symmetry implements SymmetryInterface {
       Object o = getSpaceGroupJSON(vwr, "ITA", itaIndex, 0);
       return (o instanceof Map ? ( (Map<String, Object>)o).get(key) : o);
   }
-
+  
   @Override
   public String staticCleanTransform(String tr) {
     return SymmetryOperation.getTransformABC(UnitCell.toTrm(tr, null), true);
@@ -1560,8 +1760,8 @@ public class Symmetry implements SymmetryInterface {
 
   @Override
   public String getUnitCellDisplayName() {
-    String name = (symmetryInfo != null ? symmetryInfo.getDisplayName(this)
-        : spaceGroup != null ? spaceGroup.getDisplayName() : null);
+    String name = (spaceGroup != null ? spaceGroup.getDisplayName()
+        : symmetryInfo != null ? symmetryInfo.getDisplayName(this) : null);
     return (name.length() > 0 ? name : null);
   }
   
@@ -1571,22 +1771,12 @@ public class Symmetry implements SymmetryInterface {
     return (",".equals(sep) ? s : "("+ s + ")");
   }
 
-  @Override
-  public String getClegId() {
-    if (symmetryInfo != null)
-        return symmetryInfo.getDerivedSpaceGroup().clegId;
-    return spaceGroup.clegId;
-  }
-  
   @Override
   public int getFinalOperationCount() {
     setFinalOperations(3, null, null, -1, -1, false, null);
     return spaceGroup.getOperationCount();
   }
   
-  /**
-   * Convert to/from string/matrix representation
-   */
   @Override
   public Object convertTransform(String transform, M4 trm) {
     if (transform == null) {
@@ -1600,5 +1790,60 @@ public class Symmetry implements SymmetryInterface {
     UnitCell.getMatrixAndUnitCell(null, transform, trm);
     return trm;
   }
+
+  @Override
+  public M4 staticGetMatrixTransform(String cleg) {
+    return getCLEGInstance().getMatrixTransform(vwr, cleg);
+  }
+
+
+  @Override
+  public String staticTransformSpaceGroup(BS bs, String cleg,
+                                          Object paramsOrUC, SB sb) {
+    return getCLEGInstance().transformSpaceGroup(vwr, bs, cleg, paramsOrUC, sb);
+  }
+
+
+  private CLEG getCLEGInstance() {
+    if (clegInstance == null) {
+      clegInstance = (CLEG) Interface
+          .getInterface("org.jmol.symmetry.CLEG", null, "symmetry");
+    }
+    return clegInstance;
+  }
   
+  private Viewer vwr = null;
+  
+  /**
+   * for the vwr.getSymTemp() only
+   * 
+   * @param vwr
+   */
+  @Override
+  public SymmetryInterface setViewer(Viewer vwr) {
+    this.vwr = vwr;
+    return this;
+  }
+
+  @Override
+  public P3 getUnitCellCenter() {
+    return unitCell.getCenter(getPeriodicity());
+  }
+
+  private static SpecialGroupFactory groupFactory;
+  
+  /**
+   * Called from SpaceGroup to get a special group
+   * 
+   * @return singleton SpecialGroupFactory instance
+   */
+  static SpecialGroupFactory getSGFactory() {
+    if (groupFactory == null) {
+      groupFactory = (SpecialGroupFactory) Interface
+          .getInterface("org.jmol.symmetry.SpecialGroupFactory", null, "symmetry");
+    }
+    return groupFactory;
+  }
+  
+
 }
