@@ -225,6 +225,8 @@ public class SymmetryDesc {
           lst.put(key, io[j]);
       }
       return lst;
+    case T.list:
+      return io[RET_ID] + "\t" + io[RET_XYZ] + "  \t" + io[RET_LABEL];
     case T.full:
       return io[RET_XYZ] + "  \t" + io[RET_LABEL];
     case T.xyz:
@@ -591,7 +593,8 @@ public class SymmetryDesc {
     P3 ptinv = null; // inverted point for translucent frame
     P3 ipt = null; // inversion center
     P3 ptref = null; // reflection center
-
+    V3 vShift = null; // layer group shift along C
+    
     float w = 0;
     float margin = 0; // for plane
 
@@ -608,6 +611,34 @@ public class SymmetryDesc {
 
     // handle inversion
 
+    /**
+     * Indicates that our vertical planes need to be shifted down 1/2 c
+     */
+    int periodicity = uc.getPeriodicity();
+    boolean notC = (periodicity == 0x4); // rod
+    boolean shiftA = (isSpaceGroup && (periodicity & 0x1) == 0); // rod (ab)c
+    boolean shiftB = (isSpaceGroup && (periodicity & 0x2) == 0); // frieze a(b), rod (ab)c
+    boolean shiftC = (isSpaceGroup && (periodicity & 0x4) == 0); // plane ab, layer ab(c), frieze a(b)
+
+    /**
+     * will depend upon the dot product; used to show the second vector for a rotation
+     */
+    boolean isPeriodic = !(shiftA || shiftB || shiftC);
+    
+      // check for axis colinear with c. We will not show the second of these
+      // if they exist
+      vShift = V3.newVsub(pta00, pta03);
+      double dot = Math
+          .abs(ax1.dot(vShift) / vShift.length() / ax1.length());
+      if (Math.abs(dot - 1) < 0.001d) {
+        // c dot axis = 1
+        notC = false;
+        vShift = null;
+      } else {
+        isPeriodic = !notC;
+      }
+
+    
     if (haveInversion && isTranslation) {
 
       // simple inversion operation
@@ -718,6 +749,44 @@ public class SymmetryDesc {
         isRotation = false;
         haveInversion = false;
         isMirrorPlane = true;
+        if (shiftC) {
+          vShift = V3.newVsub(pta00, pta03);
+          dot = Math
+              .abs(ax1.dot(vShift) / vShift.length() / ax1.length());
+          shiftC = (dot < 0.001f);
+          if (shiftC) {
+            vShift.scale(0.5f);
+            uc.toCartesian(vShift, true);
+          }
+        } 
+        if (shiftB) {
+          V3 vs = V3.newVsub(pta00, pta02);
+          dot = notC ? 0 : Math.abs(ax1.dot(vs) / vs.length() / ax1.length());
+          shiftB = (dot < 0.001f);
+          if (shiftB) {
+            vs.scale(0.5f);
+            uc.toCartesian(vs, true);
+            if (shiftC) {
+              vShift.add(vs);
+            } else {
+              vShift = vs;
+            }
+          }
+        }
+        if (shiftA) {
+          V3 vs = V3.newVsub(pta00, pta01);
+          dot = notC ? 0 : Math.abs(ax1.dot(vs) / vs.length() / ax1.length());
+          shiftA = (dot < 0.001f);
+          if (shiftA) {
+            vs.scale(0.5f);
+            uc.toCartesian(vs, true);
+            if (shiftB || shiftC) {
+              vShift.add(vs);
+            } else {
+              vShift = vs;
+            }
+          }
+        }
         break;
       default:
         haveInversion = false;
@@ -872,14 +941,18 @@ public class SymmetryDesc {
 
     boolean ignore = false;
     String cmds = null;
-    if (id != null && bsInfo.get(RET_DRAW)) {
+    while (true) {
+      if (id == null || !bsInfo.get(RET_DRAW))
+        break;
+
       if (op.getOpType() == SymmetryOperation.TYPE_IDENTITY
           || isSpaceGroupAll && op.isIrrelevant) {
         if (Logger.debugging)
           System.out
             .println("!!SD irrelevent " + op.getOpTitle() + op.getOpPoint());
         cmds = "";
-      } else {
+        break;
+      }
         String opType = null;
         drawID = "\ndraw ID \"" + id;
 
@@ -907,11 +980,23 @@ public class SymmetryDesc {
 
         boolean isSpecial = (pta00.distance(pt0) < 0.2d);
 
-        String title = (isSpaceGroup ? "<hover>" + id + ": " + op.xyz + "|" + info1 + "</hover>" : null);
+      String title = (isSpaceGroup
+          ? "<hover>" + id + ": " + op.xyz + "|" + info1 + "</hover>"
+          : null);
+
+      // now check for:
+      //
+      // 1) rotation or mirror plane
+      // 2) inversion
+      // 3) translation
 
         if (isRotation) {
 
-          color = (nrot == 2 ? COLOR_2 : nrot == 3 ? COLOR_BAR_3 : nrot == 4 ? COLOR_BAR_4 : COLOR_BAR_6);
+        if (notC) {
+          
+        }
+        color = (nrot == 2 ? COLOR_2
+            : nrot == 3 ? COLOR_BAR_3 : nrot == 4 ? COLOR_BAR_4 : COLOR_BAR_6);
 
           ang = ang1;
           float scale = 1f;
@@ -1073,7 +1158,8 @@ public class SymmetryDesc {
             // simple rotation
             ptemp.scaleAdd2(0.5f, vtemp, pa1);
             pa1.scaleAdd2(isSpaceGroup ? -0.5f : -0.45f, vtemp, pa1);
-            if (isSpaceGroupAll && (p2 = op.getOpPoint2()) != null) {
+            if (isSpaceGroupAll && isPeriodic 
+                && (p2 = op.getOpPoint2()) != null) {
               // second vector on other side of the cell
               ptr.setT(p2);
               uc.toCartesian(ptr, false);
@@ -1116,6 +1202,7 @@ public class SymmetryDesc {
           if (!ignore) {
             
             if (screwDir != 0) {
+              // get the polygon wings right (isSpaceGroupAll only)
               switch (order) {
               case 2:
                 // ignoring
@@ -1139,12 +1226,12 @@ public class SymmetryDesc {
             String name = opType + "_"+ nrot + "rotvector1";
             drawOrderVector(drawSB, name, "vector", THICK_LINE + wp, pa1,
                 nrot, screwDir, haveInversion && isSpaceGroupAll, isccw == Boolean.TRUE, 
-                vtemp, isTimeReversed ? "gray" : color, title);
+                vtemp, isTimeReversed ? "gray" : color, title, isSpaceGroupAll);
             if (p2 != null) {
               // second standard rotation arrow on other side of unit cell only
               drawOrderVector(drawSB, name + "2", "vector", THICK_LINE + wp,
                   ptr, order, screwDir, haveInversion, isccw == Boolean.TRUE, vtemp, 
-                  isTimeReversed ? "gray" : color, title);
+                  isTimeReversed ? "gray" : color, title, isSpaceGroupAll);
             }
           }
 
@@ -1202,7 +1289,12 @@ public class SymmetryDesc {
           // guaranteed to get cutoffs.
 
           // returns triangles and lines
-          P3[] points = uc.getCanonicalCopy(margin, true);
+        P3[] points = uc.getCanonicalCopy(margin, true);
+        if (isSpaceGroup && (shiftA || shiftB || shiftC)) {
+          for (int i = 8; --i >= 0;) {
+            points[i].add(vShift);
+          }
+        }
           Lst<Object> v = modelSet.vwr.getTriangulator().intersectPlane(plane,
               points, 3);
           if (v != null) {
@@ -1250,7 +1342,7 @@ public class SymmetryDesc {
             }
           }
 
-        }
+      } // isMirrorPlane or isRotation
 
         if (haveInversion) {
           opType = "inv";
@@ -1296,11 +1388,12 @@ public class SymmetryDesc {
               }
             }
           }
-        }
+      } // haveInversion
 
         // and display translation if still not {0 0 0}
 
         if (trans != null) {
+        // centering and glides
           if (isMirrorPlane && isSpaceGroup) {
             if (planeCenter != null) {
               ptref = planeCenter;
@@ -1312,21 +1405,27 @@ public class SymmetryDesc {
           }
           if (ptref != null && !ignore) {
             boolean isCentered = (glideType == '\0');
-            color = (isTimeReversed && !haveInversion && !isMirrorPlane
+            boolean isGlide = (isSpaceGroup && !isCentered && !isTranslationOnly);
+            if (isGlide) {
+              ptemp.scaleAdd2(0.5f, trans, ptref);
+              vtrans.setT(trans);
+              vtrans.scale(0.5f);
+            } else {
+              ptemp.setT(ptref);
+              vtrans.setT(trans);
+            }
+            color = (isGlide ? "green" : isTimeReversed && !haveInversion && !isMirrorPlane
                       && !isRotation ? "darkGray" : "gold");
             drawVector(drawSB,  (isCentered ? "centering_" : glideType + "_g") + "trans_vector", "vector",
-                (isTranslationOnly ? THICK_LINE : THIN_LINE), ptref, trans, color, title);
-            if (isSpaceGroup && !isCentered && !isTranslationOnly) {
+                (isGlide || isTranslationOnly ? THICK_LINE : THIN_LINE), ptemp, vtrans, color, title);
+            if (isGlide) {
               // draw reverse arrow as well
-              ptemp.setT(ptref);
-              ptemp.add(trans);
-              ptemp2.setT(trans);
-              ptemp2.scale(-1);
+              vtrans.scale(-1);
               drawVector(drawSB,  glideType + "_g" + "trans_vector2", "vector",
-                  THIN_LINE, ptemp, ptemp2, color, title);
+                  THICK_LINE, ptemp, vtrans, color, title);
             }
           }
-        }
+      } // trans != null
 
         if (!isSpaceGroup) {
           // draw the final frame just a bit fatter and shorter, in case they
@@ -1370,13 +1469,12 @@ public class SymmetryDesc {
                 .append(Escape.eP(vt3)).append("*0.9} color purple");
           }
           drawSB.append("\n}\n");
-
-        }
-        cmds = drawSB.toString();
-        if (Logger.debugging)
-          Logger.info(cmds);
-        drawSB = null;
-      }
+      } // end !isSpaceGroup
+      cmds = drawSB.toString();
+      if (Logger.debugging)
+        Logger.info(cmds);
+      drawSB = null;
+      break;
     }
 
     // finalize returns
@@ -1467,7 +1565,6 @@ public class SymmetryDesc {
         ret[i] = (plane == null ? approx0(ax1) : null);
         break;
       case RET_ROTANGLE:
-
         ret[i] = (ang1 != 0 ? Integer.valueOf(ang1) : null);
         break;
       case RET_MATRIX:
@@ -1592,7 +1689,7 @@ public class SymmetryDesc {
   private void drawOrderVector(SB sb, String label, String type, String d,
                                P3 pt, int order, int screwDir,
                                boolean haveInversion, boolean isCCW, V3 vtemp,
-                               String color, String title) {
+                               String color, String title, boolean isSpaceGroupAll) {
     drawVector(sb, label, type, d, pt, vtemp, color, title);
     if (order == 2 || haveInversion && !isCCW)
       return;
@@ -1602,7 +1699,7 @@ public class SymmetryDesc {
     for (int i = 0, n = l.size(); i < n; i++)
       sb.appendO(l.get(i));
     sb.append(" color ").append(color);
-    if (screwDir != 0) {
+    if (screwDir != 0 && isSpaceGroupAll) {
       // add screw axis "windmill"
       poly = getPolygon(order, screwDir, haveInversion, pt, vtemp);
       sb.append(getDrawID(label + "_key2"));
@@ -1763,7 +1860,7 @@ public class SymmetryDesc {
     BS bsInfo = getInfoBS(returnType);
 
     boolean isSpaceGroupAll = (nth == -2);
-    int iop = op;
+    int iop = op, iop0 = op;
     P3 offset = (options == T.offset && (type == T.atoms || type == T.point)
         ? pt2
         : null);
@@ -1810,7 +1907,7 @@ public class SymmetryDesc {
       }
       if (xyzOriginal != null)
         opTemp.xyzOriginal = xyzOriginal;
-      opTemp.number = op;
+      opTemp.number = (op == 0 ? iop0 : op);
       if (!isBio)
         opTemp.getCentering();
       if (pt == null && iatom >= 0)
@@ -2139,6 +2236,7 @@ public class SymmetryDesc {
         // show symop or symop(a,b)
 
         // full check
+        System.out.println(cellInfo.getSpaceGroupClegId());
         sgName = cellInfo.getSpaceGroupName();
 
       }
@@ -2247,12 +2345,6 @@ public class SymmetryDesc {
 
   public M4 getTransform(UnitCell uc, SymmetryOperation[] ops, P3 fracA,
                           P3 fracB, boolean best) {
-    if (pta01 == null) {
-      pta01 = new P3();
-      pta02 = new P3();
-      ptemp = new P3();
-      vtrans = new V3();
-    }
     pta02.setT(fracB);
     vtrans.setT(pta02);
     uc.unitize(pta02);
