@@ -49,7 +49,7 @@ class SymmetryInfo {
   /**
    * actually just the Jmol id, such as 3:abc
    */
-  String intlTableJmolID;
+  String intlTableJmolId;
   private int spaceGroupIndex;
 
   private String spaceGroupF2CTitle;
@@ -60,7 +60,7 @@ class SymmetryInfo {
    * 
    */
   protected String strSUPERCELL;
-  String intlTableIndex;
+  String intlTableIndexNdotM;
   String intlTableTransform;
   
   SymmetryInfo() {
@@ -70,7 +70,7 @@ class SymmetryInfo {
     // from Symmetry.getSymmetryInfoStr
     cellRange = null;
     sgName = sg.getName();
-    intlTableJmolID = sg.jmolId;
+    intlTableJmolId = sg.jmolId;
     intlTableNo = sg.itaNumber;
     latticeType = sg.latticeType;
     symmetryOperations = sg.finalOperations;
@@ -98,19 +98,19 @@ class SymmetryInfo {
       cellRange = (int[]) modelInfo.remove(JC.INFO_UNIT_CELL_RANGE);
       sgName = (String) modelInfo.get(JC.INFO_SPACE_GROUP);
       spaceGroupF2C = (float[][]) modelInfo.remove("f2c");
-      spaceGroupF2CTitle = (String) modelInfo.remove("f2cTitle");
+      spaceGroupF2CTitle = (String) modelInfo.remove(JC.INFO_SPACE_GROUP_F2C_TITLE);
       spaceGroupF2CParams = (float[]) modelInfo.remove("f2cParams");
       sgTitle = (String) modelInfo.remove(JC.INFO_SPACE_GROUP_TITLE);
       strSUPERCELL = (String) modelInfo.remove("supercell"); 
       if (sgName == null || sgName == "")
         sgName = "spacegroup unspecified";
       intlTableNo = (String) modelInfo.get("intlTableNo");
-      intlTableIndex = (String) modelInfo.get("intlTableIndex");
+      intlTableIndexNdotM = (String) modelInfo.get("intlTableIndex");
       intlTableTransform = (String) modelInfo.get("intlTableTransform");
-      intlTableJmolID = (String) modelInfo.remove("intlTableJmolID");
+      intlTableJmolId = (String) modelInfo.remove("intlTableJmolId");
       String s = (String) modelInfo.get("latticeType");
         latticeType = (s == null ? 'P' : s.charAt(0));
-      symmetryOperations = (SymmetryOperation[]) modelInfo.remove("symmetryOps");
+      symmetryOperations = (SymmetryOperation[]) modelInfo.remove(JC.INFO_SYMOPS_TEMP);
       coordinatesAreFractional = modelInfo.containsKey("coordinatesAreFractional")
           ? ((Boolean) modelInfo.get("coordinatesAreFractional")).booleanValue()
           : false;
@@ -158,7 +158,7 @@ class SymmetryInfo {
 
   SymmetryOperation[] getAdditionalOperations() {
     if (additionalOperations == null && symmetryOperations != null) {
-      additionalOperations = SymmetryOperation.getAdditionalOperations(symmetryOperations);
+      additionalOperations = SymmetryOperation.getAdditionalOperations(symmetryOperations, 0x7);
     }
     return additionalOperations;
   }
@@ -196,7 +196,7 @@ class SymmetryInfo {
       sgName = PT.rep(sgName, ";0,0,0", "");
       if (sgName.indexOf("#") < 0) {
         String trm = intlTableTransform;
-        String intTab = intlTableIndex;
+        String intTab = intlTableIndexNdotM;
         if (!isSlab && !isPolymer && intTab != null) {
           if (trm != null) {
             int pt = sgName.indexOf(trm);
@@ -210,7 +210,7 @@ class SymmetryInfo {
               intTab += ":" + trm;
             }
           }
-          sgName = (sgName.startsWith("0") ? "" : sgName + " #") + intTab;
+          sgName = (sgName.startsWith("0") ? "" : sgName.equals("unspecified!") ? "#" : sgName + " #") + intTab;
         }
       }
       if (sgName.indexOf(SpaceGroup.NO_NAME) >= 0)
@@ -220,6 +220,19 @@ class SymmetryInfo {
     return displayName;
   }
 
+  private String itaNo; 
+
+  public String getClegId() {
+    if (itaNo == null) {
+      itaNo = intlTableIndexNdotM;
+      if (itaNo.indexOf(":") > 0)
+        return itaNo;
+        int pt = itaNo.indexOf(".");
+      itaNo = (pt > 0 ? itaNo.substring(0, pt) : itaNo) + ":" + intlTableTransform;
+    }
+    return itaNo;
+  }
+
 
 }
 
