@@ -42,7 +42,6 @@ import javajs.util.PT;
 import javajs.util.SB;
 import javajs.util.T3;
 import javajs.util.V3;
-import javajs.util.V3d;
 
 /*
  * Bob Hanson 4/2006
@@ -121,7 +120,7 @@ public class SymmetryOperation extends M4 {
     case TYPE_INVERSION:
       return "Inv" + op48(opPoint);
     case TYPE_REFLECTION:
-      return (opMode == OP_MODE_POSITION_ONLY ? "" : "Plane") + opPlane;
+      return (opMode == OP_MODE_POSITION_ONLY ? "" : "Plane") + opRound(opPlane);
     case TYPE_SCREW_ROTATION:
       return (opMode == OP_MODE_POSITION_ONLY ? "S" + op48(opPoint) + op48(opAxis) : "Screw" + opOrder + op48(opPoint) + op48(opAxis) + op48(opTrans)
           + opIsCCW);
@@ -134,6 +133,14 @@ public class SymmetryOperation extends M4 {
     System.out.println("SymmetryOperation REJECTED TYPE FOR " + this);
     return "";
   }
+  
+  private String opRound(P4 p) {
+    return Math.round(p.x * 1000) 
+        + "," + Math.round(p.y * 1000) 
+        + "," + Math.round(p.z * 1000)
+        + "," + Math.round(p.w * 1000)
+        ;
+  }
 
   String getOpTitle() {
     if (opType == TYPE_UNKNOWN)
@@ -389,10 +396,13 @@ public class SymmetryOperation extends M4 {
       for (int j = 0; j < 3; j++)
         sb.appendI((int) r[j]).append("\t");
       float trans = r[3];
-      trans *= (trans == (int) trans ? 4 : 48);
-      sb.append(twelfthsOf(
-          isCanonical ? normalizeTwelfths(trans / 48, 48, true) : (int) trans))
-          .append("\t]\n");
+      if (trans == 0) {
+        sb.append("0");
+      } else {
+        trans *= (trans == (int) trans ? 4 : 48);
+        sb.append(twelfthsOf(isCanonical ? normalizeTwelfths(trans / 48, 48, true) : (int) trans));
+      }
+      sb.append("\t]\n");
     }
     return sb.toString();
   }
@@ -967,10 +977,13 @@ public class SymmetryOperation extends M4 {
   //  };
   //
   private static String plusMinus(String strT, float x, String sx, boolean allowFractions) {
-    float a;
-    return (x == 0 ? ""
+    float a = Math.abs(x);
+    return (a < 0.0001 ? ""
         : (x < 0 ? "-" : strT.length() == 0 ? "" : "+")
-            + (x == 1 || x == -1 ? "" : (a = Math.abs(x)) < 1 && allowFractions ? twelfthsOf(a * 12) : "" + (int) a)) + sx;
+            + (a > 0.9999 ? ""
+                : a < 1 && allowFractions ? twelfthsOf(a * 12)
+                    : "" + (int) a))
+        + sx;
   }
 
   private static float normalizeTwelfths(float iValue, int divisor,
@@ -1586,7 +1599,6 @@ public class SymmetryOperation extends M4 {
         if (opTrans.z == 0 && opTrans.lengthSquared() == 1.25f) {
           // SG 177   -x+y+2,y+1,-z+2
           dmax = 1.25f;
-//          System.out.println("SO opLong " + opTrans + " " + getXYZFromMatrix(this, false, false, false));
           opIsLong = true;
       }
       }
@@ -1696,9 +1708,7 @@ public class SymmetryOperation extends M4 {
   private static boolean checkOpPlane(P3 p1, P3 p2, P3 p3, P4 plane, V3 vtemp1, V3 vtemp2) {
     // just check all 8 cell points for directed distance to the plane
     // any mix of + and - and 0 is OK; all + or all - is a fail
-    Measure.getPlaneThroughPoints(p1, p2, p3, vtemp1, vtemp2, plane);
-    //System.out.println( "draw plane " + p1 + p2 + p3 + "//" + v + vtemp1 + vtemp2);
-    
+    Measure.getPlaneThroughPoints(p1, p2, p3, vtemp1, vtemp2, plane);    
     P3[] pts = BoxInfo.unitCubePoints;
     int nPos = 0;
     int nNeg = 0;
@@ -1722,8 +1732,7 @@ public class SymmetryOperation extends M4 {
     return !(nNeg == 8 || nPos == 8);
   }
   
-
-  public static SymmetryOperation[] getAdditionalOperations(SymmetryOperation[] ops) {
+  public static SymmetryOperation[] getAdditionalOperations(SymmetryOperation[] ops, int periodicity) {
     int n = ops.length;
     Lst<SymmetryOperation> lst = new Lst<SymmetryOperation>();
     SB xyzLst = new SB();
@@ -1741,7 +1750,7 @@ public class SymmetryOperation extends M4 {
         addCoincidentMap(mapPlanes, op, TYPE_SCREW_ROTATION, null);
     }
     for (int i = 1; i < n; i++) { // skip x,y,z
-      ops[i].addOps(xyzLst, lst, mapPlanes, n, i, vTemp);
+      ops[i].addOps(xyzLst, lst, mapPlanes, n, i, vTemp, periodicity);
     }
     return lst.toArray(new SymmetryOperation[lst.size()]);
   }
@@ -1755,9 +1764,11 @@ public class SymmetryOperation extends M4 {
    * @param mapCoincident
    * @param n0
    * @param isym 
+   * @param vTemp 
+   * @param periodicity 
    */
   void addOps(SB xyzList, Lst<SymmetryOperation> lst,
-              Map<String, Lst<SymmetryOperation>> mapCoincident, int n0, int isym, V3 vTemp) {
+              Map<String, Lst<SymmetryOperation>> mapCoincident, int n0, int isym, V3 vTemp, int periodicity) {
     V3 t0 = new V3();
     getTranslation(t0);
     boolean isPlane = ((getOpType() & TYPE_REFLECTION) == TYPE_REFLECTION);
@@ -1765,10 +1776,35 @@ public class SymmetryOperation extends M4 {
     V3 t = new V3();
 
     SymmetryOperation opTemp = null;
-    // from -2 to 2, starting with + so that we get the + version
-    for (int i = 3; --i >= -3;) {
-      for (int j = 3; --j >= -3;) {
-        for (int k = 3; --k >= -3;) {
+    // originally from -2 to 2, starting with + so that we get the + version
+    // but for "225:1/2b+1/2c,1/2a+1/2c,1/2a+1/2b" we need higher.
+    // and needed =2 to 4 to catch all the elements
+    
+    // periodicity here affects how the arrays run.
+    int i0 = 5, i1 = -2, j0 = 5, j1 = -2, k0 = 5, k1 = -2;
+    switch (periodicity) {
+    case 0x7: // abc space
+      break;
+    case 0x3: // ab plane, layer
+      k0 = 1;
+      k1 = 0;
+      break;
+    case 0x4: // c rod
+      i0 = 1;
+      i1 = 0;
+      j0 = 1;
+      j1 = 0;
+      break;
+    case 0x1: // a frieze
+      j0 = 1;
+      j1 = 0;
+      k0 = 1;
+      k1 = 0;
+      break;
+    }
+    for (int i = i0; --i >= i1;) {
+      for (int j = j0; --j >= j1;) {
+        for (int k = k0; --k >= k1;) {
           if (opTemp == null)
             opTemp = new SymmetryOperation(null, 0, false);
           t.set(i, j, k);
@@ -1891,6 +1927,7 @@ public class SymmetryOperation extends M4 {
    * Rotations: anything parallel to the normal is discarded.
    *  
    * @param t
+   * @param vTemp temp vector
    * @return true if 
    */
   private boolean checkOpSimilar(V3 t, V3 vTemp) {
@@ -2026,7 +2063,7 @@ public class SymmetryOperation extends M4 {
 //        // #230 
 //        // making sure here that this is truly a diagonal in the plane, not just
 //        // a glide parallel to a face on a diagonal plane! Mois Aroyo 2018
-        if (approx(n.x + n.y + n.z) == 1)
+        if (Math.abs(approx(n.x + n.y + n.z)) == 1)
           return 'n';
         }
         // 'g'
@@ -2192,27 +2229,15 @@ public class SymmetryOperation extends M4 {
       op.add(targetCentering);
     if (normalize) {
       t.getColumn(3, v);
+      // note that this returns only positive values, aa does the iTA
       for (int i = 0; i < 3; i++) {
-        v[i] = v[i] % 1;
+        v[i] = (10+v[i]) % 1;
       }
       t.setColumnA(3, v);
     }
     return getXYZFromMatrixFrac(t, false, true, false, allowFractions);
   }
   
-  static String transformXyzT(String xyz, String transform) {
-    return (transformStr(xyz, UnitCell.toTrm(transform, null), null, null, null, null, null, true, false));
-  }
-  
-//  static {
-//
-//    System.out.println(transformXyzT("-x+1/2, y+1/2, -z+1/2", "a+b,-a+b,c"));
-//    System.out.println(transformXyzT("x+1/2, -y+1/2, -z+1/2", "a+b,-a+b,c"));
-//    System.out.println(transformXyzT("  y+1/2, x+1/2, -z+1/2", "a+b,-a+b,c"));
-//    System.out.println(transformXyzT("y, -x, z", "a+b,-a+b,c"));
-//    
-//  }
-
   static M4 stringToMatrix(String xyz) {
     int divisor = setDivisor(xyz);
     float[] a = new float[16];
