@@ -1,20 +1,16 @@
 package org.jmol.symmetry;
 
-import java.io.BufferedReader;
 import java.util.Hashtable;
 import java.util.Map;
 
-import org.jmol.viewer.FileManager;
 import org.jmol.viewer.Viewer;
 
-import javajs.util.JSJSONParser;
 import javajs.util.Lst;
 import javajs.util.M4;
 import javajs.util.Measure;
 import javajs.util.P3;
 import javajs.util.P4;
 import javajs.util.PT;
-import javajs.util.Rdr;
 import javajs.util.SB;
 import javajs.util.V3;
 
@@ -43,6 +39,7 @@ public class WyckoffFinder {
   public final static int WYCKOFF_RET_LABEL = -1;
   public final static int WYCKOFF_RET_COORD = -2;
   public final static int WYCKOFF_RET_COORDS = -3;
+  public final static int WYCKOFF_RET_ALL_ARRAY = -4;
   public final static int WYCKOFF_RET_COORDS_ALL = '*';
   public final static int WYCKOFF_RET_GENERAL = 'G';
   public final static int WYCKOFF_RET_CENTERING = 'C';
@@ -72,14 +69,18 @@ public class WyckoffFinder {
    * @return helper
    */
   WyckoffFinder getWyckoffFinder(Viewer vwr, SpaceGroup sg) {
-    WyckoffFinder helper = helpers.get(sg.clegId);
-    if (helper == null) {
-      helper = createHelper(this, vwr, sg.clegId);
-    }
+    String cleg = sg.getClegId();
+    String key = sg.specialPrefix + cleg;
+    WyckoffFinder helper = helpers.get(key);
+    if (helper != null) 
+      return helper;
+    helper = createHelper(vwr, cleg, sg.groupType);
     if (helper == null) {
       if (nullHelper == null)
         nullHelper = new WyckoffFinder(null);
-      helpers.put(sg.clegId, nullHelper);
+      helpers.put(key, nullHelper);
+    } else {
+      helpers.put(key, helper);
     }
     return helper;
   }
@@ -119,11 +120,12 @@ public class WyckoffFinder {
    * @param returnType
    *        label, coord, label*, or
    * @param withMult
+   * @param is2d 
    * @return label or coordinate or label with centerings and coordinates or
    *         full list for space group
    */
-  Object getInfo(UnitCell uc, P3 p, int returnType, boolean withMult) {
-    Object info = createInfo(uc, p, returnType, withMult);
+  Object getInfo(UnitCell uc, P3 p, int returnType, boolean withMult, boolean is2d) {
+    Object info = createInfo(uc, p, returnType, withMult, is2d);
     return (info == null ? "?" : info);
   }
 
@@ -138,6 +140,10 @@ public class WyckoffFinder {
     return sb.appendC('(').append(xyz).appendC(')');
   }
 
+  private final static String elementList = "AlB C D FeF "
+      + "GaHeI GeK LiMgN Os"
+      + "P CaRhS T U V W XeYbZnAm";
+
   /**
    * Generate information for the symop("wyckoff") script function
    * 
@@ -148,11 +154,12 @@ public class WyckoffFinder {
    *        'C' for centerings
    * @param withMult
    *        from "wyckoffm"
+   * @param is2d 
    * @return an informational string
    */
   @SuppressWarnings("unchecked")
   private Object createInfo(UnitCell uc, P3 p, int returnType,
-                            boolean withMult) {
+                            boolean withMult, boolean is2d) {
     switch (returnType) {
     case WYCKOFF_RET_CENTERING_STRING:
       return getCenteringStr(-1, ' ', null).toString().trim();
@@ -173,6 +180,14 @@ public class WyckoffFinder {
             (i == 0 ? ncent : 0));
       }
       return sb.toString();
+    case WYCKOFF_RET_ALL_ARRAY:
+      P3[] pts = new P3[npos];
+      for (int i = 0; i < npos; i++) {
+          Map<String, Object> map = (Map<String, Object>) positions.get(i);
+          pts[i] = findPositionFor(P3.newP(p), (String) map.get("label"));
+          uc.toCartesian(pts[i], false);
+      }
+      return new Object[] { pts, elementList };
     case WYCKOFF_RET_LABEL:
     case WYCKOFF_RET_COORD:
     case WYCKOFF_RET_COORDS:
@@ -246,35 +261,34 @@ public class WyckoffFinder {
   }
 
   @SuppressWarnings("unchecked")
-  private static WyckoffFinder createHelper(Object w, Viewer vwr,
-                                            String clegId) {
+  private static WyckoffFinder createHelper(Viewer vwr, String clegId,
+                                            int groupType) {
+    String key = SpaceGroup.getGroupTypePrefix(groupType) + clegId;
     String sgname = clegId;
     int pt = sgname.indexOf(":");
-    int itno = PT.parseInt(pt < 0 ? sgname : sgname.substring(0, pt));    
-    if (itno >= 1 && itno <= 230) {
-      Map<String, Object> resource = getResource(w, vwr,
-          "ita_" + itno + ".json");
-      if (resource != null) {
-        Lst<Object> its = (Lst<Object>) resource.get("its");
-        Map<String, Object> map = null;
-        boolean haveMap = false;
-        for (int i = 0, c = its.size(); i < c; i++) {
-          map = (Map<String, Object>) its.get(i);
-          if (sgname.equals(map.get("clegId"))) {
-            haveMap = true;
-            break;
-          }
-        }
-        // "more" type, from wp-list, does note contain gp or wpos
-        if (!haveMap || map.containsKey("more"))
-          map = SpaceGroup.fillMoreData(map, clegId, itno, (Map<String, Object>) its.get(0));
-        WyckoffFinder helper = new WyckoffFinder(map);
-        helpers.put(sgname, helper);
-        return helper;
-
+    int itno = PT.parseInt(pt < 0 ? sgname : sgname.substring(0, pt));
+    if (!SpaceGroup.isInRange(itno, groupType, false, false))
+      return null;
+    Map<String, Object> resource = Symmetry.getITResource(vwr, groupType, itno, null);
+    if (resource == null)
+      return null;
+    Lst<Object> its = (Lst<Object>) resource.get("its");
+    Map<String, Object> map = null;
+    boolean haveMap = false;
+    for (int i = 0, c = its.size(); i < c; i++) {
+      map = (Map<String, Object>) its.get(i);
+      if (key.equals(map.get("clegId"))) {
+        haveMap = true;
+        break;
       }
     }
-    return null;
+    
+    // "more" type, from wp-list, does not contain gp or wpos
+    if (!haveMap || map.containsKey("more"))
+      map = SpaceGroup.fillMoreData(vwr, haveMap ? map : null, clegId, itno,
+          (Map<String, Object>) its.get(0));
+    WyckoffFinder helper = new WyckoffFinder(map);
+    return helper;
   }
 
   /**
@@ -285,7 +299,10 @@ public class WyckoffFinder {
   @SuppressWarnings("unchecked")
   private WyckoffFinder(Map<String, Object> map) {
     if (map != null) {
-      gpos = (Lst<Object>) map.get("gp");
+      // These will be turned into WyckoffCoord as needed
+      Lst<Object> gp = (Lst<Object>) map.get("gp");
+      gpos = new Lst<Object>();
+      gpos.addAll(gp);
       Map<String, Object> wpos = (Map<String, Object>) map.get("wpos");
       positions = (Lst<Object>) wpos.get("pos");
       npos = positions.size();
@@ -349,22 +366,6 @@ public class WyckoffFinder {
     return (WyckoffCoord) coord;
   }
 
-  @SuppressWarnings("unchecked")
-  private static Map<String, Object> getResource(Object w, Viewer vwr,
-                                                 String resource) {
-    try {
-      BufferedReader r = FileManager.getBufferedReaderForResource(vwr, w,
-          "org/jmol/symmetry/", "sg/json/" + resource);
-      String[] data = new String[1];
-      if (Rdr.readAllAsString(r, Integer.MAX_VALUE, false, data, 0)) {
-        return (Map<String, Object>) new JSJSONParser().parse(data[0], true);
-      }
-    } catch (Throwable e) {
-      System.err.println(e.getMessage());
-    }
-    return null;
-  }
-
   /**
    * The WyckoffCoord class.
    * 
@@ -560,6 +561,10 @@ public class WyckoffFinder {
      * @return true if found
      */
     private boolean checkLatticePt(P3 p, float slop) {
+      // problem here was with #178 
+      // where O1 #1 0.183 4.823 0.915 (0.363 0.682 0.083)
+      // needs to match 2x,x,1/12, since 
+      // 2*0.682 == 1.364
       if (checkPoint(p, slop))
         return true;
       for (int z = 125 / 2, i = -2; i < 3; i++) {
@@ -634,7 +639,7 @@ public class WyckoffFinder {
         type = TYPE_LINE;
         p1.set(0.19f, 0.53f, 0.71f);
         op.rotTrans(p1);
-        p2.set(0.51f, 0.27f, 0.6f);
+        p2.set(0.51f, 0.27f, 0.64f);
         op.rotTrans(p2);
         p2.sub2(p2, p1);
         p2.normalize();
