@@ -88,12 +88,17 @@ abstract public class JmolThread extends Thread {
     }
   }
   
+  /**
+   * @j2sOverride
+   */
   @Override
   public synchronized void start() {
-    if (isJS) {
-      //Logger.info("starting " + name);
-      run();
-    } else {
+    /**
+     * @j2sNative
+     * 
+     * this.run();
+     */
+    {
       super.start();
     }
   }
