@@ -43,7 +43,9 @@ public class SpinThread extends JmolThread {
    */
   private TransformManager transformManager;
   private float endDegrees;
+  private int nFrames;
   private Lst<P3> endPositions;
+  private P3[][] centerAndPoints;
   private float[] dihedralList;
   private float nDegrees;
   private BS bsAtoms;
@@ -57,6 +59,8 @@ public class SpinThread extends JmolThread {
   private BS[] bsBranches;
   private boolean isDone = false;
   private M4 m4;
+  private P3 ptemp;
+
   
   /**
    * @j2sIgnore
@@ -83,13 +87,18 @@ public class SpinThread extends JmolThread {
     if (options == null) {
       isNav = true;
     } else {
-      endDegrees = ((Float) options[0]).floatValue();
+      endDegrees = ((Number) options[0]).floatValue();
       endPositions = (Lst<P3>) options[1];
       dihedralList = (float[]) options[2];
       if (dihedralList != null)
         bsBranches = vwr.ms.getBsBranches(dihedralList);
       bsAtoms = (BS) options[3];
       isGesture = (options[4] != null);
+      centerAndPoints = (P3[][]) options[5];
+      if (centerAndPoints != null) {
+        ptemp = new P3();
+        nFrames = ((Integer) options[6]).intValue();
+      }
     }
     return 0;
   }
@@ -182,9 +191,10 @@ public class SpinThread extends JmolThread {
             vwr.requestRepaintAndWait("spin thread");
         else
           vwr.refresh(Viewer.REFRESH_REPAINT, "SpinThread");
-        if (endDegrees >= 1e10f ? nDegrees/endDegrees > 0.99 
+        if (nFrames >= 0 && index >= nFrames 
+            || (endDegrees >= 1e10f ? nDegrees/endDegrees > 0.99f 
             : !isNav && endDegrees >= 0 ? nDegrees >= endDegrees - 0.001
-            : -nDegrees <= endDegrees + 0.001) {
+            : -nDegrees <= endDegrees + 0.001f)) {
           isDone = true;
           transformManager.setSpinOff();
         }
@@ -214,7 +224,10 @@ public class SpinThread extends JmolThread {
   }
 
   private void doTransform() {
-    if (dihedralList != null) {
+    if (centerAndPoints != null) {
+      float f = index * 1f / nFrames;
+      vwr.ms.morphAtoms(bsAtoms, centerAndPoints, 0, f, ptemp);
+    } else if (dihedralList != null) {
       float f = 1f / myFps / endDegrees;
       vwr.setDihedrals(dihedralList, bsBranches, f);
       nDegrees += 1f / myFps;
