@@ -26,7 +26,12 @@
 package org.jmol.util;
 
 
+import java.util.Hashtable;
+import java.util.Map;
+
+import javajs.util.Measure;
 import javajs.util.P3;
+import javajs.util.P4;
 import javajs.util.T3;
 import javajs.util.V3;
 
@@ -121,6 +126,23 @@ public class BoxInfo {
   //               1 ---------4-------- 5                 
   //              Z                                       
   
+  public final static int[] faceOrder = new int[] { 0, 3, 5, 2, 1, 4 };
+  public final static int[][] facePoints = new int[][] {
+    {4, 0, 6}, // xy0
+    {4, 6, 5}, // yz1
+    {5, 7, 1}, // xy1
+    {1, 3, 0}, // yz0
+    {6, 2, 7}, // xz1
+    {1, 0, 5}, // xz0
+    
+    {0, 2, 6},
+    {6, 7, 5}, 
+    {7, 3, 1}, 
+    {3, 2, 0},
+    {2, 3, 7}, 
+    {0, 4, 5}, 
+  };
+  
   public final static P3[] unitCubePoints = { 
     P3.new3(0, 0, 0), // 0
     P3.new3(0, 0, 1), // 1
@@ -151,21 +173,6 @@ public class BoxInfo {
     return vertices;
   }
 
-  public final static int[][] facePoints = new int[][] {
-    {4, 0, 6},
-    {4, 6, 5}, 
-    {5, 7, 1}, 
-    {1, 3, 0},
-    {6, 2, 7}, 
-    {1, 0, 5}, 
-    {0, 2, 6},
-    {6, 7, 5}, 
-    {7, 3, 1}, 
-    {3, 2, 0},
-    {2, 3, 7}, 
-    {0, 4, 5}, 
-  };
-
   // canonical
   //  -- relatively standard clockwise lower, then clockwise upper
   //  -- used by Triangulator and MarchingCubes
@@ -394,11 +401,56 @@ public class BoxInfo {
     return bbVector.length() * 2;
   }
 
+  /**
+   * for {*}.boundbox("info"|"volume"|"center"|null)
+   * 
+   * @param what
+   * @return Double or Map or null
+   */
+  public Object getInfo(String what) {
+    Double vol = Double
+        .valueOf(Math.abs(8 * bbVector.x * bbVector.y * bbVector.z));
+    if ("volume".equals(what)) {
+      return vol;
+    }
+    P3 c = P3.newP(bbCenter);
+    if ("center".equals(what)) {
+      return c;
+    }
+    if (what == null || "info".equals(what)) {
+      Map<String, Object> m = new Hashtable<String, Object>();
+      m.put("center", c);
+      V3 v = V3.newVsub(bbCorner1, bbCorner0);
+      m.put("dimensions", v);
+      m.put("girth", Double.valueOf(v.x + v.y + v.z));
+      m.put("area", Double.valueOf(2 * (v.x * v.y + v.x * v.z + v.z * v.y)));
+      m.put("volume", vol);
+      return m;
+    }
+    return null;
+  }
 
   @Override
   public String toString() {
     return "" + bbCorner0 + bbCorner1;
   }
 
+  public static P4[] getBoxFacesFromOABC(P3[] oabc) {
+    P4[] faces = new P4[6];
+    V3 vNorm = new V3();
+    V3 vAB = new V3();
+    P3 pta = new P3();
+    P3 ptb = new P3();
+    P3 ptc = new P3();
+    P3[] vertices = (oabc == null ? unitCubePoints : getVerticesFromOABC(oabc));
+    for (int i = 0; i < 6; i++) {
+      pta.setT(vertices[facePoints[i][0]]);
+      ptb.setT(vertices[facePoints[i][1]]);
+      ptc.setT(vertices[facePoints[i][2]]);
+      faces[i] = Measure.getPlaneThroughPoints(pta, ptb, ptc, vNorm, vAB, new P4());
+    }
+    return faces;
+  }
+
 
 }
