@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2024-03-15 17:42:21 -0500 (Fri, 15 Mar 2024) $
- * $Revision: 22610 $
+ * $Date: 2024-08-06 09:08:14 -0400 (Tue, 06 Aug 2024) $
+ * $Revision: 22629 $
  *
  * Copyright (C) 2003-2005  Miguel, Jmol Development, www.jmol.org
  *
@@ -141,6 +141,7 @@ public final class C {
   public final static short CHANGEABLE_MASK = (short) 0x8000; // negative
   public final static int LAST_AVAILABLE_COLIX = UNMASK_CHANGEABLE_TRANSLUCENT;
   public final static int TRANSLUCENT_SHIFT = 11;
+  public static final int TRANSPARENT_LEVEL = 0xFF;
   public final static int ALPHA_SHIFT = 24 - TRANSLUCENT_SHIFT;
   public final static int TRANSLUCENT_MASK = 0xF << TRANSLUCENT_SHIFT; //0x7800
   public final static int TRANSLUCENT_SCREENED = TRANSLUCENT_MASK;
@@ -429,10 +430,14 @@ public final class C {
     case 15:
       return -1;
     default:
-      return 255;
+      return TRANSPARENT_LEVEL; // 255
     }
   }
 
+  public static boolean isTransparent(short colix) {
+    return (colix & TRANSLUCENT_MASK) == TRANSPARENT;
+  }
+
   public static short getColixS(String colorName) {
     int argb = CU.getArgbFromString(colorName);
     if (argb != 0)
