@@ -137,7 +137,7 @@ public class MeshSlicer {
     case T.boundbox:
       P3[] box = (P3[]) slabbingObject;
       sb.append("within ").append(Escape.eAP(box));
-      P4[] faces = getBoxFacesFromOABC(box);
+      P4[] faces = BoxInfo.getBoxFacesFromOABC(box);
       for (int i = 0; i < faces.length; i++) {
         getIntersection(0, faces[i], null, null, null, null, null, andCap,
             false, T.plane, isGhost);
@@ -200,23 +200,6 @@ public class MeshSlicer {
     return true;
   }
 
-  private P4[] getBoxFacesFromOABC(P3[] oabc) {
-      P4[] faces = new P4[6];
-      V3 vNorm = new V3();
-      V3 vAB = new V3();
-      P3 pta = new P3();
-      P3 ptb = new P3();
-      P3 ptc = new P3();
-      P3[] vertices = BoxInfo.getVerticesFromOABC(oabc);
-      for (int i = 0; i < 6; i++) {
-        pta.setT(vertices[BoxInfo.facePoints[i][0]]);
-        ptb.setT(vertices[BoxInfo.facePoints[i][1]]);
-        ptc.setT(vertices[BoxInfo.facePoints[i][2]]);
-        faces[i] = Measure.getPlaneThroughPoints(pta, ptb, ptc, vNorm, vAB, new P4());
-      }
-      return faces;
-    }
-
   /**
    * @param distance
    *        a distance from a plane or point
