@@ -5,6 +5,7 @@ import java.util.Map;
 
 import org.jmol.api.JmolModulationSet;
 import org.jmol.api.SymmetryInterface;
+import org.jmol.viewer.JC;
 
 import javajs.util.Lst;
 import javajs.util.M3;
@@ -143,11 +144,6 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
    */
   public float vOcc = Float.NaN;
   
-  /**
-   * final occupancy value -- absolute; in range [0,1]
-   */
-  private float occValue = Float.NaN;
-  
   // values set in setModTQ
   
   private P3 qtOffset = new P3();
@@ -358,10 +354,7 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
       vib = v;
       vib.modScale = 1;
       mxyz = new V3(); // modulations of spin
-      axesLengths = symmetry.getUnitCellParams(); // required for calculating mxyz
-      if (axesLengths == null)
-        axesLengths = symmetry.getUnitCellParams(); // required for calculating mxyz
-        
+      axesLengths = symmetry.getUnitCellParams(); // required for calculating mxyz  
     }
     Matrix vR00 = Matrix.newT(r00, true);
     Matrix vR0 = Matrix.newT(r0, true);
@@ -375,7 +368,7 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
 
     if (Logger.debuggingHigh)
       Logger.debug("MODSET create " + id + " r0=" + Escape.eP(r0) + " tau="
-          + tau);
+          + tau.toString().replace('\n', ' '));
 
     return this;
   }
@@ -602,6 +595,8 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
       modCalc.modDim = modDim;
       modCalc.mods = mods;
       modCalc.nOps = nOps;
+      modCalc.isSubsystem = isSubsystem;
+      modCalc.tFactorInv = tFactorInv;
       modCalc.occParams = occParams;
       modCalc.occSiteMultiplicity = occSiteMultiplicity;
       modCalc.r0 = r0;
@@ -648,7 +643,7 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
     if (vib == null)
       return;
     if (vib.modDim == Vibration.TYPE_SPIN) {
-      if (v.x == PT.FLOAT_MIN_SAFE && v.y == PT.FLOAT_MIN_SAFE) {
+      if (v.x == JC.FLOAT_MIN_SAFE && v.y == JC.FLOAT_MIN_SAFE) {
         // written by StateCreator -- for modulated magnetic moments
         // 957 Fe Fe_1_#957 1.4E-45 1.4E-45 0.3734652 ;
         vib.modScale = v.z;
@@ -693,8 +688,9 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
 
   @Override
   public boolean isNonzero() {
-    return x != 0 || y != 0 || z != 0 || mxyz != null
-        && (mxyz.x != 0 || mxyz.y != 0 || mxyz.z != 0);
+    return x != 0 || y != 0 || z != 0 
+        || mxyz != null && (mxyz.x != 0 || mxyz.y != 0 || mxyz.z != 0)
+        || occAbsolute;
   }
 
   /**
@@ -728,6 +724,8 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
         if (!enabled)
           return (int) (-fileOcc * 100);
       }
+    // here we were using occValue, but that caused problems
+    // with variability.
       return (int) (getOccupancy(forVibVis) * 100);
     }
 
@@ -759,7 +757,7 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
         // disabled for double presision
         //occ = (occ > 0.49 && occ < 0.50 ? 0.489 : Math.min(1, Math.max(0, occ)));
       }
-      return occValue = (float) occ;
+      return (float) occ;
   }
 
 
