@@ -63,8 +63,9 @@ public class SimpleUnitCell {
   public static final int PARAM_SLOP = 26;      // slop
   public static final int PARAM_COUNT = 27;
 
-  public final static int INFO_IS_RHOMBOHEDRAL = 8;
-  public final static int INFO_IS_HEXAGONAL = 7;  
+  public final static int INFO_IS_RHOMBOHEDRAL = 9;
+  public final static int INFO_IS_HEXAGONAL = 8;  
+  public final static int INFO_DIMENSION_TYPE = 7;
   public final static int INFO_DIMENSIONS = 6;
   public final static int INFO_GAMMA = 5;
   public final static int INFO_BETA = 4;
@@ -73,6 +74,8 @@ public class SimpleUnitCell {
   public final static int INFO_B = 1;
   public final static int INFO_A = 0;
 
+  public static final int DIMENSION_TYPE_ALL = 0x7;
+
   public static final String HEX_TO_RHOMB = "2/3a+1/3b+1/3c,-1/3a+1/3b+1/3c,-1/3a-2/3b+1/3c";
   public static final String RHOMB_TO_HEX = "a-b,b-c,a+b+c";
 
@@ -110,6 +113,10 @@ public class SimpleUnitCell {
   public double volume;
   
   protected int dimension = 3;
+  /**
+   * 0x07 : z,y,x periodic
+   */
+  public int dimensionType = DIMENSION_TYPE_ALL;
   
   private P3 fractionalOrigin;
   
@@ -169,8 +176,17 @@ public class SimpleUnitCell {
     return c;
   }
   
+  /**
+   * Allows for abc, ab, or a
+   * 
+   * @param params
+   * @return 1, 2, or 3
+   */
   public static int getDimensionFromParams(float[] params) {
-	    return (params[0] <= 0 ? 3 : params[1] < 0 ? 1 : params[2] < 0 ? 2 : 3);
+    return (params[0] <= 0 ? 3 // given elsewhere
+           : params[1] < 0 ? 1 // no b or c
+           : params[2] < 0 ? 2 // no c
+           : 3);
   }
 
 
@@ -183,6 +199,17 @@ public class SimpleUnitCell {
     boolean rotateHex = false; // special gamma = -1 indicates hex rotation for AFLOW
 
     dimension = getDimensionFromParams(params);
+    switch (dimension) {
+    case 1:
+      dimensionType = 1; // a only
+      break;
+    case 2:
+      dimensionType = 3; // a and b
+      break;
+    case 3:
+      dimensionType = 7; // a, b, and c
+      break;
+    }
     a = params[0];
     b = params[1];
     c = params[2];
@@ -521,6 +548,8 @@ public class SimpleUnitCell {
       return gamma;
     case INFO_DIMENSIONS:
       return dimension;
+    case INFO_DIMENSION_TYPE:
+      return dimensionType;
     case INFO_IS_HEXAGONAL:
       return (isHexagonal(unitCellParams) ? 1 : 0);
     case INFO_IS_RHOMBOHEDRAL:
@@ -684,7 +713,7 @@ public class SimpleUnitCell {
 
   private float setTwelfths(float x) {
     int i = twelfthsOf(x);
-    return (i >= 0 ? i / 12f : x);
+    return (i >= 0 ? i / 12f * (x < 0 ? -1 : 1) : x);
   }
 
 
@@ -830,7 +859,7 @@ public class SimpleUnitCell {
    * @param f
    * @return true or false
    */
-  protected static boolean approx0(float f) {
+  public static boolean approx0(float f) {
     return (Math.abs(f) < SLOP_PARAMS);
   }
   
@@ -845,10 +874,66 @@ public class SimpleUnitCell {
 	    return t3w;
 	  }
 
+  public static float parseCalc(Viewer vwr, String[] functions, String s) {
+    String[] parts;
+    float d = PT.parseFloatStrict(s);
+    if (!Double.isNaN(d))
+      return d;
+    s = s.toLowerCase();
+    if (functions != null && s.indexOf('(') >= 0) {
+      parts = PT.split(s, "(");
+      for (int i = parts.length - 1; --i >= 0;) {
+        String p = parts[i];
+        String f = null;
+        for (int j = functions.length; --j >= 0;) {
+          if (p.endsWith(functions[j])) {
+            f = functions[j];
+            break;
+          }
+        }
+        if (f == null) {
+          System.err.println("Unrecognized function " + s);
+          parts[i] += "?";
+        }
+      }
+      s = PT.join(parts, '(', 0);
+    }
+    // make sure all / are decimal 1/2 -> 1./2
+    if (s.indexOf('/') >= 0) {
+      parts = PT.split(s, "/");
+      for (int i = parts.length - 1; --i >= 0;) {
+        String p = parts[i];
+        boolean haveDecimal = false;
+        boolean haveDigit = false;
+        for (int j = p.length(); --j >= 0;) {
+          char c = p.charAt(j);
+          if (c == '.') {
+            haveDecimal = true;
+            break;
+          } else if (c == ')') {
+            if (haveDigit) {
+              return Float.NaN;              
+            }
+            parts[i] += "*1.0";
+            break;
+          }
+          if (!PT.isDigit(c)) {
+            break;
+          }
+          haveDigit = true;
+        }
+        if (haveDigit && !haveDecimal)
+          parts[i] += ".";
+      }
+      s = PT.join(parts, '/', 0);
+    }
+    return vwr.evaluateExpressionAsVariable(s).asFloat();
+  }
+
+  
   @Override
   public String toString() {
     return "[" + a + " " + b + " " + c + " " + alpha + " " + beta + " " + gamma + "]";
   }
 
-  
 }
