@@ -47,7 +47,7 @@ public class Tensor {
 
   // factors that give reasonable first views of ellipsoids.
   
-  private static final float ADP_FACTOR = (float) (Math.sqrt(0.5) / Math.PI);
+  private static final double ADP_FACTOR = Math.sqrt(0.5) / Math.PI;
   private static final float MAGNETIC_SUSCEPTIBILITY_FACTOR = 0.01f;
   private static final float INTERACTION_FACTOR = 0.04f;
   private static final float CHEMICAL_SHIFT_ANISOTROPY_FACTOR = 0.01f;
@@ -622,12 +622,13 @@ public class Tensor {
       break;
     case TYPE_ADP:
       forThermalEllipsoid = true;
-      typeFactor = ADP_FACTOR;
+      typeFactor = (float) ADP_FACTOR;
       altType = "1";
       break;
     case TYPE_CSA:
       sortIso = true;
       typeFactor = CHEMICAL_SHIFT_ANISOTROPY_FACTOR;
+      break;
     case TYPE_MS:
       sortIso = true;
       typeFactor = MAGNETIC_SUSCEPTIBILITY_FACTOR;
