@@ -257,6 +257,7 @@ public class GlobalSettings {
     setB("drawPicking", drawPicking);
     setB("dsspCalculateHydrogenAlways", dsspCalcHydrogen);
     setB("elementkey", elementKey);
+    setB("labelkey", labelKey);
 //    setO("edsUrlFormat", edsUrlFormat);
 //    setO("edsUrlFormatDiff", edsUrlFormatDiff);
 //    //setParameterValue("edsUrlOptions", edsUrlOptions);
@@ -323,6 +324,7 @@ public class GlobalSettings {
     setB("minimizationRefresh", minimizationRefresh);
     setB("minimizationSilent", minimizationSilent);
     setF("minimizationCriterion", minimizationCriterion);
+    setB("mode2d", mode2d);
     setB("modelKitMode", modelKitMode);
     setF("modulationScale", modulationScale);
     setB("monitorEnergy", monitorEnergy);
@@ -540,6 +542,7 @@ public class GlobalSettings {
   int dotDensity = 3;
   int dotScale = 1;
   int meshScale = 1;
+  boolean mode2d = false;
   boolean greyscaleRendering = false;
   boolean isosurfaceKey = false;
   boolean isosurfacePropertySmoothing = true;
@@ -632,6 +635,7 @@ public class GlobalSettings {
   boolean drawPicking = false;
   boolean dsspCalcHydrogen = true;
   boolean elementKey = false;
+  boolean labelKey = false;
   public String energyUnits = "kJ";
   float exportScale = 0f;
   String helpPath = JC.DEFAULT_HELP_PATH;
@@ -1003,7 +1007,7 @@ public class GlobalSettings {
       + ";selecthetero;selecthydrogen"
       // removed in Jmol 14.32.68
       + ";pointgrouplineartolerance;pointgroupdistancetolerance"//;pointgroupmmaxatoms"
-      + ";minimizationreportsteps;elementkey;symmetryhermannmauguin;")
+      + ";minimizationreportsteps;labelkey;elementkey;symmetryhermannmauguin;mode2d;")
       .toLowerCase();
 
   Object getAllVariables() {
