@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2024-05-02 13:36:04 -0500 (Thu, 02 May 2024) $
- * $Revision: 22623 $
+ * $Date: 2024-10-08 18:58:53 -0500 (Tue, 08 Oct 2024) $
+ * $Revision: 22635 $
 
  *
  * Copyright (C) 2003-2005  Miguel, Jmol Development, www.jmol.org
@@ -237,18 +237,18 @@ public final class JC {
       "pdbemap", "https://www.ebi.ac.uk/pdbe/coordinates/files/%file.ccp4",
       "pdbemapdiff",
       "https://www.ebi.ac.uk/pdbe/coordinates/files/%file_diff.ccp4",
-      "pdbemapserver",
-      "https://www.ebi.ac.uk/pdbe/densities/x-ray/%file/box/0,0,0/0,0,0?detail=6&space=cartesian&encoding=bcif",
-      "pdbemapdiffserver",
-      "https://www.ebi.ac.uk/pdbe/densities/x-ray/%file/box/0,0,0/0,0,0?detail=6&space=cartesian&encoding=bcif&diff=1", // last bit is just mine
+      "pdbemapserver", // isosurface eds
+      "https://www.ebi.ac.uk/pdbe/volume-server/x-ray/%file/box/0,0,0/0,0,0?detail=6&space=cartesian&encoding=bcif",
+      "pdbemapdiffserver", // isosurface edsdiff
+      "https://www.ebi.ac.uk/pdbe/volume-server/x-ray/%file/box/0,0,0/0,0,0?detail=6&space=cartesian&encoding=bcif&diff=1", // last bit is just mine
       //"emdbmap", "https://ftp.ebi.ac.uk/pub/databases/emdb/structures/EMD-%file/map/emd_%file.map.gz", // https did not work in Java due to certificate issues
       // was considerably slower
       "emdbmap",
-      "https://www.ebi.ac.uk/pdbe/densities/emd/emd-%file/cell?detail=6&space=cartesian&encoding=bcif",
+      "https://www.ebi.ac.uk/pdbe/volume-server/emd/emd-%file/cell?detail=6&space=cartesian&encoding=bcif",
       "emdbquery",
       "https://www.ebi.ac.uk/emdb/api/search/fitted_pdbs:%file?fl=emdb_id,map_contour_level_value&wt=csv", // to get the EMDB id from the PDB id
       "emdbmapserver",
-      "https://www.ebi.ac.uk/pdbe/densities/emd/emd-%file/box/0,0,0/0,0,0?detail=6&space=cartesian&encoding=bcif",
+      "https://www.ebi.ac.uk/pdbe/volume-server/emd/emd-%file/box/0,0,0/0,0,0?detail=6&space=cartesian&encoding=bcif",
       "xxxresolverResolver", "https://chemapps.stolaf.edu/resolver", "smiles2d",
       "https://cirx.chemicalcreatures.com/chemical/structure/%FILE/file?format=sdf&get3d=false",
       "smiles3d",
@@ -460,7 +460,7 @@ public final class JC {
     if (tmpDate != null) {
       tmpDate = tmpDate.substring(7, 23);
       // NOTE : date is updated in the properties by SVN, and is in the format
-      // "$Date: 2024-05-02 13:36:04 -0500 (Thu, 02 May 2024) $"
+      // "$Date: 2024-10-08 18:58:53 -0500 (Tue, 08 Oct 2024) $"
       //  0         1         2
       //  012345678901234567890123456789
     }
@@ -543,6 +543,7 @@ public final class JC {
   public static final int SG_IS_ASSIGN = 2;
   public static final int SG_FROM_SCRATCH = 4;
   public static final int SG_CHECK_SUPERCELL = 8;
+  public static final int SG_CALC_ONLY = 16;
 
   public final static String LOAD_ATOM_DATA_TYPES = ";xyz;vxyz;vibration;temperature;occupancy;partialcharge;";
 
@@ -961,16 +962,19 @@ public final class JC {
   public static final String MODELKIT_ELEMENT_KEY_ID = THIS_MODEL_ONLY
       + "elkey_";
 
+  public static final String MODELKIT_SET_LABEL_KEY = "setlabelkey";
   public static final String MODELKIT_SET_ELEMENT_KEY = "setelementkey";
-  public static final String MODELKIT_ELEMENT_KEY = "elementkey";
   public static final String MODELKIT_KEY = "key";
+  public static final String MODELKIT_MODEL_KEY = "key_";
+  public static final String MODELKIT_ELEMENT_KEY = "elementkey";
+  public static final String MODELKIT_LABEL_KEY = "labelkey";
   public static final String MODELKIT_NEW_MODEL_ATOM_KEYS = "newmodelatomkeys";
   public static final String MODELKIT_FRAME_RESIZED = "frameresized";
   public static final String MODELKIT_UDPATE_KEY_STATE = "updatekeysfromstate";
   public static final String MODELKIT_UPDATE_MODEL_KEYS = "updatemodelkeys";
   public static final String MODELKIT_UPDATE_ATOM_KEYS = "updateatomkeys";
-  public static final String MODELKIT_ASSIGN_BOND = "assignBond";
-  public static final String MODELKIT_ROTATE_BOND_ATOM_INDEX = "rotateBond";
+  public static final String MODELKIT_ASSIGN_BOND = "assignbond";
+  public static final String MODELKIT_ROTATE_BOND_ATOM_INDEX = "rotatebond";
   public static final String MODELKIT_BRANCH_ATOM_PICKED = "branchatomclicked";
   public static final String MODELKIT_BRANCH_ATOM_DRAGGED = "branchatomdragged";
 
@@ -1334,6 +1338,8 @@ public final class JC {
   public final static int ECHO_XY = 3;
   public final static int ECHO_XYZ = 4;
 
+  public final static String scaleName = "%SCALE";
+
   private final static String[] echoNames = { "top", "bottom", "middle", "xy",
       "xyz" };
 
@@ -1592,7 +1598,14 @@ public final class JC {
   public final static float FLOAT_MIN_SAFE = 2E-45f;
   // Float.MIN_VALUE (1.45E-45) is not reliable with JavaScript because of the float/double difference there
 
+  // these literals are used various places. Track them down with their INFO_ name.
+  
+  public static final String INFO_HM = "HermannMauguinSymbol";
+  public static final String INFO_HALL = "HallSymbol";
+  public static final String INFO_ITA = "ita";
+
   public static final String INFO_SPACE_GROUP = "spaceGroup";
+  public static final String INFO_SPACE_GROUP_F2C_TITLE = "f2cTitle";
   public static final String INFO_SPACE_GROUP_ASSIGNED = "spaceGroupAssigned";
   public static final String INFO_SPACE_GROUP_INFO = "spaceGroupInfo";
   public static final String INFO_SPACE_GROUP_INDEX = "spaceGroupIndex";
@@ -1602,11 +1615,22 @@ public final class JC {
   public static final String INFO_UNIT_CELL_PARAMS = "unitCellParams";
   public static final String INFO_UNIT_CELL_OFFSET = "unitCellOffset";
   public static final String INFO_UNIT_CELL_CONVENTIONAL = "unitcell_conventional";
-  /**
-   * used to set atom symmetry 555 556 etc.
+  public static final String INFO_SYMMETRY_OPERATIONS = "symmetryOperations";
+  public static final String INFO_SYMOPS_TEMP = "symOpsTemp";
+  
+  public static final String PROP_DELETE_MODEL_ATOMS = "deleteModelAtoms";
+  public static final String PROP_ATOMS_DELETED = "atomsDeleted";
+  public static final String PROP_ATOMS_MOVED = "atomsMoved";
+  public static final String PROP_ATOMS_LABELED = "atomslabeled";
+  
+  public static final String INFO_TRAJECTORY_STEPS = "trajectorySteps";
+  public static final String INFO_VIBRATION_STEPS = "vibrationSteps";
+
+  /** 
+   * used to set atom symmetry 555 556 etc. 
    */
   public static final String INFO_UNIT_CELL_RANGE = "ML_unitCellRange";
-  //  public static final String INFO_UNIT_CELL_TRANSLATIONS = "unitCellTranslations";
+//  public static final String INFO_UNIT_CELL_TRANSLATIONS = "unitCellTranslations";
   public static final String INFO_UNIT_CELLS = "unitCells";
   public static final String INFO_UNIT_CELL = "unitcell";
 
@@ -1624,10 +1648,6 @@ public final class JC {
         || key.startsWith("lattice") || key.startsWith("intlTable"));
   }
 
-  public static final String PROP_DELETE_MODEL_ATOMS = "deleteModelAtoms";
-  public static final String PROP_ATOMS_DELETED = "atomsDeleted";
-  public static final String PROP_ATOMS_MOVED = "atomsMoved";
-
   public static String getMenuScript(String type) {
     if (type == "openPDB") {
       return "var x__id__ = _modelTitle; if (x__id__.length != 4) { x__id__ = '1crn'};x__id__ = prompt('"
