@@ -290,17 +290,40 @@ abstract class OutputManager {
         v.removeItemAt(0);
         v.removeItemAt(0); // also "_IMAGE_"
         byte[] bytes = (byte[]) v.removeItemAt(0);
-        if (Rdr.isPngZipB(bytes)) {
-          params.put("pngImgData", bytes);
-        } else {
-          getImagePixels(vwr.fm.getImage(bytes, null, true), params);
-        }
         OC oz = getOutputChannel(null, null);
         errRet[0] = writeZipFile(oz, v, "OK JMOL", null);
+        params.put("pngAppData", oz.toByteArray());
         params.put("type", "PNGJ");
         type = "Png";
         params.put("pngAppPrefix", "Jmol Type");
-        params.put("pngAppData", oz.toByteArray());
+        if (Rdr.isPngZipB(bytes)) {
+          params.put("pngImgData", bytes);
+        } else {
+          Object image = vwr.fm.getImage(bytes, null, true);
+          Runnable r = new Runnable() {
+
+            @Override
+            public void run() {
+              try {
+                getImagePixels(image, params);
+              } catch (Exception e) {
+                e.printStackTrace();
+              }
+              finishImage(errRet, "Png", out, null, params);
+              out.closeChannel();
+            }
+          };
+          // difference here with SwingJS -- uses asyncronous Runnable
+          // since bytes will not be ready yet in JavaScript
+          // TODO: implement that here as well?
+          if (false && Viewer.isJS) {
+              errRet[0] = "async";
+              new Thread(r).start();
+              return true;
+            }
+            r.run();
+            return errRet[0] == null;
+          }
       } else if (v.size() == 1) {
         byte[] b = (byte[]) v.removeItemAt(0);
         out.write(b, 0, b.length);
@@ -310,11 +333,17 @@ abstract class OutputManager {
         return true;
       }
     }
+    finishImage(errRet, type, out, objImage, params);
+    return errRet[0] == null;
+  }
+
+  void finishImage(String[] errRet, String type, OC out,
+                           Object objImage, Map<String, Object> params) {
     GenericImageEncoder ie = (GenericImageEncoder) Interface
         .getInterface("javajs.img." + type + "Encoder", vwr, "file");
     if (ie == null) {
       errRet[0] = "Image encoder type " + type + " not available";
-      return false;
+      return;
     }
     boolean doClose = true;
     try {
@@ -333,10 +362,9 @@ abstract class OutputManager {
       if (doClose)
         out.closeChannel();
     }
-    return (errRet[0] == null);
   }
-
-  private void getImagePixels(Object objImage, Map<String, Object> params)
+  
+  void getImagePixels(Object objImage, Map<String, Object> params)
       throws Exception {
     int w = objImage == null ? -1
         : AU.isAI(objImage) ? ((Integer) params.get("width")).intValue()
