@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2023-11-13 16:26:50 -0600 (Mon, 13 Nov 2023) $
- * $Revision: 22583 $
+ * $Date: 2024-08-15 08:50:13 -0500 (Thu, 15 Aug 2024) $
+ * $Revision: 22630 $
  *
  * Copyright (C) 2003-2005  The Jmol Development Team
  *
@@ -1379,6 +1379,8 @@ public class PropertyManager implements JmolPropertyManager {
     BS bsBonds = new BS();
     for (int i = 0; i < bondCount; i++) {
       Bond bond = bonds[i];
+      if (bond == null)
+        continue;
       if (bsAtoms.get(bond.atom1.i) && bsAtoms.get(bond.atom2.i)
           && bond.isCovalent())
         bsBonds.set(i);
@@ -1600,6 +1602,8 @@ public class PropertyManager implements JmolPropertyManager {
       bs1 = ((BS[]) bsOrArray)[0];
       BS bs2 = ((BS[]) bsOrArray)[1];
       for (int i = 0; i < bondCount; i++) {
+        if (bonds[i] == null)
+          continue;
         int ia = bonds[i].atom1.i;
         int ib = bonds[i].atom2.i;
         if (bs1.get(ia) && bs2.get(ib) || bs2.get(ia) && bs1.get(ib))
@@ -1608,12 +1612,17 @@ public class PropertyManager implements JmolPropertyManager {
     } else if (bsOrArray instanceof BondSet) {
       bs1 = (BS) bsOrArray;
       for (int i = bs1.nextSetBit(0); i >= 0 && i < bondCount; i = bs1
-          .nextSetBit(i + 1))
+          .nextSetBit(i + 1)) {
+        if (bonds[i] == null)
+          continue;
         v.addLast(getBondInfo(i, ptTemp));
+      }
     } else if (bsOrArray instanceof BS) {
       bs1 = (BS) bsOrArray;
       int thisAtom = (bs1.cardinality() == 1 ? bs1.nextSetBit(0) : -1);
       for (int i = 0; i < bondCount; i++) {
+        if (bonds[i] == null)
+          continue;
         if (thisAtom >= 0 ? (bonds[i].atom1.i == thisAtom || bonds[i].atom2.i == thisAtom)
             : bs1.get(bonds[i].atom1.i) && bs1.get(bonds[i].atom2.i))
           v.addLast(getBondInfo(i, ptTemp));
@@ -1621,7 +1630,7 @@ public class PropertyManager implements JmolPropertyManager {
     }
     return v;
   }
-
+  
   private Map<String, Object> getBondInfo(int i, P3 ptTemp) {
     Bond bond = vwr.ms.bo[i];
     Atom atom1 = bond.atom1;
@@ -1879,7 +1888,6 @@ public class PropertyManager implements JmolPropertyManager {
    *****************************/
 
   @Override
-  @SuppressWarnings("static-access")
   public String getPdbData(int modelIndex, String type, BS bsSelected,
                            Object[] parameters, OC out, boolean addStructure) {
     if (vwr.ms.isJmolDataFrameForModel(modelIndex))
