@@ -309,8 +309,8 @@ public class StateCreator extends JmolStateCreator {
 
       sb.setLength(0);
 
-      for (int i = 0; i < ms.bondCount; i++)
-        if (!models[bonds[i].atom1.mi].isModelKit)
+      for (int i = 0; i < ms.bondCount; i++) {
+        if (bonds[i] != null && !models[bonds[i].atom1.mi].isModelKit) {
           if (bonds[i].isHydrogen() || (bonds[i].order & Edge.BOND_NEW) != 0) {
             Bond bond = bonds[i];
             int index = bond.atom1.i;
@@ -318,11 +318,13 @@ public class StateCreator extends JmolStateCreator {
               index = -1 - index;
             sb.appendI(index).appendC('\t').appendI(bond.atom2.i).appendC('\t')
                 .appendI(bond.order & Edge.BOND_RENDER_MASK).appendC('\t')
-                .appendF(bond.mad / 1000f).appendC('\t')
-                .appendF(bond.getEnergy()).appendC('\t')
+                .appendD(bond.mad / 1000d).appendC('\t')
+                .appendD(bond.getEnergy()).appendC('\t')
                 .append(Edge.getBondOrderNameFromOrder(bond.order))
                 .append(";\n");
           }
+        }
+      }
       if (sb.length() > 0)
         commands.append("data \"connect_atoms\"\n").appendSB(sb)
             .append("end \"connect_atoms\";\n");
@@ -334,7 +336,7 @@ public class StateCreator extends JmolStateCreator {
     if (ms.haveHiddenBonds) {
       BondSet bs = new BondSet();
       for (int i = ms.bondCount; --i >= 0;)
-        if (bonds[i].mad != 0
+        if (bonds[i] != null && bonds[i].mad != 0
             && (bonds[i].shapeVisibilityFlags & Bond.myVisibilityFlag) == 0)
           bs.set(i);
       if (bs.isEmpty())
@@ -400,6 +402,9 @@ public class StateCreator extends JmolStateCreator {
           + ";\n");
       //      if (vwr.getBoolean(T.modelkitmode))
       //      commands.append("  set modelKitMode true;\n");
+      if (vwr.is2D()) {
+        commands.append("  set mode2d TRUE;\n");
+      }
     }
     if (sfunc != null)
       commands.append("\n}\n\n");
@@ -1054,6 +1059,7 @@ public class StateCreator extends JmolStateCreator {
   private Map<String, BS> temp = new Hashtable<String, BS>();
   private Map<String, BS> temp2 = new Hashtable<String, BS>();
   private Map<String, BS> temp3 = new Hashtable<String, BS>();
+  private Map<String, BS> temp4 = new Hashtable<String, BS>();
 
   private void getShapeStatePriv(SB commands, boolean isAll, int iShape) {
     Shape[] shapes = vwr.shm.shapes;
@@ -1085,7 +1091,6 @@ public class StateCreator extends JmolStateCreator {
     boolean reportAll = shape.reportAll;
     clearTemp();
     ModelSet modelSet = vwr.ms;
-    boolean haveTainted = false;
     Bond[] bonds = modelSet.bo;
     int bondCount = modelSet.bondCount;
     short r;
@@ -1094,7 +1099,8 @@ public class StateCreator extends JmolStateCreator {
       int i0 = (reportAll ? bondCount - 1 : shape.bsSizeSet.nextSetBit(0));
       for (int i = i0; i >= 0; i = (reportAll ? i - 1 : shape.bsSizeSet
           .nextSetBit(i + 1)))
-        BSUtil.setMapBitSet(temp, i, i, "wireframe "
+        if (bonds[i] != null)
+          BSUtil.setMapBitSet(temp, i, i, "wireframe "
             + ((r = bonds[i].mad) == 1 ? "on" : "" + PT.escF(r / 2000f)));
     }
     if (reportAll || bsOrderSet != null) {
@@ -1102,7 +1108,7 @@ public class StateCreator extends JmolStateCreator {
       for (int i = i0; i >= 0; i = (reportAll ? i - 1 : bsOrderSet
           .nextSetBit(i + 1))) {
         Bond bond = bonds[i];
-        if (reportAll || (bond.order & Edge.BOND_NEW) == 0)
+        if (bond != null && (reportAll || (bond.order & Edge.BOND_NEW) == 0))
           BSUtil.setMapBitSet(temp, i, i, "bondOrder "
               + Edge.getBondOrderNameFromOrder(bond.order));
       }
@@ -1110,6 +1116,8 @@ public class StateCreator extends JmolStateCreator {
     if (shape.bsColixSet != null)
       for (int i = shape.bsColixSet.nextSetBit(0); i >= 0; i = shape.bsColixSet
           .nextSetBit(i + 1)) {
+        if (bonds[i] == null)
+          continue;
         short colix = bonds[i].colix;
         if ((colix & C.OPAQUE_MASK) == C.USE_PALETTE)
           BSUtil.setMapBitSet(temp, i, i, Shape.getColorCommand("bonds",
@@ -1119,8 +1127,8 @@ public class StateCreator extends JmolStateCreator {
               colix, shape.translucentAllowed));
       }
 
-    String s = getCommands(temp, null, "select BONDS") + "\n"
-        + (haveTainted ? getCommands(temp2, null, "select BONDS") + "\n" : "");
+    // /*16.2*/ prevents earlier bond issue fix
+    String s = getCommands(temp, null, "select /*16.2*/ BONDS") + "\n";
     clearTemp();
     return s;
   }
@@ -1214,8 +1222,12 @@ public class StateCreator extends JmolStateCreator {
       if (!l.isActive || l.bsSizeSet == null)
         return "";
       clearTemp();
+      BS bs = vwr.getAllAtoms();
+      boolean isNeg = false; // protect script from failing in old versions of Jmol
       for (int i = l.bsSizeSet.nextSetBit(0); i >= 0; i = l.bsSizeSet
           .nextSetBit(i + 1)) {
+        if (!bs.get(i))
+          continue;
         Text t = l.getLabel(i);
         String cmd = "label ";
         if (t == null) {
@@ -1261,12 +1273,23 @@ public class StateCreator extends JmolStateCreator {
 
         if (l.mads != null && l.mads[i] < 0)
           BSUtil.setMapBitSet(temp2, i, i, "set toggleLabel");
-        if (l.bsFontSet != null && l.bsFontSet.get(i))
-          BSUtil.setMapBitSet(temp2, i, i,
-              Shape.getFontCommand("label", Font.getFont3D(l.fids[i])));
+        if (l.bsFontSet != null && l.bsFontSet.get(i)) {
+          Font f = Font.getFont3D(l.fids[i]);
+          if (f.fontSizeAngstroms > 0)
+            isNeg = true;
+          BSUtil.setMapBitSet(temp4, i, i,
+              Shape.getFontCommand("label", f));
+        }
+      }
+      String sf = getCommands(null, temp4, "select");
+      if (isNeg) {
+        // protect from older versions without neg font size
+          sf = "  try{\n" + sf + "  }catch{}\n";
       }
       s = getCommands(temp, temp2, "select")
+        + sf
           + getCommands(null, temp3, "select");
+      temp4.clear();
       temp3.clear();
       clearTemp();
       break;
@@ -1355,7 +1378,7 @@ public class StateCreator extends JmolStateCreator {
   }
 
   private boolean getEchoState(SB sb, Text t) {
-    // ECHO "%SCALE" uses unformatted text
+    // ECHO JC.scaleName uses unformatted text
     boolean isScale = (t != null && t.barPixels > 0);
     String text = (t == null ? null : isScale ? t.textUnformatted : t.getStateText()); 
     if (text == null || !t.isEcho || t.target.equals("error"))
@@ -1366,7 +1389,7 @@ public class StateCreator extends JmolStateCreator {
     boolean isImage = (t.image != null);
     //    if (isDefine) {
     String strOff = null;
-    String echoCmd = "set echo ID " + PT.esc(t.target);
+    String echoCmd = "set echo ID " + PT.esc(isScale ? JC.scaleName : t.target);
     switch (t.valign) {
     case JC.ECHO_XY:
       if (t.movableXPercent == Integer.MAX_VALUE
