@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2024-04-28 11:34:10 -0500 (Sun, 28 Apr 2024) $
- * $Revision: 22620 $
+ * $Date: 2024-09-03 12:14:46 -0500 (Tue, 03 Sep 2024) $
+ * $Revision: 22631 $
  *
  * Copyright (C) 2003-2005  The Jmol Development Team
  *
@@ -312,7 +312,6 @@ public class StatusManager {
    * @param isEnabled
    * @param callback
    * @param o         the arguments to pass
-   * @param doWait TODO
    * @param doWait    generally TRUE, but FALSE for AnimFrameCallback, as otherwise delays are messed up.
    */
   private void fireJmolScriptCallback(boolean isEnabled, CBK callback,
@@ -903,9 +902,13 @@ public class StatusManager {
       audios.put(id, (JmolAudioPlayer) htParams.get("audioPlayer"));
   }
 
-  private void stopAudio(String id) {
+  public void stopAudio(String id) {
     if (audios == null)
       return;
+    if (id == null) {
+      closeAllAudio();
+      return;
+    }
     JmolAudioPlayer player = audios.get(id);
     if (player != null)
       player.action("kill");    
@@ -929,14 +932,11 @@ public class StatusManager {
           if (audios == null || audios.isEmpty())
             return;
           if (action.equals("close")) {
-            for (String key : audios.keySet()) {
-              JmolAudioPlayer player = audios.remove(key);
-              player.action("close");
-            }
+            closeAllAudio();
           }
           return;
         }
-        JmolAudioPlayer player = audios.get(id);
+        JmolAudioPlayer player = (audios == null ? null : audios.get(id));
         if (player != null) {
           player.action(action);
           return;
@@ -953,6 +953,14 @@ public class StatusManager {
     }
   }
 
+  public void closeAllAudio() {
+    for (String key : audios.keySet()) {
+      System.out.println("AUDIO " + key);
+      audios.get(key).action("close");
+    }
+    audios.clear();
+  }
+
   /**
    * called from JmolAudio
    * 
@@ -963,13 +971,14 @@ public class StatusManager {
     String script = (String) htParams.get(status);
     if (script != null)
       vwr.script(script);
-    if (status == "ended")
-      registerAudio((String) htParams.get("id"), null);
+    // only autoclose if there was no initial action
     String sJmol = getJmolScriptCallback(CBK.AUDIO);
     boolean isEnabled = notifyEnabled(CBK.AUDIO);
     if (isEnabled || sJmol != null)
       fireJmolScriptCallback(isEnabled, CBK.AUDIO,
           new Object[] { sJmol, htParams, status }, true);
+    if (status == "ended" && htParams.get("autoclose") != Boolean.FALSE)
+      registerAudio((String) htParams.get("id"), null);
   }
   
   
