@@ -260,10 +260,12 @@ public class TransformManager {
     unTransformPoint(pt2, pt2);
     vwr.setInMotion(false);
     rotateAboutPointsInternal(null, pt2, pt1, 10 * speed, Float.NaN, false,
-        true, null, true, null, null, null, null, false);
+        true, null, true, null, null, null, null, false, null);
   }
 
   protected void rotateXYBy(float degX, float degY, BS bsAtoms) {
+	    if (vwr.is2D())
+	        return;
     // from mouse action
     rotate3DBall(degX, degY, bsAtoms);
   }
@@ -364,7 +366,7 @@ public class TransformManager {
       isSpinInternal = false;
       isSpinFixed = true;
       isSpinSelected = (bsAtoms != null);
-      setSpin(eval, true, endDegrees, null, null, bsAtoms, false);
+      setSpin(eval, true, endDegrees, null, null, bsAtoms, false, null, -1);
       // fixed spin -- we will wait
       return (endDegrees != Float.MAX_VALUE);
     }
@@ -402,6 +404,8 @@ public class TransformManager {
    * @param finalPoints
    * @param dihedralList
    * @param m4 
+   * @param useModelKit 
+   * @param centerAndPoints TODO
    * @return true if synchronous so that JavaScript can restart properly
    */
   boolean rotateAboutPointsInternal(JmolScriptEvaluator eval, T3 point1,
@@ -409,7 +413,8 @@ public class TransformManager {
                                     float endDegrees, boolean isClockwise,
                                     boolean isSpin, BS bsAtoms,
                                     boolean isGesture, V3 translation,
-                                    Lst<P3> finalPoints, float[] dihedralList, M4 m4, boolean useModelKit) {
+                                    Lst<P3> finalPoints, float[] dihedralList, 
+                                    M4 m4, boolean useModelKit, P3[][] centerAndPoints) {
 
     // *THE* Viewer INTERNAL frame rotation entry point
 
@@ -418,7 +423,7 @@ public class TransformManager {
     setNavOn(false);
 
     if (dihedralList == null
-        && (translation == null || translation.length() < 0.001)
+            && centerAndPoints == null && (translation == null || translation.length() < 0.001f)
         && (isSpin ? Float.isNaN(degreesPerSecond) || degreesPerSecond == 0
             : endDegrees == 0))
       return false;
@@ -433,6 +438,7 @@ public class TransformManager {
       internalTranslation = (translation == null ? null : V3.newV(translation));
     }
     boolean isSelected = (bsAtoms != null);
+    int nFrames = -1;
     if (isSpin) {
       // we need to adjust the degreesPerSecond to match a multiple of the frame rate
       if (dihedralList == null) {
@@ -441,7 +447,7 @@ public class TransformManager {
         if (Float.isNaN(endDegrees)) {
           rotationRate = degreesPerSecond;
         } else {
-          int nFrames = (int) (Math.abs(endDegrees)
+          nFrames = (int) (Math.abs(endDegrees)
               / Math.abs(degreesPerSecond) * spinFps + 0.5);
           rotationRate = degreesPerSecond = endDegrees / nFrames * spinFps;
           if (translation != null)
@@ -456,7 +462,7 @@ public class TransformManager {
         endDegrees = degreesPerSecond;
       }
       setSpin(eval, true, endDegrees, finalPoints, dihedralList, bsAtoms,
-          isGesture);
+          isGesture, centerAndPoints, centerAndPoints == null ? -1 : nFrames);
       return !Float.isNaN(endDegrees);
     }
     float radians = (float) (endDegrees * JC.radiansPerDegree);
@@ -2092,16 +2098,16 @@ public class TransformManager {
   private boolean spinIsGesture;
 
   public void setSpinOn() {
-    setSpin(null, true, Float.MAX_VALUE, null, null, null, false);
+    setSpin(null, true, Float.MAX_VALUE, null, null, null, false, null, -1);
   }
 
   public void setSpinOff() {
-    setSpin(null, false, Float.MAX_VALUE, null, null, null, false);
+    setSpin(null, false, Float.MAX_VALUE, null, null, null, false, null, -1);
   }
 
   private void setSpin(JmolScriptEvaluator eval, boolean spinOn,
                        float endDegrees, Lst<P3> endPositions,
-                       float[] dihedralList, BS bsAtoms, boolean isGesture) {
+                       float[] dihedralList, BS bsAtoms, boolean isGesture, P3[][] centerAndPoints, int nFrames) {
     if (navOn && spinOn)
       setNavOn(false);
     if (this.spinOn == spinOn)
@@ -2114,7 +2120,9 @@ public class TransformManager {
             "tm");
         spinThread.setManager(this, vwr,
             new Object[] { Float.valueOf(endDegrees), endPositions,
-                dihedralList, bsAtoms, isGesture ? Boolean.TRUE : null });
+                dihedralList, bsAtoms, 
+                isGesture ? Boolean.TRUE : null, 
+                		centerAndPoints, Integer.valueOf(nFrames) });
         spinIsGesture = isGesture;
         if ((Float.isNaN(endDegrees) || endDegrees == Float.MAX_VALUE || !vwr.g.waitForMoveTo)) {
           spinThread.start();
@@ -2134,7 +2142,7 @@ public class TransformManager {
       return;
     boolean wasOn = this.navOn;
     if (navOn && spinOn)
-      setSpin(null, false, 0, null, null, null, false);
+      setSpin(null, false, 0, null, null, null, false, null, -1);
     this.navOn = navOn;
     vwr.g.setB("_navigating", navOn);
     if (!navOn)
