@@ -837,7 +837,8 @@ public class NMR_JmolPanel extends JmolPanel {
 
     @Override
     public void actionPerformed(ActionEvent e) {
-      atomSetChooser.setVisible(true);
+      if (atomSetChooser != null) 
+        atomSetChooser.setVisible(true);
     }
   }
 
@@ -1089,29 +1090,19 @@ public class NMR_JmolPanel extends JmolPanel {
         // this one is totally not helpful. Why doesn't MESSAGE fire this??
         break;
       case APPLETREADY:
-        break;
       case ATOMMOVED:
-        break;
       case AUDIO:
-        break;
       case CLICK:
-        break;
       case DRAGDROP:
-        break;
       case ECHO:
-        break;
       case ERROR:
-        break;
       case EVAL:
-        break;
       case HOVER:
-        break;
       case IMAGE:
-        break;
       case MINIMIZATION:
-        break;
       case RESIZE:
-        break;
+      case SELECT:
+    	  break;
       case SCRIPT:
         // looking for the script started, which has the script as data[2]
         // We make sure the script we send is a separate script that is just
