@@ -577,7 +577,7 @@ public class StatusListener implements JmolStatusListener, JmolSyncInterface, JS
   @Override
   public void syncScript(String script) {
     // called from JSpecView to send "Select: <Peaks...." script
-    jmolPanel.syncScript(script);    
+    vwr.syncScript(script, "~", 0);
   }
 
   
