@@ -523,6 +523,8 @@ public class AppConsole extends JmolConsole
         undoPointer++;
     } catch (Error e) {
       dontsave = true;
+    } catch (Exception e) {
+      Logger.error("AppConsole unoo/redo save was interrupted");
     }
     if (dontsave || Logger.checkTimer("(console", false) > 2000) {
       vwr.setBooleanProperty("undoAuto", false);
@@ -838,6 +840,9 @@ public class AppConsole extends JmolConsole
       int kid = ke.getID();
       if (kid == KeyEvent.KEY_PRESSED) {
         switch (kcode) {
+        case KeyEvent.VK_ENTER:
+          hBar.setValue(0);
+          break;
         case KeyEvent.VK_C:
           if (ke.isControlDown() && ke.isAltDown()) {
             ke.consume();
